""" Cisco_IOS_XR_ipv4_ospf_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-ospf package configuration.

This module contains definitions
for the following management objects\:
  ospf\: OSPF configuration data

This YANG module augments the
  Cisco\-IOS\-XR\-snmp\-agent\-cfg
module with configuration data.

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BfdEnableMode(Enum):
    """
    BfdEnableMode

    Bfd enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Default BFD behavior

    .. data:: strict = 2

    	Strict Mode - Hold down adj until BFD sesion up

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    strict = Enum.YLeaf(2, "strict")


class Nsr(Enum):
    """
    Nsr

    Nsr

    .. data:: true = 1

    	Enable non-stop routing

    .. data:: false = 2

    	Disable non-stop routing

    """

    true = Enum.YLeaf(1, "true")

    false = Enum.YLeaf(2, "false")


class OspfAddressFamily(Enum):
    """
    OspfAddressFamily

    Ospf address family

    .. data:: ipv4 = 1

    	IPv4

    """

    ipv4 = Enum.YLeaf(1, "ipv4")


class OspfAuthentication(Enum):
    """
    OspfAuthentication

    Ospf authentication

    .. data:: none = 0

    	No Authentication

    .. data:: plain = 1

    	Plain Text Authentication

    .. data:: md5 = 2

    	MD5 Message Digest

    """

    none = Enum.YLeaf(0, "none")

    plain = Enum.YLeaf(1, "plain")

    md5 = Enum.YLeaf(2, "md5")


class OspfCiscoNsf(Enum):
    """
    OspfCiscoNsf

    Ospf cisco nsf

    .. data:: always = 1

    	Do not require all neighbors to run NSF

    .. data:: require_nsf_neighbors = 2

    	Require all neighbors to run NSF

    """

    always = Enum.YLeaf(1, "always")

    require_nsf_neighbors = Enum.YLeaf(2, "require-nsf-neighbors")


class OspfDistListProtocol(Enum):
    """
    OspfDistListProtocol

    Ospf dist list protocol

    .. data:: all = 0

    	Default

    .. data:: connected = 1

    	Connected Routes

    .. data:: static = 3

    	Static Routes

    .. data:: bgp = 4

    	BGP

    .. data:: ospf = 7

    	OSPF

    .. data:: dagr = 9

    	DAGR

    """

    all = Enum.YLeaf(0, "all")

    connected = Enum.YLeaf(1, "connected")

    static = Enum.YLeaf(3, "static")

    bgp = Enum.YLeaf(4, "bgp")

    ospf = Enum.YLeaf(7, "ospf")

    dagr = Enum.YLeaf(9, "dagr")


class OspfDomainId(Enum):
    """
    OspfDomainId

    Ospf domain id

    .. data:: type0005 = 5

    	Type 0x0005

    .. data:: type0105 = 261

    	Type 0x0105

    .. data:: type0205 = 517

    	Type 0x0205

    .. data:: type8005 = 32773

    	Type 0x8005

    """

    type0005 = Enum.YLeaf(5, "type0005")

    type0105 = Enum.YLeaf(261, "type0105")

    type0205 = Enum.YLeaf(517, "type0205")

    type8005 = Enum.YLeaf(32773, "type8005")


class OspfEigrpRoute(Enum):
    """
    OspfEigrpRoute

    Ospf eigrp route

    .. data:: internal = 0

    	EIGRP Internal Type

    .. data:: external = 1

    	EIGRP External Type

    """

    internal = Enum.YLeaf(0, "internal")

    external = Enum.YLeaf(1, "external")


class OspfFastReroute(Enum):
    """
    OspfFastReroute

    Ospf fast reroute

    .. data:: none = 0

    	None

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class OspfFastReroutePriority(Enum):
    """
    OspfFastReroutePriority

    Ospf fast reroute priority

    .. data:: critical = 0

    	Critical

    .. data:: high = 2

    	High

    .. data:: medium = 4

    	Medium

    .. data:: low = 6

    	low

    """

    critical = Enum.YLeaf(0, "critical")

    high = Enum.YLeaf(2, "high")

    medium = Enum.YLeaf(4, "medium")

    low = Enum.YLeaf(6, "low")


class OspfFastRerouteTiebreakers(Enum):
    """
    OspfFastRerouteTiebreakers

    Ospf fast reroute tiebreakers

    .. data:: downstream = 0

    	Downstream

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: lowest_metric = 2

    	Lowest metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondar path

    .. data:: srlg_disjoint = 6

    	SRLG

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    lowest_metric = Enum.YLeaf(2, "lowest-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")


class OspfFastRerouteTiebreakersIntf(Enum):
    """
    OspfFastRerouteTiebreakersIntf

    Ospf fast reroute tiebreakers intf

    .. data:: downstream = 0

    	Downstream

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: lowest_metric = 2

    	Lowest metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondar path

    .. data:: srlg_disjoint = 6

    	SRLG

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    lowest_metric = Enum.YLeaf(2, "lowest-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")


class OspfFrrRlfaTunnel(Enum):
    """
    OspfFrrRlfaTunnel

    Ospf frr rlfa tunnel

    .. data:: none = 0

    	Disabled

    .. data:: mpls_ldp = 1

    	MPLS LDP

    """

    none = Enum.YLeaf(0, "none")

    mpls_ldp = Enum.YLeaf(1, "mpls-ldp")


class OspfIetfNsf(Enum):
    """
    OspfIetfNsf

    Ospf ietf nsf

    .. data:: all = 3

    	Use IETF NSF in planned and unplanned cases

    """

    all = Enum.YLeaf(3, "all")


class OspfIetfNsfSupport(Enum):
    """
    OspfIetfNsfSupport

    Ospf ietf nsf support

    .. data:: never = 0

    	Do not perform IETF NSF helper role

    """

    never = Enum.YLeaf(0, "never")


class OspfKeychainAuth(Enum):
    """
    OspfKeychainAuth

    Ospf keychain auth

    .. data:: none = 0

    	No Keychain Authentication

    .. data:: keychain = 3

    	Keychain Authentication

    """

    none = Enum.YLeaf(0, "none")

    keychain = Enum.YLeaf(3, "keychain")


class OspfLinkStateMetric(Enum):
    """
    OspfLinkStateMetric

    Ospf link state metric

    .. data:: type1 = 1

    	Type 1 External

    .. data:: type2 = 2

    	Type 2 External

    """

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")


class OspfLogAdj(Enum):
    """
    OspfLogAdj

    Ospf log adj

    .. data:: brief = 0

    	Limited output

    .. data:: detail = 1

    	Verbose output

    .. data:: suppress = 2

    	No output

    """

    brief = Enum.YLeaf(0, "brief")

    detail = Enum.YLeaf(1, "detail")

    suppress = Enum.YLeaf(2, "suppress")


class OspfNetwork(Enum):
    """
    OspfNetwork

    Ospf network

    .. data:: broadcast = 1

    	Broadcast

    .. data:: non_broadcast = 2

    	NonBroadcast

    .. data:: point_to_point = 3

    	Point to Point

    .. data:: point_to_multipoint = 4

    	Point to Multipoint

    .. data:: non_broadcast_point_to_multipoint = 5

    	NonBroadcast Point to Multipoint

    """

    broadcast = Enum.YLeaf(1, "broadcast")

    non_broadcast = Enum.YLeaf(2, "non-broadcast")

    point_to_point = Enum.YLeaf(3, "point-to-point")

    point_to_multipoint = Enum.YLeaf(4, "point-to-multipoint")

    non_broadcast_point_to_multipoint = Enum.YLeaf(5, "non-broadcast-point-to-multipoint")


class OspfProcFastReroute(Enum):
    """
    OspfProcFastReroute

    Ospf proc fast reroute

    .. data:: none = 0

    	None

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class OspfProcFrrRlfaTunnel(Enum):
    """
    OspfProcFrrRlfaTunnel

    Ospf proc frr rlfa tunnel

    .. data:: none = 0

    	Disabled

    .. data:: mpls_ldp = 1

    	MPLS LDP

    """

    none = Enum.YLeaf(0, "none")

    mpls_ldp = Enum.YLeaf(1, "mpls-ldp")


class OspfRedistLsa(Enum):
    """
    OspfRedistLsa

    Ospf redist lsa

    .. data:: summary = 3

    	Type 3 (summary) LSA

    .. data:: external = 5

    	Type 5 (external) LSA

    """

    summary = Enum.YLeaf(3, "summary")

    external = Enum.YLeaf(5, "external")


class OspfRedistProtocol(Enum):
    """
    OspfRedistProtocol

    Ospf redist protocol

    .. data:: all = 0

    	Default

    .. data:: connected = 1

    	Connected Routes

    .. data:: static = 3

    	Static Routes

    .. data:: bgp = 4

    	BGP

    .. data:: rip = 5

    	RIP

    .. data:: isis = 6

    	ISIS

    .. data:: ospf = 7

    	OSPF

    .. data:: eigrp = 8

    	EIGRP

    .. data:: dagr = 9

    	DAGR

    .. data:: subscriber = 10

    	Subscriber Routes

    .. data:: application = 11

    	Application Routes

    .. data:: mobile = 12

    	Mobile Routes

    """

    all = Enum.YLeaf(0, "all")

    connected = Enum.YLeaf(1, "connected")

    static = Enum.YLeaf(3, "static")

    bgp = Enum.YLeaf(4, "bgp")

    rip = Enum.YLeaf(5, "rip")

    isis = Enum.YLeaf(6, "isis")

    ospf = Enum.YLeaf(7, "ospf")

    eigrp = Enum.YLeaf(8, "eigrp")

    dagr = Enum.YLeaf(9, "dagr")

    subscriber = Enum.YLeaf(10, "subscriber")

    application = Enum.YLeaf(11, "application")

    mobile = Enum.YLeaf(12, "mobile")


class OspfRouteLevel(Enum):
    """
    OspfRouteLevel

    Ospf route level

    .. data:: type1 = 1

    	Type 1 only

    .. data:: type2 = 2

    	Type 2 only

    .. data:: type1_and2 = 3

    	Both Type 1 and Type 2

    """

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")

    type1_and2 = Enum.YLeaf(3, "type1-and2")


class OspfSegmentRouting(Enum):
    """
    OspfSegmentRouting

    Ospf segment routing

    .. data:: disable = 0

    	Disable

    .. data:: mpls = 1

    	Mpls

    """

    disable = Enum.YLeaf(0, "disable")

    mpls = Enum.YLeaf(1, "mpls")


class OspfSegmentRoutingForwarding(Enum):
    """
    OspfSegmentRoutingForwarding

    Ospf segment routing forwarding

    .. data:: disable = 0

    	Disable

    .. data:: mpls = 1

    	Mpls

    """

    disable = Enum.YLeaf(0, "disable")

    mpls = Enum.YLeaf(1, "mpls")


class OspfShutdown(Enum):
    """
    OspfShutdown

    Ospf shutdown

    .. data:: full = 1

    	Full graceful shutdown

    .. data:: hostmode = 2

    	Enter host only mode

    .. data:: onreload = 3

    	Full graceful shutdown post reload

    """

    full = Enum.YLeaf(1, "full")

    hostmode = Enum.YLeaf(2, "hostmode")

    onreload = Enum.YLeaf(3, "onreload")


class OspfSid(Enum):
    """
    OspfSid

    Ospf sid

    .. data:: index = 0

    	Index

    .. data:: absolute = 1

    	Absolute

    """

    index = Enum.YLeaf(0, "index")

    absolute = Enum.YLeaf(1, "absolute")


class OspfSubAddressFamily(Enum):
    """
    OspfSubAddressFamily

    Ospf sub address family

    .. data:: unicast = 1

    	Unicast

    """

    unicast = Enum.YLeaf(1, "unicast")


class OspfUloopAvoidance(Enum):
    """
    OspfUloopAvoidance

    Ospf uloop avoidance

    .. data:: protected = 1

    	Protected prefixes only

    .. data:: all = 2

    	All prefixes

    .. data:: segment_routing = 3

    	Microloop avoidance using Segment Routing

    """

    protected = Enum.YLeaf(1, "protected")

    all = Enum.YLeaf(2, "all")

    segment_routing = Enum.YLeaf(3, "segment-routing")



class Ospf(Entity):
    """
    OSPF configuration data
    
    .. attribute:: global_
    
    	OSPF global configuration data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Global_>`
    
    .. attribute:: processes
    
    	Process related configuration
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes>`
    
    

    """

    _prefix = 'ipv4-ospf-cfg'
    _revision = '2017-01-02'

    def __init__(self):
        super(Ospf, self).__init__()
        self._top_entity = None

        self.yang_name = "ospf"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-ospf-cfg"

        self.global_ = Ospf.Global_()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._children_yang_names.add("global")

        self.processes = Ospf.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._children_yang_names.add("processes")


    class Processes(Entity):
        """
        Process related configuration
        
        .. attribute:: process
        
        	Configuration for a particular OSPF process and associated default VRF
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process>`
        
        

        """

        _prefix = 'ipv4-ospf-cfg'
        _revision = '2017-01-02'

        def __init__(self):
            super(Ospf.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospf"

            self.process = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ospf.Processes, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ospf.Processes, self).__setattr__(name, value)


        class Process(Entity):
            """
            Configuration for a particular OSPF process and
            associated default VRF
            
            .. attribute:: process_name  <key>
            
            	Name for this OSPF process
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: default_vrf
            
            	Default VRF related configuration
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf>`
            
            .. attribute:: distribute
            
            	Enable distribution of link\-state database services
            	**type**\:   :py:class:`Distribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Distribute>`
            
            	**presence node**\: True
            
            .. attribute:: graceful_shutdown_timers
            
            	Adjust routing timers
            	**type**\:   :py:class:`GracefulShutdownTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.GracefulShutdownTimers>`
            
            .. attribute:: nsr
            
            	Enable non\-stop routing
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Nsr>`
            
            	**default value**\: true
            
            .. attribute:: protocol_shutdown
            
            	Type of protocol shutdown
            	**type**\:   :py:class:`OspfShutdown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfShutdown>`
            
            .. attribute:: running
            
            	Enable routing on an IP network
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: snmp
            
            	OSPF SNMP configuration
            	**type**\:   :py:class:`Snmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Snmp>`
            
            .. attribute:: start
            
            	Start OSPF configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: vrfs
            
            	VRF related configuration
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv4-ospf-cfg'
            _revision = '2017-01-02'

            def __init__(self):
                super(Ospf.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"

                self.process_name = YLeaf(YType.str, "process-name")

                self.nsr = YLeaf(YType.enumeration, "nsr")

                self.protocol_shutdown = YLeaf(YType.enumeration, "protocol-shutdown")

                self.running = YLeaf(YType.empty, "running")

                self.start = YLeaf(YType.empty, "start")

                self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.distribute = None
                self._children_name_map["distribute"] = "distribute"
                self._children_yang_names.add("distribute")

                self.graceful_shutdown_timers = Ospf.Processes.Process.GracefulShutdownTimers()
                self.graceful_shutdown_timers.parent = self
                self._children_name_map["graceful_shutdown_timers"] = "graceful-shutdown-timers"
                self._children_yang_names.add("graceful-shutdown-timers")

                self.snmp = Ospf.Processes.Process.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "snmp"
                self._children_yang_names.add("snmp")

                self.vrfs = Ospf.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("process_name",
                                "nsr",
                                "protocol_shutdown",
                                "running",
                                "start") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Ospf.Processes.Process, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Ospf.Processes.Process, self).__setattr__(name, value)


            class Snmp(Entity):
                """
                OSPF SNMP configuration
                
                .. attribute:: trap_rate_limit
                
                	Per OSPF process SNMP trap rate\-limit
                	**type**\:   :py:class:`TrapRateLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Snmp.TrapRateLimit>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "process"

                    self.trap_rate_limit = None
                    self._children_name_map["trap_rate_limit"] = "trap-rate-limit"
                    self._children_yang_names.add("trap-rate-limit")


                class TrapRateLimit(Entity):
                    """
                    Per OSPF process SNMP trap rate\-limit
                    
                    .. attribute:: max_window_traps
                    
                    	Max number of traps to send in window time
                    	**type**\:  int
                    
                    	**range:** 0..300
                    
                    	**mandatory**\: True
                    
                    .. attribute:: window_size
                    
                    	Trap rate limit sliding window size
                    	**type**\:  int
                    
                    	**range:** 2..60
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.Snmp.TrapRateLimit, self).__init__()

                        self.yang_name = "trap-rate-limit"
                        self.yang_parent_name = "snmp"
                        self.is_presence_container = True

                        self.max_window_traps = YLeaf(YType.uint32, "max-window-traps")

                        self.window_size = YLeaf(YType.uint32, "window-size")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("max_window_traps",
                                        "window_size") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.Snmp.TrapRateLimit, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.Snmp.TrapRateLimit, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.max_window_traps.is_set or
                            self.window_size.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.max_window_traps.yfilter != YFilter.not_set or
                            self.window_size.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "trap-rate-limit" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.max_window_traps.is_set or self.max_window_traps.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_window_traps.get_name_leafdata())
                        if (self.window_size.is_set or self.window_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.window_size.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "max-window-traps" or name == "window-size"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "max-window-traps"):
                            self.max_window_traps = value
                            self.max_window_traps.value_namespace = name_space
                            self.max_window_traps.value_namespace_prefix = name_space_prefix
                        if(value_path == "window-size"):
                            self.window_size = value
                            self.window_size.value_namespace = name_space
                            self.window_size.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.trap_rate_limit is not None)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.trap_rate_limit is not None and self.trap_rate_limit.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "snmp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "trap-rate-limit"):
                        if (self.trap_rate_limit is None):
                            self.trap_rate_limit = Ospf.Processes.Process.Snmp.TrapRateLimit()
                            self.trap_rate_limit.parent = self
                            self._children_name_map["trap_rate_limit"] = "trap-rate-limit"
                        return self.trap_rate_limit

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "trap-rate-limit"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Distribute(Entity):
                """
                Enable distribution of link\-state database
                services
                
                .. attribute:: instance_id
                
                	Instance ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: throttle
                
                	Seconds
                	**type**\:  int
                
                	**range:** 1..3600
                
                	**units**\: second
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.Distribute, self).__init__()

                    self.yang_name = "distribute"
                    self.yang_parent_name = "process"
                    self.is_presence_container = True

                    self.instance_id = YLeaf(YType.uint32, "instance-id")

                    self.throttle = YLeaf(YType.uint32, "throttle")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("instance_id",
                                    "throttle") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ospf.Processes.Process.Distribute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ospf.Processes.Process.Distribute, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.instance_id.is_set or
                        self.throttle.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.instance_id.yfilter != YFilter.not_set or
                        self.throttle.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "distribute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.instance_id.get_name_leafdata())
                    if (self.throttle.is_set or self.throttle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.throttle.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "instance-id" or name == "throttle"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "instance-id"):
                        self.instance_id = value
                        self.instance_id.value_namespace = name_space
                        self.instance_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "throttle"):
                        self.throttle = value
                        self.throttle.value_namespace = name_space
                        self.throttle.value_namespace_prefix = name_space_prefix


            class Vrfs(Entity):
                """
                VRF related configuration
                
                .. attribute:: vrf
                
                	Configuration for a particular OSPF vrf
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"

                    self.vrf = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ospf.Processes.Process.Vrfs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ospf.Processes.Process.Vrfs, self).__setattr__(name, value)


                class Vrf(Entity):
                    """
                    Configuration for a particular OSPF vrf
                    
                    .. attribute:: vrf_name  <key>
                    
                    	Name for this vrf
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: adjacency_changes
                    
                    	Log changes in adjacency state
                    	**type**\:   :py:class:`OspfLogAdj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLogAdj>`
                    
                    .. attribute:: adjacency_stagger
                    
                    	Staggering OSPF adjacency bring up
                    	**type**\:   :py:class:`AdjacencyStagger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger>`
                    
                    .. attribute:: af
                    
                    	OSPF address family
                    	**type**\:   :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Af>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: area_addresses
                    
                    	Area configuration
                    	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses>`
                    
                    .. attribute:: auto_cost
                    
                    	Controls automatic cost based on bandwidth
                    	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AutoCost>`
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation>`
                    
                    .. attribute:: default_metric
                    
                    	Set default metric of redistributed routes
                    	**type**\:  int
                    
                    	**range:** 1..16777214
                    
                    	**default value**\: 1
                    
                    .. attribute:: disable_dn_bit_check
                    
                    	Disable DN bit check
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance configuration
                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance>`
                    
                    .. attribute:: domain_id
                    
                    	OSPF Domain ID
                    	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId>`
                    
                    .. attribute:: domain_tag
                    
                    	32 bit Domain tag value
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute instance scoped parameters
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute>`
                    
                    .. attribute:: ignore_mospf
                    
                    	Ignore MOSPF (Type 6) LSAs
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_lsa
                    
                    	Set max\-lsa configuration
                    	**type**\:   :py:class:`MaxLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxLsa>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: max_metric
                    
                    	Set maximum metric configuration
                    	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric>`
                    
                    .. attribute:: maximum_interfaces
                    
                    	Max number of interfaces allowed to be configured
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    	**default value**\: 1024
                    
                    .. attribute:: maximum_paths
                    
                    	Forward packets over multiple paths (number of paths)
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    .. attribute:: maximum_redistribute_prefix
                    
                    	Maximum number of prefixes redistributed into OSPF
                    	**type**\:   :py:class:`MaximumRedistributePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix>`
                    
                    .. attribute:: microloop
                    
                    	Microloop configuration
                    	**type**\:   :py:class:`Microloop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Microloop>`
                    
                    .. attribute:: no_opaque
                    
                    	Disable opaque LSAs
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nsf
                    
                    	Non Stop Forwarding configuration
                    	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Nsf>`
                    
                    .. attribute:: outgoing_route_updates
                    
                    	Filter outgoing routing updates
                    	**type**\:   :py:class:`OutgoingRouteUpdates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates>`
                    
                    .. attribute:: process_scope
                    
                    	Process scope configuration
                    	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope>`
                    
                    .. attribute:: queue
                    
                    	Adjust OSPF input queue sizes and processing quantums
                    	**type**\:   :py:class:`Queue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Queue>`
                    
                    .. attribute:: redistribution
                    
                    	Redistribute configurations
                    	**type**\:   :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution>`
                    
                    .. attribute:: router_id
                    
                    	Router ID for this OSPF process. Enter an IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: snmp_context
                    
                    	OSPF SNMP context configuration
                    	**type**\:  str
                    
                    .. attribute:: snmp_trap_enabled
                    
                    	Enable/disable OSPF SNMP trap
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: spf_prefix_priority
                    
                    	Configure a route\-policy for prioritizing RIB route install
                    	**type**\:  str
                    
                    .. attribute:: summary_prefixes
                    
                    	Configure IP prefix summary
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: timers
                    
                    	Adjust routing timers
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers>`
                    
                    .. attribute:: type7
                    
                    	Prefer type7 externals over type5
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ucmp
                    
                    	Unequal Cost Multi\-ptah configuration
                    	**type**\:   :py:class:`Ucmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp>`
                    
                    .. attribute:: vrf_lite
                    
                    	VRF lite capability
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf_start
                    
                    	Start OSPF VRF configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.adjacency_changes = YLeaf(YType.enumeration, "adjacency-changes")

                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                        self.disable_dn_bit_check = YLeaf(YType.empty, "disable-dn-bit-check")

                        self.domain_tag = YLeaf(YType.uint32, "domain-tag")

                        self.ignore_mospf = YLeaf(YType.empty, "ignore-mospf")

                        self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                        self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                        self.no_opaque = YLeaf(YType.empty, "no-opaque")

                        self.router_id = YLeaf(YType.str, "router-id")

                        self.snmp_context = YLeaf(YType.str, "snmp-context")

                        self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                        self.spf_prefix_priority = YLeaf(YType.str, "spf-prefix-priority")

                        self.type7 = YLeaf(YType.empty, "type7")

                        self.vrf_lite = YLeaf(YType.empty, "vrf-lite")

                        self.vrf_start = YLeaf(YType.empty, "vrf-start")

                        self.adjacency_stagger = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger()
                        self.adjacency_stagger.parent = self
                        self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                        self._children_yang_names.add("adjacency-stagger")

                        self.af = None
                        self._children_name_map["af"] = "af"
                        self._children_yang_names.add("af")

                        self.area_addresses = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses()
                        self.area_addresses.parent = self
                        self._children_name_map["area_addresses"] = "area-addresses"
                        self._children_yang_names.add("area-addresses")

                        self.auto_cost = Ospf.Processes.Process.Vrfs.Vrf.AutoCost()
                        self.auto_cost.parent = self
                        self._children_name_map["auto_cost"] = "auto-cost"
                        self._children_yang_names.add("auto-cost")

                        self.default_information = Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._children_yang_names.add("default-information")

                        self.distance = Ospf.Processes.Process.Vrfs.Vrf.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"
                        self._children_yang_names.add("distance")

                        self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId()
                        self.domain_id.parent = self
                        self._children_name_map["domain_id"] = "domain-id"
                        self._children_yang_names.add("domain-id")

                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.max_lsa = None
                        self._children_name_map["max_lsa"] = "max-lsa"
                        self._children_yang_names.add("max-lsa")

                        self.max_metric = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric()
                        self.max_metric.parent = self
                        self._children_name_map["max_metric"] = "max-metric"
                        self._children_yang_names.add("max-metric")

                        self.maximum_redistribute_prefix = Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix()
                        self.maximum_redistribute_prefix.parent = self
                        self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                        self._children_yang_names.add("maximum-redistribute-prefix")

                        self.microloop = Ospf.Processes.Process.Vrfs.Vrf.Microloop()
                        self.microloop.parent = self
                        self._children_name_map["microloop"] = "microloop"
                        self._children_yang_names.add("microloop")

                        self.nsf = Ospf.Processes.Process.Vrfs.Vrf.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                        self._children_yang_names.add("nsf")

                        self.outgoing_route_updates = Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates()
                        self.outgoing_route_updates.parent = self
                        self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                        self._children_yang_names.add("outgoing-route-updates")

                        self.process_scope = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope()
                        self.process_scope.parent = self
                        self._children_name_map["process_scope"] = "process-scope"
                        self._children_yang_names.add("process-scope")

                        self.queue = Ospf.Processes.Process.Vrfs.Vrf.Queue()
                        self.queue.parent = self
                        self._children_name_map["queue"] = "queue"
                        self._children_yang_names.add("queue")

                        self.redistribution = Ospf.Processes.Process.Vrfs.Vrf.Redistribution()
                        self.redistribution.parent = self
                        self._children_name_map["redistribution"] = "redistribution"
                        self._children_yang_names.add("redistribution")

                        self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        self._children_yang_names.add("summary-prefixes")

                        self.timers = Ospf.Processes.Process.Vrfs.Vrf.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")

                        self.ucmp = Ospf.Processes.Process.Vrfs.Vrf.Ucmp()
                        self.ucmp.parent = self
                        self._children_name_map["ucmp"] = "ucmp"
                        self._children_yang_names.add("ucmp")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("vrf_name",
                                        "adjacency_changes",
                                        "default_metric",
                                        "disable_dn_bit_check",
                                        "domain_tag",
                                        "ignore_mospf",
                                        "maximum_interfaces",
                                        "maximum_paths",
                                        "no_opaque",
                                        "router_id",
                                        "snmp_context",
                                        "snmp_trap_enabled",
                                        "spf_prefix_priority",
                                        "type7",
                                        "vrf_lite",
                                        "vrf_start") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.Vrfs.Vrf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.Vrfs.Vrf, self).__setattr__(name, value)


                    class DomainId(Entity):
                        """
                        OSPF Domain ID
                        
                        .. attribute:: primary_domain_id
                        
                        	OSPF Primary domain ID
                        	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId>`
                        
                        .. attribute:: secondary_domain_ids
                        
                        	Secondary domain ID Table
                        	**type**\:   :py:class:`SecondaryDomainIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.DomainId, self).__init__()

                            self.yang_name = "domain-id"
                            self.yang_parent_name = "vrf"

                            self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId()
                            self.primary_domain_id.parent = self
                            self._children_name_map["primary_domain_id"] = "primary-domain-id"
                            self._children_yang_names.add("primary-domain-id")

                            self.secondary_domain_ids = Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds()
                            self.secondary_domain_ids.parent = self
                            self._children_name_map["secondary_domain_ids"] = "secondary-domain-ids"
                            self._children_yang_names.add("secondary-domain-ids")


                        class PrimaryDomainId(Entity):
                            """
                            OSPF Primary domain ID
                            
                            .. attribute:: domain_id_name
                            
                            	Primary domain ID value
                            	**type**\:  str
                            
                            .. attribute:: domain_id_type
                            
                            	Primary domain ID type
                            	**type**\:   :py:class:`OspfDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId, self).__init__()

                                self.yang_name = "primary-domain-id"
                                self.yang_parent_name = "domain-id"

                                self.domain_id_name = YLeaf(YType.str, "domain-id-name")

                                self.domain_id_type = YLeaf(YType.enumeration, "domain-id-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("domain_id_name",
                                                "domain_id_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.domain_id_name.is_set or
                                    self.domain_id_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.domain_id_name.yfilter != YFilter.not_set or
                                    self.domain_id_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "primary-domain-id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.domain_id_name.is_set or self.domain_id_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.domain_id_name.get_name_leafdata())
                                if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.domain_id_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "domain-id-name" or name == "domain-id-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "domain-id-name"):
                                    self.domain_id_name = value
                                    self.domain_id_name.value_namespace = name_space
                                    self.domain_id_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "domain-id-type"):
                                    self.domain_id_type = value
                                    self.domain_id_type.value_namespace = name_space
                                    self.domain_id_type.value_namespace_prefix = name_space_prefix


                        class SecondaryDomainIds(Entity):
                            """
                            Secondary domain ID Table
                            
                            .. attribute:: secondary_domain_id
                            
                            	OSPF Secondary domain ID
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds, self).__init__()

                                self.yang_name = "secondary-domain-ids"
                                self.yang_parent_name = "domain-id"

                                self.secondary_domain_id = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds, self).__setattr__(name, value)


                            class SecondaryDomainId(Entity):
                                """
                                OSPF Secondary domain ID
                                
                                .. attribute:: domain_id_type  <key>
                                
                                	Secondary domain ID type
                                	**type**\:   :py:class:`OspfDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDomainId>`
                                
                                .. attribute:: domain_id_name  <key>
                                
                                	Secondary domain ID value
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "secondary-domain-ids"

                                    self.domain_id_type = YLeaf(YType.enumeration, "domain-id-type")

                                    self.domain_id_name = YLeaf(YType.str, "domain-id-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("domain_id_type",
                                                    "domain_id_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.domain_id_type.is_set or
                                        self.domain_id_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.domain_id_type.yfilter != YFilter.not_set or
                                        self.domain_id_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "secondary-domain-id" + "[domain-id-type='" + self.domain_id_type.get() + "']" + "[domain-id-name='" + self.domain_id_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.domain_id_type.is_set or self.domain_id_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_type.get_name_leafdata())
                                    if (self.domain_id_name.is_set or self.domain_id_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.domain_id_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "domain-id-type" or name == "domain-id-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "domain-id-type"):
                                        self.domain_id_type = value
                                        self.domain_id_type.value_namespace = name_space
                                        self.domain_id_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "domain-id-name"):
                                        self.domain_id_name = value
                                        self.domain_id_name.value_namespace = name_space
                                        self.domain_id_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.secondary_domain_id:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.secondary_domain_id:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "secondary-domain-ids" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "secondary-domain-id"):
                                    for c in self.secondary_domain_id:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.secondary_domain_id.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "secondary-domain-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.primary_domain_id is not None and self.primary_domain_id.has_data()) or
                                (self.secondary_domain_ids is not None and self.secondary_domain_ids.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.primary_domain_id is not None and self.primary_domain_id.has_operation()) or
                                (self.secondary_domain_ids is not None and self.secondary_domain_ids.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "domain-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "primary-domain-id"):
                                if (self.primary_domain_id is None):
                                    self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                return self.primary_domain_id

                            if (child_yang_name == "secondary-domain-ids"):
                                if (self.secondary_domain_ids is None):
                                    self.secondary_domain_ids = Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds()
                                    self.secondary_domain_ids.parent = self
                                    self._children_name_map["secondary_domain_ids"] = "secondary-domain-ids"
                                return self.secondary_domain_ids

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "primary-domain-id" or name == "secondary-domain-ids"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Microloop(Entity):
                        """
                        Microloop configuration
                        
                        .. attribute:: avoidance
                        
                        	Microloop avoidance configuration
                        	**type**\:   :py:class:`Avoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Microloop, self).__init__()

                            self.yang_name = "microloop"
                            self.yang_parent_name = "vrf"

                            self.avoidance = Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance()
                            self.avoidance.parent = self
                            self._children_name_map["avoidance"] = "avoidance"
                            self._children_yang_names.add("avoidance")


                        class Avoidance(Entity):
                            """
                            Microloop avoidance configuration
                            
                            .. attribute:: enable
                            
                            	MicroLoop avoidance feature enable configuration
                            	**type**\:   :py:class:`OspfUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfUloopAvoidance>`
                            
                            	**default value**\: all
                            
                            .. attribute:: rib_update_delay
                            
                            	Delay to introduce between SPF and RIB update in msecs
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 5000
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance, self).__init__()

                                self.yang_name = "avoidance"
                                self.yang_parent_name = "microloop"

                                self.enable = YLeaf(YType.enumeration, "enable")

                                self.rib_update_delay = YLeaf(YType.uint32, "rib-update-delay")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("enable",
                                                "rib_update_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.enable.is_set or
                                    self.rib_update_delay.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set or
                                    self.rib_update_delay.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "avoidance" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                if (self.rib_update_delay.is_set or self.rib_update_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rib_update_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "enable" or name == "rib-update-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix
                                if(value_path == "rib-update-delay"):
                                    self.rib_update_delay = value
                                    self.rib_update_delay.value_namespace = name_space
                                    self.rib_update_delay.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.avoidance is not None and self.avoidance.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.avoidance is not None and self.avoidance.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "microloop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "avoidance"):
                                if (self.avoidance is None):
                                    self.avoidance = Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance()
                                    self.avoidance.parent = self
                                    self._children_name_map["avoidance"] = "avoidance"
                                return self.avoidance

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "avoidance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class MaximumRedistributePrefix(Entity):
                        """
                        Maximum number of prefixes redistributed into
                        OSPF
                        
                        .. attribute:: number_of_prefixes
                        
                        	Maximum number of prefixes redistributed
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: threshold
                        
                        	Threshold value (%) at which to generate a warning msg
                        	**type**\:  int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give warning messsage when limit is exceeded
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix, self).__init__()

                            self.yang_name = "maximum-redistribute-prefix"
                            self.yang_parent_name = "vrf"

                            self.number_of_prefixes = YLeaf(YType.uint32, "number-of-prefixes")

                            self.threshold = YLeaf(YType.uint32, "threshold")

                            self.warning_only = YLeaf(YType.boolean, "warning-only")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("number_of_prefixes",
                                            "threshold",
                                            "warning_only") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.number_of_prefixes.is_set or
                                self.threshold.is_set or
                                self.warning_only.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.number_of_prefixes.yfilter != YFilter.not_set or
                                self.threshold.yfilter != YFilter.not_set or
                                self.warning_only.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "maximum-redistribute-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.number_of_prefixes.is_set or self.number_of_prefixes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.number_of_prefixes.get_name_leafdata())
                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.threshold.get_name_leafdata())
                            if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.warning_only.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "number-of-prefixes" or name == "threshold" or name == "warning-only"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "number-of-prefixes"):
                                self.number_of_prefixes = value
                                self.number_of_prefixes.value_namespace = name_space
                                self.number_of_prefixes.value_namespace_prefix = name_space_prefix
                            if(value_path == "threshold"):
                                self.threshold = value
                                self.threshold.value_namespace = name_space
                                self.threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "warning-only"):
                                self.warning_only = value
                                self.warning_only.value_namespace = name_space
                                self.warning_only.value_namespace_prefix = name_space_prefix


                    class DefaultInformation(Entity):
                        """
                        Control distribution of default information
                        
                        .. attribute:: always_advertise
                        
                        	Always advertise default route
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: metric
                        
                        	OSPF metric
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 1
                        
                        .. attribute:: metric_type
                        
                        	OSPF External metric type
                        	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                        
                        	**default value**\: type2
                        
                        .. attribute:: route_policy_name
                        
                        	Routing policy name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "vrf"

                            self.always_advertise = YLeaf(YType.boolean, "always-advertise")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("always_advertise",
                                            "metric",
                                            "metric_type",
                                            "route_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.always_advertise.is_set or
                                self.metric.is_set or
                                self.metric_type.is_set or
                                self.route_policy_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.always_advertise.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.metric_type.yfilter != YFilter.not_set or
                                self.route_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-information" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.always_advertise.is_set or self.always_advertise.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.always_advertise.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric_type.get_name_leafdata())
                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "always-advertise" or name == "metric" or name == "metric-type" or name == "route-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "always-advertise"):
                                self.always_advertise = value
                                self.always_advertise.value_namespace = name_space
                                self.always_advertise.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric-type"):
                                self.metric_type = value
                                self.metric_type.value_namespace = name_space
                                self.metric_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-name"):
                                self.route_policy_name = value
                                self.route_policy_name.value_namespace = name_space
                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                    class Af(Entity):
                        """
                        OSPF address family
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`OspfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAddressFamily>`
                        
                        	**mandatory**\: True
                        
                        .. attribute:: saf_name
                        
                        	Sub\-Address family
                        	**type**\:   :py:class:`OspfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSubAddressFamily>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "vrf"
                            self.is_presence_container = True

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "saf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Af, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Af, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.saf_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "af" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "saf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix


                    class Queue(Entity):
                        """
                        Adjust OSPF input queue sizes and processing
                        quantums
                        
                        .. attribute:: dispatch_incoming
                        
                        	Maximum number of continuous incoming packet\-related events processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 300
                        
                        .. attribute:: dispatch_rate_limited
                        
                        	Maximum number of continuous rate\-limited LSAs processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: dispatch_rate_limited_flush
                        
                        	Maximum number of continuous rate\-limited LSAs processed for FLUSH
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: dispatch_spf_lsa_limit
                        
                        	Maximum number of continuous summary or external LSAs processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: limit_high
                        
                        	Hello events are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 9500
                        
                        .. attribute:: limit_low
                        
                        	DBDs/Updates are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 8000
                        
                        .. attribute:: limit_medium
                        
                        	LSA ACKs are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 9000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Queue, self).__init__()

                            self.yang_name = "queue"
                            self.yang_parent_name = "vrf"

                            self.dispatch_incoming = YLeaf(YType.uint32, "dispatch-incoming")

                            self.dispatch_rate_limited = YLeaf(YType.uint32, "dispatch-rate-limited")

                            self.dispatch_rate_limited_flush = YLeaf(YType.uint32, "dispatch-rate-limited-flush")

                            self.dispatch_spf_lsa_limit = YLeaf(YType.uint32, "dispatch-spf-lsa-limit")

                            self.limit_high = YLeaf(YType.uint32, "limit-high")

                            self.limit_low = YLeaf(YType.uint32, "limit-low")

                            self.limit_medium = YLeaf(YType.uint32, "limit-medium")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("dispatch_incoming",
                                            "dispatch_rate_limited",
                                            "dispatch_rate_limited_flush",
                                            "dispatch_spf_lsa_limit",
                                            "limit_high",
                                            "limit_low",
                                            "limit_medium") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Queue, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Queue, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.dispatch_incoming.is_set or
                                self.dispatch_rate_limited.is_set or
                                self.dispatch_rate_limited_flush.is_set or
                                self.dispatch_spf_lsa_limit.is_set or
                                self.limit_high.is_set or
                                self.limit_low.is_set or
                                self.limit_medium.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.dispatch_incoming.yfilter != YFilter.not_set or
                                self.dispatch_rate_limited.yfilter != YFilter.not_set or
                                self.dispatch_rate_limited_flush.yfilter != YFilter.not_set or
                                self.dispatch_spf_lsa_limit.yfilter != YFilter.not_set or
                                self.limit_high.yfilter != YFilter.not_set or
                                self.limit_low.yfilter != YFilter.not_set or
                                self.limit_medium.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "queue" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.dispatch_incoming.is_set or self.dispatch_incoming.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dispatch_incoming.get_name_leafdata())
                            if (self.dispatch_rate_limited.is_set or self.dispatch_rate_limited.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dispatch_rate_limited.get_name_leafdata())
                            if (self.dispatch_rate_limited_flush.is_set or self.dispatch_rate_limited_flush.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dispatch_rate_limited_flush.get_name_leafdata())
                            if (self.dispatch_spf_lsa_limit.is_set or self.dispatch_spf_lsa_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dispatch_spf_lsa_limit.get_name_leafdata())
                            if (self.limit_high.is_set or self.limit_high.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_high.get_name_leafdata())
                            if (self.limit_low.is_set or self.limit_low.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_low.get_name_leafdata())
                            if (self.limit_medium.is_set or self.limit_medium.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.limit_medium.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "dispatch-incoming" or name == "dispatch-rate-limited" or name == "dispatch-rate-limited-flush" or name == "dispatch-spf-lsa-limit" or name == "limit-high" or name == "limit-low" or name == "limit-medium"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "dispatch-incoming"):
                                self.dispatch_incoming = value
                                self.dispatch_incoming.value_namespace = name_space
                                self.dispatch_incoming.value_namespace_prefix = name_space_prefix
                            if(value_path == "dispatch-rate-limited"):
                                self.dispatch_rate_limited = value
                                self.dispatch_rate_limited.value_namespace = name_space
                                self.dispatch_rate_limited.value_namespace_prefix = name_space_prefix
                            if(value_path == "dispatch-rate-limited-flush"):
                                self.dispatch_rate_limited_flush = value
                                self.dispatch_rate_limited_flush.value_namespace = name_space
                                self.dispatch_rate_limited_flush.value_namespace_prefix = name_space_prefix
                            if(value_path == "dispatch-spf-lsa-limit"):
                                self.dispatch_spf_lsa_limit = value
                                self.dispatch_spf_lsa_limit.value_namespace = name_space
                                self.dispatch_spf_lsa_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-high"):
                                self.limit_high = value
                                self.limit_high.value_namespace = name_space
                                self.limit_high.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-low"):
                                self.limit_low = value
                                self.limit_low.value_namespace = name_space
                                self.limit_low.value_namespace_prefix = name_space_prefix
                            if(value_path == "limit-medium"):
                                self.limit_medium = value
                                self.limit_medium.value_namespace = name_space
                                self.limit_medium.value_namespace_prefix = name_space_prefix


                    class MaxMetric(Entity):
                        """
                        Set maximum metric configuration
                        
                        .. attribute:: max_metric_always
                        
                        	Set maximum metric always configuration
                        	**type**\:   :py:class:`MaxMetricAlways <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways>`
                        
                        .. attribute:: max_metric_no_abr_off
                        
                        	Block ABR\-disable mode entry while in max\-metric mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_metric_on_proc_migration
                        
                        	Set maximum metric on\-proc\-migration configuration
                        	**type**\:   :py:class:`MaxMetricOnProcMigration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration>`
                        
                        .. attribute:: max_metric_on_proc_restart
                        
                        	Set maximum metric on\-proc\-restart configuration
                        	**type**\:   :py:class:`MaxMetricOnProcRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart>`
                        
                        .. attribute:: max_metric_on_startup
                        
                        	Set maximum metric on\-startup configuration
                        	**type**\:   :py:class:`MaxMetricOnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup>`
                        
                        .. attribute:: max_metric_on_switchover
                        
                        	Set maximum metric on\-switchover configuration
                        	**type**\:   :py:class:`MaxMetricOnSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric, self).__init__()

                            self.yang_name = "max-metric"
                            self.yang_parent_name = "vrf"

                            self.max_metric_no_abr_off = YLeaf(YType.empty, "max-metric-no-abr-off")

                            self.max_metric_always = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways()
                            self.max_metric_always.parent = self
                            self._children_name_map["max_metric_always"] = "max-metric-always"
                            self._children_yang_names.add("max-metric-always")

                            self.max_metric_on_proc_migration = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration()
                            self.max_metric_on_proc_migration.parent = self
                            self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                            self._children_yang_names.add("max-metric-on-proc-migration")

                            self.max_metric_on_proc_restart = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart()
                            self.max_metric_on_proc_restart.parent = self
                            self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                            self._children_yang_names.add("max-metric-on-proc-restart")

                            self.max_metric_on_startup = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup()
                            self.max_metric_on_startup.parent = self
                            self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                            self._children_yang_names.add("max-metric-on-startup")

                            self.max_metric_on_switchover = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover()
                            self.max_metric_on_switchover.parent = self
                            self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                            self._children_yang_names.add("max-metric-on-switchover")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_metric_no_abr_off") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric, self).__setattr__(name, value)


                        class MaxMetricOnProcRestart(Entity):
                            """
                            Set maximum metric on\-proc\-restart
                            configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart, self).__init__()

                                self.yang_name = "max-metric-on-proc-restart"
                                self.yang_parent_name = "max-metric"

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_lsa",
                                                "external_lsa_maximum_metric",
                                                "include_stub",
                                                "startup_max",
                                                "summary_lsa",
                                                "summary_lsa_maximum_metric",
                                                "wait_for_bgp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_lsa.is_set or
                                    self.external_lsa_maximum_metric.is_set or
                                    self.include_stub.is_set or
                                    self.startup_max.is_set or
                                    self.summary_lsa.is_set or
                                    self.summary_lsa_maximum_metric.is_set or
                                    self.wait_for_bgp.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_lsa.yfilter != YFilter.not_set or
                                    self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.include_stub.yfilter != YFilter.not_set or
                                    self.startup_max.yfilter != YFilter.not_set or
                                    self.summary_lsa.yfilter != YFilter.not_set or
                                    self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.wait_for_bgp.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "max-metric-on-proc-restart" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa.get_name_leafdata())
                                if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                                if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.include_stub.get_name_leafdata())
                                if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.startup_max.get_name_leafdata())
                                if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                                if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                                if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-lsa"):
                                    self.external_lsa = value
                                    self.external_lsa.value_namespace = name_space
                                    self.external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-lsa-maximum-metric"):
                                    self.external_lsa_maximum_metric = value
                                    self.external_lsa_maximum_metric.value_namespace = name_space
                                    self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "include-stub"):
                                    self.include_stub = value
                                    self.include_stub.value_namespace = name_space
                                    self.include_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "startup-max"):
                                    self.startup_max = value
                                    self.startup_max.value_namespace = name_space
                                    self.startup_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa"):
                                    self.summary_lsa = value
                                    self.summary_lsa.value_namespace = name_space
                                    self.summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa-maximum-metric"):
                                    self.summary_lsa_maximum_metric = value
                                    self.summary_lsa_maximum_metric.value_namespace = name_space
                                    self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-for-bgp"):
                                    self.wait_for_bgp = value
                                    self.wait_for_bgp.value_namespace = name_space
                                    self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                        class MaxMetricOnStartup(Entity):
                            """
                            Set maximum metric on\-startup configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup, self).__init__()

                                self.yang_name = "max-metric-on-startup"
                                self.yang_parent_name = "max-metric"

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_lsa",
                                                "external_lsa_maximum_metric",
                                                "include_stub",
                                                "startup_max",
                                                "summary_lsa",
                                                "summary_lsa_maximum_metric",
                                                "wait_for_bgp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_lsa.is_set or
                                    self.external_lsa_maximum_metric.is_set or
                                    self.include_stub.is_set or
                                    self.startup_max.is_set or
                                    self.summary_lsa.is_set or
                                    self.summary_lsa_maximum_metric.is_set or
                                    self.wait_for_bgp.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_lsa.yfilter != YFilter.not_set or
                                    self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.include_stub.yfilter != YFilter.not_set or
                                    self.startup_max.yfilter != YFilter.not_set or
                                    self.summary_lsa.yfilter != YFilter.not_set or
                                    self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.wait_for_bgp.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "max-metric-on-startup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa.get_name_leafdata())
                                if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                                if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.include_stub.get_name_leafdata())
                                if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.startup_max.get_name_leafdata())
                                if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                                if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                                if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-lsa"):
                                    self.external_lsa = value
                                    self.external_lsa.value_namespace = name_space
                                    self.external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-lsa-maximum-metric"):
                                    self.external_lsa_maximum_metric = value
                                    self.external_lsa_maximum_metric.value_namespace = name_space
                                    self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "include-stub"):
                                    self.include_stub = value
                                    self.include_stub.value_namespace = name_space
                                    self.include_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "startup-max"):
                                    self.startup_max = value
                                    self.startup_max.value_namespace = name_space
                                    self.startup_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa"):
                                    self.summary_lsa = value
                                    self.summary_lsa.value_namespace = name_space
                                    self.summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa-maximum-metric"):
                                    self.summary_lsa_maximum_metric = value
                                    self.summary_lsa_maximum_metric.value_namespace = name_space
                                    self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-for-bgp"):
                                    self.wait_for_bgp = value
                                    self.wait_for_bgp.value_namespace = name_space
                                    self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                        class MaxMetricOnProcMigration(Entity):
                            """
                            Set maximum metric on\-proc\-migration
                            configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration, self).__init__()

                                self.yang_name = "max-metric-on-proc-migration"
                                self.yang_parent_name = "max-metric"

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_lsa",
                                                "external_lsa_maximum_metric",
                                                "include_stub",
                                                "startup_max",
                                                "summary_lsa",
                                                "summary_lsa_maximum_metric",
                                                "wait_for_bgp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_lsa.is_set or
                                    self.external_lsa_maximum_metric.is_set or
                                    self.include_stub.is_set or
                                    self.startup_max.is_set or
                                    self.summary_lsa.is_set or
                                    self.summary_lsa_maximum_metric.is_set or
                                    self.wait_for_bgp.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_lsa.yfilter != YFilter.not_set or
                                    self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.include_stub.yfilter != YFilter.not_set or
                                    self.startup_max.yfilter != YFilter.not_set or
                                    self.summary_lsa.yfilter != YFilter.not_set or
                                    self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.wait_for_bgp.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "max-metric-on-proc-migration" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa.get_name_leafdata())
                                if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                                if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.include_stub.get_name_leafdata())
                                if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.startup_max.get_name_leafdata())
                                if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                                if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                                if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-lsa"):
                                    self.external_lsa = value
                                    self.external_lsa.value_namespace = name_space
                                    self.external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-lsa-maximum-metric"):
                                    self.external_lsa_maximum_metric = value
                                    self.external_lsa_maximum_metric.value_namespace = name_space
                                    self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "include-stub"):
                                    self.include_stub = value
                                    self.include_stub.value_namespace = name_space
                                    self.include_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "startup-max"):
                                    self.startup_max = value
                                    self.startup_max.value_namespace = name_space
                                    self.startup_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa"):
                                    self.summary_lsa = value
                                    self.summary_lsa.value_namespace = name_space
                                    self.summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa-maximum-metric"):
                                    self.summary_lsa_maximum_metric = value
                                    self.summary_lsa_maximum_metric.value_namespace = name_space
                                    self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-for-bgp"):
                                    self.wait_for_bgp = value
                                    self.wait_for_bgp.value_namespace = name_space
                                    self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                        class MaxMetricAlways(Entity):
                            """
                            Set maximum metric always configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways, self).__init__()

                                self.yang_name = "max-metric-always"
                                self.yang_parent_name = "max-metric"

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_lsa",
                                                "external_lsa_maximum_metric",
                                                "include_stub",
                                                "summary_lsa",
                                                "summary_lsa_maximum_metric") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_lsa.is_set or
                                    self.external_lsa_maximum_metric.is_set or
                                    self.include_stub.is_set or
                                    self.summary_lsa.is_set or
                                    self.summary_lsa_maximum_metric.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_lsa.yfilter != YFilter.not_set or
                                    self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.include_stub.yfilter != YFilter.not_set or
                                    self.summary_lsa.yfilter != YFilter.not_set or
                                    self.summary_lsa_maximum_metric.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "max-metric-always" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa.get_name_leafdata())
                                if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                                if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.include_stub.get_name_leafdata())
                                if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                                if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "summary-lsa" or name == "summary-lsa-maximum-metric"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-lsa"):
                                    self.external_lsa = value
                                    self.external_lsa.value_namespace = name_space
                                    self.external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-lsa-maximum-metric"):
                                    self.external_lsa_maximum_metric = value
                                    self.external_lsa_maximum_metric.value_namespace = name_space
                                    self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "include-stub"):
                                    self.include_stub = value
                                    self.include_stub.value_namespace = name_space
                                    self.include_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa"):
                                    self.summary_lsa = value
                                    self.summary_lsa.value_namespace = name_space
                                    self.summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa-maximum-metric"):
                                    self.summary_lsa_maximum_metric = value
                                    self.summary_lsa_maximum_metric.value_namespace = name_space
                                    self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix


                        class MaxMetricOnSwitchover(Entity):
                            """
                            Set maximum metric on\-switchover configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover, self).__init__()

                                self.yang_name = "max-metric-on-switchover"
                                self.yang_parent_name = "max-metric"

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_lsa",
                                                "external_lsa_maximum_metric",
                                                "include_stub",
                                                "startup_max",
                                                "summary_lsa",
                                                "summary_lsa_maximum_metric",
                                                "wait_for_bgp") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_lsa.is_set or
                                    self.external_lsa_maximum_metric.is_set or
                                    self.include_stub.is_set or
                                    self.startup_max.is_set or
                                    self.summary_lsa.is_set or
                                    self.summary_lsa_maximum_metric.is_set or
                                    self.wait_for_bgp.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_lsa.yfilter != YFilter.not_set or
                                    self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.include_stub.yfilter != YFilter.not_set or
                                    self.startup_max.yfilter != YFilter.not_set or
                                    self.summary_lsa.yfilter != YFilter.not_set or
                                    self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                    self.wait_for_bgp.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "max-metric-on-switchover" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa.get_name_leafdata())
                                if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                                if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.include_stub.get_name_leafdata())
                                if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.startup_max.get_name_leafdata())
                                if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                                if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                                if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-lsa"):
                                    self.external_lsa = value
                                    self.external_lsa.value_namespace = name_space
                                    self.external_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-lsa-maximum-metric"):
                                    self.external_lsa_maximum_metric = value
                                    self.external_lsa_maximum_metric.value_namespace = name_space
                                    self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "include-stub"):
                                    self.include_stub = value
                                    self.include_stub.value_namespace = name_space
                                    self.include_stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "startup-max"):
                                    self.startup_max = value
                                    self.startup_max.value_namespace = name_space
                                    self.startup_max.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa"):
                                    self.summary_lsa = value
                                    self.summary_lsa.value_namespace = name_space
                                    self.summary_lsa.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-lsa-maximum-metric"):
                                    self.summary_lsa_maximum_metric = value
                                    self.summary_lsa_maximum_metric.value_namespace = name_space
                                    self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                                if(value_path == "wait-for-bgp"):
                                    self.wait_for_bgp = value
                                    self.wait_for_bgp.value_namespace = name_space
                                    self.wait_for_bgp.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.max_metric_no_abr_off.is_set or
                                (self.max_metric_always is not None and self.max_metric_always.has_data()) or
                                (self.max_metric_on_proc_migration is not None and self.max_metric_on_proc_migration.has_data()) or
                                (self.max_metric_on_proc_restart is not None and self.max_metric_on_proc_restart.has_data()) or
                                (self.max_metric_on_startup is not None and self.max_metric_on_startup.has_data()) or
                                (self.max_metric_on_switchover is not None and self.max_metric_on_switchover.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_metric_no_abr_off.yfilter != YFilter.not_set or
                                (self.max_metric_always is not None and self.max_metric_always.has_operation()) or
                                (self.max_metric_on_proc_migration is not None and self.max_metric_on_proc_migration.has_operation()) or
                                (self.max_metric_on_proc_restart is not None and self.max_metric_on_proc_restart.has_operation()) or
                                (self.max_metric_on_startup is not None and self.max_metric_on_startup.has_operation()) or
                                (self.max_metric_on_switchover is not None and self.max_metric_on_switchover.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_metric_no_abr_off.is_set or self.max_metric_no_abr_off.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_metric_no_abr_off.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "max-metric-always"):
                                if (self.max_metric_always is None):
                                    self.max_metric_always = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways()
                                    self.max_metric_always.parent = self
                                    self._children_name_map["max_metric_always"] = "max-metric-always"
                                return self.max_metric_always

                            if (child_yang_name == "max-metric-on-proc-migration"):
                                if (self.max_metric_on_proc_migration is None):
                                    self.max_metric_on_proc_migration = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration()
                                    self.max_metric_on_proc_migration.parent = self
                                    self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                                return self.max_metric_on_proc_migration

                            if (child_yang_name == "max-metric-on-proc-restart"):
                                if (self.max_metric_on_proc_restart is None):
                                    self.max_metric_on_proc_restart = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart()
                                    self.max_metric_on_proc_restart.parent = self
                                    self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                                return self.max_metric_on_proc_restart

                            if (child_yang_name == "max-metric-on-startup"):
                                if (self.max_metric_on_startup is None):
                                    self.max_metric_on_startup = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup()
                                    self.max_metric_on_startup.parent = self
                                    self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                                return self.max_metric_on_startup

                            if (child_yang_name == "max-metric-on-switchover"):
                                if (self.max_metric_on_switchover is None):
                                    self.max_metric_on_switchover = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover()
                                    self.max_metric_on_switchover.parent = self
                                    self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                                return self.max_metric_on_switchover

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-metric-always" or name == "max-metric-on-proc-migration" or name == "max-metric-on-proc-restart" or name == "max-metric-on-startup" or name == "max-metric-on-switchover" or name == "max-metric-no-abr-off"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-metric-no-abr-off"):
                                self.max_metric_no_abr_off = value
                                self.max_metric_no_abr_off.value_namespace = name_space
                                self.max_metric_no_abr_off.value_namespace_prefix = name_space_prefix


                    class Nsf(Entity):
                        """
                        Non Stop Forwarding configuration
                        
                        .. attribute:: cisco
                        
                        	Enable Cisco Non Stop Forwarding
                        	**type**\:   :py:class:`OspfCiscoNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfCiscoNsf>`
                        
                        .. attribute:: flush_delay_time
                        
                        	Maximum time allowed for external route learning (seconds)
                        	**type**\:  int
                        
                        	**range:** 1..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 60
                        
                        .. attribute:: ietf
                        
                        	Enable IETF Non Stop Forwarding
                        	**type**\:   :py:class:`OspfIetfNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsf>`
                        
                        .. attribute:: ietf_strict_lsa_checking
                        
                        	Enable Strict LSA checking of IETF NSF
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ietf_support_role
                        
                        	Disable helper support role for IETF Non Stop Forwarding
                        	**type**\:   :py:class:`OspfIetfNsfSupport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsfSupport>`
                        
                        .. attribute:: interval
                        
                        	Minimum interval between Non Stop Forwarding restarts in seconds
                        	**type**\:  int
                        
                        	**range:** 90..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 90
                        
                        .. attribute:: lifetime
                        
                        	Maximum route lifetime following restart in seconds
                        	**type**\:  int
                        
                        	**range:** 90..1800
                        
                        	**units**\: second
                        
                        	**default value**\: 90
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Nsf, self).__init__()

                            self.yang_name = "nsf"
                            self.yang_parent_name = "vrf"

                            self.cisco = YLeaf(YType.enumeration, "cisco")

                            self.flush_delay_time = YLeaf(YType.uint32, "flush-delay-time")

                            self.ietf = YLeaf(YType.enumeration, "ietf")

                            self.ietf_strict_lsa_checking = YLeaf(YType.empty, "ietf-strict-lsa-checking")

                            self.ietf_support_role = YLeaf(YType.enumeration, "ietf-support-role")

                            self.interval = YLeaf(YType.uint32, "interval")

                            self.lifetime = YLeaf(YType.uint32, "lifetime")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cisco",
                                            "flush_delay_time",
                                            "ietf",
                                            "ietf_strict_lsa_checking",
                                            "ietf_support_role",
                                            "interval",
                                            "lifetime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Nsf, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Nsf, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cisco.is_set or
                                self.flush_delay_time.is_set or
                                self.ietf.is_set or
                                self.ietf_strict_lsa_checking.is_set or
                                self.ietf_support_role.is_set or
                                self.interval.is_set or
                                self.lifetime.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cisco.yfilter != YFilter.not_set or
                                self.flush_delay_time.yfilter != YFilter.not_set or
                                self.ietf.yfilter != YFilter.not_set or
                                self.ietf_strict_lsa_checking.yfilter != YFilter.not_set or
                                self.ietf_support_role.yfilter != YFilter.not_set or
                                self.interval.yfilter != YFilter.not_set or
                                self.lifetime.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nsf" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cisco.is_set or self.cisco.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cisco.get_name_leafdata())
                            if (self.flush_delay_time.is_set or self.flush_delay_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flush_delay_time.get_name_leafdata())
                            if (self.ietf.is_set or self.ietf.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ietf.get_name_leafdata())
                            if (self.ietf_strict_lsa_checking.is_set or self.ietf_strict_lsa_checking.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ietf_strict_lsa_checking.get_name_leafdata())
                            if (self.ietf_support_role.is_set or self.ietf_support_role.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ietf_support_role.get_name_leafdata())
                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interval.get_name_leafdata())
                            if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lifetime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cisco" or name == "flush-delay-time" or name == "ietf" or name == "ietf-strict-lsa-checking" or name == "ietf-support-role" or name == "interval" or name == "lifetime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cisco"):
                                self.cisco = value
                                self.cisco.value_namespace = name_space
                                self.cisco.value_namespace_prefix = name_space_prefix
                            if(value_path == "flush-delay-time"):
                                self.flush_delay_time = value
                                self.flush_delay_time.value_namespace = name_space
                                self.flush_delay_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "ietf"):
                                self.ietf = value
                                self.ietf.value_namespace = name_space
                                self.ietf.value_namespace_prefix = name_space_prefix
                            if(value_path == "ietf-strict-lsa-checking"):
                                self.ietf_strict_lsa_checking = value
                                self.ietf_strict_lsa_checking.value_namespace = name_space
                                self.ietf_strict_lsa_checking.value_namespace_prefix = name_space_prefix
                            if(value_path == "ietf-support-role"):
                                self.ietf_support_role = value
                                self.ietf_support_role.value_namespace = name_space
                                self.ietf_support_role.value_namespace_prefix = name_space_prefix
                            if(value_path == "interval"):
                                self.interval = value
                                self.interval.value_namespace = name_space
                                self.interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "lifetime"):
                                self.lifetime = value
                                self.lifetime.value_namespace = name_space
                                self.lifetime.value_namespace_prefix = name_space_prefix


                    class ProcessScope(Entity):
                        """
                        Process scope configuration
                        
                        .. attribute:: authentication
                        
                        	Authentication
                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	BFD configuration
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd>`
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: cost_fallback
                        
                        	Interface fallback cost
                        	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: dead_interval_minimal
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal>`
                        
                        .. attribute:: demand_circuit
                        
                        	Enable/Disable OSPF demand circuit
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: distribute_list
                        
                        	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                        	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: fast_reroute
                        
                        	Fast\-reroute configuration
                        	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute>`
                        
                        .. attribute:: flood_reduction
                        
                        	Enable/Disable OSPF flood reduction
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: hello_interval
                        
                        	Interval between HELLO packets in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: ldp_auto_config
                        
                        	Enable MPLS LDP Auto Config
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ldp_sync
                        
                        	Enable/Disable MPLS LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: ldp_sync_igp_shortcuts
                        
                        	Enable/Disable MPLS LDP sync for igp\-shortcuts
                        	**type**\:  bool
                        
                        .. attribute:: link_down_fast_detect
                        
                        	Enable/Disable registration for early interface down notifications
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: loopback_stub_network
                        
                        	Enable/Disable advertising loopback as a stub network
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: mtu_ignore
                        
                        	Enable/Disable ignoring of MTU in DBD packets
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: network_type
                        
                        	Type of attached network
                        	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                        
                        .. attribute:: packet_size
                        
                        	Customize size of OSPF packets upto MTU
                        	**type**\:  int
                        
                        	**range:** 576..10000
                        
                        .. attribute:: passive
                        
                        	When enabled, prevent sending HELLO packets over link
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: prefix_suppression_primary
                        
                        	Enable/Disable prefix suppression for primary addresses
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: prefix_suppression_secondary
                        
                        	Enable/Disable prefix suppression for secondary addresses
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: priority
                        
                        	Router priority for DR and BDR election
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**default value**\: 1
                        
                        .. attribute:: retransmit_interval
                        
                        	Time in seconds between retransmitting lost link state advertisements
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        	**default value**\: 5
                        
                        .. attribute:: security
                        
                        	Container class for security related configuration parameters
                        	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: segment_routing_forwarding
                        
                        	segment\-routing forwarding configuration Applicableonly in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                        
                        .. attribute:: srgb
                        
                        	Segment Routing Global Block configuration
                        	**type**\:   :py:class:`Srgb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: transmit_delay
                        
                        	Number of seconds to delay transmission of LSAs
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        	**default value**\: 1
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope, self).__init__()

                            self.yang_name = "process-scope"
                            self.yang_parent_name = "vrf"

                            self.cost = YLeaf(YType.uint32, "cost")

                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                            self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                            self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                            self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                            self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                            self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                            self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                            self.network_type = YLeaf(YType.enumeration, "network-type")

                            self.packet_size = YLeaf(YType.uint32, "packet-size")

                            self.passive = YLeaf(YType.boolean, "passive")

                            self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                            self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                            self.authentication = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                            self._children_yang_names.add("authentication")

                            self.bfd = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"
                            self._children_yang_names.add("bfd")

                            self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback()
                            self.cost_fallback.parent = self
                            self._children_name_map["cost_fallback"] = "cost-fallback"
                            self._children_yang_names.add("cost-fallback")

                            self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal()
                            self.dead_interval_minimal.parent = self
                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                            self._children_yang_names.add("dead-interval-minimal")

                            self.distribute_list = None
                            self._children_name_map["distribute_list"] = "distribute-list"
                            self._children_yang_names.add("distribute-list")

                            self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute()
                            self.fast_reroute.parent = self
                            self._children_name_map["fast_reroute"] = "fast-reroute"
                            self._children_yang_names.add("fast-reroute")

                            self.security = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security()
                            self.security.parent = self
                            self._children_name_map["security"] = "security"
                            self._children_yang_names.add("security")

                            self.srgb = None
                            self._children_name_map["srgb"] = "srgb"
                            self._children_yang_names.add("srgb")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cost",
                                            "database_filter",
                                            "demand_circuit",
                                            "external_out",
                                            "flood_reduction",
                                            "hello_interval",
                                            "ldp_auto_config",
                                            "ldp_sync",
                                            "ldp_sync_igp_shortcuts",
                                            "link_down_fast_detect",
                                            "loopback_stub_network",
                                            "mtu_ignore",
                                            "network_type",
                                            "packet_size",
                                            "passive",
                                            "prefix_suppression_primary",
                                            "prefix_suppression_secondary",
                                            "priority",
                                            "retransmit_interval",
                                            "segment_routing",
                                            "segment_routing_forwarding",
                                            "summary_in",
                                            "transmit_delay") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope, self).__setattr__(name, value)


                        class Srgb(Entity):
                            """
                            Segment Routing Global Block configuration
                            
                            .. attribute:: lower_bound
                            
                            	The lower bound of the SRGB
                            	**type**\:  int
                            
                            	**range:** 16000..1048575
                            
                            	**mandatory**\: True
                            
                            .. attribute:: upper_bound
                            
                            	The upper bound of the SRGB
                            	**type**\:  int
                            
                            	**range:** 16000..1048575
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb, self).__init__()

                                self.yang_name = "srgb"
                                self.yang_parent_name = "process-scope"
                                self.is_presence_container = True

                                self.lower_bound = YLeaf(YType.uint32, "lower-bound")

                                self.upper_bound = YLeaf(YType.uint32, "upper-bound")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lower_bound",
                                                "upper_bound") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.lower_bound.is_set or
                                    self.upper_bound.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lower_bound.yfilter != YFilter.not_set or
                                    self.upper_bound.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "srgb" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lower_bound.is_set or self.lower_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lower_bound.get_name_leafdata())
                                if (self.upper_bound.is_set or self.upper_bound.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.upper_bound.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lower-bound" or name == "upper-bound"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lower-bound"):
                                    self.lower_bound = value
                                    self.lower_bound.value_namespace = name_space
                                    self.lower_bound.value_namespace_prefix = name_space_prefix
                                if(value_path == "upper-bound"):
                                    self.upper_bound = value
                                    self.upper_bound.value_namespace = name_space
                                    self.upper_bound.value_namespace_prefix = name_space_prefix


                        class FastReroute(Entity):
                            """
                            Fast\-reroute configuration
                            
                            .. attribute:: fast_reroute_enable
                            
                            	Enable/Disable Fast\-reroute per\-link or per\-prefix
                            	**type**\:   :py:class:`OspfProcFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFastReroute>`
                            
                            .. attribute:: per_link
                            
                            	Fast\-reroute per\-link configuration
                            	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink>`
                            
                            .. attribute:: per_prefix
                            
                            	Fast\-reroute per\-prefix configuration
                            	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "process-scope"

                                self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                self.per_link = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink()
                                self.per_link.parent = self
                                self._children_name_map["per_link"] = "per-link"
                                self._children_yang_names.add("per-link")

                                self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix()
                                self.per_prefix.parent = self
                                self._children_name_map["per_prefix"] = "per-prefix"
                                self._children_yang_names.add("per-prefix")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fast_reroute_enable") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute, self).__setattr__(name, value)


                            class PerLink(Entity):
                                """
                                Fast\-reroute per\-link configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink, self).__init__()

                                    self.yang_name = "per-link"
                                    self.yang_parent_name = "fast-reroute"

                                    self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    self._children_yang_names.add("candidate-interfaces")

                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    self._children_yang_names.add("exclude-interfaces")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink, self).__setattr__(name, value)


                                class CandidateInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                        self.yang_name = "candidate-interfaces"
                                        self.yang_parent_name = "per-link"

                                        self.candidate_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                    class CandidateInterface(Entity):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                            self.yang_name = "candidate-interface"
                                            self.yang_parent_name = "candidate-interfaces"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.interface_name.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.candidate_interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.candidate_interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-interfaces" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interface"):
                                            for c in self.candidate_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.candidate_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class ExcludeInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup or UCMP
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                        self.yang_name = "exclude-interfaces"
                                        self.yang_parent_name = "per-link"

                                        self.exclude_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                    class ExcludeInterface(Entity):
                                        """
                                        Exclude an interface from becoming a backup or
                                        UCMP
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                            self.yang_name = "exclude-interface"
                                            self.yang_parent_name = "exclude-interfaces"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.interface_name.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.exclude_interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.exclude_interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "exclude-interfaces" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "exclude-interface"):
                                            for c in self.exclude_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.exclude_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "exclude-interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.fast_reroute_use_candidate_only.is_set or
                                        (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                        (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                        (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                        (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-link" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-interfaces"):
                                        if (self.candidate_interfaces is None):
                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        return self.candidate_interfaces

                                    if (child_yang_name == "exclude-interfaces"):
                                        if (self.exclude_interfaces is None):
                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        return self.exclude_interfaces

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fast-reroute-use-candidate-only"):
                                        self.fast_reroute_use_candidate_only = value
                                        self.fast_reroute_use_candidate_only.value_namespace = name_space
                                        self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                            class PerPrefix(Entity):
                                """
                                Fast\-reroute per\-prefix configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: remote_lfa
                                
                                	Remote LFA configuration
                                	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa>`
                                
                                .. attribute:: topology_independent_lfa
                                
                                	Topology Independet LFA configuration
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix, self).__init__()

                                    self.yang_name = "per-prefix"
                                    self.yang_parent_name = "fast-reroute"

                                    self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                    self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    self._children_yang_names.add("candidate-interfaces")

                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    self._children_yang_names.add("exclude-interfaces")

                                    self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                    self.remote_lfa.parent = self
                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                    self._children_yang_names.add("remote-lfa")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fast_reroute_use_candidate_only",
                                                    "topology_independent_lfa") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                class RemoteLfa(Entity):
                                    """
                                    Remote LFA configuration
                                    
                                    .. attribute:: maximum_cost
                                    
                                    	Maximum path cost to remote LFA
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tunnel
                                    
                                    	Enable/Disable remote LFA computation
                                    	**type**\:   :py:class:`OspfProcFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFrrRlfaTunnel>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                        self.yang_name = "remote-lfa"
                                        self.yang_parent_name = "per-prefix"

                                        self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                        self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("maximum_cost",
                                                        "tunnel") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.maximum_cost.is_set or
                                            self.tunnel.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.maximum_cost.yfilter != YFilter.not_set or
                                            self.tunnel.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "remote-lfa" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                        if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tunnel.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "maximum-cost" or name == "tunnel"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "maximum-cost"):
                                            self.maximum_cost = value
                                            self.maximum_cost.value_namespace = name_space
                                            self.maximum_cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tunnel"):
                                            self.tunnel = value
                                            self.tunnel.value_namespace = name_space
                                            self.tunnel.value_namespace_prefix = name_space_prefix


                                class CandidateInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                        self.yang_name = "candidate-interfaces"
                                        self.yang_parent_name = "per-prefix"

                                        self.candidate_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                    class CandidateInterface(Entity):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                            self.yang_name = "candidate-interface"
                                            self.yang_parent_name = "candidate-interfaces"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.interface_name.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.candidate_interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.candidate_interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-interfaces" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interface"):
                                            for c in self.candidate_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.candidate_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class ExcludeInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup or UCMP
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                        self.yang_name = "exclude-interfaces"
                                        self.yang_parent_name = "per-prefix"

                                        self.exclude_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                    class ExcludeInterface(Entity):
                                        """
                                        Exclude an interface from becoming a backup or
                                        UCMP
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                            self.yang_name = "exclude-interface"
                                            self.yang_parent_name = "exclude-interfaces"

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interface_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.interface_name.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interface_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interface-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interface-name"):
                                                self.interface_name = value
                                                self.interface_name.value_namespace = name_space
                                                self.interface_name.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.exclude_interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.exclude_interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "exclude-interfaces" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "exclude-interface"):
                                            for c in self.exclude_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.exclude_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "exclude-interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.fast_reroute_use_candidate_only.is_set or
                                        self.topology_independent_lfa.is_set or
                                        (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                        (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                        (self.remote_lfa is not None and self.remote_lfa.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                        self.topology_independent_lfa.yfilter != YFilter.not_set or
                                        (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                        (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                        (self.remote_lfa is not None and self.remote_lfa.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-prefix" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                    if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-interfaces"):
                                        if (self.candidate_interfaces is None):
                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        return self.candidate_interfaces

                                    if (child_yang_name == "exclude-interfaces"):
                                        if (self.exclude_interfaces is None):
                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        return self.exclude_interfaces

                                    if (child_yang_name == "remote-lfa"):
                                        if (self.remote_lfa is None):
                                            self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                        return self.remote_lfa

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fast-reroute-use-candidate-only"):
                                        self.fast_reroute_use_candidate_only = value
                                        self.fast_reroute_use_candidate_only.value_namespace = name_space
                                        self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "topology-independent-lfa"):
                                        self.topology_independent_lfa = value
                                        self.topology_independent_lfa.value_namespace = name_space
                                        self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.fast_reroute_enable.is_set or
                                    (self.per_link is not None and self.per_link.has_data()) or
                                    (self.per_prefix is not None and self.per_prefix.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fast_reroute_enable.yfilter != YFilter.not_set or
                                    (self.per_link is not None and self.per_link.has_operation()) or
                                    (self.per_prefix is not None and self.per_prefix.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fast-reroute" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "per-link"):
                                    if (self.per_link is None):
                                        self.per_link = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                    return self.per_link

                                if (child_yang_name == "per-prefix"):
                                    if (self.per_prefix is None):
                                        self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                    return self.per_prefix

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fast-reroute-enable"):
                                    self.fast_reroute_enable = value
                                    self.fast_reroute_enable.value_namespace = name_space
                                    self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                        class DistributeList(Entity):
                            """
                            Filter networks intalled to RIB (disable as ACL
                            name means filtering is disabled)
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_name
                            
                            	Route Policy name
                            	**type**\:  str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList, self).__init__()

                                self.yang_name = "distribute-list"
                                self.yang_parent_name = "process-scope"
                                self.is_presence_container = True

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("access_list_name",
                                                "route_policy_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.access_list_name.is_set or
                                    self.route_policy_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.access_list_name.yfilter != YFilter.not_set or
                                    self.route_policy_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "distribute-list" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "access-list-name" or name == "route-policy-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "access-list-name"):
                                    self.access_list_name = value
                                    self.access_list_name.value_namespace = name_space
                                    self.access_list_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-policy-name"):
                                    self.route_policy_name = value
                                    self.route_policy_name.value_namespace = name_space
                                    self.route_policy_name.value_namespace_prefix = name_space_prefix


                        class Bfd(Entity):
                            """
                            BFD configuration
                            
                            .. attribute:: detection_multiplier
                            
                            	Detection multiplier for BFD sessions created by OSPF
                            	**type**\:  int
                            
                            	**range:** 2..50
                            
                            .. attribute:: fast_detect_mode
                            
                            	 use of Bidirectional Forwarding Detection
                            	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                            
                            .. attribute:: interval
                            
                            	Hello interval for BFD sessions created by OSPF
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "process-scope"

                                self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                self.interval = YLeaf(YType.uint32, "interval")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("detection_multiplier",
                                                "fast_detect_mode",
                                                "interval") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.detection_multiplier.is_set or
                                    self.fast_detect_mode.is_set or
                                    self.interval.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.detection_multiplier.yfilter != YFilter.not_set or
                                    self.fast_detect_mode.yfilter != YFilter.not_set or
                                    self.interval.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "bfd" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interval.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "detection-multiplier"):
                                    self.detection_multiplier = value
                                    self.detection_multiplier.value_namespace = name_space
                                    self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "fast-detect-mode"):
                                    self.fast_detect_mode = value
                                    self.fast_detect_mode.value_namespace = name_space
                                    self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "interval"):
                                    self.interval = value
                                    self.interval.value_namespace = name_space
                                    self.interval.value_namespace_prefix = name_space_prefix


                        class Authentication(Entity):
                            """
                            Authentication
                            
                            .. attribute:: key
                            
                            	Authentication key configuration
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: message_digest_keies
                            
                            	Message digest authentication password (key) configurations, first 16 chars used
                            	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies>`
                            
                            .. attribute:: type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "process-scope"

                                self.key = YLeaf(YType.str, "key")

                                self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies()
                                self.message_digest_keies.parent = self
                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                self._children_yang_names.add("message-digest-keies")

                                self.type = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type()
                                self.type.parent = self
                                self._children_name_map["type"] = "type"
                                self._children_yang_names.add("type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("key") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication, self).__setattr__(name, value)


                            class Type(Entity):
                                """
                                Authentication type
                                
                                .. attribute:: authen_type
                                
                                	Authentication type code 
                                	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                
                                .. attribute:: keychain_authen_type
                                
                                	Keychain authentication type
                                	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                
                                .. attribute:: keychain_name
                                
                                	Keychain name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type, self).__init__()

                                    self.yang_name = "type"
                                    self.yang_parent_name = "authentication"

                                    self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                    self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                    self.keychain_name = YLeaf(YType.str, "keychain-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("authen_type",
                                                    "keychain_authen_type",
                                                    "keychain_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.authen_type.is_set or
                                        self.keychain_authen_type.is_set or
                                        self.keychain_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.authen_type.yfilter != YFilter.not_set or
                                        self.keychain_authen_type.yfilter != YFilter.not_set or
                                        self.keychain_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "type" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.authen_type.get_name_leafdata())
                                    if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                    if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "authen-type"):
                                        self.authen_type = value
                                        self.authen_type.value_namespace = name_space
                                        self.authen_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "keychain-authen-type"):
                                        self.keychain_authen_type = value
                                        self.keychain_authen_type.value_namespace = name_space
                                        self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "keychain-name"):
                                        self.keychain_name = value
                                        self.keychain_name.value_namespace = name_space
                                        self.keychain_name.value_namespace_prefix = name_space_prefix


                            class MessageDigestKeies(Entity):
                                """
                                Message digest authentication password (key)
                                configurations, first 16 chars used
                                
                                .. attribute:: message_digest_key
                                
                                	Message digest authentication password (key) configuration
                                	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies, self).__init__()

                                    self.yang_name = "message-digest-keies"
                                    self.yang_parent_name = "authentication"

                                    self.message_digest_key = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configuration
                                    
                                    .. attribute:: key_id  <key>
                                    
                                    	Key ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: password
                                    
                                    	Password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "message-digest-keies"

                                        self.key_id = YLeaf(YType.uint32, "key-id")

                                        self.password = YLeaf(YType.str, "password")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key_id",
                                                        "password") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.key_id.is_set or
                                            self.password.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key_id.yfilter != YFilter.not_set or
                                            self.password.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key_id.get_name_leafdata())
                                        if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.password.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "key-id" or name == "password"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key-id"):
                                            self.key_id = value
                                            self.key_id.value_namespace = name_space
                                            self.key_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "password"):
                                            self.password = value
                                            self.password.value_namespace = name_space
                                            self.password.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.message_digest_key:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.message_digest_key:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "message-digest-keies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "message-digest-key"):
                                        for c in self.message_digest_key:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.message_digest_key.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "message-digest-key"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.key.is_set or
                                    (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                    (self.type is not None and self.type.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.key.yfilter != YFilter.not_set or
                                    (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                    (self.type is not None and self.type.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "authentication" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.key.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "message-digest-keies"):
                                    if (self.message_digest_keies is None):
                                        self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                    return self.message_digest_keies

                                if (child_yang_name == "type"):
                                    if (self.type is None):
                                        self.type = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                    return self.type

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "message-digest-keies" or name == "type" or name == "key"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "key"):
                                    self.key = value
                                    self.key.value_namespace = name_space
                                    self.key.value_namespace_prefix = name_space_prefix


                        class Security(Entity):
                            """
                            Container class for security related
                            configuration parameters
                            
                            .. attribute:: ttl
                            
                            	Enabling turns on TTL security
                            	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "process-scope"

                                self.ttl = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl()
                                self.ttl.parent = self
                                self._children_name_map["ttl"] = "ttl"
                                self._children_yang_names.add("ttl")


                            class Ttl(Entity):
                                """
                                Enabling turns on TTL security
                                
                                .. attribute:: enable
                                
                                	Enable TTL security
                                	**type**\:  bool
                                
                                .. attribute:: hop_count
                                
                                	Hop count
                                	**type**\:  int
                                
                                	**range:** 1..254
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl, self).__init__()

                                    self.yang_name = "ttl"
                                    self.yang_parent_name = "security"

                                    self.enable = YLeaf(YType.boolean, "enable")

                                    self.hop_count = YLeaf(YType.uint32, "hop-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("enable",
                                                    "hop_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.enable.is_set or
                                        self.hop_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.enable.yfilter != YFilter.not_set or
                                        self.hop_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ttl" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enable.get_name_leafdata())
                                    if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hop_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "enable" or name == "hop-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "enable"):
                                        self.enable = value
                                        self.enable.value_namespace = name_space
                                        self.enable.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hop-count"):
                                        self.hop_count = value
                                        self.hop_count.value_namespace = name_space
                                        self.hop_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (self.ttl is not None and self.ttl.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.ttl is not None and self.ttl.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "security" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ttl"):
                                    if (self.ttl is None):
                                        self.ttl = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                    return self.ttl

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ttl"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class DeadIntervalMinimal(Entity):
                            """
                            Interval after which a neighbor is declared dead
                            
                            .. attribute:: interval
                            
                            	Interval size in seconds after which a neighbor is declared dead
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: multiplier
                            
                            	Number of Hellos in one second
                            	**type**\:  int
                            
                            	**range:** 3..20
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal, self).__init__()

                                self.yang_name = "dead-interval-minimal"
                                self.yang_parent_name = "process-scope"

                                self.interval = YLeaf(YType.uint32, "interval")

                                self.multiplier = YLeaf(YType.uint32, "multiplier")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interval",
                                                "multiplier") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.interval.is_set or
                                    self.multiplier.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interval.yfilter != YFilter.not_set or
                                    self.multiplier.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dead-interval-minimal" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interval.get_name_leafdata())
                                if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.multiplier.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interval" or name == "multiplier"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interval"):
                                    self.interval = value
                                    self.interval.value_namespace = name_space
                                    self.interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "multiplier"):
                                    self.multiplier = value
                                    self.multiplier.value_namespace = name_space
                                    self.multiplier.value_namespace_prefix = name_space_prefix


                        class CostFallback(Entity):
                            """
                            Interface fallback cost
                            
                            .. attribute:: cost
                            
                            	Fallback cost of link
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: threshold
                            
                            	Bandwidth threshold
                            	**type**\:  int
                            
                            	**range:** 1..4294967
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback, self).__init__()

                                self.yang_name = "cost-fallback"
                                self.yang_parent_name = "process-scope"

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.threshold = YLeaf(YType.uint32, "threshold")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cost",
                                                "threshold") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.cost.is_set or
                                    self.threshold.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cost.yfilter != YFilter.not_set or
                                    self.threshold.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "cost-fallback" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.threshold.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "cost" or name == "threshold"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cost"):
                                    self.cost = value
                                    self.cost.value_namespace = name_space
                                    self.cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "threshold"):
                                    self.threshold = value
                                    self.threshold.value_namespace = name_space
                                    self.threshold.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.cost.is_set or
                                self.database_filter.is_set or
                                self.demand_circuit.is_set or
                                self.external_out.is_set or
                                self.flood_reduction.is_set or
                                self.hello_interval.is_set or
                                self.ldp_auto_config.is_set or
                                self.ldp_sync.is_set or
                                self.ldp_sync_igp_shortcuts.is_set or
                                self.link_down_fast_detect.is_set or
                                self.loopback_stub_network.is_set or
                                self.mtu_ignore.is_set or
                                self.network_type.is_set or
                                self.packet_size.is_set or
                                self.passive.is_set or
                                self.prefix_suppression_primary.is_set or
                                self.prefix_suppression_secondary.is_set or
                                self.priority.is_set or
                                self.retransmit_interval.is_set or
                                self.segment_routing.is_set or
                                self.segment_routing_forwarding.is_set or
                                self.summary_in.is_set or
                                self.transmit_delay.is_set or
                                (self.authentication is not None and self.authentication.has_data()) or
                                (self.bfd is not None and self.bfd.has_data()) or
                                (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                (self.security is not None and self.security.has_data()) or
                                (self.distribute_list is not None) or
                                (self.srgb is not None))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cost.yfilter != YFilter.not_set or
                                self.database_filter.yfilter != YFilter.not_set or
                                self.demand_circuit.yfilter != YFilter.not_set or
                                self.external_out.yfilter != YFilter.not_set or
                                self.flood_reduction.yfilter != YFilter.not_set or
                                self.hello_interval.yfilter != YFilter.not_set or
                                self.ldp_auto_config.yfilter != YFilter.not_set or
                                self.ldp_sync.yfilter != YFilter.not_set or
                                self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                self.link_down_fast_detect.yfilter != YFilter.not_set or
                                self.loopback_stub_network.yfilter != YFilter.not_set or
                                self.mtu_ignore.yfilter != YFilter.not_set or
                                self.network_type.yfilter != YFilter.not_set or
                                self.packet_size.yfilter != YFilter.not_set or
                                self.passive.yfilter != YFilter.not_set or
                                self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                self.retransmit_interval.yfilter != YFilter.not_set or
                                self.segment_routing.yfilter != YFilter.not_set or
                                self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                self.summary_in.yfilter != YFilter.not_set or
                                self.transmit_delay.yfilter != YFilter.not_set or
                                (self.authentication is not None and self.authentication.has_operation()) or
                                (self.bfd is not None and self.bfd.has_operation()) or
                                (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                (self.security is not None and self.security.has_operation()) or
                                (self.srgb is not None and self.srgb.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "process-scope" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cost.get_name_leafdata())
                            if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.database_filter.get_name_leafdata())
                            if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                            if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_out.get_name_leafdata())
                            if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.hello_interval.get_name_leafdata())
                            if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                            if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                            if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                            if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                            if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                            if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                            if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.network_type.get_name_leafdata())
                            if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.packet_size.get_name_leafdata())
                            if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.passive.get_name_leafdata())
                            if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                            if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())
                            if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                            if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_routing.get_name_leafdata())
                            if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                            if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_in.get_name_leafdata())
                            if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "authentication"):
                                if (self.authentication is None):
                                    self.authentication = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                return self.authentication

                            if (child_yang_name == "bfd"):
                                if (self.bfd is None):
                                    self.bfd = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                return self.bfd

                            if (child_yang_name == "cost-fallback"):
                                if (self.cost_fallback is None):
                                    self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                return self.cost_fallback

                            if (child_yang_name == "dead-interval-minimal"):
                                if (self.dead_interval_minimal is None):
                                    self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                return self.dead_interval_minimal

                            if (child_yang_name == "distribute-list"):
                                if (self.distribute_list is None):
                                    self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList()
                                    self.distribute_list.parent = self
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                return self.distribute_list

                            if (child_yang_name == "fast-reroute"):
                                if (self.fast_reroute is None):
                                    self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                return self.fast_reroute

                            if (child_yang_name == "security"):
                                if (self.security is None):
                                    self.security = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                return self.security

                            if (child_yang_name == "srgb"):
                                if (self.srgb is None):
                                    self.srgb = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb()
                                    self.srgb.parent = self
                                    self._children_name_map["srgb"] = "srgb"
                                return self.srgb

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "srgb" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "external-out" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing" or name == "segment-routing-forwarding" or name == "summary-in" or name == "transmit-delay"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cost"):
                                self.cost = value
                                self.cost.value_namespace = name_space
                                self.cost.value_namespace_prefix = name_space_prefix
                            if(value_path == "database-filter"):
                                self.database_filter = value
                                self.database_filter.value_namespace = name_space
                                self.database_filter.value_namespace_prefix = name_space_prefix
                            if(value_path == "demand-circuit"):
                                self.demand_circuit = value
                                self.demand_circuit.value_namespace = name_space
                                self.demand_circuit.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-out"):
                                self.external_out = value
                                self.external_out.value_namespace = name_space
                                self.external_out.value_namespace_prefix = name_space_prefix
                            if(value_path == "flood-reduction"):
                                self.flood_reduction = value
                                self.flood_reduction.value_namespace = name_space
                                self.flood_reduction.value_namespace_prefix = name_space_prefix
                            if(value_path == "hello-interval"):
                                self.hello_interval = value
                                self.hello_interval.value_namespace = name_space
                                self.hello_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-auto-config"):
                                self.ldp_auto_config = value
                                self.ldp_auto_config.value_namespace = name_space
                                self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-sync"):
                                self.ldp_sync = value
                                self.ldp_sync.value_namespace = name_space
                                self.ldp_sync.value_namespace_prefix = name_space_prefix
                            if(value_path == "ldp-sync-igp-shortcuts"):
                                self.ldp_sync_igp_shortcuts = value
                                self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-down-fast-detect"):
                                self.link_down_fast_detect = value
                                self.link_down_fast_detect.value_namespace = name_space
                                self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                            if(value_path == "loopback-stub-network"):
                                self.loopback_stub_network = value
                                self.loopback_stub_network.value_namespace = name_space
                                self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu-ignore"):
                                self.mtu_ignore = value
                                self.mtu_ignore.value_namespace = name_space
                                self.mtu_ignore.value_namespace_prefix = name_space_prefix
                            if(value_path == "network-type"):
                                self.network_type = value
                                self.network_type.value_namespace = name_space
                                self.network_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "packet-size"):
                                self.packet_size = value
                                self.packet_size.value_namespace = name_space
                                self.packet_size.value_namespace_prefix = name_space_prefix
                            if(value_path == "passive"):
                                self.passive = value
                                self.passive.value_namespace = name_space
                                self.passive.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-suppression-primary"):
                                self.prefix_suppression_primary = value
                                self.prefix_suppression_primary.value_namespace = name_space
                                self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-suppression-secondary"):
                                self.prefix_suppression_secondary = value
                                self.prefix_suppression_secondary.value_namespace = name_space
                                self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix
                            if(value_path == "retransmit-interval"):
                                self.retransmit_interval = value
                                self.retransmit_interval.value_namespace = name_space
                                self.retransmit_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-routing"):
                                self.segment_routing = value
                                self.segment_routing.value_namespace = name_space
                                self.segment_routing.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-routing-forwarding"):
                                self.segment_routing_forwarding = value
                                self.segment_routing_forwarding.value_namespace = name_space
                                self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-in"):
                                self.summary_in = value
                                self.summary_in.value_namespace = name_space
                                self.summary_in.value_namespace_prefix = name_space_prefix
                            if(value_path == "transmit-delay"):
                                self.transmit_delay = value
                                self.transmit_delay.value_namespace = name_space
                                self.transmit_delay.value_namespace_prefix = name_space_prefix


                    class Redistribution(Entity):
                        """
                        Redistribute configurations
                        
                        .. attribute:: redistributes
                        
                        	Redistribute information from another routing protocol
                        	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution, self).__init__()

                            self.yang_name = "redistribution"
                            self.yang_parent_name = "vrf"

                            self.redistributes = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes()
                            self.redistributes.parent = self
                            self._children_name_map["redistributes"] = "redistributes"
                            self._children_yang_names.add("redistributes")


                        class Redistributes(Entity):
                            """
                            Redistribute information from another routing
                            protocol
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes, self).__init__()

                                self.yang_name = "redistributes"
                                self.yang_parent_name = "redistribution"

                                self.redistribute = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes, self).__setattr__(name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing
                                protocol
                                
                                .. attribute:: protocol_name  <key>
                                
                                	Distribute list protocol type
                                	**type**\:   :py:class:`OspfRedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistProtocol>`
                                
                                .. attribute:: application_or_isis_or_ospf
                                
                                	application or isis or ospf
                                	**type**\: list of    :py:class:`ApplicationOrIsisOrOspf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf>`
                                
                                .. attribute:: bgp
                                
                                	bgp
                                	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp>`
                                
                                .. attribute:: connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip
                                
                                	connected or static or dagr or subscriber or mobile or rip
                                	**type**\:   :py:class:`ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	eigrp
                                	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "redistributes"

                                    self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                    self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = None
                                    self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                    self._children_yang_names.add("connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip")

                                    self.application_or_isis_or_ospf = YList(self)
                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("protocol_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute, self).__setattr__(name, value)


                                class ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip(Entity):
                                    """
                                    connected or static or dagr or subscriber or
                                    mobile or rip
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__init__()

                                        self.yang_name = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_presence_container = True

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.int32, "tag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("bgp_preserve_default_info",
                                                        "bgp_preserve_med",
                                                        "classful",
                                                        "default_redistributed_route_metric",
                                                        "eigrp_route_type",
                                                        "isis_levels",
                                                        "metric_type",
                                                        "ospf_external",
                                                        "ospf_internal",
                                                        "ospf_nssa_level",
                                                        "ospf_redist_lsa_type",
                                                        "ospfnssa_only",
                                                        "route_policy_name",
                                                        "tag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.bgp_preserve_default_info.is_set or
                                            self.bgp_preserve_med.is_set or
                                            self.classful.is_set or
                                            self.default_redistributed_route_metric.is_set or
                                            self.eigrp_route_type.is_set or
                                            self.isis_levels.is_set or
                                            self.metric_type.is_set or
                                            self.ospf_external.is_set or
                                            self.ospf_internal.is_set or
                                            self.ospf_nssa_level.is_set or
                                            self.ospf_redist_lsa_type.is_set or
                                            self.ospfnssa_only.is_set or
                                            self.route_policy_name.is_set or
                                            self.tag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                            self.bgp_preserve_med.yfilter != YFilter.not_set or
                                            self.classful.yfilter != YFilter.not_set or
                                            self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                            self.eigrp_route_type.yfilter != YFilter.not_set or
                                            self.isis_levels.yfilter != YFilter.not_set or
                                            self.metric_type.yfilter != YFilter.not_set or
                                            self.ospf_external.yfilter != YFilter.not_set or
                                            self.ospf_internal.yfilter != YFilter.not_set or
                                            self.ospf_nssa_level.yfilter != YFilter.not_set or
                                            self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                            self.ospfnssa_only.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.tag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                        if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                        if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.classful.get_name_leafdata())
                                        if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                        if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                        if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                        if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.metric_type.get_name_leafdata())
                                        if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                        if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                        if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                        if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                        if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "bgp-preserve-default-info"):
                                            self.bgp_preserve_default_info = value
                                            self.bgp_preserve_default_info.value_namespace = name_space
                                            self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-med"):
                                            self.bgp_preserve_med = value
                                            self.bgp_preserve_med.value_namespace = name_space
                                            self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                        if(value_path == "classful"):
                                            self.classful = value
                                            self.classful.value_namespace = name_space
                                            self.classful.value_namespace_prefix = name_space_prefix
                                        if(value_path == "default-redistributed-route-metric"):
                                            self.default_redistributed_route_metric = value
                                            self.default_redistributed_route_metric.value_namespace = name_space
                                            self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-route-type"):
                                            self.eigrp_route_type = value
                                            self.eigrp_route_type.value_namespace = name_space
                                            self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-levels"):
                                            self.isis_levels = value
                                            self.isis_levels.value_namespace = name_space
                                            self.isis_levels.value_namespace_prefix = name_space_prefix
                                        if(value_path == "metric-type"):
                                            self.metric_type = value
                                            self.metric_type.value_namespace = name_space
                                            self.metric_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-external"):
                                            self.ospf_external = value
                                            self.ospf_external.value_namespace = name_space
                                            self.ospf_external.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-internal"):
                                            self.ospf_internal = value
                                            self.ospf_internal.value_namespace = name_space
                                            self.ospf_internal.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-nssa-level"):
                                            self.ospf_nssa_level = value
                                            self.ospf_nssa_level.value_namespace = name_space
                                            self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-redist-lsa-type"):
                                            self.ospf_redist_lsa_type = value
                                            self.ospf_redist_lsa_type.value_namespace = name_space
                                            self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospfnssa-only"):
                                            self.ospfnssa_only = value
                                            self.ospfnssa_only.value_namespace = name_space
                                            self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag"):
                                            self.tag = value
                                            self.tag.value_namespace = name_space
                                            self.tag.value_namespace_prefix = name_space_prefix


                                class ApplicationOrIsisOrOspf(Entity):
                                    """
                                    application or isis or ospf
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__init__()

                                        self.yang_name = "application-or-isis-or-ospf"
                                        self.yang_parent_name = "redistribute"

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.int32, "tag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("instance_name",
                                                        "bgp_preserve_default_info",
                                                        "bgp_preserve_med",
                                                        "classful",
                                                        "default_redistributed_route_metric",
                                                        "eigrp_route_type",
                                                        "isis_levels",
                                                        "metric_type",
                                                        "ospf_external",
                                                        "ospf_internal",
                                                        "ospf_nssa_level",
                                                        "ospf_redist_lsa_type",
                                                        "ospfnssa_only",
                                                        "route_policy_name",
                                                        "tag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.instance_name.is_set or
                                            self.bgp_preserve_default_info.is_set or
                                            self.bgp_preserve_med.is_set or
                                            self.classful.is_set or
                                            self.default_redistributed_route_metric.is_set or
                                            self.eigrp_route_type.is_set or
                                            self.isis_levels.is_set or
                                            self.metric_type.is_set or
                                            self.ospf_external.is_set or
                                            self.ospf_internal.is_set or
                                            self.ospf_nssa_level.is_set or
                                            self.ospf_redist_lsa_type.is_set or
                                            self.ospfnssa_only.is_set or
                                            self.route_policy_name.is_set or
                                            self.tag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.instance_name.yfilter != YFilter.not_set or
                                            self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                            self.bgp_preserve_med.yfilter != YFilter.not_set or
                                            self.classful.yfilter != YFilter.not_set or
                                            self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                            self.eigrp_route_type.yfilter != YFilter.not_set or
                                            self.isis_levels.yfilter != YFilter.not_set or
                                            self.metric_type.yfilter != YFilter.not_set or
                                            self.ospf_external.yfilter != YFilter.not_set or
                                            self.ospf_internal.yfilter != YFilter.not_set or
                                            self.ospf_nssa_level.yfilter != YFilter.not_set or
                                            self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                            self.ospfnssa_only.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.tag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "application-or-isis-or-ospf" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.instance_name.get_name_leafdata())
                                        if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                        if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                        if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.classful.get_name_leafdata())
                                        if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                        if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                        if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                        if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.metric_type.get_name_leafdata())
                                        if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                        if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                        if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                        if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                        if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "instance-name" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "instance-name"):
                                            self.instance_name = value
                                            self.instance_name.value_namespace = name_space
                                            self.instance_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-default-info"):
                                            self.bgp_preserve_default_info = value
                                            self.bgp_preserve_default_info.value_namespace = name_space
                                            self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-med"):
                                            self.bgp_preserve_med = value
                                            self.bgp_preserve_med.value_namespace = name_space
                                            self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                        if(value_path == "classful"):
                                            self.classful = value
                                            self.classful.value_namespace = name_space
                                            self.classful.value_namespace_prefix = name_space_prefix
                                        if(value_path == "default-redistributed-route-metric"):
                                            self.default_redistributed_route_metric = value
                                            self.default_redistributed_route_metric.value_namespace = name_space
                                            self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-route-type"):
                                            self.eigrp_route_type = value
                                            self.eigrp_route_type.value_namespace = name_space
                                            self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-levels"):
                                            self.isis_levels = value
                                            self.isis_levels.value_namespace = name_space
                                            self.isis_levels.value_namespace_prefix = name_space_prefix
                                        if(value_path == "metric-type"):
                                            self.metric_type = value
                                            self.metric_type.value_namespace = name_space
                                            self.metric_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-external"):
                                            self.ospf_external = value
                                            self.ospf_external.value_namespace = name_space
                                            self.ospf_external.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-internal"):
                                            self.ospf_internal = value
                                            self.ospf_internal.value_namespace = name_space
                                            self.ospf_internal.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-nssa-level"):
                                            self.ospf_nssa_level = value
                                            self.ospf_nssa_level.value_namespace = name_space
                                            self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-redist-lsa-type"):
                                            self.ospf_redist_lsa_type = value
                                            self.ospf_redist_lsa_type.value_namespace = name_space
                                            self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospfnssa-only"):
                                            self.ospfnssa_only = value
                                            self.ospfnssa_only.value_namespace = name_space
                                            self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag"):
                                            self.tag = value
                                            self.tag.value_namespace = name_space
                                            self.tag.value_namespace_prefix = name_space_prefix


                                class Bgp(Entity):
                                    """
                                    bgp
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: as_yy  <key>
                                    
                                    	Second half of BGP AS number in XX.YY format . Mandatory if Protocol is BGP or EIGRP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.int32, "tag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("instance_name",
                                                        "as_xx",
                                                        "as_yy",
                                                        "bgp_preserve_default_info",
                                                        "bgp_preserve_med",
                                                        "classful",
                                                        "default_redistributed_route_metric",
                                                        "eigrp_route_type",
                                                        "isis_levels",
                                                        "metric_type",
                                                        "ospf_external",
                                                        "ospf_internal",
                                                        "ospf_nssa_level",
                                                        "ospf_redist_lsa_type",
                                                        "ospfnssa_only",
                                                        "route_policy_name",
                                                        "tag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.instance_name.is_set or
                                            self.as_xx.is_set or
                                            self.as_yy.is_set or
                                            self.bgp_preserve_default_info.is_set or
                                            self.bgp_preserve_med.is_set or
                                            self.classful.is_set or
                                            self.default_redistributed_route_metric.is_set or
                                            self.eigrp_route_type.is_set or
                                            self.isis_levels.is_set or
                                            self.metric_type.is_set or
                                            self.ospf_external.is_set or
                                            self.ospf_internal.is_set or
                                            self.ospf_nssa_level.is_set or
                                            self.ospf_redist_lsa_type.is_set or
                                            self.ospfnssa_only.is_set or
                                            self.route_policy_name.is_set or
                                            self.tag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.instance_name.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.as_yy.yfilter != YFilter.not_set or
                                            self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                            self.bgp_preserve_med.yfilter != YFilter.not_set or
                                            self.classful.yfilter != YFilter.not_set or
                                            self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                            self.eigrp_route_type.yfilter != YFilter.not_set or
                                            self.isis_levels.yfilter != YFilter.not_set or
                                            self.metric_type.yfilter != YFilter.not_set or
                                            self.ospf_external.yfilter != YFilter.not_set or
                                            self.ospf_internal.yfilter != YFilter.not_set or
                                            self.ospf_nssa_level.yfilter != YFilter.not_set or
                                            self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                            self.ospfnssa_only.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.tag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bgp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.instance_name.get_name_leafdata())
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_yy.get_name_leafdata())
                                        if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                        if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                        if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.classful.get_name_leafdata())
                                        if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                        if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                        if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                        if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.metric_type.get_name_leafdata())
                                        if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                        if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                        if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                        if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                        if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "instance-name" or name == "as-xx" or name == "as-yy" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "instance-name"):
                                            self.instance_name = value
                                            self.instance_name.value_namespace = name_space
                                            self.instance_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-yy"):
                                            self.as_yy = value
                                            self.as_yy.value_namespace = name_space
                                            self.as_yy.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-default-info"):
                                            self.bgp_preserve_default_info = value
                                            self.bgp_preserve_default_info.value_namespace = name_space
                                            self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-med"):
                                            self.bgp_preserve_med = value
                                            self.bgp_preserve_med.value_namespace = name_space
                                            self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                        if(value_path == "classful"):
                                            self.classful = value
                                            self.classful.value_namespace = name_space
                                            self.classful.value_namespace_prefix = name_space_prefix
                                        if(value_path == "default-redistributed-route-metric"):
                                            self.default_redistributed_route_metric = value
                                            self.default_redistributed_route_metric.value_namespace = name_space
                                            self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-route-type"):
                                            self.eigrp_route_type = value
                                            self.eigrp_route_type.value_namespace = name_space
                                            self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-levels"):
                                            self.isis_levels = value
                                            self.isis_levels.value_namespace = name_space
                                            self.isis_levels.value_namespace_prefix = name_space_prefix
                                        if(value_path == "metric-type"):
                                            self.metric_type = value
                                            self.metric_type.value_namespace = name_space
                                            self.metric_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-external"):
                                            self.ospf_external = value
                                            self.ospf_external.value_namespace = name_space
                                            self.ospf_external.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-internal"):
                                            self.ospf_internal = value
                                            self.ospf_internal.value_namespace = name_space
                                            self.ospf_internal.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-nssa-level"):
                                            self.ospf_nssa_level = value
                                            self.ospf_nssa_level.value_namespace = name_space
                                            self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-redist-lsa-type"):
                                            self.ospf_redist_lsa_type = value
                                            self.ospf_redist_lsa_type.value_namespace = name_space
                                            self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospfnssa-only"):
                                            self.ospfnssa_only = value
                                            self.ospfnssa_only.value_namespace = name_space
                                            self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag"):
                                            self.tag = value
                                            self.tag.value_namespace = name_space
                                            self.tag.value_namespace_prefix = name_space_prefix


                                class Eigrp(Entity):
                                    """
                                    eigrp
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.int32, "tag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("instance_name",
                                                        "as_xx",
                                                        "bgp_preserve_default_info",
                                                        "bgp_preserve_med",
                                                        "classful",
                                                        "default_redistributed_route_metric",
                                                        "eigrp_route_type",
                                                        "isis_levels",
                                                        "metric_type",
                                                        "ospf_external",
                                                        "ospf_internal",
                                                        "ospf_nssa_level",
                                                        "ospf_redist_lsa_type",
                                                        "ospfnssa_only",
                                                        "route_policy_name",
                                                        "tag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.instance_name.is_set or
                                            self.as_xx.is_set or
                                            self.bgp_preserve_default_info.is_set or
                                            self.bgp_preserve_med.is_set or
                                            self.classful.is_set or
                                            self.default_redistributed_route_metric.is_set or
                                            self.eigrp_route_type.is_set or
                                            self.isis_levels.is_set or
                                            self.metric_type.is_set or
                                            self.ospf_external.is_set or
                                            self.ospf_internal.is_set or
                                            self.ospf_nssa_level.is_set or
                                            self.ospf_redist_lsa_type.is_set or
                                            self.ospfnssa_only.is_set or
                                            self.route_policy_name.is_set or
                                            self.tag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.instance_name.yfilter != YFilter.not_set or
                                            self.as_xx.yfilter != YFilter.not_set or
                                            self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                            self.bgp_preserve_med.yfilter != YFilter.not_set or
                                            self.classful.yfilter != YFilter.not_set or
                                            self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                            self.eigrp_route_type.yfilter != YFilter.not_set or
                                            self.isis_levels.yfilter != YFilter.not_set or
                                            self.metric_type.yfilter != YFilter.not_set or
                                            self.ospf_external.yfilter != YFilter.not_set or
                                            self.ospf_internal.yfilter != YFilter.not_set or
                                            self.ospf_nssa_level.yfilter != YFilter.not_set or
                                            self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                            self.ospfnssa_only.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set or
                                            self.tag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "eigrp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.instance_name.get_name_leafdata())
                                        if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.as_xx.get_name_leafdata())
                                        if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                        if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                        if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.classful.get_name_leafdata())
                                        if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                        if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                        if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                        if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.metric_type.get_name_leafdata())
                                        if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                        if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                        if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                        if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                        if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                        if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "instance-name" or name == "as-xx" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "instance-name"):
                                            self.instance_name = value
                                            self.instance_name.value_namespace = name_space
                                            self.instance_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "as-xx"):
                                            self.as_xx = value
                                            self.as_xx.value_namespace = name_space
                                            self.as_xx.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-default-info"):
                                            self.bgp_preserve_default_info = value
                                            self.bgp_preserve_default_info.value_namespace = name_space
                                            self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                        if(value_path == "bgp-preserve-med"):
                                            self.bgp_preserve_med = value
                                            self.bgp_preserve_med.value_namespace = name_space
                                            self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                        if(value_path == "classful"):
                                            self.classful = value
                                            self.classful.value_namespace = name_space
                                            self.classful.value_namespace_prefix = name_space_prefix
                                        if(value_path == "default-redistributed-route-metric"):
                                            self.default_redistributed_route_metric = value
                                            self.default_redistributed_route_metric.value_namespace = name_space
                                            self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eigrp-route-type"):
                                            self.eigrp_route_type = value
                                            self.eigrp_route_type.value_namespace = name_space
                                            self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "isis-levels"):
                                            self.isis_levels = value
                                            self.isis_levels.value_namespace = name_space
                                            self.isis_levels.value_namespace_prefix = name_space_prefix
                                        if(value_path == "metric-type"):
                                            self.metric_type = value
                                            self.metric_type.value_namespace = name_space
                                            self.metric_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-external"):
                                            self.ospf_external = value
                                            self.ospf_external.value_namespace = name_space
                                            self.ospf_external.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-internal"):
                                            self.ospf_internal = value
                                            self.ospf_internal.value_namespace = name_space
                                            self.ospf_internal.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-nssa-level"):
                                            self.ospf_nssa_level = value
                                            self.ospf_nssa_level.value_namespace = name_space
                                            self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospf-redist-lsa-type"):
                                            self.ospf_redist_lsa_type = value
                                            self.ospf_redist_lsa_type.value_namespace = name_space
                                            self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ospfnssa-only"):
                                            self.ospfnssa_only = value
                                            self.ospfnssa_only.value_namespace = name_space
                                            self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tag"):
                                            self.tag = value
                                            self.tag.value_namespace = name_space
                                            self.tag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.application_or_isis_or_ospf:
                                        if (c.has_data()):
                                            return True
                                    for c in self.bgp:
                                        if (c.has_data()):
                                            return True
                                    for c in self.eigrp:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.protocol_name.is_set or
                                        (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is not None))

                                def has_operation(self):
                                    for c in self.application_or_isis_or_ospf:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.bgp:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.eigrp:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.protocol_name.yfilter != YFilter.not_set or
                                        (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is not None and self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistribute" + "[protocol-name='" + self.protocol_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "application-or-isis-or-ospf"):
                                        for c in self.application_or_isis_or_ospf:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.application_or_isis_or_ospf.append(c)
                                        return c

                                    if (child_yang_name == "bgp"):
                                        for c in self.bgp:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.bgp.append(c)
                                        return c

                                    if (child_yang_name == "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"):
                                        if (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is None):
                                            self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip()
                                            self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip.parent = self
                                            self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                        return self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip

                                    if (child_yang_name == "eigrp"):
                                        for c in self.eigrp:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.eigrp.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "application-or-isis-or-ospf" or name == "bgp" or name == "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" or name == "eigrp" or name == "protocol-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "protocol-name"):
                                        self.protocol_name = value
                                        self.protocol_name.value_namespace = name_space
                                        self.protocol_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.redistribute:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.redistribute:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redistributes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "redistribute"):
                                    for c in self.redistribute:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.redistribute.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "redistribute"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (self.redistributes is not None and self.redistributes.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.redistributes is not None and self.redistributes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redistribution" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redistributes"):
                                if (self.redistributes is None):
                                    self.redistributes = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes()
                                    self.redistributes.parent = self
                                    self._children_name_map["redistributes"] = "redistributes"
                                return self.redistributes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redistributes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class AdjacencyStagger(Entity):
                        """
                        Staggering OSPF adjacency bring up
                        
                        .. attribute:: disable
                        
                        	Disable OSPF adjacency stagger
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: initial_nbr
                        
                        	Adjacency Stagger\: Initial number of neighbors to bring up per area
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 2
                        
                        .. attribute:: max_nbr
                        
                        	Adjacency Stagger\: Subsequent simultaneous number of neighbors to bring up
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 64
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger, self).__init__()

                            self.yang_name = "adjacency-stagger"
                            self.yang_parent_name = "vrf"

                            self.disable = YLeaf(YType.empty, "disable")

                            self.initial_nbr = YLeaf(YType.uint32, "initial-nbr")

                            self.max_nbr = YLeaf(YType.uint32, "max-nbr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("disable",
                                            "initial_nbr",
                                            "max_nbr") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.disable.is_set or
                                self.initial_nbr.is_set or
                                self.max_nbr.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.disable.yfilter != YFilter.not_set or
                                self.initial_nbr.yfilter != YFilter.not_set or
                                self.max_nbr.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "adjacency-stagger" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable.get_name_leafdata())
                            if (self.initial_nbr.is_set or self.initial_nbr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.initial_nbr.get_name_leafdata())
                            if (self.max_nbr.is_set or self.max_nbr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_nbr.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "disable" or name == "initial-nbr" or name == "max-nbr"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "disable"):
                                self.disable = value
                                self.disable.value_namespace = name_space
                                self.disable.value_namespace_prefix = name_space_prefix
                            if(value_path == "initial-nbr"):
                                self.initial_nbr = value
                                self.initial_nbr.value_namespace = name_space
                                self.initial_nbr.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-nbr"):
                                self.max_nbr = value
                                self.max_nbr.value_namespace = name_space
                                self.max_nbr.value_namespace_prefix = name_space_prefix


                    class MaxLsa(Entity):
                        """
                        Set max\-lsa configuration
                        
                        .. attribute:: max_lsa_ignore_count
                        
                        	Set count on how many times adjacencies can be suppressed
                        	**type**\:  int
                        
                        	**range:** 1..4294967294
                        
                        .. attribute:: max_lsa_ignore_time
                        
                        	Set time during which all adjacencies are suppressed
                        	**type**\:  int
                        
                        	**range:** 1..35791394
                        
                        .. attribute:: max_lsa_limit
                        
                        	Set maximum number of non self\-generated LSAs
                        	**type**\:  int
                        
                        	**range:** 1..4294967294
                        
                        	**mandatory**\: True
                        
                        .. attribute:: max_lsa_reset_time
                        
                        	Set number of minutes after which ignore\-count is reset to zero
                        	**type**\:  int
                        
                        	**range:** 2..71582788
                        
                        	**units**\: minute
                        
                        .. attribute:: max_lsa_threshold
                        
                        	Set max\-lsa threshold for generating a warning message
                        	**type**\:  int
                        
                        	**range:** 1..100
                        
                        .. attribute:: max_lsa_warning_only
                        
                        	Only give warning message when limit is exceeded
                        	**type**\:  bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxLsa, self).__init__()

                            self.yang_name = "max-lsa"
                            self.yang_parent_name = "vrf"
                            self.is_presence_container = True

                            self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                            self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                            self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                            self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                            self.max_lsa_threshold = YLeaf(YType.uint32, "max-lsa-threshold")

                            self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("max_lsa_ignore_count",
                                            "max_lsa_ignore_time",
                                            "max_lsa_limit",
                                            "max_lsa_reset_time",
                                            "max_lsa_threshold",
                                            "max_lsa_warning_only") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MaxLsa, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MaxLsa, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.max_lsa_ignore_count.is_set or
                                self.max_lsa_ignore_time.is_set or
                                self.max_lsa_limit.is_set or
                                self.max_lsa_reset_time.is_set or
                                self.max_lsa_threshold.is_set or
                                self.max_lsa_warning_only.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_count.yfilter != YFilter.not_set or
                                self.max_lsa_ignore_time.yfilter != YFilter.not_set or
                                self.max_lsa_limit.yfilter != YFilter.not_set or
                                self.max_lsa_reset_time.yfilter != YFilter.not_set or
                                self.max_lsa_threshold.yfilter != YFilter.not_set or
                                self.max_lsa_warning_only.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-lsa" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.max_lsa_ignore_count.is_set or self.max_lsa_ignore_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_count.get_name_leafdata())
                            if (self.max_lsa_ignore_time.is_set or self.max_lsa_ignore_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_ignore_time.get_name_leafdata())
                            if (self.max_lsa_limit.is_set or self.max_lsa_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_limit.get_name_leafdata())
                            if (self.max_lsa_reset_time.is_set or self.max_lsa_reset_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_reset_time.get_name_leafdata())
                            if (self.max_lsa_threshold.is_set or self.max_lsa_threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_threshold.get_name_leafdata())
                            if (self.max_lsa_warning_only.is_set or self.max_lsa_warning_only.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_lsa_warning_only.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "max-lsa-ignore-count" or name == "max-lsa-ignore-time" or name == "max-lsa-limit" or name == "max-lsa-reset-time" or name == "max-lsa-threshold" or name == "max-lsa-warning-only"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "max-lsa-ignore-count"):
                                self.max_lsa_ignore_count = value
                                self.max_lsa_ignore_count.value_namespace = name_space
                                self.max_lsa_ignore_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-ignore-time"):
                                self.max_lsa_ignore_time = value
                                self.max_lsa_ignore_time.value_namespace = name_space
                                self.max_lsa_ignore_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-limit"):
                                self.max_lsa_limit = value
                                self.max_lsa_limit.value_namespace = name_space
                                self.max_lsa_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-reset-time"):
                                self.max_lsa_reset_time = value
                                self.max_lsa_reset_time.value_namespace = name_space
                                self.max_lsa_reset_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-threshold"):
                                self.max_lsa_threshold = value
                                self.max_lsa_threshold.value_namespace = name_space
                                self.max_lsa_threshold.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-lsa-warning-only"):
                                self.max_lsa_warning_only = value
                                self.max_lsa_warning_only.value_namespace = name_space
                                self.max_lsa_warning_only.value_namespace_prefix = name_space_prefix


                    class AutoCost(Entity):
                        """
                        Controls automatic cost based on bandwidth
                        
                        .. attribute:: bandwidth
                        
                        	The reference bandwidth in terms of Mbits per second
                        	**type**\:  int
                        
                        	**range:** 1..4294967
                        
                        	**units**\: Mbit/s
                        
                        	**default value**\: 100
                        
                        .. attribute:: disable
                        
                        	Disabling auto costing
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AutoCost, self).__init__()

                            self.yang_name = "auto-cost"
                            self.yang_parent_name = "vrf"

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.disable = YLeaf(YType.boolean, "disable")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("bandwidth",
                                            "disable") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AutoCost, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AutoCost, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.bandwidth.is_set or
                                self.disable.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.bandwidth.yfilter != YFilter.not_set or
                                self.disable.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "auto-cost" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.bandwidth.get_name_leafdata())
                            if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disable.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "bandwidth" or name == "disable"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "bandwidth"):
                                self.bandwidth = value
                                self.bandwidth.value_namespace = name_space
                                self.bandwidth.value_namespace_prefix = name_space_prefix
                            if(value_path == "disable"):
                                self.disable = value
                                self.disable.value_namespace = name_space
                                self.disable.value_namespace_prefix = name_space_prefix


                    class Ucmp(Entity):
                        """
                        Unequal Cost Multi\-ptah configuration
                        
                        .. attribute:: delay_interval
                        
                        	Delay in msecs between primary SPF and UCMP computation
                        	**type**\:  int
                        
                        	**range:** 1..5000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 100
                        
                        .. attribute:: enable
                        
                        	UCMP feature enable configuration
                        	**type**\:   :py:class:`Enable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable>`
                        
                        .. attribute:: exclude_interfaces
                        
                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp, self).__init__()

                            self.yang_name = "ucmp"
                            self.yang_parent_name = "vrf"

                            self.delay_interval = YLeaf(YType.uint32, "delay-interval")

                            self.enable = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable()
                            self.enable.parent = self
                            self._children_name_map["enable"] = "enable"
                            self._children_yang_names.add("enable")

                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces()
                            self.exclude_interfaces.parent = self
                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                            self._children_yang_names.add("exclude-interfaces")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("delay_interval") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp, self).__setattr__(name, value)


                        class Enable(Entity):
                            """
                            UCMP feature enable configuration
                            
                            .. attribute:: prefix_list_name
                            
                            	Name of the Prefix List
                            	**type**\:  str
                            
                            .. attribute:: variance
                            
                            	Value of variance
                            	**type**\:  int
                            
                            	**range:** 101..10000
                            
                            	**default value**\: 200
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable, self).__init__()

                                self.yang_name = "enable"
                                self.yang_parent_name = "ucmp"

                                self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                                self.variance = YLeaf(YType.uint32, "variance")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix_list_name",
                                                "variance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.prefix_list_name.is_set or
                                    self.variance.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix_list_name.yfilter != YFilter.not_set or
                                    self.variance.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "enable" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix_list_name.is_set or self.prefix_list_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_list_name.get_name_leafdata())
                                if (self.variance.is_set or self.variance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.variance.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix-list-name" or name == "variance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix-list-name"):
                                    self.prefix_list_name = value
                                    self.prefix_list_name.value_namespace = name_space
                                    self.prefix_list_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "variance"):
                                    self.variance = value
                                    self.variance.value_namespace = name_space
                                    self.variance.value_namespace_prefix = name_space_prefix


                        class ExcludeInterfaces(Entity):
                            """
                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                            interface configuration
                            
                            .. attribute:: exclude_interface
                            
                            	Exclude an interface from becoming a backup or UCMP
                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces, self).__init__()

                                self.yang_name = "exclude-interfaces"
                                self.yang_parent_name = "ucmp"

                                self.exclude_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces, self).__setattr__(name, value)


                            class ExcludeInterface(Entity):
                                """
                                Exclude an interface from becoming a backup or
                                UCMP
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                    self.yang_name = "exclude-interface"
                                    self.yang_parent_name = "exclude-interfaces"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.interface_name.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interface-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.exclude_interface:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.exclude_interface:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "exclude-interfaces" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "exclude-interface"):
                                    for c in self.exclude_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.exclude_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "exclude-interface"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.delay_interval.is_set or
                                (self.enable is not None and self.enable.has_data()) or
                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.delay_interval.yfilter != YFilter.not_set or
                                (self.enable is not None and self.enable.has_operation()) or
                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ucmp" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.delay_interval.is_set or self.delay_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.delay_interval.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "enable"):
                                if (self.enable is None):
                                    self.enable = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable()
                                    self.enable.parent = self
                                    self._children_name_map["enable"] = "enable"
                                return self.enable

                            if (child_yang_name == "exclude-interfaces"):
                                if (self.exclude_interfaces is None):
                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                return self.exclude_interfaces

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "enable" or name == "exclude-interfaces" or name == "delay-interval"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "delay-interval"):
                                self.delay_interval = value
                                self.delay_interval.value_namespace = name_space
                                self.delay_interval.value_namespace_prefix = name_space_prefix


                    class FastReroute(Entity):
                        """
                        Fast\-reroute instance scoped parameters
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link global configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-prefix global configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "vrf"

                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink()
                            self.per_link.parent = self
                            self._children_name_map["per_link"] = "per-link"
                            self._children_yang_names.add("per-link")

                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._children_yang_names.add("per-prefix")


                        class PerLink(Entity):
                            """
                            Fast\-reroute per\-link global configuration
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink, self).__init__()

                                self.yang_name = "per-link"
                                self.yang_parent_name = "fast-reroute"

                                self.priority = YLeaf(YType.enumeration, "priority")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink, self).__setattr__(name, value)

                            def has_data(self):
                                return self.priority.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "per-link" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix


                        class PerPrefix(Entity):
                            """
                            Fast\-reroute per\-prefix global configuration
                            
                            .. attribute:: load_sharing_disable
                            
                            	Disable load sharing between multiple backups
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                            
                            .. attribute:: tiebreakers
                            
                            	Fast\-reroute tiebreakers configurations
                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"

                                self.load_sharing_disable = YLeaf(YType.empty, "load-sharing-disable")

                                self.priority = YLeaf(YType.enumeration, "priority")

                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers()
                                self.tiebreakers.parent = self
                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                self._children_yang_names.add("tiebreakers")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("load_sharing_disable",
                                                "priority") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix, self).__setattr__(name, value)


                            class Tiebreakers(Entity):
                                """
                                Fast\-reroute tiebreakers configurations
                                
                                .. attribute:: tiebreaker
                                
                                	Fast\-reroute tiebreakers configuration
                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                    self.yang_name = "tiebreakers"
                                    self.yang_parent_name = "per-prefix"

                                    self.tiebreaker = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                class Tiebreaker(Entity):
                                    """
                                    Fast\-reroute tiebreakers configuration
                                    
                                    .. attribute:: tiebreaker_type  <key>
                                    
                                    	Tiebreaker type
                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakers>`
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Index value for a tiebreaker, 0 to disable
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                        self.yang_name = "tiebreaker"
                                        self.yang_parent_name = "tiebreakers"

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("tiebreaker_type",
                                                        "tiebreaker_index") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.tiebreaker_type.is_set or
                                            self.tiebreaker_index.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.tiebreaker_type.yfilter != YFilter.not_set or
                                            self.tiebreaker_index.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "tiebreaker-type"):
                                            self.tiebreaker_type = value
                                            self.tiebreaker_type.value_namespace = name_space
                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "tiebreaker-index"):
                                            self.tiebreaker_index = value
                                            self.tiebreaker_index.value_namespace = name_space
                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.tiebreaker:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.tiebreaker:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tiebreakers" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "tiebreaker"):
                                        for c in self.tiebreaker:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tiebreaker.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tiebreaker"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.load_sharing_disable.is_set or
                                    self.priority.is_set or
                                    (self.tiebreakers is not None and self.tiebreakers.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.load_sharing_disable.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "per-prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.load_sharing_disable.is_set or self.load_sharing_disable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.load_sharing_disable.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "tiebreakers"):
                                    if (self.tiebreakers is None):
                                        self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers()
                                        self.tiebreakers.parent = self
                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                    return self.tiebreakers

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "tiebreakers" or name == "load-sharing-disable" or name == "priority"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "load-sharing-disable"):
                                    self.load_sharing_disable = value
                                    self.load_sharing_disable.value_namespace = name_space
                                    self.load_sharing_disable.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.per_link is not None and self.per_link.has_data()) or
                                (self.per_prefix is not None and self.per_prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.per_link is not None and self.per_link.has_operation()) or
                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "fast-reroute" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "per-link"):
                                if (self.per_link is None):
                                    self.per_link = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                return self.per_link

                            if (child_yang_name == "per-prefix"):
                                if (self.per_prefix is None):
                                    self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                return self.per_prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "per-link" or name == "per-prefix"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class SummaryPrefixes(Entity):
                        """
                        Configure IP prefix summary
                        
                        .. attribute:: netmask
                        
                        	keys\: netmask
                        	**type**\: list of    :py:class:`Netmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask>`
                        
                        .. attribute:: prefix
                        
                        	keys\: prefix
                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix>`
                        
                        .. attribute:: prefix_and_netmask
                        
                        	keys\: prefix, netmask
                        	**type**\: list of    :py:class:`PrefixAndNetmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask>`
                        
                        .. attribute:: summary_prefix_data
                        
                        	Data container
                        	**type**\:   :py:class:`SummaryPrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"

                            self.summary_prefix_data = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData()
                            self.summary_prefix_data.parent = self
                            self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                            self._children_yang_names.add("summary-prefix-data")

                            self.netmask = YList(self)
                            self.prefix = YList(self)
                            self.prefix_and_netmask = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__setattr__(name, value)


                        class SummaryPrefixData(Entity):
                            """
                            Data container.
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData, self).__init__()

                                self.yang_name = "summary-prefix-data"
                                self.yang_parent_name = "summary-prefixes"

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.int32, "tag")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("not_advertise",
                                                "tag") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.not_advertise.is_set or
                                    self.tag.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.not_advertise.yfilter != YFilter.not_set or
                                    self.tag.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "summary-prefix-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_advertise.get_name_leafdata())
                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "not-advertise" or name == "tag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "not-advertise"):
                                    self.not_advertise = value
                                    self.not_advertise.value_namespace = name_space
                                    self.not_advertise.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag"):
                                    self.tag = value
                                    self.tag.value_namespace = name_space
                                    self.tag.value_namespace_prefix = name_space_prefix


                        class PrefixAndNetmask(Entity):
                            """
                            keys\: prefix, netmask
                            
                            .. attribute:: prefix  <key>
                            
                            	IP summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: netmask  <key>
                            
                            	Summary netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask, self).__init__()

                                self.yang_name = "prefix-and-netmask"
                                self.yang_parent_name = "summary-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.int32, "tag")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "netmask",
                                                "not_advertise",
                                                "tag") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.netmask.is_set or
                                    self.not_advertise.is_set or
                                    self.tag.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.netmask.yfilter != YFilter.not_set or
                                    self.not_advertise.yfilter != YFilter.not_set or
                                    self.tag.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix-and-netmask" + "[prefix='" + self.prefix.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.netmask.get_name_leafdata())
                                if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_advertise.get_name_leafdata())
                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "netmask" or name == "not-advertise" or name == "tag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "netmask"):
                                    self.netmask = value
                                    self.netmask.value_namespace = name_space
                                    self.netmask.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-advertise"):
                                    self.not_advertise = value
                                    self.not_advertise.value_namespace = name_space
                                    self.not_advertise.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag"):
                                    self.tag = value
                                    self.tag.value_namespace = name_space
                                    self.tag.value_namespace_prefix = name_space_prefix


                        class Prefix(Entity):
                            """
                            keys\: prefix
                            
                            .. attribute:: prefix  <key>
                            
                            	IP summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "summary-prefixes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.int32, "tag")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "not_advertise",
                                                "tag") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.prefix.is_set or
                                    self.not_advertise.is_set or
                                    self.tag.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.not_advertise.yfilter != YFilter.not_set or
                                    self.tag.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "prefix" + "[prefix='" + self.prefix.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_advertise.get_name_leafdata())
                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "prefix" or name == "not-advertise" or name == "tag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-advertise"):
                                    self.not_advertise = value
                                    self.not_advertise.value_namespace = name_space
                                    self.not_advertise.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag"):
                                    self.tag = value
                                    self.tag.value_namespace = name_space
                                    self.tag.value_namespace_prefix = name_space_prefix


                        class Netmask(Entity):
                            """
                            keys\: netmask
                            
                            .. attribute:: netmask  <key>
                            
                            	Summary netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask, self).__init__()

                                self.yang_name = "netmask"
                                self.yang_parent_name = "summary-prefixes"

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.int32, "tag")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("netmask",
                                                "not_advertise",
                                                "tag") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.netmask.is_set or
                                    self.not_advertise.is_set or
                                    self.tag.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.netmask.yfilter != YFilter.not_set or
                                    self.not_advertise.yfilter != YFilter.not_set or
                                    self.tag.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "netmask" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.netmask.get_name_leafdata())
                                if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.not_advertise.get_name_leafdata())
                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tag.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "netmask" or name == "not-advertise" or name == "tag"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "netmask"):
                                    self.netmask = value
                                    self.netmask.value_namespace = name_space
                                    self.netmask.value_namespace_prefix = name_space_prefix
                                if(value_path == "not-advertise"):
                                    self.not_advertise = value
                                    self.not_advertise.value_namespace = name_space
                                    self.not_advertise.value_namespace_prefix = name_space_prefix
                                if(value_path == "tag"):
                                    self.tag = value
                                    self.tag.value_namespace = name_space
                                    self.tag.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.netmask:
                                if (c.has_data()):
                                    return True
                            for c in self.prefix:
                                if (c.has_data()):
                                    return True
                            for c in self.prefix_and_netmask:
                                if (c.has_data()):
                                    return True
                            return (self.summary_prefix_data is not None and self.summary_prefix_data.has_data())

                        def has_operation(self):
                            for c in self.netmask:
                                if (c.has_operation()):
                                    return True
                            for c in self.prefix:
                                if (c.has_operation()):
                                    return True
                            for c in self.prefix_and_netmask:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.summary_prefix_data is not None and self.summary_prefix_data.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary-prefixes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "netmask"):
                                for c in self.netmask:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.netmask.append(c)
                                return c

                            if (child_yang_name == "prefix"):
                                for c in self.prefix:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.prefix.append(c)
                                return c

                            if (child_yang_name == "prefix-and-netmask"):
                                for c in self.prefix_and_netmask:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.prefix_and_netmask.append(c)
                                return c

                            if (child_yang_name == "summary-prefix-data"):
                                if (self.summary_prefix_data is None):
                                    self.summary_prefix_data = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData()
                                    self.summary_prefix_data.parent = self
                                    self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                                return self.summary_prefix_data

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "netmask" or name == "prefix" or name == "prefix-and-netmask" or name == "summary-prefix-data"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class OutgoingRouteUpdates(Entity):
                        """
                        Filter outgoing routing updates
                        
                        .. attribute:: outgoing_route_update
                        
                        	Filter outgoing routing updates for a particular protocol
                        	**type**\: list of    :py:class:`OutgoingRouteUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates, self).__init__()

                            self.yang_name = "outgoing-route-updates"
                            self.yang_parent_name = "vrf"

                            self.outgoing_route_update = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates, self).__setattr__(name, value)


                        class OutgoingRouteUpdate(Entity):
                            """
                            Filter outgoing routing updates for a
                            particular protocol
                            
                            .. attribute:: protocol_name  <key>
                            
                            	Distribute list protocol type
                            	**type**\:   :py:class:`OspfDistListProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDistListProtocol>`
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: as_xx
                            
                            	First half of BGP AS number in XX.YY format.  Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_yy
                            
                            	Second half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_process_name
                            
                            	OSPF process name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__init__()

                                self.yang_name = "outgoing-route-update"
                                self.yang_parent_name = "outgoing-route-updates"

                                self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                self.as_yy = YLeaf(YType.uint32, "as-yy")

                                self.ospf_process_name = YLeaf(YType.str, "ospf-process-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("protocol_name",
                                                "access_list_name",
                                                "as_xx",
                                                "as_yy",
                                                "ospf_process_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.protocol_name.is_set or
                                    self.access_list_name.is_set or
                                    self.as_xx.is_set or
                                    self.as_yy.is_set or
                                    self.ospf_process_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.protocol_name.yfilter != YFilter.not_set or
                                    self.access_list_name.yfilter != YFilter.not_set or
                                    self.as_xx.yfilter != YFilter.not_set or
                                    self.as_yy.yfilter != YFilter.not_set or
                                    self.ospf_process_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "outgoing-route-update" + "[protocol-name='" + self.protocol_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())
                                if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_xx.get_name_leafdata())
                                if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.as_yy.get_name_leafdata())
                                if (self.ospf_process_name.is_set or self.ospf_process_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ospf_process_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "protocol-name" or name == "access-list-name" or name == "as-xx" or name == "as-yy" or name == "ospf-process-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "protocol-name"):
                                    self.protocol_name = value
                                    self.protocol_name.value_namespace = name_space
                                    self.protocol_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "access-list-name"):
                                    self.access_list_name = value
                                    self.access_list_name.value_namespace = name_space
                                    self.access_list_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-xx"):
                                    self.as_xx = value
                                    self.as_xx.value_namespace = name_space
                                    self.as_xx.value_namespace_prefix = name_space_prefix
                                if(value_path == "as-yy"):
                                    self.as_yy = value
                                    self.as_yy.value_namespace = name_space
                                    self.as_yy.value_namespace_prefix = name_space_prefix
                                if(value_path == "ospf-process-name"):
                                    self.ospf_process_name = value
                                    self.ospf_process_name.value_namespace = name_space
                                    self.ospf_process_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.outgoing_route_update:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.outgoing_route_update:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-route-updates" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "outgoing-route-update"):
                                for c in self.outgoing_route_update:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.outgoing_route_update.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "outgoing-route-update"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Distance(Entity):
                        """
                        Administrative distance configuration
                        
                        .. attribute:: admin_distance
                        
                        	Define an administrative distance
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: ip_distances
                        
                        	IP specific administrative distance configuration
                        	**type**\:   :py:class:`IpDistances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances>`
                        
                        .. attribute:: ospf_distance
                        
                        	OSPF distance configuration
                        	**type**\:   :py:class:`OspfDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "vrf"

                            self.admin_distance = YLeaf(YType.uint32, "admin-distance")

                            self.ip_distances = Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances()
                            self.ip_distances.parent = self
                            self._children_name_map["ip_distances"] = "ip-distances"
                            self._children_yang_names.add("ip-distances")

                            self.ospf_distance = Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance()
                            self.ospf_distance.parent = self
                            self._children_name_map["ospf_distance"] = "ospf-distance"
                            self._children_yang_names.add("ospf-distance")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("admin_distance") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Distance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Distance, self).__setattr__(name, value)


                        class OspfDistance(Entity):
                            """
                            OSPF distance configuration
                            
                            .. attribute:: external_routes
                            
                            	Distance for external type 5 and type 7 routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            .. attribute:: inter_area
                            
                            	Distance for inter\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            .. attribute:: intra_area
                            
                            	Distance for intra\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance, self).__init__()

                                self.yang_name = "ospf-distance"
                                self.yang_parent_name = "distance"

                                self.external_routes = YLeaf(YType.uint32, "external-routes")

                                self.inter_area = YLeaf(YType.uint32, "inter-area")

                                self.intra_area = YLeaf(YType.uint32, "intra-area")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("external_routes",
                                                "inter_area",
                                                "intra_area") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.external_routes.is_set or
                                    self.inter_area.is_set or
                                    self.intra_area.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.external_routes.yfilter != YFilter.not_set or
                                    self.inter_area.yfilter != YFilter.not_set or
                                    self.intra_area.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ospf-distance" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.external_routes.is_set or self.external_routes.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_routes.get_name_leafdata())
                                if (self.inter_area.is_set or self.inter_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.inter_area.get_name_leafdata())
                                if (self.intra_area.is_set or self.intra_area.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.intra_area.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "external-routes" or name == "inter-area" or name == "intra-area"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "external-routes"):
                                    self.external_routes = value
                                    self.external_routes.value_namespace = name_space
                                    self.external_routes.value_namespace_prefix = name_space_prefix
                                if(value_path == "inter-area"):
                                    self.inter_area = value
                                    self.inter_area.value_namespace = name_space
                                    self.inter_area.value_namespace_prefix = name_space_prefix
                                if(value_path == "intra-area"):
                                    self.intra_area = value
                                    self.intra_area.value_namespace = name_space
                                    self.intra_area.value_namespace_prefix = name_space_prefix


                        class IpDistances(Entity):
                            """
                            IP specific administrative distance
                            configuration
                            
                            .. attribute:: ip_distance
                            
                            	Administrative distance configuration for a particular IP address
                            	**type**\: list of    :py:class:`IpDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances, self).__init__()

                                self.yang_name = "ip-distances"
                                self.yang_parent_name = "distance"

                                self.ip_distance = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances, self).__setattr__(name, value)


                            class IpDistance(Entity):
                                """
                                Administrative distance configuration for a
                                particular IP address
                                
                                .. attribute:: address  <key>
                                
                                	IP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard  <key>
                                
                                	IP wild card bits \-\- inverted mask
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: distance
                                
                                	Administrative distance
                                	**type**\:  int
                                
                                	**range:** 1..255
                                
                                	**default value**\: 110
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance, self).__init__()

                                    self.yang_name = "ip-distance"
                                    self.yang_parent_name = "ip-distances"

                                    self.address = YLeaf(YType.str, "address")

                                    self.wildcard = YLeaf(YType.str, "wildcard")

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.distance = YLeaf(YType.uint32, "distance")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "wildcard",
                                                    "access_list_name",
                                                    "distance") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.wildcard.is_set or
                                        self.access_list_name.is_set or
                                        self.distance.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.wildcard.yfilter != YFilter.not_set or
                                        self.access_list_name.yfilter != YFilter.not_set or
                                        self.distance.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ip-distance" + "[address='" + self.address.get() + "']" + "[wildcard='" + self.wildcard.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.wildcard.get_name_leafdata())
                                    if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                    if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.distance.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "wildcard" or name == "access-list-name" or name == "distance"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "wildcard"):
                                        self.wildcard = value
                                        self.wildcard.value_namespace = name_space
                                        self.wildcard.value_namespace_prefix = name_space_prefix
                                    if(value_path == "access-list-name"):
                                        self.access_list_name = value
                                        self.access_list_name.value_namespace = name_space
                                        self.access_list_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "distance"):
                                        self.distance = value
                                        self.distance.value_namespace = name_space
                                        self.distance.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.ip_distance:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.ip_distance:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ip-distances" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ip-distance"):
                                    for c in self.ip_distance:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.ip_distance.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ip-distance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.admin_distance.is_set or
                                (self.ip_distances is not None and self.ip_distances.has_data()) or
                                (self.ospf_distance is not None and self.ospf_distance.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.admin_distance.yfilter != YFilter.not_set or
                                (self.ip_distances is not None and self.ip_distances.has_operation()) or
                                (self.ospf_distance is not None and self.ospf_distance.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "distance" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.admin_distance.is_set or self.admin_distance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.admin_distance.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ip-distances"):
                                if (self.ip_distances is None):
                                    self.ip_distances = Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances()
                                    self.ip_distances.parent = self
                                    self._children_name_map["ip_distances"] = "ip-distances"
                                return self.ip_distances

                            if (child_yang_name == "ospf-distance"):
                                if (self.ospf_distance is None):
                                    self.ospf_distance = Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance()
                                    self.ospf_distance.parent = self
                                    self._children_name_map["ospf_distance"] = "ospf-distance"
                                return self.ospf_distance

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-distances" or name == "ospf-distance" or name == "admin-distance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "admin-distance"):
                                self.admin_distance = value
                                self.admin_distance.value_namespace = name_space
                                self.admin_distance.value_namespace_prefix = name_space_prefix


                    class AreaAddresses(Entity):
                        """
                        Area configuration
                        
                        .. attribute:: area_address
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress>`
                        
                        .. attribute:: area_area_id
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses, self).__init__()

                            self.yang_name = "area-addresses"
                            self.yang_parent_name = "vrf"

                            self.area_address = YList(self)
                            self.area_area_id = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses, self).__setattr__(name, value)


                        class AreaAddress(Entity):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: address  <key>
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_ranges
                            
                            	Summarize routes matching address/mask (border routers only)
                            	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges>`
                            
                            .. attribute:: area_scope
                            
                            	Area scope configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            	**default value**\: 1
                            
                            .. attribute:: external_out
                            
                            	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                            	**type**\:  bool
                            
                            .. attribute:: mpls_traffic_eng
                            
                            	Configure an OSPF area to run MPLS Traffic Engineering
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: multi_area_interface_scopes
                            
                            	Multi Area Interface scope configurations
                            	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes>`
                            
                            .. attribute:: name_scopes
                            
                            	Name scope configurations
                            	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa>`
                            
                            .. attribute:: route_policy_in
                            
                            	Configure a route policy for inbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out
                            
                            	Configure a route policy for outbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: running
                            
                            	Enable routing on an IP network
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment_routing
                            
                            	segment\-routing configuration Applicable only in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                            
                            .. attribute:: sham_link_scopes
                            
                            	Sham Link scope configurations
                            	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes>`
                            
                            .. attribute:: stub
                            
                            	Specify the area as a stub area (send summary LSA stub area)
                            	**type**\:  bool
                            
                            .. attribute:: summary_in
                            
                            	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_scopes
                            
                            	Virtual Link scope configurations
                            	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress, self).__init__()

                                self.yang_name = "area-address"
                                self.yang_parent_name = "area-addresses"

                                self.address = YLeaf(YType.str, "address")

                                self.default_cost = YLeaf(YType.uint32, "default-cost")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                self.running = YLeaf(YType.empty, "running")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.stub = YLeaf(YType.boolean, "stub")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges()
                                self.area_ranges.parent = self
                                self._children_name_map["area_ranges"] = "area-ranges"
                                self._children_yang_names.add("area-ranges")

                                self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope()
                                self.area_scope.parent = self
                                self._children_name_map["area_scope"] = "area-scope"
                                self._children_yang_names.add("area-scope")

                                self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                                self.multi_area_interface_scopes.parent = self
                                self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                self._children_yang_names.add("multi-area-interface-scopes")

                                self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes()
                                self.name_scopes.parent = self
                                self._children_name_map["name_scopes"] = "name-scopes"
                                self._children_yang_names.add("name-scopes")

                                self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa()
                                self.nssa.parent = self
                                self._children_name_map["nssa"] = "nssa"
                                self._children_yang_names.add("nssa")

                                self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                                self.sham_link_scopes.parent = self
                                self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                self._children_yang_names.add("sham-link-scopes")

                                self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                                self.virtual_link_scopes.parent = self
                                self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                self._children_yang_names.add("virtual-link-scopes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "default_cost",
                                                "external_out",
                                                "mpls_traffic_eng",
                                                "route_policy_in",
                                                "route_policy_out",
                                                "running",
                                                "segment_routing",
                                                "stub",
                                                "summary_in") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress, self).__setattr__(name, value)


                            class VirtualLinkScopes(Entity):
                                """
                                Virtual Link scope configurations
                                
                                .. attribute:: virtual_link_scope
                                
                                	Virtual Link configuration
                                	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__init__()

                                    self.yang_name = "virtual-link-scopes"
                                    self.yang_parent_name = "area-address"

                                    self.virtual_link_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__setattr__(name, value)


                                class VirtualLinkScope(Entity):
                                    """
                                    Virtual Link configuration
                                    
                                    .. attribute:: address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                        self.yang_name = "virtual-link-scope"
                                        self.yang_parent_name = "virtual-link-scopes"

                                        self.address = YLeaf(YType.str, "address")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "hello_interval",
                                                        "retransmit_interval",
                                                        "running",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "virtual-link-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "virtual-link-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.hello_interval.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "virtual-link-scope" + "[address='" + self.address.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "dead-interval-minimal" or name == "address" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.virtual_link_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.virtual_link_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "virtual-link-scope"):
                                        for c in self.virtual_link_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.virtual_link_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "virtual-link-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class ShamLinkScopes(Entity):
                                """
                                Sham Link scope configurations
                                
                                .. attribute:: sham_link_scope
                                
                                	Sham Link configuration
                                	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__init__()

                                    self.yang_name = "sham-link-scopes"
                                    self.yang_parent_name = "area-address"

                                    self.sham_link_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__setattr__(name, value)


                                class ShamLinkScope(Entity):
                                    """
                                    Sham Link configuration
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Address of the local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Address of the remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: source
                                    
                                    	Address of the local sham\-link endpoint. Enter an IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__init__()

                                        self.yang_name = "sham-link-scope"
                                        self.yang_parent_name = "sham-link-scopes"

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.source = YLeaf(YType.str, "source")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("source_address",
                                                        "destination_address",
                                                        "cost",
                                                        "hello_interval",
                                                        "retransmit_interval",
                                                        "running",
                                                        "source",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "sham-link-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "sham-link-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.source_address.is_set or
                                            self.destination_address.is_set or
                                            self.cost.is_set or
                                            self.hello_interval.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.source.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.destination_address.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.source.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "dead-interval-minimal" or name == "source-address" or name == "destination-address" or name == "cost" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "source" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "destination-address"):
                                            self.destination_address = value
                                            self.destination_address.value_namespace = name_space
                                            self.destination_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source"):
                                            self.source = value
                                            self.source.value_namespace = name_space
                                            self.source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sham_link_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sham_link_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sham-link-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sham-link-scope"):
                                        for c in self.sham_link_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sham_link_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sham-link-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AreaScope(Entity):
                                """
                                Area scope configuration
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope, self).__init__()

                                    self.yang_name = "area-scope"
                                    self.yang_parent_name = "area-address"

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("cost",
                                                    "database_filter",
                                                    "demand_circuit",
                                                    "flood_reduction",
                                                    "hello_interval",
                                                    "ldp_auto_config",
                                                    "ldp_sync",
                                                    "ldp_sync_igp_shortcuts",
                                                    "link_down_fast_detect",
                                                    "loopback_stub_network",
                                                    "mtu_ignore",
                                                    "network_type",
                                                    "packet_size",
                                                    "passive",
                                                    "prefix_suppression_primary",
                                                    "prefix_suppression_secondary",
                                                    "priority",
                                                    "retransmit_interval",
                                                    "segment_routing_forwarding",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope, self).__setattr__(name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "area-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "area-scope"

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("detection_multiplier",
                                                        "fast_detect_mode",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.detection_multiplier.is_set or
                                            self.fast_detect_mode.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.fast_detect_mode.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-mode"):
                                            self.fast_detect_mode = value
                                            self.fast_detect_mode.value_namespace = name_space
                                            self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "area-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "area-scope"

                                        self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("enable",
                                                            "hop_count") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.enable.is_set or
                                                self.hop_count.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.enable.yfilter != YFilter.not_set or
                                                self.hop_count.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ttl" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.enable.get_name_leafdata())
                                            if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.hop_count.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "enable" or name == "hop-count"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "enable"):
                                                self.enable = value
                                                self.enable.value_namespace = name_space
                                                self.enable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "hop-count"):
                                                self.hop_count = value
                                                self.hop_count.value_namespace = name_space
                                                self.hop_count.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (self.ttl is not None and self.ttl.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.ttl is not None and self.ttl.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ttl"):
                                            if (self.ttl is None):
                                                self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                                self.ttl.parent = self
                                                self._children_name_map["ttl"] = "ttl"
                                            return self.ttl

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "area-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "area-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "area-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.demand_circuit.is_set or
                                        self.flood_reduction.is_set or
                                        self.hello_interval.is_set or
                                        self.ldp_auto_config.is_set or
                                        self.ldp_sync.is_set or
                                        self.ldp_sync_igp_shortcuts.is_set or
                                        self.link_down_fast_detect.is_set or
                                        self.loopback_stub_network.is_set or
                                        self.mtu_ignore.is_set or
                                        self.network_type.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.prefix_suppression_primary.is_set or
                                        self.prefix_suppression_secondary.is_set or
                                        self.priority.is_set or
                                        self.retransmit_interval.is_set or
                                        self.segment_routing_forwarding.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.bfd is not None and self.bfd.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.security is not None and self.security.has_data()) or
                                        (self.distribute_list is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.demand_circuit.yfilter != YFilter.not_set or
                                        self.flood_reduction.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.ldp_auto_config.yfilter != YFilter.not_set or
                                        self.ldp_sync.yfilter != YFilter.not_set or
                                        self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.link_down_fast_detect.yfilter != YFilter.not_set or
                                        self.loopback_stub_network.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                        self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                        self.priority.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.bfd is not None and self.bfd.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.security is not None and self.security.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-scope" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                    if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                    if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                    if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                    if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                    if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "bfd"):
                                        if (self.bfd is None):
                                            self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                            self.bfd.parent = self
                                            self._children_name_map["bfd"] = "bfd"
                                        return self.bfd

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "security"):
                                        if (self.security is None):
                                            self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                            self.security.parent = self
                                            self._children_name_map["security"] = "security"
                                        return self.security

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "demand-circuit"):
                                        self.demand_circuit = value
                                        self.demand_circuit.value_namespace = name_space
                                        self.demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-reduction"):
                                        self.flood_reduction = value
                                        self.flood_reduction.value_namespace = name_space
                                        self.flood_reduction.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-auto-config"):
                                        self.ldp_auto_config = value
                                        self.ldp_auto_config.value_namespace = name_space
                                        self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync"):
                                        self.ldp_sync = value
                                        self.ldp_sync.value_namespace = name_space
                                        self.ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync-igp-shortcuts"):
                                        self.ldp_sync_igp_shortcuts = value
                                        self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-down-fast-detect"):
                                        self.link_down_fast_detect = value
                                        self.link_down_fast_detect.value_namespace = name_space
                                        self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "loopback-stub-network"):
                                        self.loopback_stub_network = value
                                        self.loopback_stub_network.value_namespace = name_space
                                        self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-primary"):
                                        self.prefix_suppression_primary = value
                                        self.prefix_suppression_primary.value_namespace = name_space
                                        self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-secondary"):
                                        self.prefix_suppression_secondary = value
                                        self.prefix_suppression_secondary.value_namespace = name_space
                                        self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority"):
                                        self.priority = value
                                        self.priority.value_namespace = name_space
                                        self.priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segment-routing-forwarding"):
                                        self.segment_routing_forwarding = value
                                        self.segment_routing_forwarding.value_namespace = name_space
                                        self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix


                            class NameScopes(Entity):
                                """
                                Name scope configurations
                                
                                .. attribute:: name_scope
                                
                                	Name scope configuration
                                	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes, self).__init__()

                                    self.yang_name = "name-scopes"
                                    self.yang_parent_name = "area-address"

                                    self.name_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes, self).__setattr__(name, value)


                                class NameScope(Entity):
                                    """
                                    Name scope configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	BFD configuration
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/Disable OSPF demand circuit
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/Disable OSPF flood reduction
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ldp_auto_config
                                    
                                    	Enable MPLS LDP Auto Config
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_sync_igp_shortcuts
                                    
                                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: link_down_fast_detect
                                    
                                    	Enable/Disable registration for early interface down notifications
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: loopback_stub_network
                                    
                                    	Enable/Disable advertising loopback as a stub network
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors>`
                                    
                                    .. attribute:: network_type
                                    
                                    	Type of attached network
                                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_sid
                                    
                                    	Prefix SID
                                    	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_sid_strict
                                    
                                    	Strict Prefix SID
                                    	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_suppression_primary
                                    
                                    	Enable/Disable prefix suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_suppression_secondary
                                    
                                    	Enable/Disable prefix suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: priority
                                    
                                    	Router priority for DR and BDR election
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 1
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: security
                                    
                                    	Container class for security related configuration parameters
                                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security>`
                                    
                                    .. attribute:: segment_routing_forwarding
                                    
                                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__init__()

                                        self.yang_name = "name-scope"
                                        self.yang_parent_name = "name-scopes"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                        self.priority = YLeaf(YType.uint32, "priority")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                        self._children_yang_names.add("bfd")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                        self.prefix_sid = None
                                        self._children_name_map["prefix_sid"] = "prefix-sid"
                                        self._children_yang_names.add("prefix-sid")

                                        self.prefix_sid_strict = None
                                        self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        self._children_yang_names.add("prefix-sid-strict")

                                        self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                        self._children_yang_names.add("security")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "cost",
                                                        "database_filter",
                                                        "demand_circuit",
                                                        "flood_reduction",
                                                        "hello_interval",
                                                        "ldp_auto_config",
                                                        "ldp_sync",
                                                        "ldp_sync_igp_shortcuts",
                                                        "link_down_fast_detect",
                                                        "loopback_stub_network",
                                                        "mtu_ignore",
                                                        "network_type",
                                                        "packet_size",
                                                        "passive",
                                                        "prefix_suppression_primary",
                                                        "prefix_suppression_secondary",
                                                        "priority",
                                                        "retransmit_interval",
                                                        "running",
                                                        "segment_routing_forwarding",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__setattr__(name, value)


                                    class PrefixSid(Entity):
                                        """
                                        Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__init__()

                                            self.yang_name = "prefix-sid"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_null",
                                                            "n_flag_clear",
                                                            "sid_value",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_null.is_set or
                                                self.n_flag_clear.is_set or
                                                self.sid_value.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_null.yfilter != YFilter.not_set or
                                                self.n_flag_clear.yfilter != YFilter.not_set or
                                                self.sid_value.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "prefix-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                            if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                            if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sid_value.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-null"):
                                                self.explicit_null = value
                                                self.explicit_null.value_namespace = name_space
                                                self.explicit_null.value_namespace_prefix = name_space_prefix
                                            if(value_path == "n-flag-clear"):
                                                self.n_flag_clear = value
                                                self.n_flag_clear.value_namespace = name_space
                                                self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sid-value"):
                                                self.sid_value = value
                                                self.sid_value.value_namespace = name_space
                                                self.sid_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class PrefixSidStrict(Entity):
                                        """
                                        Strict Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                            self.yang_name = "prefix-sid-strict"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_null",
                                                            "n_flag_clear",
                                                            "sid_value",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_null.is_set or
                                                self.n_flag_clear.is_set or
                                                self.sid_value.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_null.yfilter != YFilter.not_set or
                                                self.n_flag_clear.yfilter != YFilter.not_set or
                                                self.sid_value.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "prefix-sid-strict" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                            if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                            if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sid_value.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-null"):
                                                self.explicit_null = value
                                                self.explicit_null.value_namespace = name_space
                                                self.explicit_null.value_namespace_prefix = name_space_prefix
                                            if(value_path == "n-flag-clear"):
                                                self.n_flag_clear = value
                                                self.n_flag_clear.value_namespace = name_space
                                                self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sid-value"):
                                                self.sid_value = value
                                                self.sid_value.value_namespace = name_space
                                                self.sid_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("access_list_name",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.access_list_name.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.access_list_name.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "distribute-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "access-list-name" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "access-list-name"):
                                                self.access_list_name = value
                                                self.access_list_name.value_namespace = name_space
                                                self.access_list_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class Bfd(Entity):
                                        """
                                        BFD configuration
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detection multiplier for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	 use of Bidirectional Forwarding Detection
                                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__init__()

                                            self.yang_name = "bfd"
                                            self.yang_parent_name = "name-scope"

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("detection_multiplier",
                                                            "fast_detect_mode",
                                                            "interval") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.detection_multiplier.is_set or
                                                self.fast_detect_mode.is_set or
                                                self.interval.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.detection_multiplier.yfilter != YFilter.not_set or
                                                self.fast_detect_mode.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bfd" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                            if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "detection-multiplier"):
                                                self.detection_multiplier = value
                                                self.detection_multiplier.value_namespace = name_space
                                                self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fast-detect-mode"):
                                                self.fast_detect_mode = value
                                                self.fast_detect_mode.value_namespace = name_space
                                                self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "name-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class Security(Entity):
                                        """
                                        Container class for security related
                                        configuration parameters
                                        
                                        .. attribute:: ttl
                                        
                                        	Enabling turns on TTL security
                                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security, self).__init__()

                                            self.yang_name = "security"
                                            self.yang_parent_name = "name-scope"

                                            self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                            self._children_yang_names.add("ttl")


                                        class Ttl(Entity):
                                            """
                                            Enabling turns on TTL security
                                            
                                            .. attribute:: enable
                                            
                                            	Enable TTL security
                                            	**type**\:  bool
                                            
                                            .. attribute:: hop_count
                                            
                                            	Hop count
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__init__()

                                                self.yang_name = "ttl"
                                                self.yang_parent_name = "security"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.hop_count = YLeaf(YType.uint32, "hop-count")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "hop_count") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.hop_count.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.hop_count.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ttl" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.hop_count.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "hop-count"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "hop-count"):
                                                    self.hop_count = value
                                                    self.hop_count.value_namespace = name_space
                                                    self.hop_count.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (self.ttl is not None and self.ttl.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.ttl is not None and self.ttl.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "security" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ttl"):
                                                if (self.ttl is None):
                                                    self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                                    self.ttl.parent = self
                                                    self._children_name_map["ttl"] = "ttl"
                                                return self.ttl

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ttl"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "name-scope"

                                            self.neighbor = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("neighbor_address",
                                                                "cost",
                                                                "database_filter",
                                                                "poll_interval",
                                                                "priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.neighbor_address.is_set or
                                                    self.cost.is_set or
                                                    self.database_filter.is_set or
                                                    self.poll_interval.is_set or
                                                    self.priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.cost.yfilter != YFilter.not_set or
                                                    self.database_filter.yfilter != YFilter.not_set or
                                                    self.poll_interval.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                                if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost"):
                                                    self.cost = value
                                                    self.cost.value_namespace = name_space
                                                    self.cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "database-filter"):
                                                    self.database_filter = value
                                                    self.database_filter.value_namespace = name_space
                                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                                if(value_path == "poll-interval"):
                                                    self.poll_interval = value
                                                    self.poll_interval.value_namespace = name_space
                                                    self.poll_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.neighbor:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.neighbor:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbors" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor"):
                                                for c in self.neighbor:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.neighbor.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "name-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "name-scope"

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_enable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only",
                                                                "topology_independent_lfa") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("maximum_cost",
                                                                    "tunnel") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.maximum_cost.is_set or
                                                        self.tunnel.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.maximum_cost.yfilter != YFilter.not_set or
                                                        self.tunnel.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-lfa" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                    if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "maximum-cost" or name == "tunnel"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "maximum-cost"):
                                                        self.maximum_cost = value
                                                        self.maximum_cost.value_namespace = name_space
                                                        self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel"):
                                                        self.tunnel = value
                                                        self.tunnel.value_namespace = name_space
                                                        self.tunnel.value_namespace_prefix = name_space_prefix


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.tiebreaker = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("tiebreaker_type",
                                                                        "tiebreaker_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.tiebreaker_type.is_set or
                                                            self.tiebreaker_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.tiebreaker_type.yfilter != YFilter.not_set or
                                                            self.tiebreaker_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "tiebreaker-type"):
                                                            self.tiebreaker_type = value
                                                            self.tiebreaker_type.value_namespace = name_space
                                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tiebreaker-index"):
                                                            self.tiebreaker_index = value
                                                            self.tiebreaker_index.value_namespace = name_space
                                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreakers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tiebreaker"):
                                                        for c in self.tiebreaker:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tiebreaker.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    self.topology_independent_lfa.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-prefix" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                                if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                if (child_yang_name == "remote-lfa"):
                                                    if (self.remote_lfa is None):
                                                        self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                        self.remote_lfa.parent = self
                                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                                    return self.remote_lfa

                                                if (child_yang_name == "tiebreakers"):
                                                    if (self.tiebreakers is None):
                                                        self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                        self.tiebreakers.parent = self
                                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                                    return self.tiebreakers

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "topology-independent-lfa"):
                                                    self.topology_independent_lfa = value
                                                    self.topology_independent_lfa.value_namespace = name_space
                                                    self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_enable.is_set or
                                                (self.per_link is not None and self.per_link.has_data()) or
                                                (self.per_prefix is not None and self.per_prefix.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_enable.yfilter != YFilter.not_set or
                                                (self.per_link is not None and self.per_link.has_operation()) or
                                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fast-reroute" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "per-link"):
                                                if (self.per_link is None):
                                                    self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                                    self.per_link.parent = self
                                                    self._children_name_map["per_link"] = "per-link"
                                                return self.per_link

                                            if (child_yang_name == "per-prefix"):
                                                if (self.per_prefix is None):
                                                    self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                                    self.per_prefix.parent = self
                                                    self._children_name_map["per_prefix"] = "per-prefix"
                                                return self.per_prefix

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-enable"):
                                                self.fast_reroute_enable = value
                                                self.fast_reroute_enable.value_namespace = name_space
                                                self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "name-scope"

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cost",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cost.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "cost-fallback" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cost" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.interface_name.is_set or
                                            self.cost.is_set or
                                            self.database_filter.is_set or
                                            self.demand_circuit.is_set or
                                            self.flood_reduction.is_set or
                                            self.hello_interval.is_set or
                                            self.ldp_auto_config.is_set or
                                            self.ldp_sync.is_set or
                                            self.ldp_sync_igp_shortcuts.is_set or
                                            self.link_down_fast_detect.is_set or
                                            self.loopback_stub_network.is_set or
                                            self.mtu_ignore.is_set or
                                            self.network_type.is_set or
                                            self.packet_size.is_set or
                                            self.passive.is_set or
                                            self.prefix_suppression_primary.is_set or
                                            self.prefix_suppression_secondary.is_set or
                                            self.priority.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.segment_routing_forwarding.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.bfd is not None and self.bfd.has_data()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                            (self.neighbors is not None and self.neighbors.has_data()) or
                                            (self.security is not None and self.security.has_data()) or
                                            (self.distribute_list is not None) or
                                            (self.prefix_sid is not None) or
                                            (self.prefix_sid_strict is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.database_filter.yfilter != YFilter.not_set or
                                            self.demand_circuit.yfilter != YFilter.not_set or
                                            self.flood_reduction.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.ldp_auto_config.yfilter != YFilter.not_set or
                                            self.ldp_sync.yfilter != YFilter.not_set or
                                            self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                            self.link_down_fast_detect.yfilter != YFilter.not_set or
                                            self.loopback_stub_network.yfilter != YFilter.not_set or
                                            self.mtu_ignore.yfilter != YFilter.not_set or
                                            self.network_type.yfilter != YFilter.not_set or
                                            self.packet_size.yfilter != YFilter.not_set or
                                            self.passive.yfilter != YFilter.not_set or
                                            self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                            self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.bfd is not None and self.bfd.has_operation()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                            (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                            (self.neighbors is not None and self.neighbors.has_operation()) or
                                            (self.prefix_sid is not None and self.prefix_sid.has_operation()) or
                                            (self.prefix_sid_strict is not None and self.prefix_sid_strict.has_operation()) or
                                            (self.security is not None and self.security.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "name-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.database_filter.get_name_leafdata())
                                        if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                        if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                        if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                        if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                        if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                        if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                        if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                        if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.network_type.get_name_leafdata())
                                        if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_size.get_name_leafdata())
                                        if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.passive.get_name_leafdata())
                                        if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                        if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "bfd"):
                                            if (self.bfd is None):
                                                self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                                self.bfd.parent = self
                                                self._children_name_map["bfd"] = "bfd"
                                            return self.bfd

                                        if (child_yang_name == "cost-fallback"):
                                            if (self.cost_fallback is None):
                                                self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                                self.cost_fallback.parent = self
                                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                            return self.cost_fallback

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        if (child_yang_name == "distribute-list"):
                                            if (self.distribute_list is None):
                                                self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList()
                                                self.distribute_list.parent = self
                                                self._children_name_map["distribute_list"] = "distribute-list"
                                            return self.distribute_list

                                        if (child_yang_name == "fast-reroute"):
                                            if (self.fast_reroute is None):
                                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                                self.fast_reroute.parent = self
                                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                            return self.fast_reroute

                                        if (child_yang_name == "neighbors"):
                                            if (self.neighbors is None):
                                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                                self.neighbors.parent = self
                                                self._children_name_map["neighbors"] = "neighbors"
                                            return self.neighbors

                                        if (child_yang_name == "prefix-sid"):
                                            if (self.prefix_sid is None):
                                                self.prefix_sid = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid()
                                                self.prefix_sid.parent = self
                                                self._children_name_map["prefix_sid"] = "prefix-sid"
                                            return self.prefix_sid

                                        if (child_yang_name == "prefix-sid-strict"):
                                            if (self.prefix_sid_strict is None):
                                                self.prefix_sid_strict = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict()
                                                self.prefix_sid_strict.parent = self
                                                self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                            return self.prefix_sid_strict

                                        if (child_yang_name == "security"):
                                            if (self.security is None):
                                                self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                                self.security.parent = self
                                                self._children_name_map["security"] = "security"
                                            return self.security

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "prefix-sid" or name == "prefix-sid-strict" or name == "security" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "running" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "database-filter"):
                                            self.database_filter = value
                                            self.database_filter.value_namespace = name_space
                                            self.database_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "demand-circuit"):
                                            self.demand_circuit = value
                                            self.demand_circuit.value_namespace = name_space
                                            self.demand_circuit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-reduction"):
                                            self.flood_reduction = value
                                            self.flood_reduction.value_namespace = name_space
                                            self.flood_reduction.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-auto-config"):
                                            self.ldp_auto_config = value
                                            self.ldp_auto_config.value_namespace = name_space
                                            self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-sync"):
                                            self.ldp_sync = value
                                            self.ldp_sync.value_namespace = name_space
                                            self.ldp_sync.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-sync-igp-shortcuts"):
                                            self.ldp_sync_igp_shortcuts = value
                                            self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                            self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-down-fast-detect"):
                                            self.link_down_fast_detect = value
                                            self.link_down_fast_detect.value_namespace = name_space
                                            self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                        if(value_path == "loopback-stub-network"):
                                            self.loopback_stub_network = value
                                            self.loopback_stub_network.value_namespace = name_space
                                            self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-ignore"):
                                            self.mtu_ignore = value
                                            self.mtu_ignore.value_namespace = name_space
                                            self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                        if(value_path == "network-type"):
                                            self.network_type = value
                                            self.network_type.value_namespace = name_space
                                            self.network_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-size"):
                                            self.packet_size = value
                                            self.packet_size.value_namespace = name_space
                                            self.packet_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "passive"):
                                            self.passive = value
                                            self.passive.value_namespace = name_space
                                            self.passive.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppression-primary"):
                                            self.prefix_suppression_primary = value
                                            self.prefix_suppression_primary.value_namespace = name_space
                                            self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppression-secondary"):
                                            self.prefix_suppression_secondary = value
                                            self.prefix_suppression_secondary.value_namespace = name_space
                                            self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "segment-routing-forwarding"):
                                            self.segment_routing_forwarding = value
                                            self.segment_routing_forwarding.value_namespace = name_space
                                            self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.name_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.name_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "name-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "name-scope"):
                                        for c in self.name_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.name_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "name-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MultiAreaInterfaceScopes(Entity):
                                """
                                Multi Area Interface scope configurations
                                
                                .. attribute:: multi_area_interface_scope
                                
                                	Multi Area Interface configuration
                                	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__init__()

                                    self.yang_name = "multi-area-interface-scopes"
                                    self.yang_parent_name = "area-address"

                                    self.multi_area_interface_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__setattr__(name, value)


                                class MultiAreaInterfaceScope(Entity):
                                    """
                                    Multi Area Interface configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Multi Area Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                        self.yang_name = "multi-area-interface-scope"
                                        self.yang_parent_name = "multi-area-interface-scopes"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "cost",
                                                        "database_filter",
                                                        "hello_interval",
                                                        "mtu_ignore",
                                                        "packet_size",
                                                        "passive",
                                                        "retransmit_interval",
                                                        "running",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("access_list_name",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.access_list_name.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.access_list_name.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "distribute-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "access-list-name" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "access-list-name"):
                                                self.access_list_name = value
                                                self.access_list_name.value_namespace = name_space
                                                self.access_list_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.neighbor = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("neighbor_address",
                                                                "cost",
                                                                "database_filter",
                                                                "poll_interval",
                                                                "priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.neighbor_address.is_set or
                                                    self.cost.is_set or
                                                    self.database_filter.is_set or
                                                    self.poll_interval.is_set or
                                                    self.priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.cost.yfilter != YFilter.not_set or
                                                    self.database_filter.yfilter != YFilter.not_set or
                                                    self.poll_interval.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                                if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost"):
                                                    self.cost = value
                                                    self.cost.value_namespace = name_space
                                                    self.cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "database-filter"):
                                                    self.database_filter = value
                                                    self.database_filter.value_namespace = name_space
                                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                                if(value_path == "poll-interval"):
                                                    self.poll_interval = value
                                                    self.poll_interval.value_namespace = name_space
                                                    self.poll_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.neighbor:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.neighbor:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbors" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor"):
                                                for c in self.neighbor:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.neighbor.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_enable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only",
                                                                "topology_independent_lfa") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("maximum_cost",
                                                                    "tunnel") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.maximum_cost.is_set or
                                                        self.tunnel.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.maximum_cost.yfilter != YFilter.not_set or
                                                        self.tunnel.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-lfa" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                    if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "maximum-cost" or name == "tunnel"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "maximum-cost"):
                                                        self.maximum_cost = value
                                                        self.maximum_cost.value_namespace = name_space
                                                        self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel"):
                                                        self.tunnel = value
                                                        self.tunnel.value_namespace = name_space
                                                        self.tunnel.value_namespace_prefix = name_space_prefix


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.tiebreaker = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("tiebreaker_type",
                                                                        "tiebreaker_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.tiebreaker_type.is_set or
                                                            self.tiebreaker_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.tiebreaker_type.yfilter != YFilter.not_set or
                                                            self.tiebreaker_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "tiebreaker-type"):
                                                            self.tiebreaker_type = value
                                                            self.tiebreaker_type.value_namespace = name_space
                                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tiebreaker-index"):
                                                            self.tiebreaker_index = value
                                                            self.tiebreaker_index.value_namespace = name_space
                                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreakers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tiebreaker"):
                                                        for c in self.tiebreaker:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tiebreaker.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    self.topology_independent_lfa.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-prefix" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                                if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                if (child_yang_name == "remote-lfa"):
                                                    if (self.remote_lfa is None):
                                                        self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                        self.remote_lfa.parent = self
                                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                                    return self.remote_lfa

                                                if (child_yang_name == "tiebreakers"):
                                                    if (self.tiebreakers is None):
                                                        self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                        self.tiebreakers.parent = self
                                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                                    return self.tiebreakers

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "topology-independent-lfa"):
                                                    self.topology_independent_lfa = value
                                                    self.topology_independent_lfa.value_namespace = name_space
                                                    self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_enable.is_set or
                                                (self.per_link is not None and self.per_link.has_data()) or
                                                (self.per_prefix is not None and self.per_prefix.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_enable.yfilter != YFilter.not_set or
                                                (self.per_link is not None and self.per_link.has_operation()) or
                                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fast-reroute" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "per-link"):
                                                if (self.per_link is None):
                                                    self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                                    self.per_link.parent = self
                                                    self._children_name_map["per_link"] = "per-link"
                                                return self.per_link

                                            if (child_yang_name == "per-prefix"):
                                                if (self.per_prefix is None):
                                                    self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                                    self.per_prefix.parent = self
                                                    self._children_name_map["per_prefix"] = "per-prefix"
                                                return self.per_prefix

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-enable"):
                                                self.fast_reroute_enable = value
                                                self.fast_reroute_enable.value_namespace = name_space
                                                self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cost",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cost.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "cost-fallback" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cost" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.interface_name.is_set or
                                            self.cost.is_set or
                                            self.database_filter.is_set or
                                            self.hello_interval.is_set or
                                            self.mtu_ignore.is_set or
                                            self.packet_size.is_set or
                                            self.passive.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                            (self.neighbors is not None and self.neighbors.has_data()) or
                                            (self.distribute_list is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.database_filter.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.mtu_ignore.yfilter != YFilter.not_set or
                                            self.packet_size.yfilter != YFilter.not_set or
                                            self.passive.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                            (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                            (self.neighbors is not None and self.neighbors.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.database_filter.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                        if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_size.get_name_leafdata())
                                        if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.passive.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "cost-fallback"):
                                            if (self.cost_fallback is None):
                                                self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                                self.cost_fallback.parent = self
                                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                            return self.cost_fallback

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        if (child_yang_name == "distribute-list"):
                                            if (self.distribute_list is None):
                                                self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList()
                                                self.distribute_list.parent = self
                                                self._children_name_map["distribute_list"] = "distribute-list"
                                            return self.distribute_list

                                        if (child_yang_name == "fast-reroute"):
                                            if (self.fast_reroute is None):
                                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                                self.fast_reroute.parent = self
                                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                            return self.fast_reroute

                                        if (child_yang_name == "neighbors"):
                                            if (self.neighbors is None):
                                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                                self.neighbors.parent = self
                                                self._children_name_map["neighbors"] = "neighbors"
                                            return self.neighbors

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "hello-interval" or name == "mtu-ignore" or name == "packet-size" or name == "passive" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "database-filter"):
                                            self.database_filter = value
                                            self.database_filter.value_namespace = name_space
                                            self.database_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-ignore"):
                                            self.mtu_ignore = value
                                            self.mtu_ignore.value_namespace = name_space
                                            self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-size"):
                                            self.packet_size = value
                                            self.packet_size.value_namespace = name_space
                                            self.packet_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "passive"):
                                            self.passive = value
                                            self.passive.value_namespace = name_space
                                            self.passive.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.multi_area_interface_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.multi_area_interface_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-area-interface-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "multi-area-interface-scope"):
                                        for c in self.multi_area_interface_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.multi_area_interface_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "multi-area-interface-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AreaRanges(Entity):
                                """
                                Summarize routes matching address/mask (border
                                routers only)
                                
                                .. attribute:: area_range
                                
                                	Ordering index
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges, self).__init__()

                                    self.yang_name = "area-ranges"
                                    self.yang_parent_name = "area-address"

                                    self.area_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges, self).__setattr__(name, value)


                                class AreaRange(Entity):
                                    """
                                    Ordering index
                                    
                                    .. attribute:: address  <key>
                                    
                                    	IP address to match
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: netmask  <key>
                                    
                                    	IP netmask for address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise this range
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "area-ranges"

                                        self.address = YLeaf(YType.str, "address")

                                        self.netmask = YLeaf(YType.str, "netmask")

                                        self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "netmask",
                                                        "not_advertise") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.netmask.is_set or
                                            self.not_advertise.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.netmask.yfilter != YFilter.not_set or
                                            self.not_advertise.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.netmask.get_name_leafdata())
                                        if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_advertise.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "netmask" or name == "not-advertise"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "netmask"):
                                            self.netmask = value
                                            self.netmask.value_namespace = name_space
                                            self.netmask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-advertise"):
                                            self.not_advertise = value
                                            self.not_advertise.value_namespace = name_space
                                            self.not_advertise.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_range:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.area_range:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-ranges" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-range"):
                                        for c in self.area_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-range"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Nssa(Entity):
                                """
                                Specify area as a NSSA area
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric_type
                                
                                	OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                	**default value**\: type2
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: nssa_def_metric
                                
                                	OSPF default metric
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area-address"

                                    self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                    self.no_summary = YLeaf(YType.boolean, "no-summary")

                                    self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("default_info_originate",
                                                    "metric_type",
                                                    "no_redistribution",
                                                    "no_summary",
                                                    "nssa_def_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.default_info_originate.is_set or
                                        self.metric_type.is_set or
                                        self.no_redistribution.is_set or
                                        self.no_summary.is_set or
                                        self.nssa_def_metric.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.default_info_originate.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.no_redistribution.yfilter != YFilter.not_set or
                                        self.no_summary.yfilter != YFilter.not_set or
                                        self.nssa_def_metric.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nssa" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.no_redistribution.is_set or self.no_redistribution.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_redistribution.get_name_leafdata())
                                    if (self.no_summary.is_set or self.no_summary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_summary.get_name_leafdata())
                                    if (self.nssa_def_metric.is_set or self.nssa_def_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_def_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "default-info-originate" or name == "metric-type" or name == "no-redistribution" or name == "no-summary" or name == "nssa-def-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "default-info-originate"):
                                        self.default_info_originate = value
                                        self.default_info_originate.value_namespace = name_space
                                        self.default_info_originate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-redistribution"):
                                        self.no_redistribution = value
                                        self.no_redistribution.value_namespace = name_space
                                        self.no_redistribution.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-summary"):
                                        self.no_summary = value
                                        self.no_summary.value_namespace = name_space
                                        self.no_summary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-def-metric"):
                                        self.nssa_def_metric = value
                                        self.nssa_def_metric.value_namespace = name_space
                                        self.nssa_def_metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.default_cost.is_set or
                                    self.external_out.is_set or
                                    self.mpls_traffic_eng.is_set or
                                    self.route_policy_in.is_set or
                                    self.route_policy_out.is_set or
                                    self.running.is_set or
                                    self.segment_routing.is_set or
                                    self.stub.is_set or
                                    self.summary_in.is_set or
                                    (self.area_ranges is not None and self.area_ranges.has_data()) or
                                    (self.area_scope is not None and self.area_scope.has_data()) or
                                    (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_data()) or
                                    (self.name_scopes is not None and self.name_scopes.has_data()) or
                                    (self.nssa is not None and self.nssa.has_data()) or
                                    (self.sham_link_scopes is not None and self.sham_link_scopes.has_data()) or
                                    (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.default_cost.yfilter != YFilter.not_set or
                                    self.external_out.yfilter != YFilter.not_set or
                                    self.mpls_traffic_eng.yfilter != YFilter.not_set or
                                    self.route_policy_in.yfilter != YFilter.not_set or
                                    self.route_policy_out.yfilter != YFilter.not_set or
                                    self.running.yfilter != YFilter.not_set or
                                    self.segment_routing.yfilter != YFilter.not_set or
                                    self.stub.yfilter != YFilter.not_set or
                                    self.summary_in.yfilter != YFilter.not_set or
                                    (self.area_ranges is not None and self.area_ranges.has_operation()) or
                                    (self.area_scope is not None and self.area_scope.has_operation()) or
                                    (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_operation()) or
                                    (self.name_scopes is not None and self.name_scopes.has_operation()) or
                                    (self.nssa is not None and self.nssa.has_operation()) or
                                    (self.sham_link_scopes is not None and self.sham_link_scopes.has_operation()) or
                                    (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-address" + "[address='" + self.address.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.default_cost.is_set or self.default_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_cost.get_name_leafdata())
                                if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_out.get_name_leafdata())
                                if (self.mpls_traffic_eng.is_set or self.mpls_traffic_eng.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_traffic_eng.get_name_leafdata())
                                if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.running.get_name_leafdata())
                                if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing.get_name_leafdata())
                                if (self.stub.is_set or self.stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stub.get_name_leafdata())
                                if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_in.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-ranges"):
                                    if (self.area_ranges is None):
                                        self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges()
                                        self.area_ranges.parent = self
                                        self._children_name_map["area_ranges"] = "area-ranges"
                                    return self.area_ranges

                                if (child_yang_name == "area-scope"):
                                    if (self.area_scope is None):
                                        self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope()
                                        self.area_scope.parent = self
                                        self._children_name_map["area_scope"] = "area-scope"
                                    return self.area_scope

                                if (child_yang_name == "multi-area-interface-scopes"):
                                    if (self.multi_area_interface_scopes is None):
                                        self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                                        self.multi_area_interface_scopes.parent = self
                                        self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                    return self.multi_area_interface_scopes

                                if (child_yang_name == "name-scopes"):
                                    if (self.name_scopes is None):
                                        self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes()
                                        self.name_scopes.parent = self
                                        self._children_name_map["name_scopes"] = "name-scopes"
                                    return self.name_scopes

                                if (child_yang_name == "nssa"):
                                    if (self.nssa is None):
                                        self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa()
                                        self.nssa.parent = self
                                        self._children_name_map["nssa"] = "nssa"
                                    return self.nssa

                                if (child_yang_name == "sham-link-scopes"):
                                    if (self.sham_link_scopes is None):
                                        self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                                        self.sham_link_scopes.parent = self
                                        self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                    return self.sham_link_scopes

                                if (child_yang_name == "virtual-link-scopes"):
                                    if (self.virtual_link_scopes is None):
                                        self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                                        self.virtual_link_scopes.parent = self
                                        self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                    return self.virtual_link_scopes

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-ranges" or name == "area-scope" or name == "multi-area-interface-scopes" or name == "name-scopes" or name == "nssa" or name == "sham-link-scopes" or name == "virtual-link-scopes" or name == "address" or name == "default-cost" or name == "external-out" or name == "mpls-traffic-eng" or name == "route-policy-in" or name == "route-policy-out" or name == "running" or name == "segment-routing" or name == "stub" or name == "summary-in"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-cost"):
                                    self.default_cost = value
                                    self.default_cost.value_namespace = name_space
                                    self.default_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-out"):
                                    self.external_out = value
                                    self.external_out.value_namespace = name_space
                                    self.external_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-traffic-eng"):
                                    self.mpls_traffic_eng = value
                                    self.mpls_traffic_eng.value_namespace = name_space
                                    self.mpls_traffic_eng.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-policy-in"):
                                    self.route_policy_in = value
                                    self.route_policy_in.value_namespace = name_space
                                    self.route_policy_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-policy-out"):
                                    self.route_policy_out = value
                                    self.route_policy_out.value_namespace = name_space
                                    self.route_policy_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "running"):
                                    self.running = value
                                    self.running.value_namespace = name_space
                                    self.running.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing"):
                                    self.segment_routing = value
                                    self.segment_routing.value_namespace = name_space
                                    self.segment_routing.value_namespace_prefix = name_space_prefix
                                if(value_path == "stub"):
                                    self.stub = value
                                    self.stub.value_namespace = name_space
                                    self.stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-in"):
                                    self.summary_in = value
                                    self.summary_in.value_namespace = name_space
                                    self.summary_in.value_namespace_prefix = name_space_prefix


                        class AreaAreaId(Entity):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_ranges
                            
                            	Summarize routes matching address/mask (border routers only)
                            	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges>`
                            
                            .. attribute:: area_scope
                            
                            	Area scope configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            	**default value**\: 1
                            
                            .. attribute:: external_out
                            
                            	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                            	**type**\:  bool
                            
                            .. attribute:: mpls_traffic_eng
                            
                            	Configure an OSPF area to run MPLS Traffic Engineering
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: multi_area_interface_scopes
                            
                            	Multi Area Interface scope configurations
                            	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes>`
                            
                            .. attribute:: name_scopes
                            
                            	Name scope configurations
                            	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa>`
                            
                            .. attribute:: route_policy_in
                            
                            	Configure a route policy for inbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out
                            
                            	Configure a route policy for outbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: running
                            
                            	Enable routing on an IP network
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment_routing
                            
                            	segment\-routing configuration Applicable only in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                            
                            .. attribute:: sham_link_scopes
                            
                            	Sham Link scope configurations
                            	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes>`
                            
                            .. attribute:: stub
                            
                            	Specify the area as a stub area (send summary LSA stub area)
                            	**type**\:  bool
                            
                            .. attribute:: summary_in
                            
                            	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_scopes
                            
                            	Virtual Link scope configurations
                            	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId, self).__init__()

                                self.yang_name = "area-area-id"
                                self.yang_parent_name = "area-addresses"

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.default_cost = YLeaf(YType.uint32, "default-cost")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                self.running = YLeaf(YType.empty, "running")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.stub = YLeaf(YType.boolean, "stub")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges()
                                self.area_ranges.parent = self
                                self._children_name_map["area_ranges"] = "area-ranges"
                                self._children_yang_names.add("area-ranges")

                                self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope()
                                self.area_scope.parent = self
                                self._children_name_map["area_scope"] = "area-scope"
                                self._children_yang_names.add("area-scope")

                                self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                                self.multi_area_interface_scopes.parent = self
                                self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                self._children_yang_names.add("multi-area-interface-scopes")

                                self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes()
                                self.name_scopes.parent = self
                                self._children_name_map["name_scopes"] = "name-scopes"
                                self._children_yang_names.add("name-scopes")

                                self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa()
                                self.nssa.parent = self
                                self._children_name_map["nssa"] = "nssa"
                                self._children_yang_names.add("nssa")

                                self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                                self.sham_link_scopes.parent = self
                                self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                self._children_yang_names.add("sham-link-scopes")

                                self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                                self.virtual_link_scopes.parent = self
                                self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                self._children_yang_names.add("virtual-link-scopes")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("area_id",
                                                "default_cost",
                                                "external_out",
                                                "mpls_traffic_eng",
                                                "route_policy_in",
                                                "route_policy_out",
                                                "running",
                                                "segment_routing",
                                                "stub",
                                                "summary_in") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId, self).__setattr__(name, value)


                            class VirtualLinkScopes(Entity):
                                """
                                Virtual Link scope configurations
                                
                                .. attribute:: virtual_link_scope
                                
                                	Virtual Link configuration
                                	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__init__()

                                    self.yang_name = "virtual-link-scopes"
                                    self.yang_parent_name = "area-area-id"

                                    self.virtual_link_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__setattr__(name, value)


                                class VirtualLinkScope(Entity):
                                    """
                                    Virtual Link configuration
                                    
                                    .. attribute:: address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                        self.yang_name = "virtual-link-scope"
                                        self.yang_parent_name = "virtual-link-scopes"

                                        self.address = YLeaf(YType.str, "address")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "hello_interval",
                                                        "retransmit_interval",
                                                        "running",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "virtual-link-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "virtual-link-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.hello_interval.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "virtual-link-scope" + "[address='" + self.address.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "dead-interval-minimal" or name == "address" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.virtual_link_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.virtual_link_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "virtual-link-scope"):
                                        for c in self.virtual_link_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.virtual_link_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "virtual-link-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class ShamLinkScopes(Entity):
                                """
                                Sham Link scope configurations
                                
                                .. attribute:: sham_link_scope
                                
                                	Sham Link configuration
                                	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__init__()

                                    self.yang_name = "sham-link-scopes"
                                    self.yang_parent_name = "area-area-id"

                                    self.sham_link_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__setattr__(name, value)


                                class ShamLinkScope(Entity):
                                    """
                                    Sham Link configuration
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Address of the local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Address of the remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: source
                                    
                                    	Address of the local sham\-link endpoint. Enter an IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__init__()

                                        self.yang_name = "sham-link-scope"
                                        self.yang_parent_name = "sham-link-scopes"

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.source = YLeaf(YType.str, "source")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("source_address",
                                                        "destination_address",
                                                        "cost",
                                                        "hello_interval",
                                                        "retransmit_interval",
                                                        "running",
                                                        "source",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "sham-link-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "sham-link-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.source_address.is_set or
                                            self.destination_address.is_set or
                                            self.cost.is_set or
                                            self.hello_interval.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.source.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            self.destination_address.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.source.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())
                                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "dead-interval-minimal" or name == "source-address" or name == "destination-address" or name == "cost" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "source" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "destination-address"):
                                            self.destination_address = value
                                            self.destination_address.value_namespace = name_space
                                            self.destination_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source"):
                                            self.source = value
                                            self.source.value_namespace = name_space
                                            self.source.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.sham_link_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.sham_link_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sham-link-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "sham-link-scope"):
                                        for c in self.sham_link_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.sham_link_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "sham-link-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AreaScope(Entity):
                                """
                                Area scope configuration
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope, self).__init__()

                                    self.yang_name = "area-scope"
                                    self.yang_parent_name = "area-area-id"

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("cost",
                                                    "database_filter",
                                                    "demand_circuit",
                                                    "flood_reduction",
                                                    "hello_interval",
                                                    "ldp_auto_config",
                                                    "ldp_sync",
                                                    "ldp_sync_igp_shortcuts",
                                                    "link_down_fast_detect",
                                                    "loopback_stub_network",
                                                    "mtu_ignore",
                                                    "network_type",
                                                    "packet_size",
                                                    "passive",
                                                    "prefix_suppression_primary",
                                                    "prefix_suppression_secondary",
                                                    "priority",
                                                    "retransmit_interval",
                                                    "segment_routing_forwarding",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope, self).__setattr__(name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "area-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "area-scope"

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("detection_multiplier",
                                                        "fast_detect_mode",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.detection_multiplier.is_set or
                                            self.fast_detect_mode.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.fast_detect_mode.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-mode"):
                                            self.fast_detect_mode = value
                                            self.fast_detect_mode.value_namespace = name_space
                                            self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "area-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "area-scope"

                                        self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("enable",
                                                            "hop_count") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.enable.is_set or
                                                self.hop_count.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.enable.yfilter != YFilter.not_set or
                                                self.hop_count.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ttl" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.enable.get_name_leafdata())
                                            if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.hop_count.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "enable" or name == "hop-count"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "enable"):
                                                self.enable = value
                                                self.enable.value_namespace = name_space
                                                self.enable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "hop-count"):
                                                self.hop_count = value
                                                self.hop_count.value_namespace = name_space
                                                self.hop_count.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (self.ttl is not None and self.ttl.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.ttl is not None and self.ttl.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ttl"):
                                            if (self.ttl is None):
                                                self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                                self.ttl.parent = self
                                                self._children_name_map["ttl"] = "ttl"
                                            return self.ttl

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "area-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "area-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "area-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.demand_circuit.is_set or
                                        self.flood_reduction.is_set or
                                        self.hello_interval.is_set or
                                        self.ldp_auto_config.is_set or
                                        self.ldp_sync.is_set or
                                        self.ldp_sync_igp_shortcuts.is_set or
                                        self.link_down_fast_detect.is_set or
                                        self.loopback_stub_network.is_set or
                                        self.mtu_ignore.is_set or
                                        self.network_type.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.prefix_suppression_primary.is_set or
                                        self.prefix_suppression_secondary.is_set or
                                        self.priority.is_set or
                                        self.retransmit_interval.is_set or
                                        self.segment_routing_forwarding.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.bfd is not None and self.bfd.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.security is not None and self.security.has_data()) or
                                        (self.distribute_list is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.demand_circuit.yfilter != YFilter.not_set or
                                        self.flood_reduction.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.ldp_auto_config.yfilter != YFilter.not_set or
                                        self.ldp_sync.yfilter != YFilter.not_set or
                                        self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.link_down_fast_detect.yfilter != YFilter.not_set or
                                        self.loopback_stub_network.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                        self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                        self.priority.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.bfd is not None and self.bfd.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.security is not None and self.security.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-scope" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                    if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                    if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                    if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                    if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                    if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "bfd"):
                                        if (self.bfd is None):
                                            self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                            self.bfd.parent = self
                                            self._children_name_map["bfd"] = "bfd"
                                        return self.bfd

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "security"):
                                        if (self.security is None):
                                            self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                            self.security.parent = self
                                            self._children_name_map["security"] = "security"
                                        return self.security

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "demand-circuit"):
                                        self.demand_circuit = value
                                        self.demand_circuit.value_namespace = name_space
                                        self.demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-reduction"):
                                        self.flood_reduction = value
                                        self.flood_reduction.value_namespace = name_space
                                        self.flood_reduction.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-auto-config"):
                                        self.ldp_auto_config = value
                                        self.ldp_auto_config.value_namespace = name_space
                                        self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync"):
                                        self.ldp_sync = value
                                        self.ldp_sync.value_namespace = name_space
                                        self.ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync-igp-shortcuts"):
                                        self.ldp_sync_igp_shortcuts = value
                                        self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-down-fast-detect"):
                                        self.link_down_fast_detect = value
                                        self.link_down_fast_detect.value_namespace = name_space
                                        self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "loopback-stub-network"):
                                        self.loopback_stub_network = value
                                        self.loopback_stub_network.value_namespace = name_space
                                        self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-primary"):
                                        self.prefix_suppression_primary = value
                                        self.prefix_suppression_primary.value_namespace = name_space
                                        self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-secondary"):
                                        self.prefix_suppression_secondary = value
                                        self.prefix_suppression_secondary.value_namespace = name_space
                                        self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority"):
                                        self.priority = value
                                        self.priority.value_namespace = name_space
                                        self.priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segment-routing-forwarding"):
                                        self.segment_routing_forwarding = value
                                        self.segment_routing_forwarding.value_namespace = name_space
                                        self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix


                            class NameScopes(Entity):
                                """
                                Name scope configurations
                                
                                .. attribute:: name_scope
                                
                                	Name scope configuration
                                	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes, self).__init__()

                                    self.yang_name = "name-scopes"
                                    self.yang_parent_name = "area-area-id"

                                    self.name_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes, self).__setattr__(name, value)


                                class NameScope(Entity):
                                    """
                                    Name scope configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	BFD configuration
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/Disable OSPF demand circuit
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/Disable OSPF flood reduction
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ldp_auto_config
                                    
                                    	Enable MPLS LDP Auto Config
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_sync_igp_shortcuts
                                    
                                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: link_down_fast_detect
                                    
                                    	Enable/Disable registration for early interface down notifications
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: loopback_stub_network
                                    
                                    	Enable/Disable advertising loopback as a stub network
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors>`
                                    
                                    .. attribute:: network_type
                                    
                                    	Type of attached network
                                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_sid
                                    
                                    	Prefix SID
                                    	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_sid_strict
                                    
                                    	Strict Prefix SID
                                    	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_suppression_primary
                                    
                                    	Enable/Disable prefix suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_suppression_secondary
                                    
                                    	Enable/Disable prefix suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: priority
                                    
                                    	Router priority for DR and BDR election
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 1
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: security
                                    
                                    	Container class for security related configuration parameters
                                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security>`
                                    
                                    .. attribute:: segment_routing_forwarding
                                    
                                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__init__()

                                        self.yang_name = "name-scope"
                                        self.yang_parent_name = "name-scopes"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                        self.priority = YLeaf(YType.uint32, "priority")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                        self._children_yang_names.add("bfd")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                        self.prefix_sid = None
                                        self._children_name_map["prefix_sid"] = "prefix-sid"
                                        self._children_yang_names.add("prefix-sid")

                                        self.prefix_sid_strict = None
                                        self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        self._children_yang_names.add("prefix-sid-strict")

                                        self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                        self._children_yang_names.add("security")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "cost",
                                                        "database_filter",
                                                        "demand_circuit",
                                                        "flood_reduction",
                                                        "hello_interval",
                                                        "ldp_auto_config",
                                                        "ldp_sync",
                                                        "ldp_sync_igp_shortcuts",
                                                        "link_down_fast_detect",
                                                        "loopback_stub_network",
                                                        "mtu_ignore",
                                                        "network_type",
                                                        "packet_size",
                                                        "passive",
                                                        "prefix_suppression_primary",
                                                        "prefix_suppression_secondary",
                                                        "priority",
                                                        "retransmit_interval",
                                                        "running",
                                                        "segment_routing_forwarding",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__setattr__(name, value)


                                    class PrefixSid(Entity):
                                        """
                                        Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__init__()

                                            self.yang_name = "prefix-sid"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_null",
                                                            "n_flag_clear",
                                                            "sid_value",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_null.is_set or
                                                self.n_flag_clear.is_set or
                                                self.sid_value.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_null.yfilter != YFilter.not_set or
                                                self.n_flag_clear.yfilter != YFilter.not_set or
                                                self.sid_value.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "prefix-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                            if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                            if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sid_value.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-null"):
                                                self.explicit_null = value
                                                self.explicit_null.value_namespace = name_space
                                                self.explicit_null.value_namespace_prefix = name_space_prefix
                                            if(value_path == "n-flag-clear"):
                                                self.n_flag_clear = value
                                                self.n_flag_clear.value_namespace = name_space
                                                self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sid-value"):
                                                self.sid_value = value
                                                self.sid_value.value_namespace = name_space
                                                self.sid_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class PrefixSidStrict(Entity):
                                        """
                                        Strict Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                            self.yang_name = "prefix-sid-strict"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("explicit_null",
                                                            "n_flag_clear",
                                                            "sid_value",
                                                            "type") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.explicit_null.is_set or
                                                self.n_flag_clear.is_set or
                                                self.sid_value.is_set or
                                                self.type.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.explicit_null.yfilter != YFilter.not_set or
                                                self.n_flag_clear.yfilter != YFilter.not_set or
                                                self.sid_value.yfilter != YFilter.not_set or
                                                self.type.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "prefix-sid-strict" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                            if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                            if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.sid_value.get_name_leafdata())
                                            if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.type.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "explicit-null"):
                                                self.explicit_null = value
                                                self.explicit_null.value_namespace = name_space
                                                self.explicit_null.value_namespace_prefix = name_space_prefix
                                            if(value_path == "n-flag-clear"):
                                                self.n_flag_clear = value
                                                self.n_flag_clear.value_namespace = name_space
                                                self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                            if(value_path == "sid-value"):
                                                self.sid_value = value
                                                self.sid_value.value_namespace = name_space
                                                self.sid_value.value_namespace_prefix = name_space_prefix
                                            if(value_path == "type"):
                                                self.type = value
                                                self.type.value_namespace = name_space
                                                self.type.value_namespace_prefix = name_space_prefix


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "name-scope"
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("access_list_name",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.access_list_name.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.access_list_name.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "distribute-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "access-list-name" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "access-list-name"):
                                                self.access_list_name = value
                                                self.access_list_name.value_namespace = name_space
                                                self.access_list_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class Bfd(Entity):
                                        """
                                        BFD configuration
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detection multiplier for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	 use of Bidirectional Forwarding Detection
                                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__init__()

                                            self.yang_name = "bfd"
                                            self.yang_parent_name = "name-scope"

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                            self.interval = YLeaf(YType.uint32, "interval")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("detection_multiplier",
                                                            "fast_detect_mode",
                                                            "interval") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.detection_multiplier.is_set or
                                                self.fast_detect_mode.is_set or
                                                self.interval.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.detection_multiplier.yfilter != YFilter.not_set or
                                                self.fast_detect_mode.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "bfd" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                            if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "detection-multiplier"):
                                                self.detection_multiplier = value
                                                self.detection_multiplier.value_namespace = name_space
                                                self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                            if(value_path == "fast-detect-mode"):
                                                self.fast_detect_mode = value
                                                self.fast_detect_mode.value_namespace = name_space
                                                self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "name-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class Security(Entity):
                                        """
                                        Container class for security related
                                        configuration parameters
                                        
                                        .. attribute:: ttl
                                        
                                        	Enabling turns on TTL security
                                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security, self).__init__()

                                            self.yang_name = "security"
                                            self.yang_parent_name = "name-scope"

                                            self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                            self._children_yang_names.add("ttl")


                                        class Ttl(Entity):
                                            """
                                            Enabling turns on TTL security
                                            
                                            .. attribute:: enable
                                            
                                            	Enable TTL security
                                            	**type**\:  bool
                                            
                                            .. attribute:: hop_count
                                            
                                            	Hop count
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__init__()

                                                self.yang_name = "ttl"
                                                self.yang_parent_name = "security"

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.hop_count = YLeaf(YType.uint32, "hop-count")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("enable",
                                                                "hop_count") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.enable.is_set or
                                                    self.hop_count.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.enable.yfilter != YFilter.not_set or
                                                    self.hop_count.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ttl" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                                if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.hop_count.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "enable" or name == "hop-count"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "enable"):
                                                    self.enable = value
                                                    self.enable.value_namespace = name_space
                                                    self.enable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "hop-count"):
                                                    self.hop_count = value
                                                    self.hop_count.value_namespace = name_space
                                                    self.hop_count.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (self.ttl is not None and self.ttl.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.ttl is not None and self.ttl.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "security" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "ttl"):
                                                if (self.ttl is None):
                                                    self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                                    self.ttl.parent = self
                                                    self._children_name_map["ttl"] = "ttl"
                                                return self.ttl

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "ttl"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "name-scope"

                                            self.neighbor = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("neighbor_address",
                                                                "cost",
                                                                "database_filter",
                                                                "poll_interval",
                                                                "priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.neighbor_address.is_set or
                                                    self.cost.is_set or
                                                    self.database_filter.is_set or
                                                    self.poll_interval.is_set or
                                                    self.priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.cost.yfilter != YFilter.not_set or
                                                    self.database_filter.yfilter != YFilter.not_set or
                                                    self.poll_interval.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                                if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost"):
                                                    self.cost = value
                                                    self.cost.value_namespace = name_space
                                                    self.cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "database-filter"):
                                                    self.database_filter = value
                                                    self.database_filter.value_namespace = name_space
                                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                                if(value_path == "poll-interval"):
                                                    self.poll_interval = value
                                                    self.poll_interval.value_namespace = name_space
                                                    self.poll_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.neighbor:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.neighbor:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbors" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor"):
                                                for c in self.neighbor:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.neighbor.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "name-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "name-scope"

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_enable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only",
                                                                "topology_independent_lfa") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("maximum_cost",
                                                                    "tunnel") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.maximum_cost.is_set or
                                                        self.tunnel.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.maximum_cost.yfilter != YFilter.not_set or
                                                        self.tunnel.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-lfa" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                    if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "maximum-cost" or name == "tunnel"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "maximum-cost"):
                                                        self.maximum_cost = value
                                                        self.maximum_cost.value_namespace = name_space
                                                        self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel"):
                                                        self.tunnel = value
                                                        self.tunnel.value_namespace = name_space
                                                        self.tunnel.value_namespace_prefix = name_space_prefix


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.tiebreaker = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("tiebreaker_type",
                                                                        "tiebreaker_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.tiebreaker_type.is_set or
                                                            self.tiebreaker_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.tiebreaker_type.yfilter != YFilter.not_set or
                                                            self.tiebreaker_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "tiebreaker-type"):
                                                            self.tiebreaker_type = value
                                                            self.tiebreaker_type.value_namespace = name_space
                                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tiebreaker-index"):
                                                            self.tiebreaker_index = value
                                                            self.tiebreaker_index.value_namespace = name_space
                                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreakers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tiebreaker"):
                                                        for c in self.tiebreaker:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tiebreaker.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    self.topology_independent_lfa.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-prefix" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                                if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                if (child_yang_name == "remote-lfa"):
                                                    if (self.remote_lfa is None):
                                                        self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                        self.remote_lfa.parent = self
                                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                                    return self.remote_lfa

                                                if (child_yang_name == "tiebreakers"):
                                                    if (self.tiebreakers is None):
                                                        self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                        self.tiebreakers.parent = self
                                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                                    return self.tiebreakers

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "topology-independent-lfa"):
                                                    self.topology_independent_lfa = value
                                                    self.topology_independent_lfa.value_namespace = name_space
                                                    self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_enable.is_set or
                                                (self.per_link is not None and self.per_link.has_data()) or
                                                (self.per_prefix is not None and self.per_prefix.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_enable.yfilter != YFilter.not_set or
                                                (self.per_link is not None and self.per_link.has_operation()) or
                                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fast-reroute" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "per-link"):
                                                if (self.per_link is None):
                                                    self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                                    self.per_link.parent = self
                                                    self._children_name_map["per_link"] = "per-link"
                                                return self.per_link

                                            if (child_yang_name == "per-prefix"):
                                                if (self.per_prefix is None):
                                                    self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                                    self.per_prefix.parent = self
                                                    self._children_name_map["per_prefix"] = "per-prefix"
                                                return self.per_prefix

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-enable"):
                                                self.fast_reroute_enable = value
                                                self.fast_reroute_enable.value_namespace = name_space
                                                self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "name-scope"

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cost",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cost.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "cost-fallback" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cost" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.interface_name.is_set or
                                            self.cost.is_set or
                                            self.database_filter.is_set or
                                            self.demand_circuit.is_set or
                                            self.flood_reduction.is_set or
                                            self.hello_interval.is_set or
                                            self.ldp_auto_config.is_set or
                                            self.ldp_sync.is_set or
                                            self.ldp_sync_igp_shortcuts.is_set or
                                            self.link_down_fast_detect.is_set or
                                            self.loopback_stub_network.is_set or
                                            self.mtu_ignore.is_set or
                                            self.network_type.is_set or
                                            self.packet_size.is_set or
                                            self.passive.is_set or
                                            self.prefix_suppression_primary.is_set or
                                            self.prefix_suppression_secondary.is_set or
                                            self.priority.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.segment_routing_forwarding.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.bfd is not None and self.bfd.has_data()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                            (self.neighbors is not None and self.neighbors.has_data()) or
                                            (self.security is not None and self.security.has_data()) or
                                            (self.distribute_list is not None) or
                                            (self.prefix_sid is not None) or
                                            (self.prefix_sid_strict is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.database_filter.yfilter != YFilter.not_set or
                                            self.demand_circuit.yfilter != YFilter.not_set or
                                            self.flood_reduction.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.ldp_auto_config.yfilter != YFilter.not_set or
                                            self.ldp_sync.yfilter != YFilter.not_set or
                                            self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                            self.link_down_fast_detect.yfilter != YFilter.not_set or
                                            self.loopback_stub_network.yfilter != YFilter.not_set or
                                            self.mtu_ignore.yfilter != YFilter.not_set or
                                            self.network_type.yfilter != YFilter.not_set or
                                            self.packet_size.yfilter != YFilter.not_set or
                                            self.passive.yfilter != YFilter.not_set or
                                            self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                            self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.bfd is not None and self.bfd.has_operation()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                            (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                            (self.neighbors is not None and self.neighbors.has_operation()) or
                                            (self.prefix_sid is not None and self.prefix_sid.has_operation()) or
                                            (self.prefix_sid_strict is not None and self.prefix_sid_strict.has_operation()) or
                                            (self.security is not None and self.security.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "name-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.database_filter.get_name_leafdata())
                                        if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                        if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                        if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                        if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                        if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                        if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                        if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                        if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.network_type.get_name_leafdata())
                                        if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_size.get_name_leafdata())
                                        if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.passive.get_name_leafdata())
                                        if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                        if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "bfd"):
                                            if (self.bfd is None):
                                                self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                                self.bfd.parent = self
                                                self._children_name_map["bfd"] = "bfd"
                                            return self.bfd

                                        if (child_yang_name == "cost-fallback"):
                                            if (self.cost_fallback is None):
                                                self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                                self.cost_fallback.parent = self
                                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                            return self.cost_fallback

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        if (child_yang_name == "distribute-list"):
                                            if (self.distribute_list is None):
                                                self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList()
                                                self.distribute_list.parent = self
                                                self._children_name_map["distribute_list"] = "distribute-list"
                                            return self.distribute_list

                                        if (child_yang_name == "fast-reroute"):
                                            if (self.fast_reroute is None):
                                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                                self.fast_reroute.parent = self
                                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                            return self.fast_reroute

                                        if (child_yang_name == "neighbors"):
                                            if (self.neighbors is None):
                                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                                self.neighbors.parent = self
                                                self._children_name_map["neighbors"] = "neighbors"
                                            return self.neighbors

                                        if (child_yang_name == "prefix-sid"):
                                            if (self.prefix_sid is None):
                                                self.prefix_sid = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid()
                                                self.prefix_sid.parent = self
                                                self._children_name_map["prefix_sid"] = "prefix-sid"
                                            return self.prefix_sid

                                        if (child_yang_name == "prefix-sid-strict"):
                                            if (self.prefix_sid_strict is None):
                                                self.prefix_sid_strict = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict()
                                                self.prefix_sid_strict.parent = self
                                                self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                            return self.prefix_sid_strict

                                        if (child_yang_name == "security"):
                                            if (self.security is None):
                                                self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                                self.security.parent = self
                                                self._children_name_map["security"] = "security"
                                            return self.security

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "prefix-sid" or name == "prefix-sid-strict" or name == "security" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "running" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "database-filter"):
                                            self.database_filter = value
                                            self.database_filter.value_namespace = name_space
                                            self.database_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "demand-circuit"):
                                            self.demand_circuit = value
                                            self.demand_circuit.value_namespace = name_space
                                            self.demand_circuit.value_namespace_prefix = name_space_prefix
                                        if(value_path == "flood-reduction"):
                                            self.flood_reduction = value
                                            self.flood_reduction.value_namespace = name_space
                                            self.flood_reduction.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-auto-config"):
                                            self.ldp_auto_config = value
                                            self.ldp_auto_config.value_namespace = name_space
                                            self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-sync"):
                                            self.ldp_sync = value
                                            self.ldp_sync.value_namespace = name_space
                                            self.ldp_sync.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ldp-sync-igp-shortcuts"):
                                            self.ldp_sync_igp_shortcuts = value
                                            self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                            self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                        if(value_path == "link-down-fast-detect"):
                                            self.link_down_fast_detect = value
                                            self.link_down_fast_detect.value_namespace = name_space
                                            self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                        if(value_path == "loopback-stub-network"):
                                            self.loopback_stub_network = value
                                            self.loopback_stub_network.value_namespace = name_space
                                            self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-ignore"):
                                            self.mtu_ignore = value
                                            self.mtu_ignore.value_namespace = name_space
                                            self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                        if(value_path == "network-type"):
                                            self.network_type = value
                                            self.network_type.value_namespace = name_space
                                            self.network_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-size"):
                                            self.packet_size = value
                                            self.packet_size.value_namespace = name_space
                                            self.packet_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "passive"):
                                            self.passive = value
                                            self.passive.value_namespace = name_space
                                            self.passive.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppression-primary"):
                                            self.prefix_suppression_primary = value
                                            self.prefix_suppression_primary.value_namespace = name_space
                                            self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                        if(value_path == "prefix-suppression-secondary"):
                                            self.prefix_suppression_secondary = value
                                            self.prefix_suppression_secondary.value_namespace = name_space
                                            self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "segment-routing-forwarding"):
                                            self.segment_routing_forwarding = value
                                            self.segment_routing_forwarding.value_namespace = name_space
                                            self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.name_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.name_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "name-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "name-scope"):
                                        for c in self.name_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.name_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "name-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class MultiAreaInterfaceScopes(Entity):
                                """
                                Multi Area Interface scope configurations
                                
                                .. attribute:: multi_area_interface_scope
                                
                                	Multi Area Interface configuration
                                	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__init__()

                                    self.yang_name = "multi-area-interface-scopes"
                                    self.yang_parent_name = "area-area-id"

                                    self.multi_area_interface_scope = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__setattr__(name, value)


                                class MultiAreaInterfaceScope(Entity):
                                    """
                                    Multi Area Interface configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Multi Area Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                        self.yang_name = "multi-area-interface-scope"
                                        self.yang_parent_name = "multi-area-interface-scopes"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "cost",
                                                        "database_filter",
                                                        "hello_interval",
                                                        "mtu_ignore",
                                                        "packet_size",
                                                        "passive",
                                                        "retransmit_interval",
                                                        "running",
                                                        "transmit_delay") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("access_list_name",
                                                            "route_policy_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.access_list_name.is_set or
                                                self.route_policy_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.access_list_name.yfilter != YFilter.not_set or
                                                self.route_policy_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "distribute-list" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "access-list-name" or name == "route-policy-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "access-list-name"):
                                                self.access_list_name = value
                                                self.access_list_name.value_namespace = name_space
                                                self.access_list_name.value_namespace_prefix = name_space_prefix
                                            if(value_path == "route-policy-name"):
                                                self.route_policy_name = value
                                                self.route_policy_name.value_namespace = name_space
                                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("authen_type",
                                                                "keychain_authen_type",
                                                                "keychain_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.authen_type.is_set or
                                                    self.keychain_authen_type.is_set or
                                                    self.keychain_name.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                                    self.keychain_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "type" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "authen-type"):
                                                    self.authen_type = value
                                                    self.authen_type.value_namespace = name_space
                                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-authen-type"):
                                                    self.keychain_authen_type = value
                                                    self.keychain_authen_type.value_namespace = name_space
                                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "keychain-name"):
                                                    self.keychain_name = value
                                                    self.keychain_name.value_namespace = name_space
                                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"

                                                self.message_digest_key = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("key_id",
                                                                    "password") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.key_id.is_set or
                                                        self.password.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.key_id.yfilter != YFilter.not_set or
                                                        self.password.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.password.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "key-id" or name == "password"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "key-id"):
                                                        self.key_id = value
                                                        self.key_id.value_namespace = name_space
                                                        self.key_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "password"):
                                                        self.password = value
                                                        self.password.value_namespace = name_space
                                                        self.password.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.message_digest_key:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-keies" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "message-digest-key"):
                                                    for c in self.message_digest_key:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.message_digest_key.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "message-digest-key"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.key.is_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                                (self.type is not None and self.type.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key.yfilter != YFilter.not_set or
                                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                                (self.type is not None and self.type.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "authentication" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-keies"):
                                                if (self.message_digest_keies is None):
                                                    self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                                    self.message_digest_keies.parent = self
                                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                                return self.message_digest_keies

                                            if (child_yang_name == "type"):
                                                if (self.type is None):
                                                    self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                                    self.type.parent = self
                                                    self._children_name_map["type"] = "type"
                                                return self.type

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key"):
                                                self.key = value
                                                self.key.value_namespace = name_space
                                                self.key.value_namespace_prefix = name_space_prefix


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.neighbor = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("neighbor_address",
                                                                "cost",
                                                                "database_filter",
                                                                "poll_interval",
                                                                "priority") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.neighbor_address.is_set or
                                                    self.cost.is_set or
                                                    self.database_filter.is_set or
                                                    self.poll_interval.is_set or
                                                    self.priority.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.cost.yfilter != YFilter.not_set or
                                                    self.database_filter.yfilter != YFilter.not_set or
                                                    self.poll_interval.yfilter != YFilter.not_set or
                                                    self.priority.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                                if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.priority.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "cost"):
                                                    self.cost = value
                                                    self.cost.value_namespace = name_space
                                                    self.cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "database-filter"):
                                                    self.database_filter = value
                                                    self.database_filter.value_namespace = name_space
                                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                                if(value_path == "poll-interval"):
                                                    self.poll_interval = value
                                                    self.poll_interval.value_namespace = name_space
                                                    self.poll_interval.value_namespace_prefix = name_space_prefix
                                                if(value_path == "priority"):
                                                    self.priority = value
                                                    self.priority.value_namespace = name_space
                                                    self.priority.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.neighbor:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.neighbor:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbors" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "neighbor"):
                                                for c in self.neighbor:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.neighbor.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("interval",
                                                            "multiplier") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.interval.is_set or
                                                self.multiplier.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.interval.yfilter != YFilter.not_set or
                                                self.multiplier.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "dead-interval-minimal" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.interval.get_name_leafdata())
                                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "interval" or name == "multiplier"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "interval"):
                                                self.interval = value
                                                self.interval.value_namespace = name_space
                                                self.interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multiplier"):
                                                self.multiplier = value
                                                self.multiplier.value_namespace = name_space
                                                self.multiplier.value_namespace_prefix = name_space_prefix


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_enable") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-link" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("fast_reroute_use_candidate_only",
                                                                "topology_independent_lfa") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("maximum_cost",
                                                                    "tunnel") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.maximum_cost.is_set or
                                                        self.tunnel.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.maximum_cost.yfilter != YFilter.not_set or
                                                        self.tunnel.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "remote-lfa" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                    if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "maximum-cost" or name == "tunnel"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "maximum-cost"):
                                                        self.maximum_cost = value
                                                        self.maximum_cost.value_namespace = name_space
                                                        self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel"):
                                                        self.tunnel = value
                                                        self.tunnel.value_namespace = name_space
                                                        self.tunnel.value_namespace_prefix = name_space_prefix


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.tiebreaker = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("tiebreaker_type",
                                                                        "tiebreaker_index") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.tiebreaker_type.is_set or
                                                            self.tiebreaker_index.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.tiebreaker_type.yfilter != YFilter.not_set or
                                                            self.tiebreaker_index.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                        if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "tiebreaker-type"):
                                                            self.tiebreaker_type = value
                                                            self.tiebreaker_type.value_namespace = name_space
                                                            self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tiebreaker-index"):
                                                            self.tiebreaker_index = value
                                                            self.tiebreaker_index.value_namespace = name_space
                                                            self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.tiebreaker:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreakers" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "tiebreaker"):
                                                        for c in self.tiebreaker:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.tiebreaker.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.candidate_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.candidate_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "candidate-interface"):
                                                        for c in self.candidate_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.candidate_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "candidate-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"

                                                    self.exclude_interface = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in () and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-01-02'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("interface_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.interface_name.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.interface_name.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "interface-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "interface-name"):
                                                            self.interface_name = value
                                                            self.interface_name.value_namespace = name_space
                                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_data()):
                                                            return True
                                                    return False

                                                def has_operation(self):
                                                    for c in self.exclude_interface:
                                                        if (c.has_operation()):
                                                            return True
                                                    return self.yfilter != YFilter.not_set

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interfaces" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "exclude-interface"):
                                                        for c in self.exclude_interface:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.exclude_interface.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "exclude-interface"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    self.fast_reroute_use_candidate_only.is_set or
                                                    self.topology_independent_lfa.is_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                    self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                    (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                    (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-prefix" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                                if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interfaces"):
                                                    if (self.candidate_interfaces is None):
                                                        self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                        self.candidate_interfaces.parent = self
                                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                    return self.candidate_interfaces

                                                if (child_yang_name == "exclude-interfaces"):
                                                    if (self.exclude_interfaces is None):
                                                        self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                        self.exclude_interfaces.parent = self
                                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                    return self.exclude_interfaces

                                                if (child_yang_name == "remote-lfa"):
                                                    if (self.remote_lfa is None):
                                                        self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                        self.remote_lfa.parent = self
                                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                                    return self.remote_lfa

                                                if (child_yang_name == "tiebreakers"):
                                                    if (self.tiebreakers is None):
                                                        self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                        self.tiebreakers.parent = self
                                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                                    return self.tiebreakers

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "fast-reroute-use-candidate-only"):
                                                    self.fast_reroute_use_candidate_only = value
                                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                                if(value_path == "topology-independent-lfa"):
                                                    self.topology_independent_lfa = value
                                                    self.topology_independent_lfa.value_namespace = name_space
                                                    self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_enable.is_set or
                                                (self.per_link is not None and self.per_link.has_data()) or
                                                (self.per_prefix is not None and self.per_prefix.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_enable.yfilter != YFilter.not_set or
                                                (self.per_link is not None and self.per_link.has_operation()) or
                                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "fast-reroute" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "per-link"):
                                                if (self.per_link is None):
                                                    self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                                    self.per_link.parent = self
                                                    self._children_name_map["per_link"] = "per-link"
                                                return self.per_link

                                            if (child_yang_name == "per-prefix"):
                                                if (self.per_prefix is None):
                                                    self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                                    self.per_prefix.parent = self
                                                    self._children_name_map["per_prefix"] = "per-prefix"
                                                return self.per_prefix

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-enable"):
                                                self.fast_reroute_enable = value
                                                self.fast_reroute_enable.value_namespace = name_space
                                                self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "multi-area-interface-scope"

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("cost",
                                                            "threshold") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.cost.is_set or
                                                self.threshold.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.threshold.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "cost-fallback" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.threshold.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "cost" or name == "threshold"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "threshold"):
                                                self.threshold = value
                                                self.threshold.value_namespace = name_space
                                                self.threshold.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.interface_name.is_set or
                                            self.cost.is_set or
                                            self.database_filter.is_set or
                                            self.hello_interval.is_set or
                                            self.mtu_ignore.is_set or
                                            self.packet_size.is_set or
                                            self.passive.is_set or
                                            self.retransmit_interval.is_set or
                                            self.running.is_set or
                                            self.transmit_delay.is_set or
                                            (self.authentication is not None and self.authentication.has_data()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                            (self.neighbors is not None and self.neighbors.has_data()) or
                                            (self.distribute_list is not None))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.database_filter.yfilter != YFilter.not_set or
                                            self.hello_interval.yfilter != YFilter.not_set or
                                            self.mtu_ignore.yfilter != YFilter.not_set or
                                            self.packet_size.yfilter != YFilter.not_set or
                                            self.passive.yfilter != YFilter.not_set or
                                            self.retransmit_interval.yfilter != YFilter.not_set or
                                            self.running.yfilter != YFilter.not_set or
                                            self.transmit_delay.yfilter != YFilter.not_set or
                                            (self.authentication is not None and self.authentication.has_operation()) or
                                            (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                            (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                            (self.neighbors is not None and self.neighbors.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.database_filter.get_name_leafdata())
                                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                        if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                        if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.packet_size.get_name_leafdata())
                                        if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.passive.get_name_leafdata())
                                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                        if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.running.get_name_leafdata())
                                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "authentication"):
                                            if (self.authentication is None):
                                                self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                            return self.authentication

                                        if (child_yang_name == "cost-fallback"):
                                            if (self.cost_fallback is None):
                                                self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                                self.cost_fallback.parent = self
                                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                            return self.cost_fallback

                                        if (child_yang_name == "dead-interval-minimal"):
                                            if (self.dead_interval_minimal is None):
                                                self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                                self.dead_interval_minimal.parent = self
                                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                            return self.dead_interval_minimal

                                        if (child_yang_name == "distribute-list"):
                                            if (self.distribute_list is None):
                                                self.distribute_list = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList()
                                                self.distribute_list.parent = self
                                                self._children_name_map["distribute_list"] = "distribute-list"
                                            return self.distribute_list

                                        if (child_yang_name == "fast-reroute"):
                                            if (self.fast_reroute is None):
                                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                                self.fast_reroute.parent = self
                                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                            return self.fast_reroute

                                        if (child_yang_name == "neighbors"):
                                            if (self.neighbors is None):
                                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                                self.neighbors.parent = self
                                                self._children_name_map["neighbors"] = "neighbors"
                                            return self.neighbors

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authentication" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "hello-interval" or name == "mtu-ignore" or name == "packet-size" or name == "passive" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "database-filter"):
                                            self.database_filter = value
                                            self.database_filter.value_namespace = name_space
                                            self.database_filter.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hello-interval"):
                                            self.hello_interval = value
                                            self.hello_interval.value_namespace = name_space
                                            self.hello_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "mtu-ignore"):
                                            self.mtu_ignore = value
                                            self.mtu_ignore.value_namespace = name_space
                                            self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                        if(value_path == "packet-size"):
                                            self.packet_size = value
                                            self.packet_size.value_namespace = name_space
                                            self.packet_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "passive"):
                                            self.passive = value
                                            self.passive.value_namespace = name_space
                                            self.passive.value_namespace_prefix = name_space_prefix
                                        if(value_path == "retransmit-interval"):
                                            self.retransmit_interval = value
                                            self.retransmit_interval.value_namespace = name_space
                                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "running"):
                                            self.running = value
                                            self.running.value_namespace = name_space
                                            self.running.value_namespace_prefix = name_space_prefix
                                        if(value_path == "transmit-delay"):
                                            self.transmit_delay = value
                                            self.transmit_delay.value_namespace = name_space
                                            self.transmit_delay.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.multi_area_interface_scope:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.multi_area_interface_scope:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-area-interface-scopes" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "multi-area-interface-scope"):
                                        for c in self.multi_area_interface_scope:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.multi_area_interface_scope.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "multi-area-interface-scope"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AreaRanges(Entity):
                                """
                                Summarize routes matching address/mask (border
                                routers only)
                                
                                .. attribute:: area_range
                                
                                	Ordering index
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges, self).__init__()

                                    self.yang_name = "area-ranges"
                                    self.yang_parent_name = "area-area-id"

                                    self.area_range = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges, self).__setattr__(name, value)


                                class AreaRange(Entity):
                                    """
                                    Ordering index
                                    
                                    .. attribute:: address  <key>
                                    
                                    	IP address to match
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: netmask  <key>
                                    
                                    	IP netmask for address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise this range
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "area-ranges"

                                        self.address = YLeaf(YType.str, "address")

                                        self.netmask = YLeaf(YType.str, "netmask")

                                        self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("address",
                                                        "netmask",
                                                        "not_advertise") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.address.is_set or
                                            self.netmask.is_set or
                                            self.not_advertise.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.address.yfilter != YFilter.not_set or
                                            self.netmask.yfilter != YFilter.not_set or
                                            self.not_advertise.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.address.get_name_leafdata())
                                        if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.netmask.get_name_leafdata())
                                        if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.not_advertise.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "address" or name == "netmask" or name == "not-advertise"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "address"):
                                            self.address = value
                                            self.address.value_namespace = name_space
                                            self.address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "netmask"):
                                            self.netmask = value
                                            self.netmask.value_namespace = name_space
                                            self.netmask.value_namespace_prefix = name_space_prefix
                                        if(value_path == "not-advertise"):
                                            self.not_advertise = value
                                            self.not_advertise.value_namespace = name_space
                                            self.not_advertise.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.area_range:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.area_range:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-ranges" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "area-range"):
                                        for c in self.area_range:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.area_range.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "area-range"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Nssa(Entity):
                                """
                                Specify area as a NSSA area
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric_type
                                
                                	OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                	**default value**\: type2
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: nssa_def_metric
                                
                                	OSPF default metric
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area-area-id"

                                    self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                    self.no_summary = YLeaf(YType.boolean, "no-summary")

                                    self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("default_info_originate",
                                                    "metric_type",
                                                    "no_redistribution",
                                                    "no_summary",
                                                    "nssa_def_metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.default_info_originate.is_set or
                                        self.metric_type.is_set or
                                        self.no_redistribution.is_set or
                                        self.no_summary.is_set or
                                        self.nssa_def_metric.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.default_info_originate.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.no_redistribution.yfilter != YFilter.not_set or
                                        self.no_summary.yfilter != YFilter.not_set or
                                        self.nssa_def_metric.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "nssa" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.no_redistribution.is_set or self.no_redistribution.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_redistribution.get_name_leafdata())
                                    if (self.no_summary.is_set or self.no_summary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.no_summary.get_name_leafdata())
                                    if (self.nssa_def_metric.is_set or self.nssa_def_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.nssa_def_metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "default-info-originate" or name == "metric-type" or name == "no-redistribution" or name == "no-summary" or name == "nssa-def-metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "default-info-originate"):
                                        self.default_info_originate = value
                                        self.default_info_originate.value_namespace = name_space
                                        self.default_info_originate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-redistribution"):
                                        self.no_redistribution = value
                                        self.no_redistribution.value_namespace = name_space
                                        self.no_redistribution.value_namespace_prefix = name_space_prefix
                                    if(value_path == "no-summary"):
                                        self.no_summary = value
                                        self.no_summary.value_namespace = name_space
                                        self.no_summary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "nssa-def-metric"):
                                        self.nssa_def_metric = value
                                        self.nssa_def_metric.value_namespace = name_space
                                        self.nssa_def_metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.area_id.is_set or
                                    self.default_cost.is_set or
                                    self.external_out.is_set or
                                    self.mpls_traffic_eng.is_set or
                                    self.route_policy_in.is_set or
                                    self.route_policy_out.is_set or
                                    self.running.is_set or
                                    self.segment_routing.is_set or
                                    self.stub.is_set or
                                    self.summary_in.is_set or
                                    (self.area_ranges is not None and self.area_ranges.has_data()) or
                                    (self.area_scope is not None and self.area_scope.has_data()) or
                                    (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_data()) or
                                    (self.name_scopes is not None and self.name_scopes.has_data()) or
                                    (self.nssa is not None and self.nssa.has_data()) or
                                    (self.sham_link_scopes is not None and self.sham_link_scopes.has_data()) or
                                    (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.area_id.yfilter != YFilter.not_set or
                                    self.default_cost.yfilter != YFilter.not_set or
                                    self.external_out.yfilter != YFilter.not_set or
                                    self.mpls_traffic_eng.yfilter != YFilter.not_set or
                                    self.route_policy_in.yfilter != YFilter.not_set or
                                    self.route_policy_out.yfilter != YFilter.not_set or
                                    self.running.yfilter != YFilter.not_set or
                                    self.segment_routing.yfilter != YFilter.not_set or
                                    self.stub.yfilter != YFilter.not_set or
                                    self.summary_in.yfilter != YFilter.not_set or
                                    (self.area_ranges is not None and self.area_ranges.has_operation()) or
                                    (self.area_scope is not None and self.area_scope.has_operation()) or
                                    (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_operation()) or
                                    (self.name_scopes is not None and self.name_scopes.has_operation()) or
                                    (self.nssa is not None and self.nssa.has_operation()) or
                                    (self.sham_link_scopes is not None and self.sham_link_scopes.has_operation()) or
                                    (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-area-id" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.area_id.get_name_leafdata())
                                if (self.default_cost.is_set or self.default_cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_cost.get_name_leafdata())
                                if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.external_out.get_name_leafdata())
                                if (self.mpls_traffic_eng.is_set or self.mpls_traffic_eng.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mpls_traffic_eng.get_name_leafdata())
                                if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                                if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                                if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.running.get_name_leafdata())
                                if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing.get_name_leafdata())
                                if (self.stub.is_set or self.stub.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.stub.get_name_leafdata())
                                if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.summary_in.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-ranges"):
                                    if (self.area_ranges is None):
                                        self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges()
                                        self.area_ranges.parent = self
                                        self._children_name_map["area_ranges"] = "area-ranges"
                                    return self.area_ranges

                                if (child_yang_name == "area-scope"):
                                    if (self.area_scope is None):
                                        self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope()
                                        self.area_scope.parent = self
                                        self._children_name_map["area_scope"] = "area-scope"
                                    return self.area_scope

                                if (child_yang_name == "multi-area-interface-scopes"):
                                    if (self.multi_area_interface_scopes is None):
                                        self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                                        self.multi_area_interface_scopes.parent = self
                                        self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                    return self.multi_area_interface_scopes

                                if (child_yang_name == "name-scopes"):
                                    if (self.name_scopes is None):
                                        self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes()
                                        self.name_scopes.parent = self
                                        self._children_name_map["name_scopes"] = "name-scopes"
                                    return self.name_scopes

                                if (child_yang_name == "nssa"):
                                    if (self.nssa is None):
                                        self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa()
                                        self.nssa.parent = self
                                        self._children_name_map["nssa"] = "nssa"
                                    return self.nssa

                                if (child_yang_name == "sham-link-scopes"):
                                    if (self.sham_link_scopes is None):
                                        self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                                        self.sham_link_scopes.parent = self
                                        self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                    return self.sham_link_scopes

                                if (child_yang_name == "virtual-link-scopes"):
                                    if (self.virtual_link_scopes is None):
                                        self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                                        self.virtual_link_scopes.parent = self
                                        self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                    return self.virtual_link_scopes

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-ranges" or name == "area-scope" or name == "multi-area-interface-scopes" or name == "name-scopes" or name == "nssa" or name == "sham-link-scopes" or name == "virtual-link-scopes" or name == "area-id" or name == "default-cost" or name == "external-out" or name == "mpls-traffic-eng" or name == "route-policy-in" or name == "route-policy-out" or name == "running" or name == "segment-routing" or name == "stub" or name == "summary-in"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "area-id"):
                                    self.area_id = value
                                    self.area_id.value_namespace = name_space
                                    self.area_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "default-cost"):
                                    self.default_cost = value
                                    self.default_cost.value_namespace = name_space
                                    self.default_cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "external-out"):
                                    self.external_out = value
                                    self.external_out.value_namespace = name_space
                                    self.external_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "mpls-traffic-eng"):
                                    self.mpls_traffic_eng = value
                                    self.mpls_traffic_eng.value_namespace = name_space
                                    self.mpls_traffic_eng.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-policy-in"):
                                    self.route_policy_in = value
                                    self.route_policy_in.value_namespace = name_space
                                    self.route_policy_in.value_namespace_prefix = name_space_prefix
                                if(value_path == "route-policy-out"):
                                    self.route_policy_out = value
                                    self.route_policy_out.value_namespace = name_space
                                    self.route_policy_out.value_namespace_prefix = name_space_prefix
                                if(value_path == "running"):
                                    self.running = value
                                    self.running.value_namespace = name_space
                                    self.running.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing"):
                                    self.segment_routing = value
                                    self.segment_routing.value_namespace = name_space
                                    self.segment_routing.value_namespace_prefix = name_space_prefix
                                if(value_path == "stub"):
                                    self.stub = value
                                    self.stub.value_namespace = name_space
                                    self.stub.value_namespace_prefix = name_space_prefix
                                if(value_path == "summary-in"):
                                    self.summary_in = value
                                    self.summary_in.value_namespace = name_space
                                    self.summary_in.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.area_address:
                                if (c.has_data()):
                                    return True
                            for c in self.area_area_id:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.area_address:
                                if (c.has_operation()):
                                    return True
                            for c in self.area_area_id:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "area-addresses" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area-address"):
                                for c in self.area_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.area_address.append(c)
                                return c

                            if (child_yang_name == "area-area-id"):
                                for c in self.area_area_id:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.area_area_id.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area-address" or name == "area-area-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Timers(Entity):
                        """
                        Adjust routing timers
                        
                        .. attribute:: fast_reroute_timer
                        
                        	Number of ms between end of SPF and start of IPFRR computation
                        	**type**\:  int
                        
                        	**range:** 50..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 500
                        
                        .. attribute:: lsa_generation_timer
                        
                        	OSPF LSA timers (in milliseconds)
                        	**type**\:   :py:class:`LsaGenerationTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer>`
                        
                        .. attribute:: lsa_group_pacing
                        
                        	LSA group pacing timer (Seconds between group of LSAs being refreshed or maxaged)
                        	**type**\:  int
                        
                        	**range:** 10..1800
                        
                        	**units**\: second
                        
                        	**default value**\: 240
                        
                        .. attribute:: lsa_min_arrival
                        
                        	MinLSArrival timer (minimum interval in milliseconds between accepting the same LSA)
                        	**type**\:  int
                        
                        	**range:** 0..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 100
                        
                        .. attribute:: lsa_pacing_flood
                        
                        	Seconds between group of LSAs being refreshed or maxaged
                        	**type**\:  int
                        
                        	**range:** 5..100
                        
                        	**units**\: second
                        
                        .. attribute:: lsa_refresh
                        
                        	How often self\-originated LSAs should be refreshed
                        	**type**\:  int
                        
                        	**range:** 1800..2700
                        
                        	**units**\: second
                        
                        	**default value**\: 1800
                        
                        .. attribute:: spf_timer
                        
                        	OSPF SPF timers (in milliseconds)
                        	**type**\:   :py:class:`SpfTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrf"

                            self.fast_reroute_timer = YLeaf(YType.uint32, "fast-reroute-timer")

                            self.lsa_group_pacing = YLeaf(YType.uint32, "lsa-group-pacing")

                            self.lsa_min_arrival = YLeaf(YType.uint32, "lsa-min-arrival")

                            self.lsa_pacing_flood = YLeaf(YType.uint32, "lsa-pacing-flood")

                            self.lsa_refresh = YLeaf(YType.uint32, "lsa-refresh")

                            self.lsa_generation_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer()
                            self.lsa_generation_timer.parent = self
                            self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                            self._children_yang_names.add("lsa-generation-timer")

                            self.spf_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer()
                            self.spf_timer.parent = self
                            self._children_name_map["spf_timer"] = "spf-timer"
                            self._children_yang_names.add("spf-timer")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("fast_reroute_timer",
                                            "lsa_group_pacing",
                                            "lsa_min_arrival",
                                            "lsa_pacing_flood",
                                            "lsa_refresh") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Timers, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Timers, self).__setattr__(name, value)


                        class SpfTimer(Entity):
                            """
                            OSPF SPF timers (in milliseconds)
                            
                            .. attribute:: backoff_increment
                            
                            	Number of milliseconds delay between successive SPF runs
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 10000
                            
                            .. attribute:: initial_delay
                            
                            	Number of milliseconds before first SPF run
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 5000
                            
                            .. attribute:: max_delay
                            
                            	Max number of milliseconds between consecutive SPF calculations
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 10000
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer, self).__init__()

                                self.yang_name = "spf-timer"
                                self.yang_parent_name = "timers"

                                self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                                self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                                self.max_delay = YLeaf(YType.uint32, "max-delay")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("backoff_increment",
                                                "initial_delay",
                                                "max_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.backoff_increment.is_set or
                                    self.initial_delay.is_set or
                                    self.max_delay.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.backoff_increment.yfilter != YFilter.not_set or
                                    self.initial_delay.yfilter != YFilter.not_set or
                                    self.max_delay.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "spf-timer" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.backoff_increment.is_set or self.backoff_increment.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backoff_increment.get_name_leafdata())
                                if (self.initial_delay.is_set or self.initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.initial_delay.get_name_leafdata())
                                if (self.max_delay.is_set or self.max_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backoff-increment" or name == "initial-delay" or name == "max-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "backoff-increment"):
                                    self.backoff_increment = value
                                    self.backoff_increment.value_namespace = name_space
                                    self.backoff_increment.value_namespace_prefix = name_space_prefix
                                if(value_path == "initial-delay"):
                                    self.initial_delay = value
                                    self.initial_delay.value_namespace = name_space
                                    self.initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-delay"):
                                    self.max_delay = value
                                    self.max_delay.value_namespace = name_space
                                    self.max_delay.value_namespace_prefix = name_space_prefix


                        class LsaGenerationTimer(Entity):
                            """
                            OSPF LSA timers (in milliseconds)
                            
                            .. attribute:: backoff_increment
                            
                            	Number of milliseconds delay between successive LSA builds
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 200
                            
                            .. attribute:: initial_delay
                            
                            	Number of milliseconds before generating first LSA
                            	**type**\:  int
                            
                            	**range:** 0..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 50
                            
                            .. attribute:: max_delay
                            
                            	Max number of milliseconds between consecutive LSA builds 
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 200
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer, self).__init__()

                                self.yang_name = "lsa-generation-timer"
                                self.yang_parent_name = "timers"

                                self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                                self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                                self.max_delay = YLeaf(YType.uint32, "max-delay")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("backoff_increment",
                                                "initial_delay",
                                                "max_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.backoff_increment.is_set or
                                    self.initial_delay.is_set or
                                    self.max_delay.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.backoff_increment.yfilter != YFilter.not_set or
                                    self.initial_delay.yfilter != YFilter.not_set or
                                    self.max_delay.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsa-generation-timer" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.backoff_increment.is_set or self.backoff_increment.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.backoff_increment.get_name_leafdata())
                                if (self.initial_delay.is_set or self.initial_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.initial_delay.get_name_leafdata())
                                if (self.max_delay.is_set or self.max_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.max_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "backoff-increment" or name == "initial-delay" or name == "max-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "backoff-increment"):
                                    self.backoff_increment = value
                                    self.backoff_increment.value_namespace = name_space
                                    self.backoff_increment.value_namespace_prefix = name_space_prefix
                                if(value_path == "initial-delay"):
                                    self.initial_delay = value
                                    self.initial_delay.value_namespace = name_space
                                    self.initial_delay.value_namespace_prefix = name_space_prefix
                                if(value_path == "max-delay"):
                                    self.max_delay = value
                                    self.max_delay.value_namespace = name_space
                                    self.max_delay.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.fast_reroute_timer.is_set or
                                self.lsa_group_pacing.is_set or
                                self.lsa_min_arrival.is_set or
                                self.lsa_pacing_flood.is_set or
                                self.lsa_refresh.is_set or
                                (self.lsa_generation_timer is not None and self.lsa_generation_timer.has_data()) or
                                (self.spf_timer is not None and self.spf_timer.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.fast_reroute_timer.yfilter != YFilter.not_set or
                                self.lsa_group_pacing.yfilter != YFilter.not_set or
                                self.lsa_min_arrival.yfilter != YFilter.not_set or
                                self.lsa_pacing_flood.yfilter != YFilter.not_set or
                                self.lsa_refresh.yfilter != YFilter.not_set or
                                (self.lsa_generation_timer is not None and self.lsa_generation_timer.has_operation()) or
                                (self.spf_timer is not None and self.spf_timer.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "timers" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.fast_reroute_timer.is_set or self.fast_reroute_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fast_reroute_timer.get_name_leafdata())
                            if (self.lsa_group_pacing.is_set or self.lsa_group_pacing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_group_pacing.get_name_leafdata())
                            if (self.lsa_min_arrival.is_set or self.lsa_min_arrival.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_min_arrival.get_name_leafdata())
                            if (self.lsa_pacing_flood.is_set or self.lsa_pacing_flood.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_pacing_flood.get_name_leafdata())
                            if (self.lsa_refresh.is_set or self.lsa_refresh.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsa_refresh.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "lsa-generation-timer"):
                                if (self.lsa_generation_timer is None):
                                    self.lsa_generation_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer()
                                    self.lsa_generation_timer.parent = self
                                    self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                                return self.lsa_generation_timer

                            if (child_yang_name == "spf-timer"):
                                if (self.spf_timer is None):
                                    self.spf_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer()
                                    self.spf_timer.parent = self
                                    self._children_name_map["spf_timer"] = "spf-timer"
                                return self.spf_timer

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lsa-generation-timer" or name == "spf-timer" or name == "fast-reroute-timer" or name == "lsa-group-pacing" or name == "lsa-min-arrival" or name == "lsa-pacing-flood" or name == "lsa-refresh"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "fast-reroute-timer"):
                                self.fast_reroute_timer = value
                                self.fast_reroute_timer.value_namespace = name_space
                                self.fast_reroute_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-group-pacing"):
                                self.lsa_group_pacing = value
                                self.lsa_group_pacing.value_namespace = name_space
                                self.lsa_group_pacing.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-min-arrival"):
                                self.lsa_min_arrival = value
                                self.lsa_min_arrival.value_namespace = name_space
                                self.lsa_min_arrival.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-pacing-flood"):
                                self.lsa_pacing_flood = value
                                self.lsa_pacing_flood.value_namespace = name_space
                                self.lsa_pacing_flood.value_namespace_prefix = name_space_prefix
                            if(value_path == "lsa-refresh"):
                                self.lsa_refresh = value
                                self.lsa_refresh.value_namespace = name_space
                                self.lsa_refresh.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.vrf_name.is_set or
                            self.adjacency_changes.is_set or
                            self.default_metric.is_set or
                            self.disable_dn_bit_check.is_set or
                            self.domain_tag.is_set or
                            self.ignore_mospf.is_set or
                            self.maximum_interfaces.is_set or
                            self.maximum_paths.is_set or
                            self.no_opaque.is_set or
                            self.router_id.is_set or
                            self.snmp_context.is_set or
                            self.snmp_trap_enabled.is_set or
                            self.spf_prefix_priority.is_set or
                            self.type7.is_set or
                            self.vrf_lite.is_set or
                            self.vrf_start.is_set or
                            (self.adjacency_stagger is not None and self.adjacency_stagger.has_data()) or
                            (self.area_addresses is not None and self.area_addresses.has_data()) or
                            (self.auto_cost is not None and self.auto_cost.has_data()) or
                            (self.default_information is not None and self.default_information.has_data()) or
                            (self.distance is not None and self.distance.has_data()) or
                            (self.domain_id is not None and self.domain_id.has_data()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                            (self.max_metric is not None and self.max_metric.has_data()) or
                            (self.maximum_redistribute_prefix is not None and self.maximum_redistribute_prefix.has_data()) or
                            (self.microloop is not None and self.microloop.has_data()) or
                            (self.nsf is not None and self.nsf.has_data()) or
                            (self.outgoing_route_updates is not None and self.outgoing_route_updates.has_data()) or
                            (self.process_scope is not None and self.process_scope.has_data()) or
                            (self.queue is not None and self.queue.has_data()) or
                            (self.redistribution is not None and self.redistribution.has_data()) or
                            (self.summary_prefixes is not None and self.summary_prefixes.has_data()) or
                            (self.timers is not None and self.timers.has_data()) or
                            (self.ucmp is not None and self.ucmp.has_data()) or
                            (self.af is not None) or
                            (self.max_lsa is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.vrf_name.yfilter != YFilter.not_set or
                            self.adjacency_changes.yfilter != YFilter.not_set or
                            self.default_metric.yfilter != YFilter.not_set or
                            self.disable_dn_bit_check.yfilter != YFilter.not_set or
                            self.domain_tag.yfilter != YFilter.not_set or
                            self.ignore_mospf.yfilter != YFilter.not_set or
                            self.maximum_interfaces.yfilter != YFilter.not_set or
                            self.maximum_paths.yfilter != YFilter.not_set or
                            self.no_opaque.yfilter != YFilter.not_set or
                            self.router_id.yfilter != YFilter.not_set or
                            self.snmp_context.yfilter != YFilter.not_set or
                            self.snmp_trap_enabled.yfilter != YFilter.not_set or
                            self.spf_prefix_priority.yfilter != YFilter.not_set or
                            self.type7.yfilter != YFilter.not_set or
                            self.vrf_lite.yfilter != YFilter.not_set or
                            self.vrf_start.yfilter != YFilter.not_set or
                            (self.adjacency_stagger is not None and self.adjacency_stagger.has_operation()) or
                            (self.af is not None and self.af.has_operation()) or
                            (self.area_addresses is not None and self.area_addresses.has_operation()) or
                            (self.auto_cost is not None and self.auto_cost.has_operation()) or
                            (self.default_information is not None and self.default_information.has_operation()) or
                            (self.distance is not None and self.distance.has_operation()) or
                            (self.domain_id is not None and self.domain_id.has_operation()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                            (self.max_lsa is not None and self.max_lsa.has_operation()) or
                            (self.max_metric is not None and self.max_metric.has_operation()) or
                            (self.maximum_redistribute_prefix is not None and self.maximum_redistribute_prefix.has_operation()) or
                            (self.microloop is not None and self.microloop.has_operation()) or
                            (self.nsf is not None and self.nsf.has_operation()) or
                            (self.outgoing_route_updates is not None and self.outgoing_route_updates.has_operation()) or
                            (self.process_scope is not None and self.process_scope.has_operation()) or
                            (self.queue is not None and self.queue.has_operation()) or
                            (self.redistribution is not None and self.redistribution.has_operation()) or
                            (self.summary_prefixes is not None and self.summary_prefixes.has_operation()) or
                            (self.timers is not None and self.timers.has_operation()) or
                            (self.ucmp is not None and self.ucmp.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_name.get_name_leafdata())
                        if (self.adjacency_changes.is_set or self.adjacency_changes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.adjacency_changes.get_name_leafdata())
                        if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_metric.get_name_leafdata())
                        if (self.disable_dn_bit_check.is_set or self.disable_dn_bit_check.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable_dn_bit_check.get_name_leafdata())
                        if (self.domain_tag.is_set or self.domain_tag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.domain_tag.get_name_leafdata())
                        if (self.ignore_mospf.is_set or self.ignore_mospf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ignore_mospf.get_name_leafdata())
                        if (self.maximum_interfaces.is_set or self.maximum_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_interfaces.get_name_leafdata())
                        if (self.maximum_paths.is_set or self.maximum_paths.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_paths.get_name_leafdata())
                        if (self.no_opaque.is_set or self.no_opaque.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_opaque.get_name_leafdata())
                        if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_id.get_name_leafdata())
                        if (self.snmp_context.is_set or self.snmp_context.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.snmp_context.get_name_leafdata())
                        if (self.snmp_trap_enabled.is_set or self.snmp_trap_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.snmp_trap_enabled.get_name_leafdata())
                        if (self.spf_prefix_priority.is_set or self.spf_prefix_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.spf_prefix_priority.get_name_leafdata())
                        if (self.type7.is_set or self.type7.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.type7.get_name_leafdata())
                        if (self.vrf_lite.is_set or self.vrf_lite.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_lite.get_name_leafdata())
                        if (self.vrf_start.is_set or self.vrf_start.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_start.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "adjacency-stagger"):
                            if (self.adjacency_stagger is None):
                                self.adjacency_stagger = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger()
                                self.adjacency_stagger.parent = self
                                self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                            return self.adjacency_stagger

                        if (child_yang_name == "af"):
                            if (self.af is None):
                                self.af = Ospf.Processes.Process.Vrfs.Vrf.Af()
                                self.af.parent = self
                                self._children_name_map["af"] = "af"
                            return self.af

                        if (child_yang_name == "area-addresses"):
                            if (self.area_addresses is None):
                                self.area_addresses = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses()
                                self.area_addresses.parent = self
                                self._children_name_map["area_addresses"] = "area-addresses"
                            return self.area_addresses

                        if (child_yang_name == "auto-cost"):
                            if (self.auto_cost is None):
                                self.auto_cost = Ospf.Processes.Process.Vrfs.Vrf.AutoCost()
                                self.auto_cost.parent = self
                                self._children_name_map["auto_cost"] = "auto-cost"
                            return self.auto_cost

                        if (child_yang_name == "default-information"):
                            if (self.default_information is None):
                                self.default_information = Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation()
                                self.default_information.parent = self
                                self._children_name_map["default_information"] = "default-information"
                            return self.default_information

                        if (child_yang_name == "distance"):
                            if (self.distance is None):
                                self.distance = Ospf.Processes.Process.Vrfs.Vrf.Distance()
                                self.distance.parent = self
                                self._children_name_map["distance"] = "distance"
                            return self.distance

                        if (child_yang_name == "domain-id"):
                            if (self.domain_id is None):
                                self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId()
                                self.domain_id.parent = self
                                self._children_name_map["domain_id"] = "domain-id"
                            return self.domain_id

                        if (child_yang_name == "fast-reroute"):
                            if (self.fast_reroute is None):
                                self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                            return self.fast_reroute

                        if (child_yang_name == "max-lsa"):
                            if (self.max_lsa is None):
                                self.max_lsa = Ospf.Processes.Process.Vrfs.Vrf.MaxLsa()
                                self.max_lsa.parent = self
                                self._children_name_map["max_lsa"] = "max-lsa"
                            return self.max_lsa

                        if (child_yang_name == "max-metric"):
                            if (self.max_metric is None):
                                self.max_metric = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric()
                                self.max_metric.parent = self
                                self._children_name_map["max_metric"] = "max-metric"
                            return self.max_metric

                        if (child_yang_name == "maximum-redistribute-prefix"):
                            if (self.maximum_redistribute_prefix is None):
                                self.maximum_redistribute_prefix = Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix()
                                self.maximum_redistribute_prefix.parent = self
                                self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                            return self.maximum_redistribute_prefix

                        if (child_yang_name == "microloop"):
                            if (self.microloop is None):
                                self.microloop = Ospf.Processes.Process.Vrfs.Vrf.Microloop()
                                self.microloop.parent = self
                                self._children_name_map["microloop"] = "microloop"
                            return self.microloop

                        if (child_yang_name == "nsf"):
                            if (self.nsf is None):
                                self.nsf = Ospf.Processes.Process.Vrfs.Vrf.Nsf()
                                self.nsf.parent = self
                                self._children_name_map["nsf"] = "nsf"
                            return self.nsf

                        if (child_yang_name == "outgoing-route-updates"):
                            if (self.outgoing_route_updates is None):
                                self.outgoing_route_updates = Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates()
                                self.outgoing_route_updates.parent = self
                                self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                            return self.outgoing_route_updates

                        if (child_yang_name == "process-scope"):
                            if (self.process_scope is None):
                                self.process_scope = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope()
                                self.process_scope.parent = self
                                self._children_name_map["process_scope"] = "process-scope"
                            return self.process_scope

                        if (child_yang_name == "queue"):
                            if (self.queue is None):
                                self.queue = Ospf.Processes.Process.Vrfs.Vrf.Queue()
                                self.queue.parent = self
                                self._children_name_map["queue"] = "queue"
                            return self.queue

                        if (child_yang_name == "redistribution"):
                            if (self.redistribution is None):
                                self.redistribution = Ospf.Processes.Process.Vrfs.Vrf.Redistribution()
                                self.redistribution.parent = self
                                self._children_name_map["redistribution"] = "redistribution"
                            return self.redistribution

                        if (child_yang_name == "summary-prefixes"):
                            if (self.summary_prefixes is None):
                                self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                                self.summary_prefixes.parent = self
                                self._children_name_map["summary_prefixes"] = "summary-prefixes"
                            return self.summary_prefixes

                        if (child_yang_name == "timers"):
                            if (self.timers is None):
                                self.timers = Ospf.Processes.Process.Vrfs.Vrf.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                            return self.timers

                        if (child_yang_name == "ucmp"):
                            if (self.ucmp is None):
                                self.ucmp = Ospf.Processes.Process.Vrfs.Vrf.Ucmp()
                                self.ucmp.parent = self
                                self._children_name_map["ucmp"] = "ucmp"
                            return self.ucmp

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "adjacency-stagger" or name == "af" or name == "area-addresses" or name == "auto-cost" or name == "default-information" or name == "distance" or name == "domain-id" or name == "fast-reroute" or name == "max-lsa" or name == "max-metric" or name == "maximum-redistribute-prefix" or name == "microloop" or name == "nsf" or name == "outgoing-route-updates" or name == "process-scope" or name == "queue" or name == "redistribution" or name == "summary-prefixes" or name == "timers" or name == "ucmp" or name == "vrf-name" or name == "adjacency-changes" or name == "default-metric" or name == "disable-dn-bit-check" or name == "domain-tag" or name == "ignore-mospf" or name == "maximum-interfaces" or name == "maximum-paths" or name == "no-opaque" or name == "router-id" or name == "snmp-context" or name == "snmp-trap-enabled" or name == "spf-prefix-priority" or name == "type7" or name == "vrf-lite" or name == "vrf-start"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "vrf-name"):
                            self.vrf_name = value
                            self.vrf_name.value_namespace = name_space
                            self.vrf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "adjacency-changes"):
                            self.adjacency_changes = value
                            self.adjacency_changes.value_namespace = name_space
                            self.adjacency_changes.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-metric"):
                            self.default_metric = value
                            self.default_metric.value_namespace = name_space
                            self.default_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable-dn-bit-check"):
                            self.disable_dn_bit_check = value
                            self.disable_dn_bit_check.value_namespace = name_space
                            self.disable_dn_bit_check.value_namespace_prefix = name_space_prefix
                        if(value_path == "domain-tag"):
                            self.domain_tag = value
                            self.domain_tag.value_namespace = name_space
                            self.domain_tag.value_namespace_prefix = name_space_prefix
                        if(value_path == "ignore-mospf"):
                            self.ignore_mospf = value
                            self.ignore_mospf.value_namespace = name_space
                            self.ignore_mospf.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-interfaces"):
                            self.maximum_interfaces = value
                            self.maximum_interfaces.value_namespace = name_space
                            self.maximum_interfaces.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-paths"):
                            self.maximum_paths = value
                            self.maximum_paths.value_namespace = name_space
                            self.maximum_paths.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-opaque"):
                            self.no_opaque = value
                            self.no_opaque.value_namespace = name_space
                            self.no_opaque.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-id"):
                            self.router_id = value
                            self.router_id.value_namespace = name_space
                            self.router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "snmp-context"):
                            self.snmp_context = value
                            self.snmp_context.value_namespace = name_space
                            self.snmp_context.value_namespace_prefix = name_space_prefix
                        if(value_path == "snmp-trap-enabled"):
                            self.snmp_trap_enabled = value
                            self.snmp_trap_enabled.value_namespace = name_space
                            self.snmp_trap_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "spf-prefix-priority"):
                            self.spf_prefix_priority = value
                            self.spf_prefix_priority.value_namespace = name_space
                            self.spf_prefix_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "type7"):
                            self.type7 = value
                            self.type7.value_namespace = name_space
                            self.type7.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-lite"):
                            self.vrf_lite = value
                            self.vrf_lite.value_namespace = name_space
                            self.vrf_lite.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-start"):
                            self.vrf_start = value
                            self.vrf_start.value_namespace = name_space
                            self.vrf_start.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.vrf:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.vrf:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrfs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "vrf"):
                        for c in self.vrf:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Ospf.Processes.Process.Vrfs.Vrf()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.vrf.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "vrf"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GracefulShutdownTimers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: graceful_shutdown_initial_delay
                
                	Number of seconds to delay before beginning graceful shutdown
                	**type**\:  int
                
                	**range:** 0..90
                
                	**units**\: second
                
                	**default value**\: 5
                
                .. attribute:: graceful_shutdown_retain_routes
                
                	Time to keep OSPF routes active after graceful shutdown(in seconds)
                	**type**\:  int
                
                	**range:** 0..90
                
                	**units**\: second
                
                	**default value**\: 5
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.GracefulShutdownTimers, self).__init__()

                    self.yang_name = "graceful-shutdown-timers"
                    self.yang_parent_name = "process"

                    self.graceful_shutdown_initial_delay = YLeaf(YType.uint32, "graceful-shutdown-initial-delay")

                    self.graceful_shutdown_retain_routes = YLeaf(YType.uint32, "graceful-shutdown-retain-routes")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("graceful_shutdown_initial_delay",
                                    "graceful_shutdown_retain_routes") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ospf.Processes.Process.GracefulShutdownTimers, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ospf.Processes.Process.GracefulShutdownTimers, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.graceful_shutdown_initial_delay.is_set or
                        self.graceful_shutdown_retain_routes.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.graceful_shutdown_initial_delay.yfilter != YFilter.not_set or
                        self.graceful_shutdown_retain_routes.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "graceful-shutdown-timers" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.graceful_shutdown_initial_delay.is_set or self.graceful_shutdown_initial_delay.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.graceful_shutdown_initial_delay.get_name_leafdata())
                    if (self.graceful_shutdown_retain_routes.is_set or self.graceful_shutdown_retain_routes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.graceful_shutdown_retain_routes.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "graceful-shutdown-initial-delay" or name == "graceful-shutdown-retain-routes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "graceful-shutdown-initial-delay"):
                        self.graceful_shutdown_initial_delay = value
                        self.graceful_shutdown_initial_delay.value_namespace = name_space
                        self.graceful_shutdown_initial_delay.value_namespace_prefix = name_space_prefix
                    if(value_path == "graceful-shutdown-retain-routes"):
                        self.graceful_shutdown_retain_routes = value
                        self.graceful_shutdown_retain_routes.value_namespace = name_space
                        self.graceful_shutdown_retain_routes.value_namespace_prefix = name_space_prefix


            class DefaultVrf(Entity):
                """
                Default VRF related configuration
                
                .. attribute:: adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:   :py:class:`OspfLogAdj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLogAdj>`
                
                .. attribute:: adjacency_stagger
                
                	Staggering OSPF adjacency bring up
                	**type**\:   :py:class:`AdjacencyStagger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AdjacencyStagger>`
                
                .. attribute:: af
                
                	OSPF address family
                	**type**\:   :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Af>`
                
                	**presence node**\: True
                
                .. attribute:: area_addresses
                
                	Area configuration
                	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses>`
                
                .. attribute:: auto_cost
                
                	Controls automatic cost based on bandwidth
                	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AutoCost>`
                
                .. attribute:: default_information
                
                	Control distribution of default information
                	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.DefaultInformation>`
                
                .. attribute:: default_metric
                
                	Set default metric of redistributed routes
                	**type**\:  int
                
                	**range:** 1..16777214
                
                	**default value**\: 1
                
                .. attribute:: distance
                
                	Administrative distance configuration
                	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance>`
                
                .. attribute:: fast_reroute
                
                	Fast\-reroute instance scoped parameters
                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute>`
                
                .. attribute:: ignore_mospf
                
                	Ignore MOSPF (Type 6) LSAs
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: max_lsa
                
                	Set max\-lsa configuration
                	**type**\:   :py:class:`MaxLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxLsa>`
                
                	**presence node**\: True
                
                .. attribute:: max_metric
                
                	Set maximum metric configuration
                	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric>`
                
                .. attribute:: maximum_interfaces
                
                	Max number of interfaces allowed to be configured
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                	**default value**\: 1024
                
                .. attribute:: maximum_paths
                
                	Forward packets over multiple paths (number of paths)
                	**type**\:  int
                
                	**range:** 1..64
                
                .. attribute:: maximum_redistribute_prefix
                
                	Maximum number of prefixes redistributed into OSPF
                	**type**\:   :py:class:`MaximumRedistributePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix>`
                
                .. attribute:: microloop
                
                	Microloop configuration
                	**type**\:   :py:class:`Microloop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Microloop>`
                
                .. attribute:: monitor_convergence
                
                	Enable convergence monitoring
                	**type**\:   :py:class:`MonitorConvergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MonitorConvergence>`
                
                .. attribute:: mpls
                
                	Configure MPLS routing protocol parameters
                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Mpls>`
                
                .. attribute:: no_opaque
                
                	Disable opaque LSAs
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nsf
                
                	Non Stop Forwarding configuration
                	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Nsf>`
                
                .. attribute:: outgoing_route_updates
                
                	Filter outgoing routing updates
                	**type**\:   :py:class:`OutgoingRouteUpdates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates>`
                
                .. attribute:: process_scope
                
                	Process scope configuration
                	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope>`
                
                .. attribute:: queue
                
                	Adjust OSPF input queue sizes and processing quantums
                	**type**\:   :py:class:`Queue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Queue>`
                
                .. attribute:: redistribution
                
                	Redistribute configurations
                	**type**\:   :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution>`
                
                .. attribute:: router_id
                
                	Router ID for this OSPF process. Enter an IP Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: segment_routing
                
                	Segment Routing instance scoped parameters
                	**type**\:   :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SegmentRouting>`
                
                .. attribute:: snmp_context
                
                	OSPF SNMP context configuration
                	**type**\:  str
                
                .. attribute:: spf_prefix_priority
                
                	Configure a route\-policy for prioritizing RIB route install
                	**type**\:  str
                
                .. attribute:: summary_prefixes
                
                	Configure IP prefix summary
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: timers
                
                	Adjust routing timers
                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers>`
                
                .. attribute:: type7
                
                	Prefer type7 externals over type5
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ucmp
                
                	Unequal Cost Multi\-ptah configuration
                	**type**\:   :py:class:`Ucmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp>`
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-01-02'

                def __init__(self):
                    super(Ospf.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"

                    self.adjacency_changes = YLeaf(YType.enumeration, "adjacency-changes")

                    self.default_metric = YLeaf(YType.uint32, "default-metric")

                    self.ignore_mospf = YLeaf(YType.empty, "ignore-mospf")

                    self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                    self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                    self.no_opaque = YLeaf(YType.empty, "no-opaque")

                    self.router_id = YLeaf(YType.str, "router-id")

                    self.snmp_context = YLeaf(YType.str, "snmp-context")

                    self.spf_prefix_priority = YLeaf(YType.str, "spf-prefix-priority")

                    self.type7 = YLeaf(YType.empty, "type7")

                    self.adjacency_stagger = Ospf.Processes.Process.DefaultVrf.AdjacencyStagger()
                    self.adjacency_stagger.parent = self
                    self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                    self._children_yang_names.add("adjacency-stagger")

                    self.af = None
                    self._children_name_map["af"] = "af"
                    self._children_yang_names.add("af")

                    self.area_addresses = Ospf.Processes.Process.DefaultVrf.AreaAddresses()
                    self.area_addresses.parent = self
                    self._children_name_map["area_addresses"] = "area-addresses"
                    self._children_yang_names.add("area-addresses")

                    self.auto_cost = Ospf.Processes.Process.DefaultVrf.AutoCost()
                    self.auto_cost.parent = self
                    self._children_name_map["auto_cost"] = "auto-cost"
                    self._children_yang_names.add("auto-cost")

                    self.default_information = Ospf.Processes.Process.DefaultVrf.DefaultInformation()
                    self.default_information.parent = self
                    self._children_name_map["default_information"] = "default-information"
                    self._children_yang_names.add("default-information")

                    self.distance = Ospf.Processes.Process.DefaultVrf.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"
                    self._children_yang_names.add("distance")

                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                    self.fast_reroute.parent = self
                    self._children_name_map["fast_reroute"] = "fast-reroute"
                    self._children_yang_names.add("fast-reroute")

                    self.max_lsa = None
                    self._children_name_map["max_lsa"] = "max-lsa"
                    self._children_yang_names.add("max-lsa")

                    self.max_metric = Ospf.Processes.Process.DefaultVrf.MaxMetric()
                    self.max_metric.parent = self
                    self._children_name_map["max_metric"] = "max-metric"
                    self._children_yang_names.add("max-metric")

                    self.maximum_redistribute_prefix = Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix()
                    self.maximum_redistribute_prefix.parent = self
                    self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                    self._children_yang_names.add("maximum-redistribute-prefix")

                    self.microloop = Ospf.Processes.Process.DefaultVrf.Microloop()
                    self.microloop.parent = self
                    self._children_name_map["microloop"] = "microloop"
                    self._children_yang_names.add("microloop")

                    self.monitor_convergence = Ospf.Processes.Process.DefaultVrf.MonitorConvergence()
                    self.monitor_convergence.parent = self
                    self._children_name_map["monitor_convergence"] = "monitor-convergence"
                    self._children_yang_names.add("monitor-convergence")

                    self.mpls = Ospf.Processes.Process.DefaultVrf.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"
                    self._children_yang_names.add("mpls")

                    self.nsf = Ospf.Processes.Process.DefaultVrf.Nsf()
                    self.nsf.parent = self
                    self._children_name_map["nsf"] = "nsf"
                    self._children_yang_names.add("nsf")

                    self.outgoing_route_updates = Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates()
                    self.outgoing_route_updates.parent = self
                    self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                    self._children_yang_names.add("outgoing-route-updates")

                    self.process_scope = Ospf.Processes.Process.DefaultVrf.ProcessScope()
                    self.process_scope.parent = self
                    self._children_name_map["process_scope"] = "process-scope"
                    self._children_yang_names.add("process-scope")

                    self.queue = Ospf.Processes.Process.DefaultVrf.Queue()
                    self.queue.parent = self
                    self._children_name_map["queue"] = "queue"
                    self._children_yang_names.add("queue")

                    self.redistribution = Ospf.Processes.Process.DefaultVrf.Redistribution()
                    self.redistribution.parent = self
                    self._children_name_map["redistribution"] = "redistribution"
                    self._children_yang_names.add("redistribution")

                    self.segment_routing = Ospf.Processes.Process.DefaultVrf.SegmentRouting()
                    self.segment_routing.parent = self
                    self._children_name_map["segment_routing"] = "segment-routing"
                    self._children_yang_names.add("segment-routing")

                    self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"
                    self._children_yang_names.add("summary-prefixes")

                    self.timers = Ospf.Processes.Process.DefaultVrf.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._children_yang_names.add("timers")

                    self.ucmp = Ospf.Processes.Process.DefaultVrf.Ucmp()
                    self.ucmp.parent = self
                    self._children_name_map["ucmp"] = "ucmp"
                    self._children_yang_names.add("ucmp")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("adjacency_changes",
                                    "default_metric",
                                    "ignore_mospf",
                                    "maximum_interfaces",
                                    "maximum_paths",
                                    "no_opaque",
                                    "router_id",
                                    "snmp_context",
                                    "spf_prefix_priority",
                                    "type7") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Ospf.Processes.Process.DefaultVrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Ospf.Processes.Process.DefaultVrf, self).__setattr__(name, value)


                class MonitorConvergence(Entity):
                    """
                    Enable convergence monitoring
                    
                    .. attribute:: enable
                    
                    	Enable convergence monitoring
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix_list
                    
                    	Enable the monitoring of individual prefixes (prefix list name)
                    	**type**\:  str
                    
                    .. attribute:: track_external_routes
                    
                    	Enable the monitoring of External routes
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: track_ip_frr
                    
                    	Enable the Tracking of IP\-Frr Convergence
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: track_summary_routes
                    
                    	Enable the monitoring of Summary routes
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MonitorConvergence, self).__init__()

                        self.yang_name = "monitor-convergence"
                        self.yang_parent_name = "default-vrf"

                        self.enable = YLeaf(YType.empty, "enable")

                        self.prefix_list = YLeaf(YType.str, "prefix-list")

                        self.track_external_routes = YLeaf(YType.empty, "track-external-routes")

                        self.track_ip_frr = YLeaf(YType.empty, "track-ip-frr")

                        self.track_summary_routes = YLeaf(YType.empty, "track-summary-routes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("enable",
                                        "prefix_list",
                                        "track_external_routes",
                                        "track_ip_frr",
                                        "track_summary_routes") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.MonitorConvergence, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.MonitorConvergence, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.enable.is_set or
                            self.prefix_list.is_set or
                            self.track_external_routes.is_set or
                            self.track_ip_frr.is_set or
                            self.track_summary_routes.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.enable.yfilter != YFilter.not_set or
                            self.prefix_list.yfilter != YFilter.not_set or
                            self.track_external_routes.yfilter != YFilter.not_set or
                            self.track_ip_frr.yfilter != YFilter.not_set or
                            self.track_summary_routes.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "monitor-convergence" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enable.get_name_leafdata())
                        if (self.prefix_list.is_set or self.prefix_list.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_list.get_name_leafdata())
                        if (self.track_external_routes.is_set or self.track_external_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.track_external_routes.get_name_leafdata())
                        if (self.track_ip_frr.is_set or self.track_ip_frr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.track_ip_frr.get_name_leafdata())
                        if (self.track_summary_routes.is_set or self.track_summary_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.track_summary_routes.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "enable" or name == "prefix-list" or name == "track-external-routes" or name == "track-ip-frr" or name == "track-summary-routes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "enable"):
                            self.enable = value
                            self.enable.value_namespace = name_space
                            self.enable.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-list"):
                            self.prefix_list = value
                            self.prefix_list.value_namespace = name_space
                            self.prefix_list.value_namespace_prefix = name_space_prefix
                        if(value_path == "track-external-routes"):
                            self.track_external_routes = value
                            self.track_external_routes.value_namespace = name_space
                            self.track_external_routes.value_namespace_prefix = name_space_prefix
                        if(value_path == "track-ip-frr"):
                            self.track_ip_frr = value
                            self.track_ip_frr.value_namespace = name_space
                            self.track_ip_frr.value_namespace_prefix = name_space_prefix
                        if(value_path == "track-summary-routes"):
                            self.track_summary_routes = value
                            self.track_summary_routes.value_namespace = name_space
                            self.track_summary_routes.value_namespace_prefix = name_space_prefix


                class SegmentRouting(Entity):
                    """
                    Segment Routing instance scoped parameters
                    
                    .. attribute:: prefix_sid_map_advertise_local
                    
                    	Enable advertisement of local SRMS entries
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix_sid_map_receive_disable
                    
                    	Disable prefix\-SID mapping client
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sr_prefer
                    
                    	Prefer segment routing labels over LDP labels
                    	**type**\:   :py:class:`SrPrefer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer>`
                    
                    .. attribute:: strict_spf_disable
                    
                    	Strict\-SPF support and SID advertisement
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SegmentRouting, self).__init__()

                        self.yang_name = "segment-routing"
                        self.yang_parent_name = "default-vrf"

                        self.prefix_sid_map_advertise_local = YLeaf(YType.empty, "prefix-sid-map-advertise-local")

                        self.prefix_sid_map_receive_disable = YLeaf(YType.empty, "prefix-sid-map-receive-disable")

                        self.strict_spf_disable = YLeaf(YType.empty, "strict-spf-disable")

                        self.sr_prefer = Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer()
                        self.sr_prefer.parent = self
                        self._children_name_map["sr_prefer"] = "sr-prefer"
                        self._children_yang_names.add("sr-prefer")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("prefix_sid_map_advertise_local",
                                        "prefix_sid_map_receive_disable",
                                        "strict_spf_disable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.SegmentRouting, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.SegmentRouting, self).__setattr__(name, value)


                    class SrPrefer(Entity):
                        """
                        Prefer segment routing labels over LDP
                        labels
                        
                        .. attribute:: enable
                        
                        	Enable SR labels to be preferred over LDP labels
                        	**type**\:  bool
                        
                        .. attribute:: prefix_list_name
                        
                        	Name of the Prefix List
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer, self).__init__()

                            self.yang_name = "sr-prefer"
                            self.yang_parent_name = "segment-routing"

                            self.enable = YLeaf(YType.boolean, "enable")

                            self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("enable",
                                            "prefix_list_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.enable.is_set or
                                self.prefix_list_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.enable.yfilter != YFilter.not_set or
                                self.prefix_list_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sr-prefer" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enable.get_name_leafdata())
                            if (self.prefix_list_name.is_set or self.prefix_list_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_list_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "enable" or name == "prefix-list-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "enable"):
                                self.enable = value
                                self.enable.value_namespace = name_space
                                self.enable.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-list-name"):
                                self.prefix_list_name = value
                                self.prefix_list_name.value_namespace = name_space
                                self.prefix_list_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.prefix_sid_map_advertise_local.is_set or
                            self.prefix_sid_map_receive_disable.is_set or
                            self.strict_spf_disable.is_set or
                            (self.sr_prefer is not None and self.sr_prefer.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.prefix_sid_map_advertise_local.yfilter != YFilter.not_set or
                            self.prefix_sid_map_receive_disable.yfilter != YFilter.not_set or
                            self.strict_spf_disable.yfilter != YFilter.not_set or
                            (self.sr_prefer is not None and self.sr_prefer.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "segment-routing" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.prefix_sid_map_advertise_local.is_set or self.prefix_sid_map_advertise_local.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_sid_map_advertise_local.get_name_leafdata())
                        if (self.prefix_sid_map_receive_disable.is_set or self.prefix_sid_map_receive_disable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_sid_map_receive_disable.get_name_leafdata())
                        if (self.strict_spf_disable.is_set or self.strict_spf_disable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.strict_spf_disable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "sr-prefer"):
                            if (self.sr_prefer is None):
                                self.sr_prefer = Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer()
                                self.sr_prefer.parent = self
                                self._children_name_map["sr_prefer"] = "sr-prefer"
                            return self.sr_prefer

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "sr-prefer" or name == "prefix-sid-map-advertise-local" or name == "prefix-sid-map-receive-disable" or name == "strict-spf-disable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "prefix-sid-map-advertise-local"):
                            self.prefix_sid_map_advertise_local = value
                            self.prefix_sid_map_advertise_local.value_namespace = name_space
                            self.prefix_sid_map_advertise_local.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-sid-map-receive-disable"):
                            self.prefix_sid_map_receive_disable = value
                            self.prefix_sid_map_receive_disable.value_namespace = name_space
                            self.prefix_sid_map_receive_disable.value_namespace_prefix = name_space_prefix
                        if(value_path == "strict-spf-disable"):
                            self.strict_spf_disable = value
                            self.strict_spf_disable.value_namespace = name_space
                            self.strict_spf_disable.value_namespace_prefix = name_space_prefix


                class Mpls(Entity):
                    """
                    Configure MPLS routing protocol parameters
                    
                    .. attribute:: autoroute_exclude
                    
                    	Exclude IP destinations from using TE tunnels
                    	**type**\:  str
                    
                    .. attribute:: igp_intact
                    
                    	Enable igp\-intact mode in OSPF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ldp_sync_update
                    
                    	Enable LDP sync induced metric propagation
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mpls_router_id
                    
                    	MPLS\-TE stable loopback address for this OSPF process.Enter either as IP Address or Interface name, but not both. Unused field must be nil
                    	**type**\:   :py:class:`MplsRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId>`
                    
                    .. attribute:: multicast_intact
                    
                    	Enable multicast\-intact mode in OSPF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "default-vrf"

                        self.autoroute_exclude = YLeaf(YType.str, "autoroute-exclude")

                        self.igp_intact = YLeaf(YType.empty, "igp-intact")

                        self.ldp_sync_update = YLeaf(YType.empty, "ldp-sync-update")

                        self.multicast_intact = YLeaf(YType.empty, "multicast-intact")

                        self.mpls_router_id = Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId()
                        self.mpls_router_id.parent = self
                        self._children_name_map["mpls_router_id"] = "mpls-router-id"
                        self._children_yang_names.add("mpls-router-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("autoroute_exclude",
                                        "igp_intact",
                                        "ldp_sync_update",
                                        "multicast_intact") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Mpls, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Mpls, self).__setattr__(name, value)


                    class MplsRouterId(Entity):
                        """
                        MPLS\-TE stable loopback address for this
                        OSPF process.Enter either as IP Address or
                        Interface name, but not both. Unused field
                        must be nil
                        
                        .. attribute:: address
                        
                        	MPLS\-TE stable IP address for this OSPF process
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	MPLS\-TE stable loopback interface for this OSPF process
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId, self).__init__()

                            self.yang_name = "mpls-router-id"
                            self.yang_parent_name = "mpls"

                            self.address = YLeaf(YType.str, "address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.interface_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "mpls-router-id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.autoroute_exclude.is_set or
                            self.igp_intact.is_set or
                            self.ldp_sync_update.is_set or
                            self.multicast_intact.is_set or
                            (self.mpls_router_id is not None and self.mpls_router_id.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.autoroute_exclude.yfilter != YFilter.not_set or
                            self.igp_intact.yfilter != YFilter.not_set or
                            self.ldp_sync_update.yfilter != YFilter.not_set or
                            self.multicast_intact.yfilter != YFilter.not_set or
                            (self.mpls_router_id is not None and self.mpls_router_id.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mpls" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.autoroute_exclude.is_set or self.autoroute_exclude.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.autoroute_exclude.get_name_leafdata())
                        if (self.igp_intact.is_set or self.igp_intact.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igp_intact.get_name_leafdata())
                        if (self.ldp_sync_update.is_set or self.ldp_sync_update.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_sync_update.get_name_leafdata())
                        if (self.multicast_intact.is_set or self.multicast_intact.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.multicast_intact.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "mpls-router-id"):
                            if (self.mpls_router_id is None):
                                self.mpls_router_id = Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId()
                                self.mpls_router_id.parent = self
                                self._children_name_map["mpls_router_id"] = "mpls-router-id"
                            return self.mpls_router_id

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "mpls-router-id" or name == "autoroute-exclude" or name == "igp-intact" or name == "ldp-sync-update" or name == "multicast-intact"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "autoroute-exclude"):
                            self.autoroute_exclude = value
                            self.autoroute_exclude.value_namespace = name_space
                            self.autoroute_exclude.value_namespace_prefix = name_space_prefix
                        if(value_path == "igp-intact"):
                            self.igp_intact = value
                            self.igp_intact.value_namespace = name_space
                            self.igp_intact.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-sync-update"):
                            self.ldp_sync_update = value
                            self.ldp_sync_update.value_namespace = name_space
                            self.ldp_sync_update.value_namespace_prefix = name_space_prefix
                        if(value_path == "multicast-intact"):
                            self.multicast_intact = value
                            self.multicast_intact.value_namespace = name_space
                            self.multicast_intact.value_namespace_prefix = name_space_prefix


                class Microloop(Entity):
                    """
                    Microloop configuration
                    
                    .. attribute:: avoidance
                    
                    	Microloop avoidance configuration
                    	**type**\:   :py:class:`Avoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Microloop, self).__init__()

                        self.yang_name = "microloop"
                        self.yang_parent_name = "default-vrf"

                        self.avoidance = Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance()
                        self.avoidance.parent = self
                        self._children_name_map["avoidance"] = "avoidance"
                        self._children_yang_names.add("avoidance")


                    class Avoidance(Entity):
                        """
                        Microloop avoidance configuration
                        
                        .. attribute:: enable
                        
                        	MicroLoop avoidance feature enable configuration
                        	**type**\:   :py:class:`OspfUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfUloopAvoidance>`
                        
                        	**default value**\: all
                        
                        .. attribute:: rib_update_delay
                        
                        	Delay to introduce between SPF and RIB update in msecs
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 5000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance, self).__init__()

                            self.yang_name = "avoidance"
                            self.yang_parent_name = "microloop"

                            self.enable = YLeaf(YType.enumeration, "enable")

                            self.rib_update_delay = YLeaf(YType.uint32, "rib-update-delay")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("enable",
                                            "rib_update_delay") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.enable.is_set or
                                self.rib_update_delay.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.enable.yfilter != YFilter.not_set or
                                self.rib_update_delay.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avoidance" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enable.get_name_leafdata())
                            if (self.rib_update_delay.is_set or self.rib_update_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_update_delay.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "enable" or name == "rib-update-delay"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "enable"):
                                self.enable = value
                                self.enable.value_namespace = name_space
                                self.enable.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-update-delay"):
                                self.rib_update_delay = value
                                self.rib_update_delay.value_namespace = name_space
                                self.rib_update_delay.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.avoidance is not None and self.avoidance.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.avoidance is not None and self.avoidance.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "microloop" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "avoidance"):
                            if (self.avoidance is None):
                                self.avoidance = Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance()
                                self.avoidance.parent = self
                                self._children_name_map["avoidance"] = "avoidance"
                            return self.avoidance

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "avoidance"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class MaximumRedistributePrefix(Entity):
                    """
                    Maximum number of prefixes redistributed into
                    OSPF
                    
                    .. attribute:: number_of_prefixes
                    
                    	Maximum number of prefixes redistributed
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: threshold
                    
                    	Threshold value (%) at which to generate a warning msg
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    .. attribute:: warning_only
                    
                    	Only give warning messsage when limit is exceeded
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix, self).__init__()

                        self.yang_name = "maximum-redistribute-prefix"
                        self.yang_parent_name = "default-vrf"

                        self.number_of_prefixes = YLeaf(YType.uint32, "number-of-prefixes")

                        self.threshold = YLeaf(YType.uint32, "threshold")

                        self.warning_only = YLeaf(YType.boolean, "warning-only")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("number_of_prefixes",
                                        "threshold",
                                        "warning_only") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.number_of_prefixes.is_set or
                            self.threshold.is_set or
                            self.warning_only.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.number_of_prefixes.yfilter != YFilter.not_set or
                            self.threshold.yfilter != YFilter.not_set or
                            self.warning_only.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "maximum-redistribute-prefix" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.number_of_prefixes.is_set or self.number_of_prefixes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.number_of_prefixes.get_name_leafdata())
                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.threshold.get_name_leafdata())
                        if (self.warning_only.is_set or self.warning_only.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.warning_only.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "number-of-prefixes" or name == "threshold" or name == "warning-only"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "number-of-prefixes"):
                            self.number_of_prefixes = value
                            self.number_of_prefixes.value_namespace = name_space
                            self.number_of_prefixes.value_namespace_prefix = name_space_prefix
                        if(value_path == "threshold"):
                            self.threshold = value
                            self.threshold.value_namespace = name_space
                            self.threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "warning-only"):
                            self.warning_only = value
                            self.warning_only.value_namespace = name_space
                            self.warning_only.value_namespace_prefix = name_space_prefix


                class DefaultInformation(Entity):
                    """
                    Control distribution of default information
                    
                    .. attribute:: always_advertise
                    
                    	Always advertise default route
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: metric
                    
                    	OSPF metric
                    	**type**\:  int
                    
                    	**range:** 1..16777214
                    
                    	**default value**\: 1
                    
                    .. attribute:: metric_type
                    
                    	OSPF External metric type
                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                    
                    	**default value**\: type2
                    
                    .. attribute:: route_policy_name
                    
                    	Routing policy name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.DefaultInformation, self).__init__()

                        self.yang_name = "default-information"
                        self.yang_parent_name = "default-vrf"

                        self.always_advertise = YLeaf(YType.boolean, "always-advertise")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("always_advertise",
                                        "metric",
                                        "metric_type",
                                        "route_policy_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.DefaultInformation, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.DefaultInformation, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.always_advertise.is_set or
                            self.metric.is_set or
                            self.metric_type.is_set or
                            self.route_policy_name.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.always_advertise.yfilter != YFilter.not_set or
                            self.metric.yfilter != YFilter.not_set or
                            self.metric_type.yfilter != YFilter.not_set or
                            self.route_policy_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "default-information" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.always_advertise.is_set or self.always_advertise.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.always_advertise.get_name_leafdata())
                        if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric.get_name_leafdata())
                        if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.metric_type.get_name_leafdata())
                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "always-advertise" or name == "metric" or name == "metric-type" or name == "route-policy-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "always-advertise"):
                            self.always_advertise = value
                            self.always_advertise.value_namespace = name_space
                            self.always_advertise.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric"):
                            self.metric = value
                            self.metric.value_namespace = name_space
                            self.metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "metric-type"):
                            self.metric_type = value
                            self.metric_type.value_namespace = name_space
                            self.metric_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "route-policy-name"):
                            self.route_policy_name = value
                            self.route_policy_name.value_namespace = name_space
                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                class Af(Entity):
                    """
                    OSPF address family
                    
                    .. attribute:: af_name
                    
                    	Address family
                    	**type**\:   :py:class:`OspfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAddressFamily>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: saf_name
                    
                    	Sub\-Address family
                    	**type**\:   :py:class:`OspfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSubAddressFamily>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "default-vrf"
                        self.is_presence_container = True

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "saf_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Af, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Af, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.saf_name.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "af" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "af-name" or name == "saf-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix


                class Queue(Entity):
                    """
                    Adjust OSPF input queue sizes and processing
                    quantums
                    
                    .. attribute:: dispatch_incoming
                    
                    	Maximum number of continuous incoming packet\-related events processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 300
                    
                    .. attribute:: dispatch_rate_limited
                    
                    	Maximum number of continuous rate\-limited LSAs processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: dispatch_rate_limited_flush
                    
                    	Maximum number of continuous rate\-limited LSAs processed for FLUSH
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: dispatch_spf_lsa_limit
                    
                    	Maximum number of continuous summary or external LSAs processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: limit_high
                    
                    	Hello events are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 9500
                    
                    .. attribute:: limit_low
                    
                    	DBDs/Updates are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 8000
                    
                    .. attribute:: limit_medium
                    
                    	LSA ACKs are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 9000
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Queue, self).__init__()

                        self.yang_name = "queue"
                        self.yang_parent_name = "default-vrf"

                        self.dispatch_incoming = YLeaf(YType.uint32, "dispatch-incoming")

                        self.dispatch_rate_limited = YLeaf(YType.uint32, "dispatch-rate-limited")

                        self.dispatch_rate_limited_flush = YLeaf(YType.uint32, "dispatch-rate-limited-flush")

                        self.dispatch_spf_lsa_limit = YLeaf(YType.uint32, "dispatch-spf-lsa-limit")

                        self.limit_high = YLeaf(YType.uint32, "limit-high")

                        self.limit_low = YLeaf(YType.uint32, "limit-low")

                        self.limit_medium = YLeaf(YType.uint32, "limit-medium")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dispatch_incoming",
                                        "dispatch_rate_limited",
                                        "dispatch_rate_limited_flush",
                                        "dispatch_spf_lsa_limit",
                                        "limit_high",
                                        "limit_low",
                                        "limit_medium") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Queue, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Queue, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.dispatch_incoming.is_set or
                            self.dispatch_rate_limited.is_set or
                            self.dispatch_rate_limited_flush.is_set or
                            self.dispatch_spf_lsa_limit.is_set or
                            self.limit_high.is_set or
                            self.limit_low.is_set or
                            self.limit_medium.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dispatch_incoming.yfilter != YFilter.not_set or
                            self.dispatch_rate_limited.yfilter != YFilter.not_set or
                            self.dispatch_rate_limited_flush.yfilter != YFilter.not_set or
                            self.dispatch_spf_lsa_limit.yfilter != YFilter.not_set or
                            self.limit_high.yfilter != YFilter.not_set or
                            self.limit_low.yfilter != YFilter.not_set or
                            self.limit_medium.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "queue" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dispatch_incoming.is_set or self.dispatch_incoming.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dispatch_incoming.get_name_leafdata())
                        if (self.dispatch_rate_limited.is_set or self.dispatch_rate_limited.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dispatch_rate_limited.get_name_leafdata())
                        if (self.dispatch_rate_limited_flush.is_set or self.dispatch_rate_limited_flush.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dispatch_rate_limited_flush.get_name_leafdata())
                        if (self.dispatch_spf_lsa_limit.is_set or self.dispatch_spf_lsa_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dispatch_spf_lsa_limit.get_name_leafdata())
                        if (self.limit_high.is_set or self.limit_high.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_high.get_name_leafdata())
                        if (self.limit_low.is_set or self.limit_low.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_low.get_name_leafdata())
                        if (self.limit_medium.is_set or self.limit_medium.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.limit_medium.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dispatch-incoming" or name == "dispatch-rate-limited" or name == "dispatch-rate-limited-flush" or name == "dispatch-spf-lsa-limit" or name == "limit-high" or name == "limit-low" or name == "limit-medium"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dispatch-incoming"):
                            self.dispatch_incoming = value
                            self.dispatch_incoming.value_namespace = name_space
                            self.dispatch_incoming.value_namespace_prefix = name_space_prefix
                        if(value_path == "dispatch-rate-limited"):
                            self.dispatch_rate_limited = value
                            self.dispatch_rate_limited.value_namespace = name_space
                            self.dispatch_rate_limited.value_namespace_prefix = name_space_prefix
                        if(value_path == "dispatch-rate-limited-flush"):
                            self.dispatch_rate_limited_flush = value
                            self.dispatch_rate_limited_flush.value_namespace = name_space
                            self.dispatch_rate_limited_flush.value_namespace_prefix = name_space_prefix
                        if(value_path == "dispatch-spf-lsa-limit"):
                            self.dispatch_spf_lsa_limit = value
                            self.dispatch_spf_lsa_limit.value_namespace = name_space
                            self.dispatch_spf_lsa_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-high"):
                            self.limit_high = value
                            self.limit_high.value_namespace = name_space
                            self.limit_high.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-low"):
                            self.limit_low = value
                            self.limit_low.value_namespace = name_space
                            self.limit_low.value_namespace_prefix = name_space_prefix
                        if(value_path == "limit-medium"):
                            self.limit_medium = value
                            self.limit_medium.value_namespace = name_space
                            self.limit_medium.value_namespace_prefix = name_space_prefix


                class MaxMetric(Entity):
                    """
                    Set maximum metric configuration
                    
                    .. attribute:: max_metric_always
                    
                    	Set maximum metric always configuration
                    	**type**\:   :py:class:`MaxMetricAlways <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways>`
                    
                    .. attribute:: max_metric_no_abr_off
                    
                    	Block ABR\-disable mode entry while in max\-metric mode
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_metric_on_proc_migration
                    
                    	Set maximum metric on\-proc\-migration configuration
                    	**type**\:   :py:class:`MaxMetricOnProcMigration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration>`
                    
                    .. attribute:: max_metric_on_proc_restart
                    
                    	Set maximum metric on\-proc\-restart configuration
                    	**type**\:   :py:class:`MaxMetricOnProcRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart>`
                    
                    .. attribute:: max_metric_on_startup
                    
                    	Set maximum metric on\-startup configuration
                    	**type**\:   :py:class:`MaxMetricOnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup>`
                    
                    .. attribute:: max_metric_on_switchover
                    
                    	Set maximum metric on\-switchover configuration
                    	**type**\:   :py:class:`MaxMetricOnSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric, self).__init__()

                        self.yang_name = "max-metric"
                        self.yang_parent_name = "default-vrf"

                        self.max_metric_no_abr_off = YLeaf(YType.empty, "max-metric-no-abr-off")

                        self.max_metric_always = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways()
                        self.max_metric_always.parent = self
                        self._children_name_map["max_metric_always"] = "max-metric-always"
                        self._children_yang_names.add("max-metric-always")

                        self.max_metric_on_proc_migration = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration()
                        self.max_metric_on_proc_migration.parent = self
                        self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                        self._children_yang_names.add("max-metric-on-proc-migration")

                        self.max_metric_on_proc_restart = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart()
                        self.max_metric_on_proc_restart.parent = self
                        self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                        self._children_yang_names.add("max-metric-on-proc-restart")

                        self.max_metric_on_startup = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup()
                        self.max_metric_on_startup.parent = self
                        self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                        self._children_yang_names.add("max-metric-on-startup")

                        self.max_metric_on_switchover = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover()
                        self.max_metric_on_switchover.parent = self
                        self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                        self._children_yang_names.add("max-metric-on-switchover")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("max_metric_no_abr_off") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.MaxMetric, self).__setattr__(name, value)


                    class MaxMetricOnProcRestart(Entity):
                        """
                        Set maximum metric on\-proc\-restart
                        configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart, self).__init__()

                            self.yang_name = "max-metric-on-proc-restart"
                            self.yang_parent_name = "max-metric"

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_lsa",
                                            "external_lsa_maximum_metric",
                                            "include_stub",
                                            "startup_max",
                                            "summary_lsa",
                                            "summary_lsa_maximum_metric",
                                            "wait_for_bgp") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_lsa.is_set or
                                self.external_lsa_maximum_metric.is_set or
                                self.include_stub.is_set or
                                self.startup_max.is_set or
                                self.summary_lsa.is_set or
                                self.summary_lsa_maximum_metric.is_set or
                                self.wait_for_bgp.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_lsa.yfilter != YFilter.not_set or
                                self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.include_stub.yfilter != YFilter.not_set or
                                self.startup_max.yfilter != YFilter.not_set or
                                self.summary_lsa.yfilter != YFilter.not_set or
                                self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.wait_for_bgp.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric-on-proc-restart" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa.get_name_leafdata())
                            if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                            if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_stub.get_name_leafdata())
                            if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.startup_max.get_name_leafdata())
                            if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                            if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                            if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-lsa"):
                                self.external_lsa = value
                                self.external_lsa.value_namespace = name_space
                                self.external_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-lsa-maximum-metric"):
                                self.external_lsa_maximum_metric = value
                                self.external_lsa_maximum_metric.value_namespace = name_space
                                self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-stub"):
                                self.include_stub = value
                                self.include_stub.value_namespace = name_space
                                self.include_stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "startup-max"):
                                self.startup_max = value
                                self.startup_max.value_namespace = name_space
                                self.startup_max.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa"):
                                self.summary_lsa = value
                                self.summary_lsa.value_namespace = name_space
                                self.summary_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa-maximum-metric"):
                                self.summary_lsa_maximum_metric = value
                                self.summary_lsa_maximum_metric.value_namespace = name_space
                                self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-for-bgp"):
                                self.wait_for_bgp = value
                                self.wait_for_bgp.value_namespace = name_space
                                self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                    class MaxMetricOnStartup(Entity):
                        """
                        Set maximum metric on\-startup configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup, self).__init__()

                            self.yang_name = "max-metric-on-startup"
                            self.yang_parent_name = "max-metric"

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_lsa",
                                            "external_lsa_maximum_metric",
                                            "include_stub",
                                            "startup_max",
                                            "summary_lsa",
                                            "summary_lsa_maximum_metric",
                                            "wait_for_bgp") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_lsa.is_set or
                                self.external_lsa_maximum_metric.is_set or
                                self.include_stub.is_set or
                                self.startup_max.is_set or
                                self.summary_lsa.is_set or
                                self.summary_lsa_maximum_metric.is_set or
                                self.wait_for_bgp.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_lsa.yfilter != YFilter.not_set or
                                self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.include_stub.yfilter != YFilter.not_set or
                                self.startup_max.yfilter != YFilter.not_set or
                                self.summary_lsa.yfilter != YFilter.not_set or
                                self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.wait_for_bgp.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric-on-startup" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa.get_name_leafdata())
                            if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                            if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_stub.get_name_leafdata())
                            if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.startup_max.get_name_leafdata())
                            if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                            if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                            if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-lsa"):
                                self.external_lsa = value
                                self.external_lsa.value_namespace = name_space
                                self.external_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-lsa-maximum-metric"):
                                self.external_lsa_maximum_metric = value
                                self.external_lsa_maximum_metric.value_namespace = name_space
                                self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-stub"):
                                self.include_stub = value
                                self.include_stub.value_namespace = name_space
                                self.include_stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "startup-max"):
                                self.startup_max = value
                                self.startup_max.value_namespace = name_space
                                self.startup_max.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa"):
                                self.summary_lsa = value
                                self.summary_lsa.value_namespace = name_space
                                self.summary_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa-maximum-metric"):
                                self.summary_lsa_maximum_metric = value
                                self.summary_lsa_maximum_metric.value_namespace = name_space
                                self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-for-bgp"):
                                self.wait_for_bgp = value
                                self.wait_for_bgp.value_namespace = name_space
                                self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                    class MaxMetricOnProcMigration(Entity):
                        """
                        Set maximum metric on\-proc\-migration
                        configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration, self).__init__()

                            self.yang_name = "max-metric-on-proc-migration"
                            self.yang_parent_name = "max-metric"

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_lsa",
                                            "external_lsa_maximum_metric",
                                            "include_stub",
                                            "startup_max",
                                            "summary_lsa",
                                            "summary_lsa_maximum_metric",
                                            "wait_for_bgp") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_lsa.is_set or
                                self.external_lsa_maximum_metric.is_set or
                                self.include_stub.is_set or
                                self.startup_max.is_set or
                                self.summary_lsa.is_set or
                                self.summary_lsa_maximum_metric.is_set or
                                self.wait_for_bgp.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_lsa.yfilter != YFilter.not_set or
                                self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.include_stub.yfilter != YFilter.not_set or
                                self.startup_max.yfilter != YFilter.not_set or
                                self.summary_lsa.yfilter != YFilter.not_set or
                                self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.wait_for_bgp.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric-on-proc-migration" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa.get_name_leafdata())
                            if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                            if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_stub.get_name_leafdata())
                            if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.startup_max.get_name_leafdata())
                            if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                            if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                            if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-lsa"):
                                self.external_lsa = value
                                self.external_lsa.value_namespace = name_space
                                self.external_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-lsa-maximum-metric"):
                                self.external_lsa_maximum_metric = value
                                self.external_lsa_maximum_metric.value_namespace = name_space
                                self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-stub"):
                                self.include_stub = value
                                self.include_stub.value_namespace = name_space
                                self.include_stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "startup-max"):
                                self.startup_max = value
                                self.startup_max.value_namespace = name_space
                                self.startup_max.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa"):
                                self.summary_lsa = value
                                self.summary_lsa.value_namespace = name_space
                                self.summary_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa-maximum-metric"):
                                self.summary_lsa_maximum_metric = value
                                self.summary_lsa_maximum_metric.value_namespace = name_space
                                self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-for-bgp"):
                                self.wait_for_bgp = value
                                self.wait_for_bgp.value_namespace = name_space
                                self.wait_for_bgp.value_namespace_prefix = name_space_prefix


                    class MaxMetricAlways(Entity):
                        """
                        Set maximum metric always configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways, self).__init__()

                            self.yang_name = "max-metric-always"
                            self.yang_parent_name = "max-metric"

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_lsa",
                                            "external_lsa_maximum_metric",
                                            "include_stub",
                                            "summary_lsa",
                                            "summary_lsa_maximum_metric") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_lsa.is_set or
                                self.external_lsa_maximum_metric.is_set or
                                self.include_stub.is_set or
                                self.summary_lsa.is_set or
                                self.summary_lsa_maximum_metric.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_lsa.yfilter != YFilter.not_set or
                                self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.include_stub.yfilter != YFilter.not_set or
                                self.summary_lsa.yfilter != YFilter.not_set or
                                self.summary_lsa_maximum_metric.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric-always" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa.get_name_leafdata())
                            if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                            if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_stub.get_name_leafdata())
                            if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                            if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "summary-lsa" or name == "summary-lsa-maximum-metric"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-lsa"):
                                self.external_lsa = value
                                self.external_lsa.value_namespace = name_space
                                self.external_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-lsa-maximum-metric"):
                                self.external_lsa_maximum_metric = value
                                self.external_lsa_maximum_metric.value_namespace = name_space
                                self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-stub"):
                                self.include_stub = value
                                self.include_stub.value_namespace = name_space
                                self.include_stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa"):
                                self.summary_lsa = value
                                self.summary_lsa.value_namespace = name_space
                                self.summary_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa-maximum-metric"):
                                self.summary_lsa_maximum_metric = value
                                self.summary_lsa_maximum_metric.value_namespace = name_space
                                self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix


                    class MaxMetricOnSwitchover(Entity):
                        """
                        Set maximum metric on\-switchover configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover, self).__init__()

                            self.yang_name = "max-metric-on-switchover"
                            self.yang_parent_name = "max-metric"

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_lsa",
                                            "external_lsa_maximum_metric",
                                            "include_stub",
                                            "startup_max",
                                            "summary_lsa",
                                            "summary_lsa_maximum_metric",
                                            "wait_for_bgp") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_lsa.is_set or
                                self.external_lsa_maximum_metric.is_set or
                                self.include_stub.is_set or
                                self.startup_max.is_set or
                                self.summary_lsa.is_set or
                                self.summary_lsa_maximum_metric.is_set or
                                self.wait_for_bgp.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_lsa.yfilter != YFilter.not_set or
                                self.external_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.include_stub.yfilter != YFilter.not_set or
                                self.startup_max.yfilter != YFilter.not_set or
                                self.summary_lsa.yfilter != YFilter.not_set or
                                self.summary_lsa_maximum_metric.yfilter != YFilter.not_set or
                                self.wait_for_bgp.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "max-metric-on-switchover" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_lsa.is_set or self.external_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa.get_name_leafdata())
                            if (self.external_lsa_maximum_metric.is_set or self.external_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_lsa_maximum_metric.get_name_leafdata())
                            if (self.include_stub.is_set or self.include_stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_stub.get_name_leafdata())
                            if (self.startup_max.is_set or self.startup_max.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.startup_max.get_name_leafdata())
                            if (self.summary_lsa.is_set or self.summary_lsa.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa.get_name_leafdata())
                            if (self.summary_lsa_maximum_metric.is_set or self.summary_lsa_maximum_metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_lsa_maximum_metric.get_name_leafdata())
                            if (self.wait_for_bgp.is_set or self.wait_for_bgp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.wait_for_bgp.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-lsa" or name == "external-lsa-maximum-metric" or name == "include-stub" or name == "startup-max" or name == "summary-lsa" or name == "summary-lsa-maximum-metric" or name == "wait-for-bgp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-lsa"):
                                self.external_lsa = value
                                self.external_lsa.value_namespace = name_space
                                self.external_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-lsa-maximum-metric"):
                                self.external_lsa_maximum_metric = value
                                self.external_lsa_maximum_metric.value_namespace = name_space
                                self.external_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-stub"):
                                self.include_stub = value
                                self.include_stub.value_namespace = name_space
                                self.include_stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "startup-max"):
                                self.startup_max = value
                                self.startup_max.value_namespace = name_space
                                self.startup_max.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa"):
                                self.summary_lsa = value
                                self.summary_lsa.value_namespace = name_space
                                self.summary_lsa.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-lsa-maximum-metric"):
                                self.summary_lsa_maximum_metric = value
                                self.summary_lsa_maximum_metric.value_namespace = name_space
                                self.summary_lsa_maximum_metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "wait-for-bgp"):
                                self.wait_for_bgp = value
                                self.wait_for_bgp.value_namespace = name_space
                                self.wait_for_bgp.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.max_metric_no_abr_off.is_set or
                            (self.max_metric_always is not None and self.max_metric_always.has_data()) or
                            (self.max_metric_on_proc_migration is not None and self.max_metric_on_proc_migration.has_data()) or
                            (self.max_metric_on_proc_restart is not None and self.max_metric_on_proc_restart.has_data()) or
                            (self.max_metric_on_startup is not None and self.max_metric_on_startup.has_data()) or
                            (self.max_metric_on_switchover is not None and self.max_metric_on_switchover.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.max_metric_no_abr_off.yfilter != YFilter.not_set or
                            (self.max_metric_always is not None and self.max_metric_always.has_operation()) or
                            (self.max_metric_on_proc_migration is not None and self.max_metric_on_proc_migration.has_operation()) or
                            (self.max_metric_on_proc_restart is not None and self.max_metric_on_proc_restart.has_operation()) or
                            (self.max_metric_on_startup is not None and self.max_metric_on_startup.has_operation()) or
                            (self.max_metric_on_switchover is not None and self.max_metric_on_switchover.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "max-metric" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.max_metric_no_abr_off.is_set or self.max_metric_no_abr_off.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_metric_no_abr_off.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "max-metric-always"):
                            if (self.max_metric_always is None):
                                self.max_metric_always = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways()
                                self.max_metric_always.parent = self
                                self._children_name_map["max_metric_always"] = "max-metric-always"
                            return self.max_metric_always

                        if (child_yang_name == "max-metric-on-proc-migration"):
                            if (self.max_metric_on_proc_migration is None):
                                self.max_metric_on_proc_migration = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration()
                                self.max_metric_on_proc_migration.parent = self
                                self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                            return self.max_metric_on_proc_migration

                        if (child_yang_name == "max-metric-on-proc-restart"):
                            if (self.max_metric_on_proc_restart is None):
                                self.max_metric_on_proc_restart = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart()
                                self.max_metric_on_proc_restart.parent = self
                                self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                            return self.max_metric_on_proc_restart

                        if (child_yang_name == "max-metric-on-startup"):
                            if (self.max_metric_on_startup is None):
                                self.max_metric_on_startup = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup()
                                self.max_metric_on_startup.parent = self
                                self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                            return self.max_metric_on_startup

                        if (child_yang_name == "max-metric-on-switchover"):
                            if (self.max_metric_on_switchover is None):
                                self.max_metric_on_switchover = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover()
                                self.max_metric_on_switchover.parent = self
                                self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                            return self.max_metric_on_switchover

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "max-metric-always" or name == "max-metric-on-proc-migration" or name == "max-metric-on-proc-restart" or name == "max-metric-on-startup" or name == "max-metric-on-switchover" or name == "max-metric-no-abr-off"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "max-metric-no-abr-off"):
                            self.max_metric_no_abr_off = value
                            self.max_metric_no_abr_off.value_namespace = name_space
                            self.max_metric_no_abr_off.value_namespace_prefix = name_space_prefix


                class Nsf(Entity):
                    """
                    Non Stop Forwarding configuration
                    
                    .. attribute:: cisco
                    
                    	Enable Cisco Non Stop Forwarding
                    	**type**\:   :py:class:`OspfCiscoNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfCiscoNsf>`
                    
                    .. attribute:: flush_delay_time
                    
                    	Maximum time allowed for external route learning (seconds)
                    	**type**\:  int
                    
                    	**range:** 1..3600
                    
                    	**units**\: second
                    
                    	**default value**\: 60
                    
                    .. attribute:: ietf
                    
                    	Enable IETF Non Stop Forwarding
                    	**type**\:   :py:class:`OspfIetfNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsf>`
                    
                    .. attribute:: ietf_strict_lsa_checking
                    
                    	Enable Strict LSA checking of IETF NSF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ietf_support_role
                    
                    	Disable helper support role for IETF Non Stop Forwarding
                    	**type**\:   :py:class:`OspfIetfNsfSupport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsfSupport>`
                    
                    .. attribute:: interval
                    
                    	Minimum interval between Non Stop Forwarding restarts in seconds
                    	**type**\:  int
                    
                    	**range:** 90..3600
                    
                    	**units**\: second
                    
                    	**default value**\: 90
                    
                    .. attribute:: lifetime
                    
                    	Maximum route lifetime following restart in seconds
                    	**type**\:  int
                    
                    	**range:** 90..1800
                    
                    	**units**\: second
                    
                    	**default value**\: 90
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Nsf, self).__init__()

                        self.yang_name = "nsf"
                        self.yang_parent_name = "default-vrf"

                        self.cisco = YLeaf(YType.enumeration, "cisco")

                        self.flush_delay_time = YLeaf(YType.uint32, "flush-delay-time")

                        self.ietf = YLeaf(YType.enumeration, "ietf")

                        self.ietf_strict_lsa_checking = YLeaf(YType.empty, "ietf-strict-lsa-checking")

                        self.ietf_support_role = YLeaf(YType.enumeration, "ietf-support-role")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("cisco",
                                        "flush_delay_time",
                                        "ietf",
                                        "ietf_strict_lsa_checking",
                                        "ietf_support_role",
                                        "interval",
                                        "lifetime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Nsf, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Nsf, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.cisco.is_set or
                            self.flush_delay_time.is_set or
                            self.ietf.is_set or
                            self.ietf_strict_lsa_checking.is_set or
                            self.ietf_support_role.is_set or
                            self.interval.is_set or
                            self.lifetime.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.cisco.yfilter != YFilter.not_set or
                            self.flush_delay_time.yfilter != YFilter.not_set or
                            self.ietf.yfilter != YFilter.not_set or
                            self.ietf_strict_lsa_checking.yfilter != YFilter.not_set or
                            self.ietf_support_role.yfilter != YFilter.not_set or
                            self.interval.yfilter != YFilter.not_set or
                            self.lifetime.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "nsf" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.cisco.is_set or self.cisco.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cisco.get_name_leafdata())
                        if (self.flush_delay_time.is_set or self.flush_delay_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flush_delay_time.get_name_leafdata())
                        if (self.ietf.is_set or self.ietf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ietf.get_name_leafdata())
                        if (self.ietf_strict_lsa_checking.is_set or self.ietf_strict_lsa_checking.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ietf_strict_lsa_checking.get_name_leafdata())
                        if (self.ietf_support_role.is_set or self.ietf_support_role.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ietf_support_role.get_name_leafdata())
                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interval.get_name_leafdata())
                        if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lifetime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "cisco" or name == "flush-delay-time" or name == "ietf" or name == "ietf-strict-lsa-checking" or name == "ietf-support-role" or name == "interval" or name == "lifetime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "cisco"):
                            self.cisco = value
                            self.cisco.value_namespace = name_space
                            self.cisco.value_namespace_prefix = name_space_prefix
                        if(value_path == "flush-delay-time"):
                            self.flush_delay_time = value
                            self.flush_delay_time.value_namespace = name_space
                            self.flush_delay_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "ietf"):
                            self.ietf = value
                            self.ietf.value_namespace = name_space
                            self.ietf.value_namespace_prefix = name_space_prefix
                        if(value_path == "ietf-strict-lsa-checking"):
                            self.ietf_strict_lsa_checking = value
                            self.ietf_strict_lsa_checking.value_namespace = name_space
                            self.ietf_strict_lsa_checking.value_namespace_prefix = name_space_prefix
                        if(value_path == "ietf-support-role"):
                            self.ietf_support_role = value
                            self.ietf_support_role.value_namespace = name_space
                            self.ietf_support_role.value_namespace_prefix = name_space_prefix
                        if(value_path == "interval"):
                            self.interval = value
                            self.interval.value_namespace = name_space
                            self.interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "lifetime"):
                            self.lifetime = value
                            self.lifetime.value_namespace = name_space
                            self.lifetime.value_namespace_prefix = name_space_prefix


                class ProcessScope(Entity):
                    """
                    Process scope configuration
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	BFD configuration
                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd>`
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: cost_fallback
                    
                    	Interface fallback cost
                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: dead_interval_minimal
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal>`
                    
                    .. attribute:: demand_circuit
                    
                    	Enable/Disable OSPF demand circuit
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: distribute_list
                    
                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: external_out
                    
                    	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                    	**type**\:  bool
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute configuration
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	Enable/Disable OSPF flood reduction
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: hello_interval
                    
                    	Interval between HELLO packets in seconds
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    .. attribute:: ldp_auto_config
                    
                    	Enable MPLS LDP Auto Config
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ldp_sync
                    
                    	Enable/Disable MPLS LDP sync
                    	**type**\:  bool
                    
                    .. attribute:: ldp_sync_igp_shortcuts
                    
                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                    	**type**\:  bool
                    
                    .. attribute:: link_down_fast_detect
                    
                    	Enable/Disable registration for early interface down notifications
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: loopback_stub_network
                    
                    	Enable/Disable advertising loopback as a stub network
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: mtu_ignore
                    
                    	Enable/Disable ignoring of MTU in DBD packets
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: network_type
                    
                    	Type of attached network
                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                    
                    .. attribute:: packet_size
                    
                    	Customize size of OSPF packets upto MTU
                    	**type**\:  int
                    
                    	**range:** 576..10000
                    
                    .. attribute:: passive
                    
                    	When enabled, prevent sending HELLO packets over link
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: prefix_suppression_primary
                    
                    	Enable/Disable prefix suppression for primary addresses
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: prefix_suppression_secondary
                    
                    	Enable/Disable prefix suppression for secondary addresses
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: priority
                    
                    	Router priority for DR and BDR election
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**default value**\: 1
                    
                    .. attribute:: retransmit_interval
                    
                    	Time in seconds between retransmitting lost link state advertisements
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    	**default value**\: 5
                    
                    .. attribute:: security
                    
                    	Container class for security related configuration parameters
                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Security>`
                    
                    .. attribute:: segment_routing
                    
                    	segment\-routing configuration Applicable only in Default VRF
                    	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                    
                    .. attribute:: segment_routing_forwarding
                    
                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                    
                    .. attribute:: srgb
                    
                    	Segment Routing Global Block configuration
                    	**type**\:   :py:class:`Srgb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: summary_in
                    
                    	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                    	**type**\:  bool
                    
                    .. attribute:: transmit_delay
                    
                    	Number of seconds to delay transmission of LSAs
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    	**default value**\: 1
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope, self).__init__()

                        self.yang_name = "process-scope"
                        self.yang_parent_name = "default-vrf"

                        self.cost = YLeaf(YType.uint32, "cost")

                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                        self.external_out = YLeaf(YType.boolean, "external-out")

                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                        self.network_type = YLeaf(YType.enumeration, "network-type")

                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                        self.passive = YLeaf(YType.boolean, "passive")

                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                        self.priority = YLeaf(YType.uint32, "priority")

                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                        self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                        self.summary_in = YLeaf(YType.boolean, "summary-in")

                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                        self.authentication = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._children_yang_names.add("authentication")

                        self.bfd = Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"
                        self._children_yang_names.add("bfd")

                        self.cost_fallback = Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback()
                        self.cost_fallback.parent = self
                        self._children_name_map["cost_fallback"] = "cost-fallback"
                        self._children_yang_names.add("cost-fallback")

                        self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal()
                        self.dead_interval_minimal.parent = self
                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                        self._children_yang_names.add("dead-interval-minimal")

                        self.distribute_list = None
                        self._children_name_map["distribute_list"] = "distribute-list"
                        self._children_yang_names.add("distribute-list")

                        self.fast_reroute = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.security = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security()
                        self.security.parent = self
                        self._children_name_map["security"] = "security"
                        self._children_yang_names.add("security")

                        self.srgb = None
                        self._children_name_map["srgb"] = "srgb"
                        self._children_yang_names.add("srgb")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("cost",
                                        "database_filter",
                                        "demand_circuit",
                                        "external_out",
                                        "flood_reduction",
                                        "hello_interval",
                                        "ldp_auto_config",
                                        "ldp_sync",
                                        "ldp_sync_igp_shortcuts",
                                        "link_down_fast_detect",
                                        "loopback_stub_network",
                                        "mtu_ignore",
                                        "network_type",
                                        "packet_size",
                                        "passive",
                                        "prefix_suppression_primary",
                                        "prefix_suppression_secondary",
                                        "priority",
                                        "retransmit_interval",
                                        "segment_routing",
                                        "segment_routing_forwarding",
                                        "summary_in",
                                        "transmit_delay") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope, self).__setattr__(name, value)


                    class Srgb(Entity):
                        """
                        Segment Routing Global Block configuration
                        
                        .. attribute:: lower_bound
                        
                        	The lower bound of the SRGB
                        	**type**\:  int
                        
                        	**range:** 16000..1048575
                        
                        	**mandatory**\: True
                        
                        .. attribute:: upper_bound
                        
                        	The upper bound of the SRGB
                        	**type**\:  int
                        
                        	**range:** 16000..1048575
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb, self).__init__()

                            self.yang_name = "srgb"
                            self.yang_parent_name = "process-scope"
                            self.is_presence_container = True

                            self.lower_bound = YLeaf(YType.uint32, "lower-bound")

                            self.upper_bound = YLeaf(YType.uint32, "upper-bound")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("lower_bound",
                                            "upper_bound") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.lower_bound.is_set or
                                self.upper_bound.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.lower_bound.yfilter != YFilter.not_set or
                                self.upper_bound.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "srgb" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.lower_bound.is_set or self.lower_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lower_bound.get_name_leafdata())
                            if (self.upper_bound.is_set or self.upper_bound.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.upper_bound.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lower-bound" or name == "upper-bound"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "lower-bound"):
                                self.lower_bound = value
                                self.lower_bound.value_namespace = name_space
                                self.lower_bound.value_namespace_prefix = name_space_prefix
                            if(value_path == "upper-bound"):
                                self.upper_bound = value
                                self.upper_bound.value_namespace = name_space
                                self.upper_bound.value_namespace_prefix = name_space_prefix


                    class FastReroute(Entity):
                        """
                        Fast\-reroute configuration
                        
                        .. attribute:: fast_reroute_enable
                        
                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                        	**type**\:   :py:class:`OspfProcFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFastReroute>`
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-prefix configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "process-scope"

                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                            self.per_link = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink()
                            self.per_link.parent = self
                            self._children_name_map["per_link"] = "per-link"
                            self._children_yang_names.add("per-link")

                            self.per_prefix = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._children_yang_names.add("per-prefix")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("fast_reroute_enable") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute, self).__setattr__(name, value)


                        class PerLink(Entity):
                            """
                            Fast\-reroute per\-link configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink, self).__init__()

                                self.yang_name = "per-link"
                                self.yang_parent_name = "fast-reroute"

                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                self._children_yang_names.add("candidate-interfaces")

                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                self._children_yang_names.add("exclude-interfaces")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink, self).__setattr__(name, value)


                            class CandidateInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                    self.yang_name = "candidate-interfaces"
                                    self.yang_parent_name = "per-link"

                                    self.candidate_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                class CandidateInterface(Entity):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                        self.yang_name = "candidate-interface"
                                        self.yang_parent_name = "candidate-interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.candidate_interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.candidate_interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-interface"):
                                        for c in self.candidate_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.candidate_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class ExcludeInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup or UCMP
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                    self.yang_name = "exclude-interfaces"
                                    self.yang_parent_name = "per-link"

                                    self.exclude_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                class ExcludeInterface(Entity):
                                    """
                                    Exclude an interface from becoming a backup or
                                    UCMP
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                        self.yang_name = "exclude-interface"
                                        self.yang_parent_name = "exclude-interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.exclude_interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.exclude_interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "exclude-interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "exclude-interface"):
                                        for c in self.exclude_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.exclude_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "exclude-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fast_reroute_use_candidate_only.is_set or
                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "per-link" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-interfaces"):
                                    if (self.candidate_interfaces is None):
                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    return self.candidate_interfaces

                                if (child_yang_name == "exclude-interfaces"):
                                    if (self.exclude_interfaces is None):
                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    return self.exclude_interfaces

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fast-reroute-use-candidate-only"):
                                    self.fast_reroute_use_candidate_only = value
                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                        class PerPrefix(Entity):
                            """
                            Fast\-reroute per\-prefix configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: remote_lfa
                            
                            	Remote LFA configuration
                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa>`
                            
                            .. attribute:: topology_independent_lfa
                            
                            	Topology Independet LFA configuration
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"

                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                self._children_yang_names.add("candidate-interfaces")

                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                self._children_yang_names.add("exclude-interfaces")

                                self.remote_lfa = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                self.remote_lfa.parent = self
                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                self._children_yang_names.add("remote-lfa")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("fast_reroute_use_candidate_only",
                                                "topology_independent_lfa") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                            class RemoteLfa(Entity):
                                """
                                Remote LFA configuration
                                
                                .. attribute:: maximum_cost
                                
                                	Maximum path cost to remote LFA
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tunnel
                                
                                	Enable/Disable remote LFA computation
                                	**type**\:   :py:class:`OspfProcFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFrrRlfaTunnel>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                    self.yang_name = "remote-lfa"
                                    self.yang_parent_name = "per-prefix"

                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("maximum_cost",
                                                    "tunnel") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.maximum_cost.is_set or
                                        self.tunnel.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.maximum_cost.yfilter != YFilter.not_set or
                                        self.tunnel.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "remote-lfa" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                    if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tunnel.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "maximum-cost" or name == "tunnel"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "maximum-cost"):
                                        self.maximum_cost = value
                                        self.maximum_cost.value_namespace = name_space
                                        self.maximum_cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tunnel"):
                                        self.tunnel = value
                                        self.tunnel.value_namespace = name_space
                                        self.tunnel.value_namespace_prefix = name_space_prefix


                            class CandidateInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                    self.yang_name = "candidate-interfaces"
                                    self.yang_parent_name = "per-prefix"

                                    self.candidate_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                class CandidateInterface(Entity):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                        self.yang_name = "candidate-interface"
                                        self.yang_parent_name = "candidate-interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.candidate_interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.candidate_interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "candidate-interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "candidate-interface"):
                                        for c in self.candidate_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.candidate_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "candidate-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class ExcludeInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup or UCMP
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                    self.yang_name = "exclude-interfaces"
                                    self.yang_parent_name = "per-prefix"

                                    self.exclude_interface = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                class ExcludeInterface(Entity):
                                    """
                                    Exclude an interface from becoming a backup or
                                    UCMP
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                        self.yang_name = "exclude-interface"
                                        self.yang_parent_name = "exclude-interfaces"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.interface_name.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.exclude_interface:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.exclude_interface:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "exclude-interfaces" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "exclude-interface"):
                                        for c in self.exclude_interface:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.exclude_interface.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "exclude-interface"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.fast_reroute_use_candidate_only.is_set or
                                    self.topology_independent_lfa.is_set or
                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                    (self.remote_lfa is not None and self.remote_lfa.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                    self.topology_independent_lfa.yfilter != YFilter.not_set or
                                    (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                    (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                    (self.remote_lfa is not None and self.remote_lfa.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "per-prefix" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "candidate-interfaces"):
                                    if (self.candidate_interfaces is None):
                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    return self.candidate_interfaces

                                if (child_yang_name == "exclude-interfaces"):
                                    if (self.exclude_interfaces is None):
                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    return self.exclude_interfaces

                                if (child_yang_name == "remote-lfa"):
                                    if (self.remote_lfa is None):
                                        self.remote_lfa = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                        self.remote_lfa.parent = self
                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                    return self.remote_lfa

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "fast-reroute-use-candidate-only"):
                                    self.fast_reroute_use_candidate_only = value
                                    self.fast_reroute_use_candidate_only.value_namespace = name_space
                                    self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-independent-lfa"):
                                    self.topology_independent_lfa = value
                                    self.topology_independent_lfa.value_namespace = name_space
                                    self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.fast_reroute_enable.is_set or
                                (self.per_link is not None and self.per_link.has_data()) or
                                (self.per_prefix is not None and self.per_prefix.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.fast_reroute_enable.yfilter != YFilter.not_set or
                                (self.per_link is not None and self.per_link.has_operation()) or
                                (self.per_prefix is not None and self.per_prefix.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "fast-reroute" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "per-link"):
                                if (self.per_link is None):
                                    self.per_link = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                return self.per_link

                            if (child_yang_name == "per-prefix"):
                                if (self.per_prefix is None):
                                    self.per_prefix = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                return self.per_prefix

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "fast-reroute-enable"):
                                self.fast_reroute_enable = value
                                self.fast_reroute_enable.value_namespace = name_space
                                self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                    class DistributeList(Entity):
                        """
                        Filter networks intalled to RIB (disable as ACL
                        name means filtering is disabled)
                        
                        .. attribute:: access_list_name
                        
                        	Access Control List name
                        	**type**\:  str
                        
                        .. attribute:: route_policy_name
                        
                        	Route Policy name
                        	**type**\:  str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList, self).__init__()

                            self.yang_name = "distribute-list"
                            self.yang_parent_name = "process-scope"
                            self.is_presence_container = True

                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("access_list_name",
                                            "route_policy_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.access_list_name.is_set or
                                self.route_policy_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.access_list_name.yfilter != YFilter.not_set or
                                self.route_policy_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "distribute-list" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                            if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "access-list-name" or name == "route-policy-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "access-list-name"):
                                self.access_list_name = value
                                self.access_list_name.value_namespace = name_space
                                self.access_list_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-name"):
                                self.route_policy_name = value
                                self.route_policy_name.value_namespace = name_space
                                self.route_policy_name.value_namespace_prefix = name_space_prefix


                    class Bfd(Entity):
                        """
                        BFD configuration
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection multiplier for BFD sessions created by OSPF
                        	**type**\:  int
                        
                        	**range:** 2..50
                        
                        .. attribute:: fast_detect_mode
                        
                        	 use of Bidirectional Forwarding Detection
                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                        
                        .. attribute:: interval
                        
                        	Hello interval for BFD sessions created by OSPF
                        	**type**\:  int
                        
                        	**range:** 3..30000
                        
                        	**units**\: millisecond
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-scope"

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                            self.interval = YLeaf(YType.uint32, "interval")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("detection_multiplier",
                                            "fast_detect_mode",
                                            "interval") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.detection_multiplier.is_set or
                                self.fast_detect_mode.is_set or
                                self.interval.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.detection_multiplier.yfilter != YFilter.not_set or
                                self.fast_detect_mode.yfilter != YFilter.not_set or
                                self.interval.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "bfd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                            if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interval.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "detection-multiplier"):
                                self.detection_multiplier = value
                                self.detection_multiplier.value_namespace = name_space
                                self.detection_multiplier.value_namespace_prefix = name_space_prefix
                            if(value_path == "fast-detect-mode"):
                                self.fast_detect_mode = value
                                self.fast_detect_mode.value_namespace = name_space
                                self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "interval"):
                                self.interval = value
                                self.interval.value_namespace = name_space
                                self.interval.value_namespace_prefix = name_space_prefix


                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: key
                        
                        	Authentication key configuration
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: message_digest_keies
                        
                        	Message digest authentication password (key) configurations, first 16 chars used
                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies>`
                        
                        .. attribute:: type
                        
                        	Authentication type
                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-scope"

                            self.key = YLeaf(YType.str, "key")

                            self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies()
                            self.message_digest_keies.parent = self
                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                            self._children_yang_names.add("message-digest-keies")

                            self.type = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type()
                            self.type.parent = self
                            self._children_name_map["type"] = "type"
                            self._children_yang_names.add("type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("key") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication, self).__setattr__(name, value)


                        class Type(Entity):
                            """
                            Authentication type
                            
                            .. attribute:: authen_type
                            
                            	Authentication type code 
                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                            
                            .. attribute:: keychain_authen_type
                            
                            	Keychain authentication type
                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                            
                            .. attribute:: keychain_name
                            
                            	Keychain name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "authentication"

                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                self.keychain_name = YLeaf(YType.str, "keychain-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("authen_type",
                                                "keychain_authen_type",
                                                "keychain_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.authen_type.is_set or
                                    self.keychain_authen_type.is_set or
                                    self.keychain_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.authen_type.yfilter != YFilter.not_set or
                                    self.keychain_authen_type.yfilter != YFilter.not_set or
                                    self.keychain_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "type" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.authen_type.get_name_leafdata())
                                if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "authen-type"):
                                    self.authen_type = value
                                    self.authen_type.value_namespace = name_space
                                    self.authen_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "keychain-authen-type"):
                                    self.keychain_authen_type = value
                                    self.keychain_authen_type.value_namespace = name_space
                                    self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "keychain-name"):
                                    self.keychain_name = value
                                    self.keychain_name.value_namespace = name_space
                                    self.keychain_name.value_namespace_prefix = name_space_prefix


                        class MessageDigestKeies(Entity):
                            """
                            Message digest authentication password (key)
                            configurations, first 16 chars used
                            
                            .. attribute:: message_digest_key
                            
                            	Message digest authentication password (key) configuration
                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies, self).__init__()

                                self.yang_name = "message-digest-keies"
                                self.yang_parent_name = "authentication"

                                self.message_digest_key = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                            class MessageDigestKey(Entity):
                                """
                                Message digest authentication password (key)
                                configuration
                                
                                .. attribute:: key_id  <key>
                                
                                	Key ID
                                	**type**\:  int
                                
                                	**range:** 1..255
                                
                                .. attribute:: password
                                
                                	Password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "message-digest-keies"

                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                    self.password = YLeaf(YType.str, "password")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key_id",
                                                    "password") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.key_id.is_set or
                                        self.password.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key_id.yfilter != YFilter.not_set or
                                        self.password.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key_id.get_name_leafdata())
                                    if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.password.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "key-id" or name == "password"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key-id"):
                                        self.key_id = value
                                        self.key_id.value_namespace = name_space
                                        self.key_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "password"):
                                        self.password = value
                                        self.password.value_namespace = name_space
                                        self.password.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.message_digest_key:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.message_digest_key:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "message-digest-keies" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "message-digest-key"):
                                    for c in self.message_digest_key:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.message_digest_key.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "message-digest-key"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.key.is_set or
                                (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                (self.type is not None and self.type.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.key.yfilter != YFilter.not_set or
                                (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                (self.type is not None and self.type.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "authentication" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.key.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "message-digest-keies"):
                                if (self.message_digest_keies is None):
                                    self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies()
                                    self.message_digest_keies.parent = self
                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                return self.message_digest_keies

                            if (child_yang_name == "type"):
                                if (self.type is None):
                                    self.type = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type()
                                    self.type.parent = self
                                    self._children_name_map["type"] = "type"
                                return self.type

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "message-digest-keies" or name == "type" or name == "key"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "key"):
                                self.key = value
                                self.key.value_namespace = name_space
                                self.key.value_namespace_prefix = name_space_prefix


                    class Security(Entity):
                        """
                        Container class for security related
                        configuration parameters
                        
                        .. attribute:: ttl
                        
                        	Enabling turns on TTL security
                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security, self).__init__()

                            self.yang_name = "security"
                            self.yang_parent_name = "process-scope"

                            self.ttl = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl()
                            self.ttl.parent = self
                            self._children_name_map["ttl"] = "ttl"
                            self._children_yang_names.add("ttl")


                        class Ttl(Entity):
                            """
                            Enabling turns on TTL security
                            
                            .. attribute:: enable
                            
                            	Enable TTL security
                            	**type**\:  bool
                            
                            .. attribute:: hop_count
                            
                            	Hop count
                            	**type**\:  int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "security"

                                self.enable = YLeaf(YType.boolean, "enable")

                                self.hop_count = YLeaf(YType.uint32, "hop-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("enable",
                                                "hop_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.enable.is_set or
                                    self.hop_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.enable.yfilter != YFilter.not_set or
                                    self.hop_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ttl" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enable.get_name_leafdata())
                                if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hop_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "enable" or name == "hop-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "enable"):
                                    self.enable = value
                                    self.enable.value_namespace = name_space
                                    self.enable.value_namespace_prefix = name_space_prefix
                                if(value_path == "hop-count"):
                                    self.hop_count = value
                                    self.hop_count.value_namespace = name_space
                                    self.hop_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.ttl is not None and self.ttl.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.ttl is not None and self.ttl.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "security" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ttl"):
                                if (self.ttl is None):
                                    self.ttl = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl()
                                    self.ttl.parent = self
                                    self._children_name_map["ttl"] = "ttl"
                                return self.ttl

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ttl"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DeadIntervalMinimal(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: interval
                        
                        	Interval size in seconds after which a neighbor is declared dead
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: multiplier
                        
                        	Number of Hellos in one second
                        	**type**\:  int
                        
                        	**range:** 3..20
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal, self).__init__()

                            self.yang_name = "dead-interval-minimal"
                            self.yang_parent_name = "process-scope"

                            self.interval = YLeaf(YType.uint32, "interval")

                            self.multiplier = YLeaf(YType.uint32, "multiplier")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interval",
                                            "multiplier") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interval.is_set or
                                self.multiplier.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interval.yfilter != YFilter.not_set or
                                self.multiplier.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dead-interval-minimal" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interval.get_name_leafdata())
                            if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.multiplier.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interval" or name == "multiplier"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interval"):
                                self.interval = value
                                self.interval.value_namespace = name_space
                                self.interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "multiplier"):
                                self.multiplier = value
                                self.multiplier.value_namespace = name_space
                                self.multiplier.value_namespace_prefix = name_space_prefix


                    class CostFallback(Entity):
                        """
                        Interface fallback cost
                        
                        .. attribute:: cost
                        
                        	Fallback cost of link
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: threshold
                        
                        	Bandwidth threshold
                        	**type**\:  int
                        
                        	**range:** 1..4294967
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback, self).__init__()

                            self.yang_name = "cost-fallback"
                            self.yang_parent_name = "process-scope"

                            self.cost = YLeaf(YType.uint32, "cost")

                            self.threshold = YLeaf(YType.uint32, "threshold")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("cost",
                                            "threshold") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.cost.is_set or
                                self.threshold.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.cost.yfilter != YFilter.not_set or
                                self.threshold.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "cost-fallback" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.cost.get_name_leafdata())
                            if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.threshold.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "cost" or name == "threshold"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "cost"):
                                self.cost = value
                                self.cost.value_namespace = name_space
                                self.cost.value_namespace_prefix = name_space_prefix
                            if(value_path == "threshold"):
                                self.threshold = value
                                self.threshold.value_namespace = name_space
                                self.threshold.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.cost.is_set or
                            self.database_filter.is_set or
                            self.demand_circuit.is_set or
                            self.external_out.is_set or
                            self.flood_reduction.is_set or
                            self.hello_interval.is_set or
                            self.ldp_auto_config.is_set or
                            self.ldp_sync.is_set or
                            self.ldp_sync_igp_shortcuts.is_set or
                            self.link_down_fast_detect.is_set or
                            self.loopback_stub_network.is_set or
                            self.mtu_ignore.is_set or
                            self.network_type.is_set or
                            self.packet_size.is_set or
                            self.passive.is_set or
                            self.prefix_suppression_primary.is_set or
                            self.prefix_suppression_secondary.is_set or
                            self.priority.is_set or
                            self.retransmit_interval.is_set or
                            self.segment_routing.is_set or
                            self.segment_routing_forwarding.is_set or
                            self.summary_in.is_set or
                            self.transmit_delay.is_set or
                            (self.authentication is not None and self.authentication.has_data()) or
                            (self.bfd is not None and self.bfd.has_data()) or
                            (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                            (self.security is not None and self.security.has_data()) or
                            (self.distribute_list is not None) or
                            (self.srgb is not None))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.cost.yfilter != YFilter.not_set or
                            self.database_filter.yfilter != YFilter.not_set or
                            self.demand_circuit.yfilter != YFilter.not_set or
                            self.external_out.yfilter != YFilter.not_set or
                            self.flood_reduction.yfilter != YFilter.not_set or
                            self.hello_interval.yfilter != YFilter.not_set or
                            self.ldp_auto_config.yfilter != YFilter.not_set or
                            self.ldp_sync.yfilter != YFilter.not_set or
                            self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                            self.link_down_fast_detect.yfilter != YFilter.not_set or
                            self.loopback_stub_network.yfilter != YFilter.not_set or
                            self.mtu_ignore.yfilter != YFilter.not_set or
                            self.network_type.yfilter != YFilter.not_set or
                            self.packet_size.yfilter != YFilter.not_set or
                            self.passive.yfilter != YFilter.not_set or
                            self.prefix_suppression_primary.yfilter != YFilter.not_set or
                            self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                            self.priority.yfilter != YFilter.not_set or
                            self.retransmit_interval.yfilter != YFilter.not_set or
                            self.segment_routing.yfilter != YFilter.not_set or
                            self.segment_routing_forwarding.yfilter != YFilter.not_set or
                            self.summary_in.yfilter != YFilter.not_set or
                            self.transmit_delay.yfilter != YFilter.not_set or
                            (self.authentication is not None and self.authentication.has_operation()) or
                            (self.bfd is not None and self.bfd.has_operation()) or
                            (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                            (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                            (self.distribute_list is not None and self.distribute_list.has_operation()) or
                            (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                            (self.security is not None and self.security.has_operation()) or
                            (self.srgb is not None and self.srgb.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "process-scope" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.cost.get_name_leafdata())
                        if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.database_filter.get_name_leafdata())
                        if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                        if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.external_out.get_name_leafdata())
                        if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                        if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello_interval.get_name_leafdata())
                        if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                        if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                        if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                        if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                        if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                        if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                        if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.network_type.get_name_leafdata())
                        if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_size.get_name_leafdata())
                        if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.passive.get_name_leafdata())
                        if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                        if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.priority.get_name_leafdata())
                        if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                        if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_routing.get_name_leafdata())
                        if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                        if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.summary_in.get_name_leafdata())
                        if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "authentication"):
                            if (self.authentication is None):
                                self.authentication = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                            return self.authentication

                        if (child_yang_name == "bfd"):
                            if (self.bfd is None):
                                self.bfd = Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                            return self.bfd

                        if (child_yang_name == "cost-fallback"):
                            if (self.cost_fallback is None):
                                self.cost_fallback = Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback()
                                self.cost_fallback.parent = self
                                self._children_name_map["cost_fallback"] = "cost-fallback"
                            return self.cost_fallback

                        if (child_yang_name == "dead-interval-minimal"):
                            if (self.dead_interval_minimal is None):
                                self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal()
                                self.dead_interval_minimal.parent = self
                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                            return self.dead_interval_minimal

                        if (child_yang_name == "distribute-list"):
                            if (self.distribute_list is None):
                                self.distribute_list = Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList()
                                self.distribute_list.parent = self
                                self._children_name_map["distribute_list"] = "distribute-list"
                            return self.distribute_list

                        if (child_yang_name == "fast-reroute"):
                            if (self.fast_reroute is None):
                                self.fast_reroute = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                            return self.fast_reroute

                        if (child_yang_name == "security"):
                            if (self.security is None):
                                self.security = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security()
                                self.security.parent = self
                                self._children_name_map["security"] = "security"
                            return self.security

                        if (child_yang_name == "srgb"):
                            if (self.srgb is None):
                                self.srgb = Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb()
                                self.srgb.parent = self
                                self._children_name_map["srgb"] = "srgb"
                            return self.srgb

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "srgb" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "external-out" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing" or name == "segment-routing-forwarding" or name == "summary-in" or name == "transmit-delay"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "cost"):
                            self.cost = value
                            self.cost.value_namespace = name_space
                            self.cost.value_namespace_prefix = name_space_prefix
                        if(value_path == "database-filter"):
                            self.database_filter = value
                            self.database_filter.value_namespace = name_space
                            self.database_filter.value_namespace_prefix = name_space_prefix
                        if(value_path == "demand-circuit"):
                            self.demand_circuit = value
                            self.demand_circuit.value_namespace = name_space
                            self.demand_circuit.value_namespace_prefix = name_space_prefix
                        if(value_path == "external-out"):
                            self.external_out = value
                            self.external_out.value_namespace = name_space
                            self.external_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "flood-reduction"):
                            self.flood_reduction = value
                            self.flood_reduction.value_namespace = name_space
                            self.flood_reduction.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello-interval"):
                            self.hello_interval = value
                            self.hello_interval.value_namespace = name_space
                            self.hello_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-auto-config"):
                            self.ldp_auto_config = value
                            self.ldp_auto_config.value_namespace = name_space
                            self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-sync"):
                            self.ldp_sync = value
                            self.ldp_sync.value_namespace = name_space
                            self.ldp_sync.value_namespace_prefix = name_space_prefix
                        if(value_path == "ldp-sync-igp-shortcuts"):
                            self.ldp_sync_igp_shortcuts = value
                            self.ldp_sync_igp_shortcuts.value_namespace = name_space
                            self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                        if(value_path == "link-down-fast-detect"):
                            self.link_down_fast_detect = value
                            self.link_down_fast_detect.value_namespace = name_space
                            self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                        if(value_path == "loopback-stub-network"):
                            self.loopback_stub_network = value
                            self.loopback_stub_network.value_namespace = name_space
                            self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu-ignore"):
                            self.mtu_ignore = value
                            self.mtu_ignore.value_namespace = name_space
                            self.mtu_ignore.value_namespace_prefix = name_space_prefix
                        if(value_path == "network-type"):
                            self.network_type = value
                            self.network_type.value_namespace = name_space
                            self.network_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-size"):
                            self.packet_size = value
                            self.packet_size.value_namespace = name_space
                            self.packet_size.value_namespace_prefix = name_space_prefix
                        if(value_path == "passive"):
                            self.passive = value
                            self.passive.value_namespace = name_space
                            self.passive.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-suppression-primary"):
                            self.prefix_suppression_primary = value
                            self.prefix_suppression_primary.value_namespace = name_space
                            self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-suppression-secondary"):
                            self.prefix_suppression_secondary = value
                            self.prefix_suppression_secondary.value_namespace = name_space
                            self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                        if(value_path == "priority"):
                            self.priority = value
                            self.priority.value_namespace = name_space
                            self.priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "retransmit-interval"):
                            self.retransmit_interval = value
                            self.retransmit_interval.value_namespace = name_space
                            self.retransmit_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-routing"):
                            self.segment_routing = value
                            self.segment_routing.value_namespace = name_space
                            self.segment_routing.value_namespace_prefix = name_space_prefix
                        if(value_path == "segment-routing-forwarding"):
                            self.segment_routing_forwarding = value
                            self.segment_routing_forwarding.value_namespace = name_space
                            self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                        if(value_path == "summary-in"):
                            self.summary_in = value
                            self.summary_in.value_namespace = name_space
                            self.summary_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "transmit-delay"):
                            self.transmit_delay = value
                            self.transmit_delay.value_namespace = name_space
                            self.transmit_delay.value_namespace_prefix = name_space_prefix


                class Redistribution(Entity):
                    """
                    Redistribute configurations
                    
                    .. attribute:: redistributes
                    
                    	Redistribute information from another routing protocol
                    	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Redistribution, self).__init__()

                        self.yang_name = "redistribution"
                        self.yang_parent_name = "default-vrf"

                        self.redistributes = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes()
                        self.redistributes.parent = self
                        self._children_name_map["redistributes"] = "redistributes"
                        self._children_yang_names.add("redistributes")


                    class Redistributes(Entity):
                        """
                        Redistribute information from another routing
                        protocol
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes, self).__init__()

                            self.yang_name = "redistributes"
                            self.yang_parent_name = "redistribution"

                            self.redistribute = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes, self).__setattr__(name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing
                            protocol
                            
                            .. attribute:: protocol_name  <key>
                            
                            	Distribute list protocol type
                            	**type**\:   :py:class:`OspfRedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistProtocol>`
                            
                            .. attribute:: application_or_isis_or_ospf
                            
                            	application or isis or ospf
                            	**type**\: list of    :py:class:`ApplicationOrIsisOrOspf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf>`
                            
                            .. attribute:: bgp
                            
                            	bgp
                            	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp>`
                            
                            .. attribute:: connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip
                            
                            	connected or static or dagr or subscriber or mobile or rip
                            	**type**\:   :py:class:`ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	eigrp
                            	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "redistributes"

                                self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = None
                                self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                self._children_yang_names.add("connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip")

                                self.application_or_isis_or_ospf = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("protocol_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute, self).__setattr__(name, value)


                            class ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip(Entity):
                                """
                                connected or static or dagr or subscriber or
                                mobile or rip
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__init__()

                                    self.yang_name = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_presence_container = True

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.int32, "tag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("bgp_preserve_default_info",
                                                    "bgp_preserve_med",
                                                    "classful",
                                                    "default_redistributed_route_metric",
                                                    "eigrp_route_type",
                                                    "isis_levels",
                                                    "metric_type",
                                                    "ospf_external",
                                                    "ospf_internal",
                                                    "ospf_nssa_level",
                                                    "ospf_redist_lsa_type",
                                                    "ospfnssa_only",
                                                    "route_policy_name",
                                                    "tag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.bgp_preserve_default_info.is_set or
                                        self.bgp_preserve_med.is_set or
                                        self.classful.is_set or
                                        self.default_redistributed_route_metric.is_set or
                                        self.eigrp_route_type.is_set or
                                        self.isis_levels.is_set or
                                        self.metric_type.is_set or
                                        self.ospf_external.is_set or
                                        self.ospf_internal.is_set or
                                        self.ospf_nssa_level.is_set or
                                        self.ospf_redist_lsa_type.is_set or
                                        self.ospfnssa_only.is_set or
                                        self.route_policy_name.is_set or
                                        self.tag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                        self.bgp_preserve_med.yfilter != YFilter.not_set or
                                        self.classful.yfilter != YFilter.not_set or
                                        self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                        self.eigrp_route_type.yfilter != YFilter.not_set or
                                        self.isis_levels.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.ospf_external.yfilter != YFilter.not_set or
                                        self.ospf_internal.yfilter != YFilter.not_set or
                                        self.ospf_nssa_level.yfilter != YFilter.not_set or
                                        self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                        self.ospfnssa_only.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set or
                                        self.tag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                    if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                    if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classful.get_name_leafdata())
                                    if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                    if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                    if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                    if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                    if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                    if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                    if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "bgp-preserve-default-info"):
                                        self.bgp_preserve_default_info = value
                                        self.bgp_preserve_default_info.value_namespace = name_space
                                        self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-med"):
                                        self.bgp_preserve_med = value
                                        self.bgp_preserve_med.value_namespace = name_space
                                        self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                    if(value_path == "classful"):
                                        self.classful = value
                                        self.classful.value_namespace = name_space
                                        self.classful.value_namespace_prefix = name_space_prefix
                                    if(value_path == "default-redistributed-route-metric"):
                                        self.default_redistributed_route_metric = value
                                        self.default_redistributed_route_metric.value_namespace = name_space
                                        self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-route-type"):
                                        self.eigrp_route_type = value
                                        self.eigrp_route_type.value_namespace = name_space
                                        self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-levels"):
                                        self.isis_levels = value
                                        self.isis_levels.value_namespace = name_space
                                        self.isis_levels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-external"):
                                        self.ospf_external = value
                                        self.ospf_external.value_namespace = name_space
                                        self.ospf_external.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-internal"):
                                        self.ospf_internal = value
                                        self.ospf_internal.value_namespace = name_space
                                        self.ospf_internal.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-nssa-level"):
                                        self.ospf_nssa_level = value
                                        self.ospf_nssa_level.value_namespace = name_space
                                        self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-redist-lsa-type"):
                                        self.ospf_redist_lsa_type = value
                                        self.ospf_redist_lsa_type.value_namespace = name_space
                                        self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospfnssa-only"):
                                        self.ospfnssa_only = value
                                        self.ospfnssa_only.value_namespace = name_space
                                        self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag"):
                                        self.tag = value
                                        self.tag.value_namespace = name_space
                                        self.tag.value_namespace_prefix = name_space_prefix


                            class ApplicationOrIsisOrOspf(Entity):
                                """
                                application or isis or ospf
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__init__()

                                    self.yang_name = "application-or-isis-or-ospf"
                                    self.yang_parent_name = "redistribute"

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.int32, "tag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance_name",
                                                    "bgp_preserve_default_info",
                                                    "bgp_preserve_med",
                                                    "classful",
                                                    "default_redistributed_route_metric",
                                                    "eigrp_route_type",
                                                    "isis_levels",
                                                    "metric_type",
                                                    "ospf_external",
                                                    "ospf_internal",
                                                    "ospf_nssa_level",
                                                    "ospf_redist_lsa_type",
                                                    "ospfnssa_only",
                                                    "route_policy_name",
                                                    "tag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.instance_name.is_set or
                                        self.bgp_preserve_default_info.is_set or
                                        self.bgp_preserve_med.is_set or
                                        self.classful.is_set or
                                        self.default_redistributed_route_metric.is_set or
                                        self.eigrp_route_type.is_set or
                                        self.isis_levels.is_set or
                                        self.metric_type.is_set or
                                        self.ospf_external.is_set or
                                        self.ospf_internal.is_set or
                                        self.ospf_nssa_level.is_set or
                                        self.ospf_redist_lsa_type.is_set or
                                        self.ospfnssa_only.is_set or
                                        self.route_policy_name.is_set or
                                        self.tag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance_name.yfilter != YFilter.not_set or
                                        self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                        self.bgp_preserve_med.yfilter != YFilter.not_set or
                                        self.classful.yfilter != YFilter.not_set or
                                        self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                        self.eigrp_route_type.yfilter != YFilter.not_set or
                                        self.isis_levels.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.ospf_external.yfilter != YFilter.not_set or
                                        self.ospf_internal.yfilter != YFilter.not_set or
                                        self.ospf_nssa_level.yfilter != YFilter.not_set or
                                        self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                        self.ospfnssa_only.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set or
                                        self.tag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "application-or-isis-or-ospf" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_name.get_name_leafdata())
                                    if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                    if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                    if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classful.get_name_leafdata())
                                    if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                    if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                    if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                    if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                    if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                    if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                    if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance-name" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance-name"):
                                        self.instance_name = value
                                        self.instance_name.value_namespace = name_space
                                        self.instance_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-default-info"):
                                        self.bgp_preserve_default_info = value
                                        self.bgp_preserve_default_info.value_namespace = name_space
                                        self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-med"):
                                        self.bgp_preserve_med = value
                                        self.bgp_preserve_med.value_namespace = name_space
                                        self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                    if(value_path == "classful"):
                                        self.classful = value
                                        self.classful.value_namespace = name_space
                                        self.classful.value_namespace_prefix = name_space_prefix
                                    if(value_path == "default-redistributed-route-metric"):
                                        self.default_redistributed_route_metric = value
                                        self.default_redistributed_route_metric.value_namespace = name_space
                                        self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-route-type"):
                                        self.eigrp_route_type = value
                                        self.eigrp_route_type.value_namespace = name_space
                                        self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-levels"):
                                        self.isis_levels = value
                                        self.isis_levels.value_namespace = name_space
                                        self.isis_levels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-external"):
                                        self.ospf_external = value
                                        self.ospf_external.value_namespace = name_space
                                        self.ospf_external.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-internal"):
                                        self.ospf_internal = value
                                        self.ospf_internal.value_namespace = name_space
                                        self.ospf_internal.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-nssa-level"):
                                        self.ospf_nssa_level = value
                                        self.ospf_nssa_level.value_namespace = name_space
                                        self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-redist-lsa-type"):
                                        self.ospf_redist_lsa_type = value
                                        self.ospf_redist_lsa_type.value_namespace = name_space
                                        self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospfnssa-only"):
                                        self.ospfnssa_only = value
                                        self.ospfnssa_only.value_namespace = name_space
                                        self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag"):
                                        self.tag = value
                                        self.tag.value_namespace = name_space
                                        self.tag.value_namespace_prefix = name_space_prefix


                            class Bgp(Entity):
                                """
                                bgp
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: as_xx  <key>
                                
                                	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_yy  <key>
                                
                                	Second half of BGP AS number in XX.YY format . Mandatory if Protocol is BGP or EIGRP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.int32, "tag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance_name",
                                                    "as_xx",
                                                    "as_yy",
                                                    "bgp_preserve_default_info",
                                                    "bgp_preserve_med",
                                                    "classful",
                                                    "default_redistributed_route_metric",
                                                    "eigrp_route_type",
                                                    "isis_levels",
                                                    "metric_type",
                                                    "ospf_external",
                                                    "ospf_internal",
                                                    "ospf_nssa_level",
                                                    "ospf_redist_lsa_type",
                                                    "ospfnssa_only",
                                                    "route_policy_name",
                                                    "tag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.instance_name.is_set or
                                        self.as_xx.is_set or
                                        self.as_yy.is_set or
                                        self.bgp_preserve_default_info.is_set or
                                        self.bgp_preserve_med.is_set or
                                        self.classful.is_set or
                                        self.default_redistributed_route_metric.is_set or
                                        self.eigrp_route_type.is_set or
                                        self.isis_levels.is_set or
                                        self.metric_type.is_set or
                                        self.ospf_external.is_set or
                                        self.ospf_internal.is_set or
                                        self.ospf_nssa_level.is_set or
                                        self.ospf_redist_lsa_type.is_set or
                                        self.ospfnssa_only.is_set or
                                        self.route_policy_name.is_set or
                                        self.tag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance_name.yfilter != YFilter.not_set or
                                        self.as_xx.yfilter != YFilter.not_set or
                                        self.as_yy.yfilter != YFilter.not_set or
                                        self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                        self.bgp_preserve_med.yfilter != YFilter.not_set or
                                        self.classful.yfilter != YFilter.not_set or
                                        self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                        self.eigrp_route_type.yfilter != YFilter.not_set or
                                        self.isis_levels.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.ospf_external.yfilter != YFilter.not_set or
                                        self.ospf_internal.yfilter != YFilter.not_set or
                                        self.ospf_nssa_level.yfilter != YFilter.not_set or
                                        self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                        self.ospfnssa_only.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set or
                                        self.tag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bgp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_name.get_name_leafdata())
                                    if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_xx.get_name_leafdata())
                                    if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_yy.get_name_leafdata())
                                    if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                    if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                    if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classful.get_name_leafdata())
                                    if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                    if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                    if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                    if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                    if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                    if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                    if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance-name" or name == "as-xx" or name == "as-yy" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance-name"):
                                        self.instance_name = value
                                        self.instance_name.value_namespace = name_space
                                        self.instance_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-xx"):
                                        self.as_xx = value
                                        self.as_xx.value_namespace = name_space
                                        self.as_xx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-yy"):
                                        self.as_yy = value
                                        self.as_yy.value_namespace = name_space
                                        self.as_yy.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-default-info"):
                                        self.bgp_preserve_default_info = value
                                        self.bgp_preserve_default_info.value_namespace = name_space
                                        self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-med"):
                                        self.bgp_preserve_med = value
                                        self.bgp_preserve_med.value_namespace = name_space
                                        self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                    if(value_path == "classful"):
                                        self.classful = value
                                        self.classful.value_namespace = name_space
                                        self.classful.value_namespace_prefix = name_space_prefix
                                    if(value_path == "default-redistributed-route-metric"):
                                        self.default_redistributed_route_metric = value
                                        self.default_redistributed_route_metric.value_namespace = name_space
                                        self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-route-type"):
                                        self.eigrp_route_type = value
                                        self.eigrp_route_type.value_namespace = name_space
                                        self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-levels"):
                                        self.isis_levels = value
                                        self.isis_levels.value_namespace = name_space
                                        self.isis_levels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-external"):
                                        self.ospf_external = value
                                        self.ospf_external.value_namespace = name_space
                                        self.ospf_external.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-internal"):
                                        self.ospf_internal = value
                                        self.ospf_internal.value_namespace = name_space
                                        self.ospf_internal.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-nssa-level"):
                                        self.ospf_nssa_level = value
                                        self.ospf_nssa_level.value_namespace = name_space
                                        self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-redist-lsa-type"):
                                        self.ospf_redist_lsa_type = value
                                        self.ospf_redist_lsa_type.value_namespace = name_space
                                        self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospfnssa-only"):
                                        self.ospfnssa_only = value
                                        self.ospfnssa_only.value_namespace = name_space
                                        self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag"):
                                        self.tag = value
                                        self.tag.value_namespace = name_space
                                        self.tag.value_namespace_prefix = name_space_prefix


                            class Eigrp(Entity):
                                """
                                eigrp
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: as_xx  <key>
                                
                                	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.int32, "tag")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("instance_name",
                                                    "as_xx",
                                                    "bgp_preserve_default_info",
                                                    "bgp_preserve_med",
                                                    "classful",
                                                    "default_redistributed_route_metric",
                                                    "eigrp_route_type",
                                                    "isis_levels",
                                                    "metric_type",
                                                    "ospf_external",
                                                    "ospf_internal",
                                                    "ospf_nssa_level",
                                                    "ospf_redist_lsa_type",
                                                    "ospfnssa_only",
                                                    "route_policy_name",
                                                    "tag") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.instance_name.is_set or
                                        self.as_xx.is_set or
                                        self.bgp_preserve_default_info.is_set or
                                        self.bgp_preserve_med.is_set or
                                        self.classful.is_set or
                                        self.default_redistributed_route_metric.is_set or
                                        self.eigrp_route_type.is_set or
                                        self.isis_levels.is_set or
                                        self.metric_type.is_set or
                                        self.ospf_external.is_set or
                                        self.ospf_internal.is_set or
                                        self.ospf_nssa_level.is_set or
                                        self.ospf_redist_lsa_type.is_set or
                                        self.ospfnssa_only.is_set or
                                        self.route_policy_name.is_set or
                                        self.tag.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.instance_name.yfilter != YFilter.not_set or
                                        self.as_xx.yfilter != YFilter.not_set or
                                        self.bgp_preserve_default_info.yfilter != YFilter.not_set or
                                        self.bgp_preserve_med.yfilter != YFilter.not_set or
                                        self.classful.yfilter != YFilter.not_set or
                                        self.default_redistributed_route_metric.yfilter != YFilter.not_set or
                                        self.eigrp_route_type.yfilter != YFilter.not_set or
                                        self.isis_levels.yfilter != YFilter.not_set or
                                        self.metric_type.yfilter != YFilter.not_set or
                                        self.ospf_external.yfilter != YFilter.not_set or
                                        self.ospf_internal.yfilter != YFilter.not_set or
                                        self.ospf_nssa_level.yfilter != YFilter.not_set or
                                        self.ospf_redist_lsa_type.yfilter != YFilter.not_set or
                                        self.ospfnssa_only.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set or
                                        self.tag.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "eigrp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.instance_name.get_name_leafdata())
                                    if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.as_xx.get_name_leafdata())
                                    if (self.bgp_preserve_default_info.is_set or self.bgp_preserve_default_info.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_default_info.get_name_leafdata())
                                    if (self.bgp_preserve_med.is_set or self.bgp_preserve_med.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_preserve_med.get_name_leafdata())
                                    if (self.classful.is_set or self.classful.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.classful.get_name_leafdata())
                                    if (self.default_redistributed_route_metric.is_set or self.default_redistributed_route_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.default_redistributed_route_metric.get_name_leafdata())
                                    if (self.eigrp_route_type.is_set or self.eigrp_route_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_route_type.get_name_leafdata())
                                    if (self.isis_levels.is_set or self.isis_levels.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_levels.get_name_leafdata())
                                    if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric_type.get_name_leafdata())
                                    if (self.ospf_external.is_set or self.ospf_external.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_external.get_name_leafdata())
                                    if (self.ospf_internal.is_set or self.ospf_internal.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_internal.get_name_leafdata())
                                    if (self.ospf_nssa_level.is_set or self.ospf_nssa_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_nssa_level.get_name_leafdata())
                                    if (self.ospf_redist_lsa_type.is_set or self.ospf_redist_lsa_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_redist_lsa_type.get_name_leafdata())
                                    if (self.ospfnssa_only.is_set or self.ospfnssa_only.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospfnssa_only.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())
                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tag.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "instance-name" or name == "as-xx" or name == "bgp-preserve-default-info" or name == "bgp-preserve-med" or name == "classful" or name == "default-redistributed-route-metric" or name == "eigrp-route-type" or name == "isis-levels" or name == "metric-type" or name == "ospf-external" or name == "ospf-internal" or name == "ospf-nssa-level" or name == "ospf-redist-lsa-type" or name == "ospfnssa-only" or name == "route-policy-name" or name == "tag"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "instance-name"):
                                        self.instance_name = value
                                        self.instance_name.value_namespace = name_space
                                        self.instance_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "as-xx"):
                                        self.as_xx = value
                                        self.as_xx.value_namespace = name_space
                                        self.as_xx.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-default-info"):
                                        self.bgp_preserve_default_info = value
                                        self.bgp_preserve_default_info.value_namespace = name_space
                                        self.bgp_preserve_default_info.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-preserve-med"):
                                        self.bgp_preserve_med = value
                                        self.bgp_preserve_med.value_namespace = name_space
                                        self.bgp_preserve_med.value_namespace_prefix = name_space_prefix
                                    if(value_path == "classful"):
                                        self.classful = value
                                        self.classful.value_namespace = name_space
                                        self.classful.value_namespace_prefix = name_space_prefix
                                    if(value_path == "default-redistributed-route-metric"):
                                        self.default_redistributed_route_metric = value
                                        self.default_redistributed_route_metric.value_namespace = name_space
                                        self.default_redistributed_route_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-route-type"):
                                        self.eigrp_route_type = value
                                        self.eigrp_route_type.value_namespace = name_space
                                        self.eigrp_route_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-levels"):
                                        self.isis_levels = value
                                        self.isis_levels.value_namespace = name_space
                                        self.isis_levels.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric-type"):
                                        self.metric_type = value
                                        self.metric_type.value_namespace = name_space
                                        self.metric_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-external"):
                                        self.ospf_external = value
                                        self.ospf_external.value_namespace = name_space
                                        self.ospf_external.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-internal"):
                                        self.ospf_internal = value
                                        self.ospf_internal.value_namespace = name_space
                                        self.ospf_internal.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-nssa-level"):
                                        self.ospf_nssa_level = value
                                        self.ospf_nssa_level.value_namespace = name_space
                                        self.ospf_nssa_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-redist-lsa-type"):
                                        self.ospf_redist_lsa_type = value
                                        self.ospf_redist_lsa_type.value_namespace = name_space
                                        self.ospf_redist_lsa_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospfnssa-only"):
                                        self.ospfnssa_only = value
                                        self.ospfnssa_only.value_namespace = name_space
                                        self.ospfnssa_only.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tag"):
                                        self.tag = value
                                        self.tag.value_namespace = name_space
                                        self.tag.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.application_or_isis_or_ospf:
                                    if (c.has_data()):
                                        return True
                                for c in self.bgp:
                                    if (c.has_data()):
                                        return True
                                for c in self.eigrp:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.protocol_name.is_set or
                                    (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is not None))

                            def has_operation(self):
                                for c in self.application_or_isis_or_ospf:
                                    if (c.has_operation()):
                                        return True
                                for c in self.bgp:
                                    if (c.has_operation()):
                                        return True
                                for c in self.eigrp:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.protocol_name.yfilter != YFilter.not_set or
                                    (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is not None and self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "redistribute" + "[protocol-name='" + self.protocol_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "application-or-isis-or-ospf"):
                                    for c in self.application_or_isis_or_ospf:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.application_or_isis_or_ospf.append(c)
                                    return c

                                if (child_yang_name == "bgp"):
                                    for c in self.bgp:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.bgp.append(c)
                                    return c

                                if (child_yang_name == "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"):
                                    if (self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip is None):
                                        self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip()
                                        self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip.parent = self
                                        self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                    return self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip

                                if (child_yang_name == "eigrp"):
                                    for c in self.eigrp:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.eigrp.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "application-or-isis-or-ospf" or name == "bgp" or name == "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" or name == "eigrp" or name == "protocol-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "protocol-name"):
                                    self.protocol_name = value
                                    self.protocol_name.value_namespace = name_space
                                    self.protocol_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.redistribute:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.redistribute:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redistributes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "redistribute"):
                                for c in self.redistribute:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.redistribute.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "redistribute"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (self.redistributes is not None and self.redistributes.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.redistributes is not None and self.redistributes.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "redistribution" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "redistributes"):
                            if (self.redistributes is None):
                                self.redistributes = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes()
                                self.redistributes.parent = self
                                self._children_name_map["redistributes"] = "redistributes"
                            return self.redistributes

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "redistributes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class AdjacencyStagger(Entity):
                    """
                    Staggering OSPF adjacency bring up
                    
                    .. attribute:: disable
                    
                    	Disable OSPF adjacency stagger
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: initial_nbr
                    
                    	Adjacency Stagger\: Initial number of neighbors to bring up per area
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**default value**\: 2
                    
                    .. attribute:: max_nbr
                    
                    	Adjacency Stagger\: Subsequent simultaneous number of neighbors to bring up
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**default value**\: 64
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyStagger, self).__init__()

                        self.yang_name = "adjacency-stagger"
                        self.yang_parent_name = "default-vrf"

                        self.disable = YLeaf(YType.empty, "disable")

                        self.initial_nbr = YLeaf(YType.uint32, "initial-nbr")

                        self.max_nbr = YLeaf(YType.uint32, "max-nbr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("disable",
                                        "initial_nbr",
                                        "max_nbr") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyStagger, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyStagger, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.disable.is_set or
                            self.initial_nbr.is_set or
                            self.max_nbr.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.disable.yfilter != YFilter.not_set or
                            self.initial_nbr.yfilter != YFilter.not_set or
                            self.max_nbr.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "adjacency-stagger" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable.get_name_leafdata())
                        if (self.initial_nbr.is_set or self.initial_nbr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.initial_nbr.get_name_leafdata())
                        if (self.max_nbr.is_set or self.max_nbr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_nbr.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "disable" or name == "initial-nbr" or name == "max-nbr"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "disable"):
                            self.disable = value
                            self.disable.value_namespace = name_space
                            self.disable.value_namespace_prefix = name_space_prefix
                        if(value_path == "initial-nbr"):
                            self.initial_nbr = value
                            self.initial_nbr.value_namespace = name_space
                            self.initial_nbr.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-nbr"):
                            self.max_nbr = value
                            self.max_nbr.value_namespace = name_space
                            self.max_nbr.value_namespace_prefix = name_space_prefix


                class MaxLsa(Entity):
                    """
                    Set max\-lsa configuration
                    
                    .. attribute:: max_lsa_ignore_count
                    
                    	Set count on how many times adjacencies can be suppressed
                    	**type**\:  int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: max_lsa_ignore_time
                    
                    	Set time during which all adjacencies are suppressed
                    	**type**\:  int
                    
                    	**range:** 1..35791394
                    
                    .. attribute:: max_lsa_limit
                    
                    	Set maximum number of non self\-generated LSAs
                    	**type**\:  int
                    
                    	**range:** 1..4294967294
                    
                    	**mandatory**\: True
                    
                    .. attribute:: max_lsa_reset_time
                    
                    	Set number of minutes after which ignore\-count is reset to zero
                    	**type**\:  int
                    
                    	**range:** 2..71582788
                    
                    	**units**\: minute
                    
                    .. attribute:: max_lsa_threshold
                    
                    	Set max\-lsa threshold for generating a warning message
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    .. attribute:: max_lsa_warning_only
                    
                    	Only give warning message when limit is exceeded
                    	**type**\:  bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaxLsa, self).__init__()

                        self.yang_name = "max-lsa"
                        self.yang_parent_name = "default-vrf"
                        self.is_presence_container = True

                        self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                        self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                        self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                        self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                        self.max_lsa_threshold = YLeaf(YType.uint32, "max-lsa-threshold")

                        self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("max_lsa_ignore_count",
                                        "max_lsa_ignore_time",
                                        "max_lsa_limit",
                                        "max_lsa_reset_time",
                                        "max_lsa_threshold",
                                        "max_lsa_warning_only") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.MaxLsa, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.MaxLsa, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.max_lsa_ignore_count.is_set or
                            self.max_lsa_ignore_time.is_set or
                            self.max_lsa_limit.is_set or
                            self.max_lsa_reset_time.is_set or
                            self.max_lsa_threshold.is_set or
                            self.max_lsa_warning_only.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.max_lsa_ignore_count.yfilter != YFilter.not_set or
                            self.max_lsa_ignore_time.yfilter != YFilter.not_set or
                            self.max_lsa_limit.yfilter != YFilter.not_set or
                            self.max_lsa_reset_time.yfilter != YFilter.not_set or
                            self.max_lsa_threshold.yfilter != YFilter.not_set or
                            self.max_lsa_warning_only.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "max-lsa" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.max_lsa_ignore_count.is_set or self.max_lsa_ignore_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_ignore_count.get_name_leafdata())
                        if (self.max_lsa_ignore_time.is_set or self.max_lsa_ignore_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_ignore_time.get_name_leafdata())
                        if (self.max_lsa_limit.is_set or self.max_lsa_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_limit.get_name_leafdata())
                        if (self.max_lsa_reset_time.is_set or self.max_lsa_reset_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_reset_time.get_name_leafdata())
                        if (self.max_lsa_threshold.is_set or self.max_lsa_threshold.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_threshold.get_name_leafdata())
                        if (self.max_lsa_warning_only.is_set or self.max_lsa_warning_only.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_lsa_warning_only.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "max-lsa-ignore-count" or name == "max-lsa-ignore-time" or name == "max-lsa-limit" or name == "max-lsa-reset-time" or name == "max-lsa-threshold" or name == "max-lsa-warning-only"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "max-lsa-ignore-count"):
                            self.max_lsa_ignore_count = value
                            self.max_lsa_ignore_count.value_namespace = name_space
                            self.max_lsa_ignore_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-lsa-ignore-time"):
                            self.max_lsa_ignore_time = value
                            self.max_lsa_ignore_time.value_namespace = name_space
                            self.max_lsa_ignore_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-lsa-limit"):
                            self.max_lsa_limit = value
                            self.max_lsa_limit.value_namespace = name_space
                            self.max_lsa_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-lsa-reset-time"):
                            self.max_lsa_reset_time = value
                            self.max_lsa_reset_time.value_namespace = name_space
                            self.max_lsa_reset_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-lsa-threshold"):
                            self.max_lsa_threshold = value
                            self.max_lsa_threshold.value_namespace = name_space
                            self.max_lsa_threshold.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-lsa-warning-only"):
                            self.max_lsa_warning_only = value
                            self.max_lsa_warning_only.value_namespace = name_space
                            self.max_lsa_warning_only.value_namespace_prefix = name_space_prefix


                class AutoCost(Entity):
                    """
                    Controls automatic cost based on bandwidth
                    
                    .. attribute:: bandwidth
                    
                    	The reference bandwidth in terms of Mbits per second
                    	**type**\:  int
                    
                    	**range:** 1..4294967
                    
                    	**units**\: Mbit/s
                    
                    	**default value**\: 100
                    
                    .. attribute:: disable
                    
                    	Disabling auto costing
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AutoCost, self).__init__()

                        self.yang_name = "auto-cost"
                        self.yang_parent_name = "default-vrf"

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.disable = YLeaf(YType.boolean, "disable")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("bandwidth",
                                        "disable") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.AutoCost, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.AutoCost, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.bandwidth.is_set or
                            self.disable.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.bandwidth.yfilter != YFilter.not_set or
                            self.disable.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "auto-cost" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.bandwidth.is_set or self.bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bandwidth.get_name_leafdata())
                        if (self.disable.is_set or self.disable.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disable.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "bandwidth" or name == "disable"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "bandwidth"):
                            self.bandwidth = value
                            self.bandwidth.value_namespace = name_space
                            self.bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "disable"):
                            self.disable = value
                            self.disable.value_namespace = name_space
                            self.disable.value_namespace_prefix = name_space_prefix


                class Ucmp(Entity):
                    """
                    Unequal Cost Multi\-ptah configuration
                    
                    .. attribute:: delay_interval
                    
                    	Delay in msecs between primary SPF and UCMP computation
                    	**type**\:  int
                    
                    	**range:** 1..5000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 100
                    
                    .. attribute:: enable
                    
                    	UCMP feature enable configuration
                    	**type**\:   :py:class:`Enable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.Enable>`
                    
                    .. attribute:: exclude_interfaces
                    
                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Ucmp, self).__init__()

                        self.yang_name = "ucmp"
                        self.yang_parent_name = "default-vrf"

                        self.delay_interval = YLeaf(YType.uint32, "delay-interval")

                        self.enable = Ospf.Processes.Process.DefaultVrf.Ucmp.Enable()
                        self.enable.parent = self
                        self._children_name_map["enable"] = "enable"
                        self._children_yang_names.add("enable")

                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces()
                        self.exclude_interfaces.parent = self
                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                        self._children_yang_names.add("exclude-interfaces")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("delay_interval") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Ucmp, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Ucmp, self).__setattr__(name, value)


                    class Enable(Entity):
                        """
                        UCMP feature enable configuration
                        
                        .. attribute:: prefix_list_name
                        
                        	Name of the Prefix List
                        	**type**\:  str
                        
                        .. attribute:: variance
                        
                        	Value of variance
                        	**type**\:  int
                        
                        	**range:** 101..10000
                        
                        	**default value**\: 200
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Ucmp.Enable, self).__init__()

                            self.yang_name = "enable"
                            self.yang_parent_name = "ucmp"

                            self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                            self.variance = YLeaf(YType.uint32, "variance")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix_list_name",
                                            "variance") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Ucmp.Enable, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Ucmp.Enable, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix_list_name.is_set or
                                self.variance.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix_list_name.yfilter != YFilter.not_set or
                                self.variance.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "enable" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix_list_name.is_set or self.prefix_list_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_list_name.get_name_leafdata())
                            if (self.variance.is_set or self.variance.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.variance.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix-list-name" or name == "variance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix-list-name"):
                                self.prefix_list_name = value
                                self.prefix_list_name.value_namespace = name_space
                                self.prefix_list_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "variance"):
                                self.variance = value
                                self.variance.value_namespace = name_space
                                self.variance.value_namespace_prefix = name_space_prefix


                    class ExcludeInterfaces(Entity):
                        """
                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                        interface configuration
                        
                        .. attribute:: exclude_interface
                        
                        	Exclude an interface from becoming a backup or UCMP
                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces, self).__init__()

                            self.yang_name = "exclude-interfaces"
                            self.yang_parent_name = "ucmp"

                            self.exclude_interface = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces, self).__setattr__(name, value)


                        class ExcludeInterface(Entity):
                            """
                            Exclude an interface from becoming a backup or
                            UCMP
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                self.yang_name = "exclude-interface"
                                self.yang_parent_name = "exclude-interfaces"

                                self.interface_name = YLeaf(YType.str, "interface-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                            def has_data(self):
                                return self.interface_name.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "interface-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.exclude_interface:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.exclude_interface:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "exclude-interfaces" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "exclude-interface"):
                                for c in self.exclude_interface:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.exclude_interface.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "exclude-interface"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.delay_interval.is_set or
                            (self.enable is not None and self.enable.has_data()) or
                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.delay_interval.yfilter != YFilter.not_set or
                            (self.enable is not None and self.enable.has_operation()) or
                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ucmp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.delay_interval.is_set or self.delay_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.delay_interval.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "enable"):
                            if (self.enable is None):
                                self.enable = Ospf.Processes.Process.DefaultVrf.Ucmp.Enable()
                                self.enable.parent = self
                                self._children_name_map["enable"] = "enable"
                            return self.enable

                        if (child_yang_name == "exclude-interfaces"):
                            if (self.exclude_interfaces is None):
                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                            return self.exclude_interfaces

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "enable" or name == "exclude-interfaces" or name == "delay-interval"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "delay-interval"):
                            self.delay_interval = value
                            self.delay_interval.value_namespace = name_space
                            self.delay_interval.value_namespace_prefix = name_space_prefix


                class FastReroute(Entity):
                    """
                    Fast\-reroute instance scoped parameters
                    
                    .. attribute:: per_link
                    
                    	Fast\-reroute per\-link global configuration
                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink>`
                    
                    .. attribute:: per_prefix
                    
                    	Fast\-reroute per\-prefix global configuration
                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FastReroute, self).__init__()

                        self.yang_name = "fast-reroute"
                        self.yang_parent_name = "default-vrf"

                        self.per_link = Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink()
                        self.per_link.parent = self
                        self._children_name_map["per_link"] = "per-link"
                        self._children_yang_names.add("per-link")

                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix()
                        self.per_prefix.parent = self
                        self._children_name_map["per_prefix"] = "per-prefix"
                        self._children_yang_names.add("per-prefix")


                    class PerLink(Entity):
                        """
                        Fast\-reroute per\-link global configuration
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink, self).__init__()

                            self.yang_name = "per-link"
                            self.yang_parent_name = "fast-reroute"

                            self.priority = YLeaf(YType.enumeration, "priority")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink, self).__setattr__(name, value)

                        def has_data(self):
                            return self.priority.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "per-link" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix


                    class PerPrefix(Entity):
                        """
                        Fast\-reroute per\-prefix global configuration
                        
                        .. attribute:: load_sharing_disable
                        
                        	Disable load sharing between multiple backups
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                        
                        .. attribute:: tiebreakers
                        
                        	Fast\-reroute tiebreakers configurations
                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix, self).__init__()

                            self.yang_name = "per-prefix"
                            self.yang_parent_name = "fast-reroute"

                            self.load_sharing_disable = YLeaf(YType.empty, "load-sharing-disable")

                            self.priority = YLeaf(YType.enumeration, "priority")

                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers()
                            self.tiebreakers.parent = self
                            self._children_name_map["tiebreakers"] = "tiebreakers"
                            self._children_yang_names.add("tiebreakers")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("load_sharing_disable",
                                            "priority") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix, self).__setattr__(name, value)


                        class Tiebreakers(Entity):
                            """
                            Fast\-reroute tiebreakers configurations
                            
                            .. attribute:: tiebreaker
                            
                            	Fast\-reroute tiebreakers configuration
                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                self.yang_name = "tiebreakers"
                                self.yang_parent_name = "per-prefix"

                                self.tiebreaker = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                            class Tiebreaker(Entity):
                                """
                                Fast\-reroute tiebreakers configuration
                                
                                .. attribute:: tiebreaker_type  <key>
                                
                                	Tiebreaker type
                                	**type**\:   :py:class:`OspfFastRerouteTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakers>`
                                
                                .. attribute:: tiebreaker_index
                                
                                	Index value for a tiebreaker, 0 to disable
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                    self.yang_name = "tiebreaker"
                                    self.yang_parent_name = "tiebreakers"

                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("tiebreaker_type",
                                                    "tiebreaker_index") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.tiebreaker_type.is_set or
                                        self.tiebreaker_index.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "tiebreaker-type"):
                                        self.tiebreaker_type = value
                                        self.tiebreaker_type.value_namespace = name_space
                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "tiebreaker-index"):
                                        self.tiebreaker_index = value
                                        self.tiebreaker_index.value_namespace = name_space
                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.tiebreaker:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.tiebreaker:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "tiebreakers" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "tiebreaker"):
                                    for c in self.tiebreaker:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.tiebreaker.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "tiebreaker"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                self.load_sharing_disable.is_set or
                                self.priority.is_set or
                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.load_sharing_disable.yfilter != YFilter.not_set or
                                self.priority.yfilter != YFilter.not_set or
                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "per-prefix" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.load_sharing_disable.is_set or self.load_sharing_disable.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.load_sharing_disable.get_name_leafdata())
                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.priority.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "tiebreakers"):
                                if (self.tiebreakers is None):
                                    self.tiebreakers = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers()
                                    self.tiebreakers.parent = self
                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                return self.tiebreakers

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "tiebreakers" or name == "load-sharing-disable" or name == "priority"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "load-sharing-disable"):
                                self.load_sharing_disable = value
                                self.load_sharing_disable.value_namespace = name_space
                                self.load_sharing_disable.value_namespace_prefix = name_space_prefix
                            if(value_path == "priority"):
                                self.priority = value
                                self.priority.value_namespace = name_space
                                self.priority.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.per_link is not None and self.per_link.has_data()) or
                            (self.per_prefix is not None and self.per_prefix.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.per_link is not None and self.per_link.has_operation()) or
                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "fast-reroute" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "per-link"):
                            if (self.per_link is None):
                                self.per_link = Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink()
                                self.per_link.parent = self
                                self._children_name_map["per_link"] = "per-link"
                            return self.per_link

                        if (child_yang_name == "per-prefix"):
                            if (self.per_prefix is None):
                                self.per_prefix = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix()
                                self.per_prefix.parent = self
                                self._children_name_map["per_prefix"] = "per-prefix"
                            return self.per_prefix

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "per-link" or name == "per-prefix"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SummaryPrefixes(Entity):
                    """
                    Configure IP prefix summary
                    
                    .. attribute:: netmask
                    
                    	keys\: netmask
                    	**type**\: list of    :py:class:`Netmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask>`
                    
                    .. attribute:: prefix
                    
                    	keys\: prefix
                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix>`
                    
                    .. attribute:: prefix_and_netmask
                    
                    	keys\: prefix, netmask
                    	**type**\: list of    :py:class:`PrefixAndNetmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask>`
                    
                    .. attribute:: summary_prefix_data
                    
                    	Data container
                    	**type**\:   :py:class:`SummaryPrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"

                        self.summary_prefix_data = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData()
                        self.summary_prefix_data.parent = self
                        self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                        self._children_yang_names.add("summary-prefix-data")

                        self.netmask = YList(self)
                        self.prefix = YList(self)
                        self.prefix_and_netmask = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__setattr__(name, value)


                    class SummaryPrefixData(Entity):
                        """
                        Data container.
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData, self).__init__()

                            self.yang_name = "summary-prefix-data"
                            self.yang_parent_name = "summary-prefixes"

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.int32, "tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("not_advertise",
                                            "tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.not_advertise.is_set or
                                self.tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.not_advertise.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "summary-prefix-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_advertise.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "not-advertise" or name == "tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "not-advertise"):
                                self.not_advertise = value
                                self.not_advertise.value_namespace = name_space
                                self.not_advertise.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix


                    class PrefixAndNetmask(Entity):
                        """
                        keys\: prefix, netmask
                        
                        .. attribute:: prefix  <key>
                        
                        	IP summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: netmask  <key>
                        
                        	Summary netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask, self).__init__()

                            self.yang_name = "prefix-and-netmask"
                            self.yang_parent_name = "summary-prefixes"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.int32, "tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "netmask",
                                            "not_advertise",
                                            "tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.netmask.is_set or
                                self.not_advertise.is_set or
                                self.tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.netmask.yfilter != YFilter.not_set or
                                self.not_advertise.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix-and-netmask" + "[prefix='" + self.prefix.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.netmask.get_name_leafdata())
                            if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_advertise.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "netmask" or name == "not-advertise" or name == "tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "netmask"):
                                self.netmask = value
                                self.netmask.value_namespace = name_space
                                self.netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-advertise"):
                                self.not_advertise = value
                                self.not_advertise.value_namespace = name_space
                                self.not_advertise.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix


                    class Prefix(Entity):
                        """
                        keys\: prefix
                        
                        .. attribute:: prefix  <key>
                        
                        	IP summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "summary-prefixes"

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.int32, "tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("prefix",
                                            "not_advertise",
                                            "tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.prefix.is_set or
                                self.not_advertise.is_set or
                                self.tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.prefix.yfilter != YFilter.not_set or
                                self.not_advertise.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "prefix" + "[prefix='" + self.prefix.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix.get_name_leafdata())
                            if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_advertise.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "prefix" or name == "not-advertise" or name == "tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "prefix"):
                                self.prefix = value
                                self.prefix.value_namespace = name_space
                                self.prefix.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-advertise"):
                                self.not_advertise = value
                                self.not_advertise.value_namespace = name_space
                                self.not_advertise.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix


                    class Netmask(Entity):
                        """
                        keys\: netmask
                        
                        .. attribute:: netmask  <key>
                        
                        	Summary netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask, self).__init__()

                            self.yang_name = "netmask"
                            self.yang_parent_name = "summary-prefixes"

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.int32, "tag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("netmask",
                                            "not_advertise",
                                            "tag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.netmask.is_set or
                                self.not_advertise.is_set or
                                self.tag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.netmask.yfilter != YFilter.not_set or
                                self.not_advertise.yfilter != YFilter.not_set or
                                self.tag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "netmask" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.netmask.get_name_leafdata())
                            if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.not_advertise.get_name_leafdata())
                            if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "netmask" or name == "not-advertise" or name == "tag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "netmask"):
                                self.netmask = value
                                self.netmask.value_namespace = name_space
                                self.netmask.value_namespace_prefix = name_space_prefix
                            if(value_path == "not-advertise"):
                                self.not_advertise = value
                                self.not_advertise.value_namespace = name_space
                                self.not_advertise.value_namespace_prefix = name_space_prefix
                            if(value_path == "tag"):
                                self.tag = value
                                self.tag.value_namespace = name_space
                                self.tag.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.netmask:
                            if (c.has_data()):
                                return True
                        for c in self.prefix:
                            if (c.has_data()):
                                return True
                        for c in self.prefix_and_netmask:
                            if (c.has_data()):
                                return True
                        return (self.summary_prefix_data is not None and self.summary_prefix_data.has_data())

                    def has_operation(self):
                        for c in self.netmask:
                            if (c.has_operation()):
                                return True
                        for c in self.prefix:
                            if (c.has_operation()):
                                return True
                        for c in self.prefix_and_netmask:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.summary_prefix_data is not None and self.summary_prefix_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary-prefixes" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "netmask"):
                            for c in self.netmask:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.netmask.append(c)
                            return c

                        if (child_yang_name == "prefix"):
                            for c in self.prefix:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.prefix.append(c)
                            return c

                        if (child_yang_name == "prefix-and-netmask"):
                            for c in self.prefix_and_netmask:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.prefix_and_netmask.append(c)
                            return c

                        if (child_yang_name == "summary-prefix-data"):
                            if (self.summary_prefix_data is None):
                                self.summary_prefix_data = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData()
                                self.summary_prefix_data.parent = self
                                self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                            return self.summary_prefix_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "netmask" or name == "prefix" or name == "prefix-and-netmask" or name == "summary-prefix-data"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class OutgoingRouteUpdates(Entity):
                    """
                    Filter outgoing routing updates
                    
                    .. attribute:: outgoing_route_update
                    
                    	Filter outgoing routing updates for a particular protocol
                    	**type**\: list of    :py:class:`OutgoingRouteUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates, self).__init__()

                        self.yang_name = "outgoing-route-updates"
                        self.yang_parent_name = "default-vrf"

                        self.outgoing_route_update = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates, self).__setattr__(name, value)


                    class OutgoingRouteUpdate(Entity):
                        """
                        Filter outgoing routing updates for a
                        particular protocol
                        
                        .. attribute:: protocol_name  <key>
                        
                        	Distribute list protocol type
                        	**type**\:   :py:class:`OspfDistListProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDistListProtocol>`
                        
                        .. attribute:: access_list_name
                        
                        	Access Control List name
                        	**type**\:  str
                        
                        .. attribute:: as_xx
                        
                        	First half of BGP AS number in XX.YY format.  Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_yy
                        
                        	Second half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ospf_process_name
                        
                        	OSPF process name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__init__()

                            self.yang_name = "outgoing-route-update"
                            self.yang_parent_name = "outgoing-route-updates"

                            self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                            self.as_xx = YLeaf(YType.uint32, "as-xx")

                            self.as_yy = YLeaf(YType.uint32, "as-yy")

                            self.ospf_process_name = YLeaf(YType.str, "ospf-process-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("protocol_name",
                                            "access_list_name",
                                            "as_xx",
                                            "as_yy",
                                            "ospf_process_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.protocol_name.is_set or
                                self.access_list_name.is_set or
                                self.as_xx.is_set or
                                self.as_yy.is_set or
                                self.ospf_process_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.protocol_name.yfilter != YFilter.not_set or
                                self.access_list_name.yfilter != YFilter.not_set or
                                self.as_xx.yfilter != YFilter.not_set or
                                self.as_yy.yfilter != YFilter.not_set or
                                self.ospf_process_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "outgoing-route-update" + "[protocol-name='" + self.protocol_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.protocol_name.is_set or self.protocol_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol_name.get_name_leafdata())
                            if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.access_list_name.get_name_leafdata())
                            if (self.as_xx.is_set or self.as_xx.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_xx.get_name_leafdata())
                            if (self.as_yy.is_set or self.as_yy.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.as_yy.get_name_leafdata())
                            if (self.ospf_process_name.is_set or self.ospf_process_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ospf_process_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "protocol-name" or name == "access-list-name" or name == "as-xx" or name == "as-yy" or name == "ospf-process-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "protocol-name"):
                                self.protocol_name = value
                                self.protocol_name.value_namespace = name_space
                                self.protocol_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "access-list-name"):
                                self.access_list_name = value
                                self.access_list_name.value_namespace = name_space
                                self.access_list_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-xx"):
                                self.as_xx = value
                                self.as_xx.value_namespace = name_space
                                self.as_xx.value_namespace_prefix = name_space_prefix
                            if(value_path == "as-yy"):
                                self.as_yy = value
                                self.as_yy.value_namespace = name_space
                                self.as_yy.value_namespace_prefix = name_space_prefix
                            if(value_path == "ospf-process-name"):
                                self.ospf_process_name = value
                                self.ospf_process_name.value_namespace = name_space
                                self.ospf_process_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.outgoing_route_update:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.outgoing_route_update:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "outgoing-route-updates" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "outgoing-route-update"):
                            for c in self.outgoing_route_update:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.outgoing_route_update.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "outgoing-route-update"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Distance(Entity):
                    """
                    Administrative distance configuration
                    
                    .. attribute:: admin_distance
                    
                    	Define an administrative distance
                    	**type**\:  int
                    
                    	**range:** 1..255
                    
                    	**default value**\: 110
                    
                    .. attribute:: ip_distances
                    
                    	IP specific administrative distance configuration
                    	**type**\:   :py:class:`IpDistances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.IpDistances>`
                    
                    .. attribute:: ospf_distance
                    
                    	OSPF distance configuration
                    	**type**\:   :py:class:`OspfDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "default-vrf"

                        self.admin_distance = YLeaf(YType.uint32, "admin-distance")

                        self.ip_distances = Ospf.Processes.Process.DefaultVrf.Distance.IpDistances()
                        self.ip_distances.parent = self
                        self._children_name_map["ip_distances"] = "ip-distances"
                        self._children_yang_names.add("ip-distances")

                        self.ospf_distance = Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance()
                        self.ospf_distance.parent = self
                        self._children_name_map["ospf_distance"] = "ospf-distance"
                        self._children_yang_names.add("ospf-distance")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("admin_distance") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Distance, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Distance, self).__setattr__(name, value)


                    class OspfDistance(Entity):
                        """
                        OSPF distance configuration
                        
                        .. attribute:: external_routes
                        
                        	Distance for external type 5 and type 7 routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: inter_area
                        
                        	Distance for inter\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: intra_area
                        
                        	Distance for intra\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance, self).__init__()

                            self.yang_name = "ospf-distance"
                            self.yang_parent_name = "distance"

                            self.external_routes = YLeaf(YType.uint32, "external-routes")

                            self.inter_area = YLeaf(YType.uint32, "inter-area")

                            self.intra_area = YLeaf(YType.uint32, "intra-area")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("external_routes",
                                            "inter_area",
                                            "intra_area") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.external_routes.is_set or
                                self.inter_area.is_set or
                                self.intra_area.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.external_routes.yfilter != YFilter.not_set or
                                self.inter_area.yfilter != YFilter.not_set or
                                self.intra_area.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ospf-distance" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.external_routes.is_set or self.external_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_routes.get_name_leafdata())
                            if (self.inter_area.is_set or self.inter_area.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.inter_area.get_name_leafdata())
                            if (self.intra_area.is_set or self.intra_area.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.intra_area.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "external-routes" or name == "inter-area" or name == "intra-area"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "external-routes"):
                                self.external_routes = value
                                self.external_routes.value_namespace = name_space
                                self.external_routes.value_namespace_prefix = name_space_prefix
                            if(value_path == "inter-area"):
                                self.inter_area = value
                                self.inter_area.value_namespace = name_space
                                self.inter_area.value_namespace_prefix = name_space_prefix
                            if(value_path == "intra-area"):
                                self.intra_area = value
                                self.intra_area.value_namespace = name_space
                                self.intra_area.value_namespace_prefix = name_space_prefix


                    class IpDistances(Entity):
                        """
                        IP specific administrative distance
                        configuration
                        
                        .. attribute:: ip_distance
                        
                        	Administrative distance configuration for a particular IP address
                        	**type**\: list of    :py:class:`IpDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances, self).__init__()

                            self.yang_name = "ip-distances"
                            self.yang_parent_name = "distance"

                            self.ip_distance = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances, self).__setattr__(name, value)


                        class IpDistance(Entity):
                            """
                            Administrative distance configuration for a
                            particular IP address
                            
                            .. attribute:: address  <key>
                            
                            	IP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: wildcard  <key>
                            
                            	IP wild card bits \-\- inverted mask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance, self).__init__()

                                self.yang_name = "ip-distance"
                                self.yang_parent_name = "ip-distances"

                                self.address = YLeaf(YType.str, "address")

                                self.wildcard = YLeaf(YType.str, "wildcard")

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.distance = YLeaf(YType.uint32, "distance")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("address",
                                                "wildcard",
                                                "access_list_name",
                                                "distance") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.address.is_set or
                                    self.wildcard.is_set or
                                    self.access_list_name.is_set or
                                    self.distance.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.address.yfilter != YFilter.not_set or
                                    self.wildcard.yfilter != YFilter.not_set or
                                    self.access_list_name.yfilter != YFilter.not_set or
                                    self.distance.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ip-distance" + "[address='" + self.address.get() + "']" + "[wildcard='" + self.wildcard.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.address.get_name_leafdata())
                                if (self.wildcard.is_set or self.wildcard.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.wildcard.get_name_leafdata())
                                if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                if (self.distance.is_set or self.distance.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.distance.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "wildcard" or name == "access-list-name" or name == "distance"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "address"):
                                    self.address = value
                                    self.address.value_namespace = name_space
                                    self.address.value_namespace_prefix = name_space_prefix
                                if(value_path == "wildcard"):
                                    self.wildcard = value
                                    self.wildcard.value_namespace = name_space
                                    self.wildcard.value_namespace_prefix = name_space_prefix
                                if(value_path == "access-list-name"):
                                    self.access_list_name = value
                                    self.access_list_name.value_namespace = name_space
                                    self.access_list_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "distance"):
                                    self.distance = value
                                    self.distance.value_namespace = name_space
                                    self.distance.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ip_distance:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ip_distance:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ip-distances" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ip-distance"):
                                for c in self.ip_distance:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ip_distance.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ip-distance"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.admin_distance.is_set or
                            (self.ip_distances is not None and self.ip_distances.has_data()) or
                            (self.ospf_distance is not None and self.ospf_distance.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.admin_distance.yfilter != YFilter.not_set or
                            (self.ip_distances is not None and self.ip_distances.has_operation()) or
                            (self.ospf_distance is not None and self.ospf_distance.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "distance" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.admin_distance.is_set or self.admin_distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.admin_distance.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ip-distances"):
                            if (self.ip_distances is None):
                                self.ip_distances = Ospf.Processes.Process.DefaultVrf.Distance.IpDistances()
                                self.ip_distances.parent = self
                                self._children_name_map["ip_distances"] = "ip-distances"
                            return self.ip_distances

                        if (child_yang_name == "ospf-distance"):
                            if (self.ospf_distance is None):
                                self.ospf_distance = Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance()
                                self.ospf_distance.parent = self
                                self._children_name_map["ospf_distance"] = "ospf-distance"
                            return self.ospf_distance

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ip-distances" or name == "ospf-distance" or name == "admin-distance"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "admin-distance"):
                            self.admin_distance = value
                            self.admin_distance.value_namespace = name_space
                            self.admin_distance.value_namespace_prefix = name_space_prefix


                class AreaAddresses(Entity):
                    """
                    Area configuration
                    
                    .. attribute:: area_address
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress>`
                    
                    .. attribute:: area_area_id
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses, self).__init__()

                        self.yang_name = "area-addresses"
                        self.yang_parent_name = "default-vrf"

                        self.area_address = YList(self)
                        self.area_area_id = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses, self).__setattr__(name, value)


                    class AreaAddress(Entity):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: address  <key>
                        
                        	Area ID if in IP address format
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: area_ranges
                        
                        	Summarize routes matching address/mask (border routers only)
                        	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges>`
                        
                        .. attribute:: area_scope
                        
                        	Area scope configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope>`
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        	**default value**\: 1
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: mpls_traffic_eng
                        
                        	Configure an OSPF area to run MPLS Traffic Engineering
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_area_interface_scopes
                        
                        	Multi Area Interface scope configurations
                        	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes>`
                        
                        .. attribute:: name_scopes
                        
                        	Name scope configurations
                        	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa>`
                        
                        .. attribute:: route_policy_in
                        
                        	Configure a route policy for inbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: route_policy_out
                        
                        	Configure a route policy for outbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: running
                        
                        	Enable routing on an IP network
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: sham_link_scopes
                        
                        	Sham Link scope configurations
                        	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes>`
                        
                        .. attribute:: stub
                        
                        	Specify the area as a stub area (send summary LSA stub area)
                        	**type**\:  bool
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_scopes
                        
                        	Virtual Link scope configurations
                        	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress, self).__init__()

                            self.yang_name = "area-address"
                            self.yang_parent_name = "area-addresses"

                            self.address = YLeaf(YType.str, "address")

                            self.default_cost = YLeaf(YType.uint32, "default-cost")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                            self.running = YLeaf(YType.empty, "running")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.stub = YLeaf(YType.boolean, "stub")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges()
                            self.area_ranges.parent = self
                            self._children_name_map["area_ranges"] = "area-ranges"
                            self._children_yang_names.add("area-ranges")

                            self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope()
                            self.area_scope.parent = self
                            self._children_name_map["area_scope"] = "area-scope"
                            self._children_yang_names.add("area-scope")

                            self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                            self.multi_area_interface_scopes.parent = self
                            self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                            self._children_yang_names.add("multi-area-interface-scopes")

                            self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes()
                            self.name_scopes.parent = self
                            self._children_name_map["name_scopes"] = "name-scopes"
                            self._children_yang_names.add("name-scopes")

                            self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa()
                            self.nssa.parent = self
                            self._children_name_map["nssa"] = "nssa"
                            self._children_yang_names.add("nssa")

                            self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                            self.sham_link_scopes.parent = self
                            self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                            self._children_yang_names.add("sham-link-scopes")

                            self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                            self.virtual_link_scopes.parent = self
                            self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                            self._children_yang_names.add("virtual-link-scopes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("address",
                                            "default_cost",
                                            "external_out",
                                            "mpls_traffic_eng",
                                            "route_policy_in",
                                            "route_policy_out",
                                            "running",
                                            "segment_routing",
                                            "stub",
                                            "summary_in") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress, self).__setattr__(name, value)


                        class VirtualLinkScopes(Entity):
                            """
                            Virtual Link scope configurations
                            
                            .. attribute:: virtual_link_scope
                            
                            	Virtual Link configuration
                            	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__init__()

                                self.yang_name = "virtual-link-scopes"
                                self.yang_parent_name = "area-address"

                                self.virtual_link_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__setattr__(name, value)


                            class VirtualLinkScope(Entity):
                                """
                                Virtual Link configuration
                                
                                .. attribute:: address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                    self.yang_name = "virtual-link-scope"
                                    self.yang_parent_name = "virtual-link-scopes"

                                    self.address = YLeaf(YType.str, "address")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "hello_interval",
                                                    "retransmit_interval",
                                                    "running",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "virtual-link-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.hello_interval.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-scope" + "[address='" + self.address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "dead-interval-minimal" or name == "address" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.virtual_link_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.virtual_link_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "virtual-link-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "virtual-link-scope"):
                                    for c in self.virtual_link_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.virtual_link_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "virtual-link-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ShamLinkScopes(Entity):
                            """
                            Sham Link scope configurations
                            
                            .. attribute:: sham_link_scope
                            
                            	Sham Link configuration
                            	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__init__()

                                self.yang_name = "sham-link-scopes"
                                self.yang_parent_name = "area-address"

                                self.sham_link_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__setattr__(name, value)


                            class ShamLinkScope(Entity):
                                """
                                Sham Link configuration
                                
                                .. attribute:: source_address  <key>
                                
                                	Address of the local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_address  <key>
                                
                                	Address of the remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: source
                                
                                	Address of the local sham\-link endpoint. Enter an IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__init__()

                                    self.yang_name = "sham-link-scope"
                                    self.yang_parent_name = "sham-link-scopes"

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.destination_address = YLeaf(YType.str, "destination-address")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.source = YLeaf(YType.str, "source")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("source_address",
                                                    "destination_address",
                                                    "cost",
                                                    "hello_interval",
                                                    "retransmit_interval",
                                                    "running",
                                                    "source",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "sham-link-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "sham-link-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.source_address.is_set or
                                        self.destination_address.is_set or
                                        self.cost.is_set or
                                        self.hello_interval.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.source.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.destination_address.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.source.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "dead-interval-minimal" or name == "source-address" or name == "destination-address" or name == "cost" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "source" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "destination-address"):
                                        self.destination_address = value
                                        self.destination_address.value_namespace = name_space
                                        self.destination_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source"):
                                        self.source = value
                                        self.source.value_namespace = name_space
                                        self.source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sham_link_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sham_link_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sham-link-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sham-link-scope"):
                                    for c in self.sham_link_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sham_link_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sham-link-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AreaScope(Entity):
                            """
                            Area scope configuration
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback>`
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: dead_interval_minimal
                            
                            	Interval after which a neighbor is declared dead
                            	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal>`
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/Disable OSPF demand circuit
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/Disable OSPF flood reduction
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: hello_interval
                            
                            	Interval between HELLO packets in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ldp_auto_config
                            
                            	Enable MPLS LDP Auto Config
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: ldp_sync_igp_shortcuts
                            
                            	Enable/Disable MPLS LDP sync for igp\-shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: link_down_fast_detect
                            
                            	Enable/Disable registration for early interface down notifications
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: loopback_stub_network
                            
                            	Enable/Disable advertising loopback as a stub network
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/Disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: network_type
                            
                            	Type of attached network
                            	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                            
                            .. attribute:: packet_size
                            
                            	Customize size of OSPF packets upto MTU
                            	**type**\:  int
                            
                            	**range:** 576..10000
                            
                            .. attribute:: passive
                            
                            	When enabled, prevent sending HELLO packets over link
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_primary
                            
                            	Enable/Disable prefix suppression for primary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_secondary
                            
                            	Enable/Disable prefix suppression for secondary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: priority
                            
                            	Router priority for DR and BDR election
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 1
                            
                            .. attribute:: retransmit_interval
                            
                            	Time in seconds between retransmitting lost link state advertisements
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 5
                            
                            .. attribute:: security
                            
                            	Container class for security related configuration parameters
                            	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security>`
                            
                            .. attribute:: segment_routing_forwarding
                            
                            	segment\-routing forwarding configuration Applicableonly in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                            
                            .. attribute:: transmit_delay
                            
                            	Number of seconds to delay transmission of LSAs
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope, self).__init__()

                                self.yang_name = "area-scope"
                                self.yang_parent_name = "area-address"

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.packet_size = YLeaf(YType.uint32, "packet-size")

                                self.passive = YLeaf(YType.boolean, "passive")

                                self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")

                                self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                self.cost_fallback.parent = self
                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                self._children_yang_names.add("cost-fallback")

                                self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                self.dead_interval_minimal.parent = self
                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                self._children_yang_names.add("dead-interval-minimal")

                                self.distribute_list = None
                                self._children_name_map["distribute_list"] = "distribute-list"
                                self._children_yang_names.add("distribute-list")

                                self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                self._children_yang_names.add("fast-reroute")

                                self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                self.security.parent = self
                                self._children_name_map["security"] = "security"
                                self._children_yang_names.add("security")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cost",
                                                "database_filter",
                                                "demand_circuit",
                                                "flood_reduction",
                                                "hello_interval",
                                                "ldp_auto_config",
                                                "ldp_sync",
                                                "ldp_sync_igp_shortcuts",
                                                "link_down_fast_detect",
                                                "loopback_stub_network",
                                                "mtu_ignore",
                                                "network_type",
                                                "packet_size",
                                                "passive",
                                                "prefix_suppression_primary",
                                                "prefix_suppression_secondary",
                                                "priority",
                                                "retransmit_interval",
                                                "segment_routing_forwarding",
                                                "transmit_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope, self).__setattr__(name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks intalled to RIB (disable as ACL
                                name means filtering is disabled)
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_name
                                
                                	Route Policy name
                                	**type**\:  str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "area-scope"
                                    self.is_presence_container = True

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("access_list_name",
                                                    "route_policy_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.access_list_name.is_set or
                                        self.route_policy_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.access_list_name.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "distribute-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "access-list-name" or name == "route-policy-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "access-list-name"):
                                        self.access_list_name = value
                                        self.access_list_name.value_namespace = name_space
                                        self.access_list_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	 use of Bidirectional Forwarding Detection
                                	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "area-scope"

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                    self.interval = YLeaf(YType.uint32, "interval")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("detection_multiplier",
                                                    "fast_detect_mode",
                                                    "interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.detection_multiplier.is_set or
                                        self.fast_detect_mode.is_set or
                                        self.interval.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.detection_multiplier.yfilter != YFilter.not_set or
                                        self.fast_detect_mode.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                    if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "detection-multiplier"):
                                        self.detection_multiplier = value
                                        self.detection_multiplier.value_namespace = name_space
                                        self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-mode"):
                                        self.fast_detect_mode = value
                                        self.fast_detect_mode.value_namespace = name_space
                                        self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: key
                                
                                	Authentication key configuration
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: message_digest_keies
                                
                                	Message digest authentication password (key) configurations, first 16 chars used
                                	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies>`
                                
                                .. attribute:: type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area-scope"

                                    self.key = YLeaf(YType.str, "key")

                                    self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                    self.message_digest_keies.parent = self
                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                    self._children_yang_names.add("message-digest-keies")

                                    self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                    self.type.parent = self
                                    self._children_name_map["type"] = "type"
                                    self._children_yang_names.add("type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__setattr__(name, value)


                                class Type(Entity):
                                    """
                                    Authentication type
                                    
                                    .. attribute:: authen_type
                                    
                                    	Authentication type code 
                                    	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                    
                                    .. attribute:: keychain_authen_type
                                    
                                    	Keychain authentication type
                                    	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Keychain name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__init__()

                                        self.yang_name = "type"
                                        self.yang_parent_name = "authentication"

                                        self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                        self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("authen_type",
                                                        "keychain_authen_type",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.authen_type.is_set or
                                            self.keychain_authen_type.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.authen_type.yfilter != YFilter.not_set or
                                            self.keychain_authen_type.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.authen_type.get_name_leafdata())
                                        if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "authen-type"):
                                            self.authen_type = value
                                            self.authen_type.value_namespace = name_space
                                            self.authen_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-authen-type"):
                                            self.keychain_authen_type = value
                                            self.keychain_authen_type.value_namespace = name_space
                                            self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class MessageDigestKeies(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configurations, first 16 chars used
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Message digest authentication password (key) configuration
                                    	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                        self.yang_name = "message-digest-keies"
                                        self.yang_parent_name = "authentication"

                                        self.message_digest_key = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configuration
                                        
                                        .. attribute:: key_id  <key>
                                        
                                        	Key ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: password
                                        
                                        	Password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "message-digest-keies"

                                            self.key_id = YLeaf(YType.uint32, "key-id")

                                            self.password = YLeaf(YType.str, "password")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key_id",
                                                            "password") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.key_id.is_set or
                                                self.password.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key_id.yfilter != YFilter.not_set or
                                                self.password.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key_id.get_name_leafdata())
                                            if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.password.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "key-id" or name == "password"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key-id"):
                                                self.key_id = value
                                                self.key_id.value_namespace = name_space
                                                self.key_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "password"):
                                                self.password = value
                                                self.password.value_namespace = name_space
                                                self.password.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.message_digest_key:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.message_digest_key:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "message-digest-keies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-key"):
                                            for c in self.message_digest_key:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.message_digest_key.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                        (self.type is not None and self.type.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                        (self.type is not None and self.type.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "authentication" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "message-digest-keies"):
                                        if (self.message_digest_keies is None):
                                            self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        return self.message_digest_keies

                                    if (child_yang_name == "type"):
                                        if (self.type is None):
                                            self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                        return self.type

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "message-digest-keies" or name == "type" or name == "key"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix


                            class Security(Entity):
                                """
                                Container class for security related
                                configuration parameters
                                
                                .. attribute:: ttl
                                
                                	Enabling turns on TTL security
                                	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security, self).__init__()

                                    self.yang_name = "security"
                                    self.yang_parent_name = "area-scope"

                                    self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                    self.ttl.parent = self
                                    self._children_name_map["ttl"] = "ttl"
                                    self._children_yang_names.add("ttl")


                                class Ttl(Entity):
                                    """
                                    Enabling turns on TTL security
                                    
                                    .. attribute:: enable
                                    
                                    	Enable TTL security
                                    	**type**\:  bool
                                    
                                    .. attribute:: hop_count
                                    
                                    	Hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__init__()

                                        self.yang_name = "ttl"
                                        self.yang_parent_name = "security"

                                        self.enable = YLeaf(YType.boolean, "enable")

                                        self.hop_count = YLeaf(YType.uint32, "hop-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "hop_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.hop_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.hop_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ttl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hop_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "enable" or name == "hop-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hop-count"):
                                            self.hop_count = value
                                            self.hop_count.value_namespace = name_space
                                            self.hop_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (self.ttl is not None and self.ttl.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.ttl is not None and self.ttl.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ttl"):
                                        if (self.ttl is None):
                                            self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                        return self.ttl

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ttl"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DeadIntervalMinimal(Entity):
                                """
                                Interval after which a neighbor is declared dead
                                
                                .. attribute:: interval
                                
                                	Interval size in seconds after which a neighbor is declared dead
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: multiplier
                                
                                	Number of Hellos in one second
                                	**type**\:  int
                                
                                	**range:** 3..20
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__init__()

                                    self.yang_name = "dead-interval-minimal"
                                    self.yang_parent_name = "area-scope"

                                    self.interval = YLeaf(YType.uint32, "interval")

                                    self.multiplier = YLeaf(YType.uint32, "multiplier")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interval",
                                                    "multiplier") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.interval.is_set or
                                        self.multiplier.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set or
                                        self.multiplier.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dead-interval-minimal" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())
                                    if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multiplier.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interval" or name == "multiplier"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multiplier"):
                                        self.multiplier = value
                                        self.multiplier.value_namespace = name_space
                                        self.multiplier.value_namespace_prefix = name_space_prefix


                            class FastReroute(Entity):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-prefix global configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__init__()

                                    self.yang_name = "fast-reroute"
                                    self.yang_parent_name = "area-scope"

                                    self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                    self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                    self._children_yang_names.add("per-link")

                                    self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                    self._children_yang_names.add("per-prefix")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fast_reroute_enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__setattr__(name, value)


                                class PerLink(Entity):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__init__()

                                        self.yang_name = "per-link"
                                        self.yang_parent_name = "fast-reroute"

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-link"

                                            self.candidate_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.candidate_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.candidate_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interface"):
                                                for c in self.candidate_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.candidate_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-link"

                                            self.exclude_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.exclude_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.exclude_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "exclude-interface"):
                                                for c in self.exclude_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.exclude_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "exclude-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_use_candidate_only.is_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "per-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interfaces"):
                                            if (self.candidate_interfaces is None):
                                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            return self.candidate_interfaces

                                        if (child_yang_name == "exclude-interfaces"):
                                            if (self.exclude_interfaces is None):
                                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            return self.exclude_interfaces

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-use-candidate-only"):
                                            self.fast_reroute_use_candidate_only = value
                                            self.fast_reroute_use_candidate_only.value_namespace = name_space
                                            self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                class PerPrefix(Entity):
                                    """
                                    Fast\-reroute per\-prefix global configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: remote_lfa
                                    
                                    	Remote LFA configuration
                                    	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                    
                                    .. attribute:: tiebreakers
                                    
                                    	Fast\-reroute tiebreakers configurations
                                    	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                    
                                    .. attribute:: topology_independent_lfa
                                    
                                    	Topology Independet LFA configuration
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__init__()

                                        self.yang_name = "per-prefix"
                                        self.yang_parent_name = "fast-reroute"

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                        self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                        self.remote_lfa.parent = self
                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                        self._children_yang_names.add("remote-lfa")

                                        self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                        self.tiebreakers.parent = self
                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                        self._children_yang_names.add("tiebreakers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_use_candidate_only",
                                                        "topology_independent_lfa") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                    class RemoteLfa(Entity):
                                        """
                                        Remote LFA configuration
                                        
                                        .. attribute:: maximum_cost
                                        
                                        	Maximum path cost to remote LFA
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel
                                        
                                        	Enable/Disable remote LFA computation
                                        	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                            self.yang_name = "remote-lfa"
                                            self.yang_parent_name = "per-prefix"

                                            self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                            self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("maximum_cost",
                                                            "tunnel") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.maximum_cost.is_set or
                                                self.tunnel.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.maximum_cost.yfilter != YFilter.not_set or
                                                self.tunnel.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-lfa" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                            if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-cost" or name == "tunnel"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "maximum-cost"):
                                                self.maximum_cost = value
                                                self.maximum_cost.value_namespace = name_space
                                                self.maximum_cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel"):
                                                self.tunnel = value
                                                self.tunnel.value_namespace = name_space
                                                self.tunnel.value_namespace_prefix = name_space_prefix


                                    class Tiebreakers(Entity):
                                        """
                                        Fast\-reroute tiebreakers configurations
                                        
                                        .. attribute:: tiebreaker
                                        
                                        	Fast\-reroute tiebreakers configuration
                                        	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                            self.yang_name = "tiebreakers"
                                            self.yang_parent_name = "per-prefix"

                                            self.tiebreaker = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                        class Tiebreaker(Entity):
                                            """
                                            Fast\-reroute tiebreakers configuration
                                            
                                            .. attribute:: tiebreaker_type  <key>
                                            
                                            	Tiebreaker type
                                            	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                            
                                            .. attribute:: tiebreaker_index
                                            
                                            	Index value for a tiebreaker, 0 to disable
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                self.yang_name = "tiebreaker"
                                                self.yang_parent_name = "tiebreakers"

                                                self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tiebreaker_type",
                                                                "tiebreaker_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.tiebreaker_type.is_set or
                                                    self.tiebreaker_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tiebreaker_type.yfilter != YFilter.not_set or
                                                    self.tiebreaker_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tiebreaker-type"):
                                                    self.tiebreaker_type = value
                                                    self.tiebreaker_type.value_namespace = name_space
                                                    self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tiebreaker-index"):
                                                    self.tiebreaker_index = value
                                                    self.tiebreaker_index.value_namespace = name_space
                                                    self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tiebreaker:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.tiebreaker:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tiebreakers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tiebreaker"):
                                                for c in self.tiebreaker:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tiebreaker.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tiebreaker"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-prefix"

                                            self.candidate_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.candidate_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.candidate_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interface"):
                                                for c in self.candidate_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.candidate_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-prefix"

                                            self.exclude_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.exclude_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.exclude_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "exclude-interface"):
                                                for c in self.exclude_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.exclude_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "exclude-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_use_candidate_only.is_set or
                                            self.topology_independent_lfa.is_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                            (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                            (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                            self.topology_independent_lfa.yfilter != YFilter.not_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                            (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                            (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "per-prefix" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                        if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interfaces"):
                                            if (self.candidate_interfaces is None):
                                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            return self.candidate_interfaces

                                        if (child_yang_name == "exclude-interfaces"):
                                            if (self.exclude_interfaces is None):
                                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            return self.exclude_interfaces

                                        if (child_yang_name == "remote-lfa"):
                                            if (self.remote_lfa is None):
                                                self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                            return self.remote_lfa

                                        if (child_yang_name == "tiebreakers"):
                                            if (self.tiebreakers is None):
                                                self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                            return self.tiebreakers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-use-candidate-only"):
                                            self.fast_reroute_use_candidate_only = value
                                            self.fast_reroute_use_candidate_only.value_namespace = name_space
                                            self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-independent-lfa"):
                                            self.topology_independent_lfa = value
                                            self.topology_independent_lfa.value_namespace = name_space
                                            self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.fast_reroute_enable.is_set or
                                        (self.per_link is not None and self.per_link.has_data()) or
                                        (self.per_prefix is not None and self.per_prefix.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fast_reroute_enable.yfilter != YFilter.not_set or
                                        (self.per_link is not None and self.per_link.has_operation()) or
                                        (self.per_prefix is not None and self.per_prefix.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fast-reroute" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "per-link"):
                                        if (self.per_link is None):
                                            self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                        return self.per_link

                                    if (child_yang_name == "per-prefix"):
                                        if (self.per_prefix is None):
                                            self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                        return self.per_prefix

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fast-reroute-enable"):
                                        self.fast_reroute_enable = value
                                        self.fast_reroute_enable.value_namespace = name_space
                                        self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                            class CostFallback(Entity):
                                """
                                Interface fallback cost
                                
                                .. attribute:: cost
                                
                                	Fallback cost of link
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: threshold
                                
                                	Bandwidth threshold
                                	**type**\:  int
                                
                                	**range:** 1..4294967
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__init__()

                                    self.yang_name = "cost-fallback"
                                    self.yang_parent_name = "area-scope"

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.threshold = YLeaf(YType.uint32, "threshold")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("cost",
                                                    "threshold") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.cost.is_set or
                                        self.threshold.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.threshold.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "cost-fallback" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cost" or name == "threshold"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "threshold"):
                                        self.threshold = value
                                        self.threshold.value_namespace = name_space
                                        self.threshold.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.cost.is_set or
                                    self.database_filter.is_set or
                                    self.demand_circuit.is_set or
                                    self.flood_reduction.is_set or
                                    self.hello_interval.is_set or
                                    self.ldp_auto_config.is_set or
                                    self.ldp_sync.is_set or
                                    self.ldp_sync_igp_shortcuts.is_set or
                                    self.link_down_fast_detect.is_set or
                                    self.loopback_stub_network.is_set or
                                    self.mtu_ignore.is_set or
                                    self.network_type.is_set or
                                    self.packet_size.is_set or
                                    self.passive.is_set or
                                    self.prefix_suppression_primary.is_set or
                                    self.prefix_suppression_secondary.is_set or
                                    self.priority.is_set or
                                    self.retransmit_interval.is_set or
                                    self.segment_routing_forwarding.is_set or
                                    self.transmit_delay.is_set or
                                    (self.authentication is not None and self.authentication.has_data()) or
                                    (self.bfd is not None and self.bfd.has_data()) or
                                    (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                    (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                    (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                    (self.security is not None and self.security.has_data()) or
                                    (self.distribute_list is not None))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cost.yfilter != YFilter.not_set or
                                    self.database_filter.yfilter != YFilter.not_set or
                                    self.demand_circuit.yfilter != YFilter.not_set or
                                    self.flood_reduction.yfilter != YFilter.not_set or
                                    self.hello_interval.yfilter != YFilter.not_set or
                                    self.ldp_auto_config.yfilter != YFilter.not_set or
                                    self.ldp_sync.yfilter != YFilter.not_set or
                                    self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                    self.link_down_fast_detect.yfilter != YFilter.not_set or
                                    self.loopback_stub_network.yfilter != YFilter.not_set or
                                    self.mtu_ignore.yfilter != YFilter.not_set or
                                    self.network_type.yfilter != YFilter.not_set or
                                    self.packet_size.yfilter != YFilter.not_set or
                                    self.passive.yfilter != YFilter.not_set or
                                    self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                    self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.retransmit_interval.yfilter != YFilter.not_set or
                                    self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                    self.transmit_delay.yfilter != YFilter.not_set or
                                    (self.authentication is not None and self.authentication.has_operation()) or
                                    (self.bfd is not None and self.bfd.has_operation()) or
                                    (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                    (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                    (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                    (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                    (self.security is not None and self.security.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-scope" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.network_type.get_name_leafdata())
                                if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.packet_size.get_name_leafdata())
                                if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.passive.get_name_leafdata())
                                if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "authentication"):
                                    if (self.authentication is None):
                                        self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                    return self.authentication

                                if (child_yang_name == "bfd"):
                                    if (self.bfd is None):
                                        self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                    return self.bfd

                                if (child_yang_name == "cost-fallback"):
                                    if (self.cost_fallback is None):
                                        self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                    return self.cost_fallback

                                if (child_yang_name == "dead-interval-minimal"):
                                    if (self.dead_interval_minimal is None):
                                        self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    return self.dead_interval_minimal

                                if (child_yang_name == "distribute-list"):
                                    if (self.distribute_list is None):
                                        self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList()
                                        self.distribute_list.parent = self
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                    return self.distribute_list

                                if (child_yang_name == "fast-reroute"):
                                    if (self.fast_reroute is None):
                                        self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                    return self.fast_reroute

                                if (child_yang_name == "security"):
                                    if (self.security is None):
                                        self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                    return self.security

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cost"):
                                    self.cost = value
                                    self.cost.value_namespace = name_space
                                    self.cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "database-filter"):
                                    self.database_filter = value
                                    self.database_filter.value_namespace = name_space
                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                if(value_path == "demand-circuit"):
                                    self.demand_circuit = value
                                    self.demand_circuit.value_namespace = name_space
                                    self.demand_circuit.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-reduction"):
                                    self.flood_reduction = value
                                    self.flood_reduction.value_namespace = name_space
                                    self.flood_reduction.value_namespace_prefix = name_space_prefix
                                if(value_path == "hello-interval"):
                                    self.hello_interval = value
                                    self.hello_interval.value_namespace = name_space
                                    self.hello_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-auto-config"):
                                    self.ldp_auto_config = value
                                    self.ldp_auto_config.value_namespace = name_space
                                    self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-sync"):
                                    self.ldp_sync = value
                                    self.ldp_sync.value_namespace = name_space
                                    self.ldp_sync.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-sync-igp-shortcuts"):
                                    self.ldp_sync_igp_shortcuts = value
                                    self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                    self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-down-fast-detect"):
                                    self.link_down_fast_detect = value
                                    self.link_down_fast_detect.value_namespace = name_space
                                    self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                if(value_path == "loopback-stub-network"):
                                    self.loopback_stub_network = value
                                    self.loopback_stub_network.value_namespace = name_space
                                    self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-ignore"):
                                    self.mtu_ignore = value
                                    self.mtu_ignore.value_namespace = name_space
                                    self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                if(value_path == "network-type"):
                                    self.network_type = value
                                    self.network_type.value_namespace = name_space
                                    self.network_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "packet-size"):
                                    self.packet_size = value
                                    self.packet_size.value_namespace = name_space
                                    self.packet_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "passive"):
                                    self.passive = value
                                    self.passive.value_namespace = name_space
                                    self.passive.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppression-primary"):
                                    self.prefix_suppression_primary = value
                                    self.prefix_suppression_primary.value_namespace = name_space
                                    self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppression-secondary"):
                                    self.prefix_suppression_secondary = value
                                    self.prefix_suppression_secondary.value_namespace = name_space
                                    self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmit-interval"):
                                    self.retransmit_interval = value
                                    self.retransmit_interval.value_namespace = name_space
                                    self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing-forwarding"):
                                    self.segment_routing_forwarding = value
                                    self.segment_routing_forwarding.value_namespace = name_space
                                    self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmit-delay"):
                                    self.transmit_delay = value
                                    self.transmit_delay.value_namespace = name_space
                                    self.transmit_delay.value_namespace_prefix = name_space_prefix


                        class NameScopes(Entity):
                            """
                            Name scope configurations
                            
                            .. attribute:: name_scope
                            
                            	Name scope configuration
                            	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes, self).__init__()

                                self.yang_name = "name-scopes"
                                self.yang_parent_name = "area-address"

                                self.name_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes, self).__setattr__(name, value)


                            class NameScope(Entity):
                                """
                                Name scope configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors>`
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_sid
                                
                                	Prefix SID
                                	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_sid_strict
                                
                                	Strict Prefix SID
                                	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__init__()

                                    self.yang_name = "name-scope"
                                    self.yang_parent_name = "name-scopes"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                    self.prefix_sid = None
                                    self._children_name_map["prefix_sid"] = "prefix-sid"
                                    self._children_yang_names.add("prefix-sid")

                                    self.prefix_sid_strict = None
                                    self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                    self._children_yang_names.add("prefix-sid-strict")

                                    self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "cost",
                                                    "database_filter",
                                                    "demand_circuit",
                                                    "flood_reduction",
                                                    "hello_interval",
                                                    "ldp_auto_config",
                                                    "ldp_sync",
                                                    "ldp_sync_igp_shortcuts",
                                                    "link_down_fast_detect",
                                                    "loopback_stub_network",
                                                    "mtu_ignore",
                                                    "network_type",
                                                    "packet_size",
                                                    "passive",
                                                    "prefix_suppression_primary",
                                                    "prefix_suppression_secondary",
                                                    "priority",
                                                    "retransmit_interval",
                                                    "running",
                                                    "segment_routing_forwarding",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__setattr__(name, value)


                                class PrefixSid(Entity):
                                    """
                                    Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__init__()

                                        self.yang_name = "prefix-sid"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("explicit_null",
                                                        "n_flag_clear",
                                                        "sid_value",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.explicit_null.is_set or
                                            self.n_flag_clear.is_set or
                                            self.sid_value.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.explicit_null.yfilter != YFilter.not_set or
                                            self.n_flag_clear.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "prefix-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                        if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "explicit-null"):
                                            self.explicit_null = value
                                            self.explicit_null.value_namespace = name_space
                                            self.explicit_null.value_namespace_prefix = name_space_prefix
                                        if(value_path == "n-flag-clear"):
                                            self.n_flag_clear = value
                                            self.n_flag_clear.value_namespace = name_space
                                            self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class PrefixSidStrict(Entity):
                                    """
                                    Strict Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                        self.yang_name = "prefix-sid-strict"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("explicit_null",
                                                        "n_flag_clear",
                                                        "sid_value",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.explicit_null.is_set or
                                            self.n_flag_clear.is_set or
                                            self.sid_value.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.explicit_null.yfilter != YFilter.not_set or
                                            self.n_flag_clear.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "prefix-sid-strict" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                        if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "explicit-null"):
                                            self.explicit_null = value
                                            self.explicit_null.value_namespace = name_space
                                            self.explicit_null.value_namespace_prefix = name_space_prefix
                                        if(value_path == "n-flag-clear"):
                                            self.n_flag_clear = value
                                            self.n_flag_clear.value_namespace = name_space
                                            self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "name-scope"

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("detection_multiplier",
                                                        "fast_detect_mode",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.detection_multiplier.is_set or
                                            self.fast_detect_mode.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.fast_detect_mode.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-mode"):
                                            self.fast_detect_mode = value
                                            self.fast_detect_mode.value_namespace = name_space
                                            self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "name-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "name-scope"

                                        self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("enable",
                                                            "hop_count") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.enable.is_set or
                                                self.hop_count.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.enable.yfilter != YFilter.not_set or
                                                self.hop_count.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ttl" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.enable.get_name_leafdata())
                                            if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.hop_count.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "enable" or name == "hop-count"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "enable"):
                                                self.enable = value
                                                self.enable.value_namespace = name_space
                                                self.enable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "hop-count"):
                                                self.hop_count = value
                                                self.hop_count.value_namespace = name_space
                                                self.hop_count.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (self.ttl is not None and self.ttl.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.ttl is not None and self.ttl.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ttl"):
                                            if (self.ttl is None):
                                                self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                                self.ttl.parent = self
                                                self._children_name_map["ttl"] = "ttl"
                                            return self.ttl

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "name-scope"

                                        self.neighbor = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("neighbor_address",
                                                            "cost",
                                                            "database_filter",
                                                            "poll_interval",
                                                            "priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.neighbor_address.is_set or
                                                self.cost.is_set or
                                                self.database_filter.is_set or
                                                self.poll_interval.is_set or
                                                self.priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.neighbor_address.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.database_filter.yfilter != YFilter.not_set or
                                                self.poll_interval.yfilter != YFilter.not_set or
                                                self.priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.database_filter.get_name_leafdata())
                                            if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "neighbor-address"):
                                                self.neighbor_address = value
                                                self.neighbor_address.value_namespace = name_space
                                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "database-filter"):
                                                self.database_filter = value
                                                self.database_filter.value_namespace = name_space
                                                self.database_filter.value_namespace_prefix = name_space_prefix
                                            if(value_path == "poll-interval"):
                                                self.poll_interval = value
                                                self.poll_interval.value_namespace = name_space
                                                self.poll_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority"):
                                                self.priority = value
                                                self.priority.value_namespace = name_space
                                                self.priority.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor"):
                                            for c in self.neighbor:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "name-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "name-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "name-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.demand_circuit.is_set or
                                        self.flood_reduction.is_set or
                                        self.hello_interval.is_set or
                                        self.ldp_auto_config.is_set or
                                        self.ldp_sync.is_set or
                                        self.ldp_sync_igp_shortcuts.is_set or
                                        self.link_down_fast_detect.is_set or
                                        self.loopback_stub_network.is_set or
                                        self.mtu_ignore.is_set or
                                        self.network_type.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.prefix_suppression_primary.is_set or
                                        self.prefix_suppression_secondary.is_set or
                                        self.priority.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.segment_routing_forwarding.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.bfd is not None and self.bfd.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.neighbors is not None and self.neighbors.has_data()) or
                                        (self.security is not None and self.security.has_data()) or
                                        (self.distribute_list is not None) or
                                        (self.prefix_sid is not None) or
                                        (self.prefix_sid_strict is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.demand_circuit.yfilter != YFilter.not_set or
                                        self.flood_reduction.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.ldp_auto_config.yfilter != YFilter.not_set or
                                        self.ldp_sync.yfilter != YFilter.not_set or
                                        self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.link_down_fast_detect.yfilter != YFilter.not_set or
                                        self.loopback_stub_network.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                        self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                        self.priority.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.bfd is not None and self.bfd.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.neighbors is not None and self.neighbors.has_operation()) or
                                        (self.prefix_sid is not None and self.prefix_sid.has_operation()) or
                                        (self.prefix_sid_strict is not None and self.prefix_sid_strict.has_operation()) or
                                        (self.security is not None and self.security.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "name-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                    if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                    if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                    if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                    if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                    if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "bfd"):
                                        if (self.bfd is None):
                                            self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                            self.bfd.parent = self
                                            self._children_name_map["bfd"] = "bfd"
                                        return self.bfd

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "neighbors"):
                                        if (self.neighbors is None):
                                            self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                            self.neighbors.parent = self
                                            self._children_name_map["neighbors"] = "neighbors"
                                        return self.neighbors

                                    if (child_yang_name == "prefix-sid"):
                                        if (self.prefix_sid is None):
                                            self.prefix_sid = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid()
                                            self.prefix_sid.parent = self
                                            self._children_name_map["prefix_sid"] = "prefix-sid"
                                        return self.prefix_sid

                                    if (child_yang_name == "prefix-sid-strict"):
                                        if (self.prefix_sid_strict is None):
                                            self.prefix_sid_strict = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict()
                                            self.prefix_sid_strict.parent = self
                                            self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        return self.prefix_sid_strict

                                    if (child_yang_name == "security"):
                                        if (self.security is None):
                                            self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                            self.security.parent = self
                                            self._children_name_map["security"] = "security"
                                        return self.security

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "prefix-sid" or name == "prefix-sid-strict" or name == "security" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "running" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "demand-circuit"):
                                        self.demand_circuit = value
                                        self.demand_circuit.value_namespace = name_space
                                        self.demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-reduction"):
                                        self.flood_reduction = value
                                        self.flood_reduction.value_namespace = name_space
                                        self.flood_reduction.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-auto-config"):
                                        self.ldp_auto_config = value
                                        self.ldp_auto_config.value_namespace = name_space
                                        self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync"):
                                        self.ldp_sync = value
                                        self.ldp_sync.value_namespace = name_space
                                        self.ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync-igp-shortcuts"):
                                        self.ldp_sync_igp_shortcuts = value
                                        self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-down-fast-detect"):
                                        self.link_down_fast_detect = value
                                        self.link_down_fast_detect.value_namespace = name_space
                                        self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "loopback-stub-network"):
                                        self.loopback_stub_network = value
                                        self.loopback_stub_network.value_namespace = name_space
                                        self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-primary"):
                                        self.prefix_suppression_primary = value
                                        self.prefix_suppression_primary.value_namespace = name_space
                                        self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-secondary"):
                                        self.prefix_suppression_secondary = value
                                        self.prefix_suppression_secondary.value_namespace = name_space
                                        self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority"):
                                        self.priority = value
                                        self.priority.value_namespace = name_space
                                        self.priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segment-routing-forwarding"):
                                        self.segment_routing_forwarding = value
                                        self.segment_routing_forwarding.value_namespace = name_space
                                        self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.name_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.name_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "name-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "name-scope"):
                                    for c in self.name_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.name_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "name-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MultiAreaInterfaceScopes(Entity):
                            """
                            Multi Area Interface scope configurations
                            
                            .. attribute:: multi_area_interface_scope
                            
                            	Multi Area Interface configuration
                            	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__init__()

                                self.yang_name = "multi-area-interface-scopes"
                                self.yang_parent_name = "area-address"

                                self.multi_area_interface_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__setattr__(name, value)


                            class MultiAreaInterfaceScope(Entity):
                                """
                                Multi Area Interface configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Multi Area Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                    self.yang_name = "multi-area-interface-scope"
                                    self.yang_parent_name = "multi-area-interface-scopes"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "cost",
                                                    "database_filter",
                                                    "hello_interval",
                                                    "mtu_ignore",
                                                    "packet_size",
                                                    "passive",
                                                    "retransmit_interval",
                                                    "running",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.neighbor = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("neighbor_address",
                                                            "cost",
                                                            "database_filter",
                                                            "poll_interval",
                                                            "priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.neighbor_address.is_set or
                                                self.cost.is_set or
                                                self.database_filter.is_set or
                                                self.poll_interval.is_set or
                                                self.priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.neighbor_address.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.database_filter.yfilter != YFilter.not_set or
                                                self.poll_interval.yfilter != YFilter.not_set or
                                                self.priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.database_filter.get_name_leafdata())
                                            if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "neighbor-address"):
                                                self.neighbor_address = value
                                                self.neighbor_address.value_namespace = name_space
                                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "database-filter"):
                                                self.database_filter = value
                                                self.database_filter.value_namespace = name_space
                                                self.database_filter.value_namespace_prefix = name_space_prefix
                                            if(value_path == "poll-interval"):
                                                self.poll_interval = value
                                                self.poll_interval.value_namespace = name_space
                                                self.poll_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority"):
                                                self.priority = value
                                                self.priority.value_namespace = name_space
                                                self.priority.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor"):
                                            for c in self.neighbor:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.hello_interval.is_set or
                                        self.mtu_ignore.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.neighbors is not None and self.neighbors.has_data()) or
                                        (self.distribute_list is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.neighbors is not None and self.neighbors.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "neighbors"):
                                        if (self.neighbors is None):
                                            self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                            self.neighbors.parent = self
                                            self._children_name_map["neighbors"] = "neighbors"
                                        return self.neighbors

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "hello-interval" or name == "mtu-ignore" or name == "packet-size" or name == "passive" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.multi_area_interface_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.multi_area_interface_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "multi-area-interface-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "multi-area-interface-scope"):
                                    for c in self.multi_area_interface_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.multi_area_interface_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multi-area-interface-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AreaRanges(Entity):
                            """
                            Summarize routes matching address/mask (border
                            routers only)
                            
                            .. attribute:: area_range
                            
                            	Ordering index
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges, self).__init__()

                                self.yang_name = "area-ranges"
                                self.yang_parent_name = "area-address"

                                self.area_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges, self).__setattr__(name, value)


                            class AreaRange(Entity):
                                """
                                Ordering index
                                
                                .. attribute:: address  <key>
                                
                                	IP address to match
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: netmask  <key>
                                
                                	IP netmask for address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise this range
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-ranges"

                                    self.address = YLeaf(YType.str, "address")

                                    self.netmask = YLeaf(YType.str, "netmask")

                                    self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "netmask",
                                                    "not_advertise") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.netmask.is_set or
                                        self.not_advertise.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.netmask.yfilter != YFilter.not_set or
                                        self.not_advertise.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.netmask.get_name_leafdata())
                                    if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_advertise.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "netmask" or name == "not-advertise"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "netmask"):
                                        self.netmask = value
                                        self.netmask.value_namespace = name_space
                                        self.netmask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-advertise"):
                                        self.not_advertise = value
                                        self.not_advertise.value_namespace = name_space
                                        self.not_advertise.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_range:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.area_range:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-ranges" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-range"):
                                    for c in self.area_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-range"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Nssa(Entity):
                            """
                            Specify area as a NSSA area
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric_type
                            
                            	OSPF External metric type
                            	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                            
                            	**default value**\: type2
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: nssa_def_metric
                            
                            	OSPF default metric
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa, self).__init__()

                                self.yang_name = "nssa"
                                self.yang_parent_name = "area-address"

                                self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                self.no_summary = YLeaf(YType.boolean, "no-summary")

                                self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("default_info_originate",
                                                "metric_type",
                                                "no_redistribution",
                                                "no_summary",
                                                "nssa_def_metric") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.default_info_originate.is_set or
                                    self.metric_type.is_set or
                                    self.no_redistribution.is_set or
                                    self.no_summary.is_set or
                                    self.nssa_def_metric.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.default_info_originate.yfilter != YFilter.not_set or
                                    self.metric_type.yfilter != YFilter.not_set or
                                    self.no_redistribution.yfilter != YFilter.not_set or
                                    self.no_summary.yfilter != YFilter.not_set or
                                    self.nssa_def_metric.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nssa" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                                if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_type.get_name_leafdata())
                                if (self.no_redistribution.is_set or self.no_redistribution.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.no_redistribution.get_name_leafdata())
                                if (self.no_summary.is_set or self.no_summary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.no_summary.get_name_leafdata())
                                if (self.nssa_def_metric.is_set or self.nssa_def_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_def_metric.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "default-info-originate" or name == "metric-type" or name == "no-redistribution" or name == "no-summary" or name == "nssa-def-metric"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "default-info-originate"):
                                    self.default_info_originate = value
                                    self.default_info_originate.value_namespace = name_space
                                    self.default_info_originate.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-type"):
                                    self.metric_type = value
                                    self.metric_type.value_namespace = name_space
                                    self.metric_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "no-redistribution"):
                                    self.no_redistribution = value
                                    self.no_redistribution.value_namespace = name_space
                                    self.no_redistribution.value_namespace_prefix = name_space_prefix
                                if(value_path == "no-summary"):
                                    self.no_summary = value
                                    self.no_summary.value_namespace = name_space
                                    self.no_summary.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-def-metric"):
                                    self.nssa_def_metric = value
                                    self.nssa_def_metric.value_namespace = name_space
                                    self.nssa_def_metric.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.address.is_set or
                                self.default_cost.is_set or
                                self.external_out.is_set or
                                self.mpls_traffic_eng.is_set or
                                self.route_policy_in.is_set or
                                self.route_policy_out.is_set or
                                self.running.is_set or
                                self.segment_routing.is_set or
                                self.stub.is_set or
                                self.summary_in.is_set or
                                (self.area_ranges is not None and self.area_ranges.has_data()) or
                                (self.area_scope is not None and self.area_scope.has_data()) or
                                (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_data()) or
                                (self.name_scopes is not None and self.name_scopes.has_data()) or
                                (self.nssa is not None and self.nssa.has_data()) or
                                (self.sham_link_scopes is not None and self.sham_link_scopes.has_data()) or
                                (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.address.yfilter != YFilter.not_set or
                                self.default_cost.yfilter != YFilter.not_set or
                                self.external_out.yfilter != YFilter.not_set or
                                self.mpls_traffic_eng.yfilter != YFilter.not_set or
                                self.route_policy_in.yfilter != YFilter.not_set or
                                self.route_policy_out.yfilter != YFilter.not_set or
                                self.running.yfilter != YFilter.not_set or
                                self.segment_routing.yfilter != YFilter.not_set or
                                self.stub.yfilter != YFilter.not_set or
                                self.summary_in.yfilter != YFilter.not_set or
                                (self.area_ranges is not None and self.area_ranges.has_operation()) or
                                (self.area_scope is not None and self.area_scope.has_operation()) or
                                (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_operation()) or
                                (self.name_scopes is not None and self.name_scopes.has_operation()) or
                                (self.nssa is not None and self.nssa.has_operation()) or
                                (self.sham_link_scopes is not None and self.sham_link_scopes.has_operation()) or
                                (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "area-address" + "[address='" + self.address.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.address.get_name_leafdata())
                            if (self.default_cost.is_set or self.default_cost.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_cost.get_name_leafdata())
                            if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_out.get_name_leafdata())
                            if (self.mpls_traffic_eng.is_set or self.mpls_traffic_eng.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mpls_traffic_eng.get_name_leafdata())
                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                            if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.running.get_name_leafdata())
                            if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_routing.get_name_leafdata())
                            if (self.stub.is_set or self.stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.stub.get_name_leafdata())
                            if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_in.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area-ranges"):
                                if (self.area_ranges is None):
                                    self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges()
                                    self.area_ranges.parent = self
                                    self._children_name_map["area_ranges"] = "area-ranges"
                                return self.area_ranges

                            if (child_yang_name == "area-scope"):
                                if (self.area_scope is None):
                                    self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope()
                                    self.area_scope.parent = self
                                    self._children_name_map["area_scope"] = "area-scope"
                                return self.area_scope

                            if (child_yang_name == "multi-area-interface-scopes"):
                                if (self.multi_area_interface_scopes is None):
                                    self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                                    self.multi_area_interface_scopes.parent = self
                                    self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                return self.multi_area_interface_scopes

                            if (child_yang_name == "name-scopes"):
                                if (self.name_scopes is None):
                                    self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes()
                                    self.name_scopes.parent = self
                                    self._children_name_map["name_scopes"] = "name-scopes"
                                return self.name_scopes

                            if (child_yang_name == "nssa"):
                                if (self.nssa is None):
                                    self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa()
                                    self.nssa.parent = self
                                    self._children_name_map["nssa"] = "nssa"
                                return self.nssa

                            if (child_yang_name == "sham-link-scopes"):
                                if (self.sham_link_scopes is None):
                                    self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                                    self.sham_link_scopes.parent = self
                                    self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                return self.sham_link_scopes

                            if (child_yang_name == "virtual-link-scopes"):
                                if (self.virtual_link_scopes is None):
                                    self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                                    self.virtual_link_scopes.parent = self
                                    self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                return self.virtual_link_scopes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area-ranges" or name == "area-scope" or name == "multi-area-interface-scopes" or name == "name-scopes" or name == "nssa" or name == "sham-link-scopes" or name == "virtual-link-scopes" or name == "address" or name == "default-cost" or name == "external-out" or name == "mpls-traffic-eng" or name == "route-policy-in" or name == "route-policy-out" or name == "running" or name == "segment-routing" or name == "stub" or name == "summary-in"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "address"):
                                self.address = value
                                self.address.value_namespace = name_space
                                self.address.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-cost"):
                                self.default_cost = value
                                self.default_cost.value_namespace = name_space
                                self.default_cost.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-out"):
                                self.external_out = value
                                self.external_out.value_namespace = name_space
                                self.external_out.value_namespace_prefix = name_space_prefix
                            if(value_path == "mpls-traffic-eng"):
                                self.mpls_traffic_eng = value
                                self.mpls_traffic_eng.value_namespace = name_space
                                self.mpls_traffic_eng.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-in"):
                                self.route_policy_in = value
                                self.route_policy_in.value_namespace = name_space
                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-out"):
                                self.route_policy_out = value
                                self.route_policy_out.value_namespace = name_space
                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                            if(value_path == "running"):
                                self.running = value
                                self.running.value_namespace = name_space
                                self.running.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-routing"):
                                self.segment_routing = value
                                self.segment_routing.value_namespace = name_space
                                self.segment_routing.value_namespace_prefix = name_space_prefix
                            if(value_path == "stub"):
                                self.stub = value
                                self.stub.value_namespace = name_space
                                self.stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-in"):
                                self.summary_in = value
                                self.summary_in.value_namespace = name_space
                                self.summary_in.value_namespace_prefix = name_space_prefix


                    class AreaAreaId(Entity):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID if in integer format
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_ranges
                        
                        	Summarize routes matching address/mask (border routers only)
                        	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges>`
                        
                        .. attribute:: area_scope
                        
                        	Area scope configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope>`
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        	**default value**\: 1
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: mpls_traffic_eng
                        
                        	Configure an OSPF area to run MPLS Traffic Engineering
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_area_interface_scopes
                        
                        	Multi Area Interface scope configurations
                        	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes>`
                        
                        .. attribute:: name_scopes
                        
                        	Name scope configurations
                        	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa>`
                        
                        .. attribute:: route_policy_in
                        
                        	Configure a route policy for inbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: route_policy_out
                        
                        	Configure a route policy for outbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: running
                        
                        	Enable routing on an IP network
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: sham_link_scopes
                        
                        	Sham Link scope configurations
                        	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes>`
                        
                        .. attribute:: stub
                        
                        	Specify the area as a stub area (send summary LSA stub area)
                        	**type**\:  bool
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_scopes
                        
                        	Virtual Link scope configurations
                        	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId, self).__init__()

                            self.yang_name = "area-area-id"
                            self.yang_parent_name = "area-addresses"

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.default_cost = YLeaf(YType.uint32, "default-cost")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                            self.running = YLeaf(YType.empty, "running")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.stub = YLeaf(YType.boolean, "stub")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges()
                            self.area_ranges.parent = self
                            self._children_name_map["area_ranges"] = "area-ranges"
                            self._children_yang_names.add("area-ranges")

                            self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope()
                            self.area_scope.parent = self
                            self._children_name_map["area_scope"] = "area-scope"
                            self._children_yang_names.add("area-scope")

                            self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                            self.multi_area_interface_scopes.parent = self
                            self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                            self._children_yang_names.add("multi-area-interface-scopes")

                            self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes()
                            self.name_scopes.parent = self
                            self._children_name_map["name_scopes"] = "name-scopes"
                            self._children_yang_names.add("name-scopes")

                            self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa()
                            self.nssa.parent = self
                            self._children_name_map["nssa"] = "nssa"
                            self._children_yang_names.add("nssa")

                            self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                            self.sham_link_scopes.parent = self
                            self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                            self._children_yang_names.add("sham-link-scopes")

                            self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                            self.virtual_link_scopes.parent = self
                            self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                            self._children_yang_names.add("virtual-link-scopes")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("area_id",
                                            "default_cost",
                                            "external_out",
                                            "mpls_traffic_eng",
                                            "route_policy_in",
                                            "route_policy_out",
                                            "running",
                                            "segment_routing",
                                            "stub",
                                            "summary_in") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId, self).__setattr__(name, value)


                        class VirtualLinkScopes(Entity):
                            """
                            Virtual Link scope configurations
                            
                            .. attribute:: virtual_link_scope
                            
                            	Virtual Link configuration
                            	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__init__()

                                self.yang_name = "virtual-link-scopes"
                                self.yang_parent_name = "area-area-id"

                                self.virtual_link_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__setattr__(name, value)


                            class VirtualLinkScope(Entity):
                                """
                                Virtual Link configuration
                                
                                .. attribute:: address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                    self.yang_name = "virtual-link-scope"
                                    self.yang_parent_name = "virtual-link-scopes"

                                    self.address = YLeaf(YType.str, "address")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "hello_interval",
                                                    "retransmit_interval",
                                                    "running",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__setattr__(name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "virtual-link-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.hello_interval.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "virtual-link-scope" + "[address='" + self.address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "dead-interval-minimal" or name == "address" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.virtual_link_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.virtual_link_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "virtual-link-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "virtual-link-scope"):
                                    for c in self.virtual_link_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.virtual_link_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "virtual-link-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class ShamLinkScopes(Entity):
                            """
                            Sham Link scope configurations
                            
                            .. attribute:: sham_link_scope
                            
                            	Sham Link configuration
                            	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__init__()

                                self.yang_name = "sham-link-scopes"
                                self.yang_parent_name = "area-area-id"

                                self.sham_link_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__setattr__(name, value)


                            class ShamLinkScope(Entity):
                                """
                                Sham Link configuration
                                
                                .. attribute:: source_address  <key>
                                
                                	Address of the local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_address  <key>
                                
                                	Address of the remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: source
                                
                                	Address of the local sham\-link endpoint. Enter an IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__init__()

                                    self.yang_name = "sham-link-scope"
                                    self.yang_parent_name = "sham-link-scopes"

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.destination_address = YLeaf(YType.str, "destination-address")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.source = YLeaf(YType.str, "source")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("source_address",
                                                    "destination_address",
                                                    "cost",
                                                    "hello_interval",
                                                    "retransmit_interval",
                                                    "running",
                                                    "source",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__setattr__(name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "sham-link-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "sham-link-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.source_address.is_set or
                                        self.destination_address.is_set or
                                        self.cost.is_set or
                                        self.hello_interval.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.source.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.source_address.yfilter != YFilter.not_set or
                                        self.destination_address.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.source.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source_address.get_name_leafdata())
                                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.source.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "dead-interval-minimal" or name == "source-address" or name == "destination-address" or name == "cost" or name == "hello-interval" or name == "retransmit-interval" or name == "running" or name == "source" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "source-address"):
                                        self.source_address = value
                                        self.source_address.value_namespace = name_space
                                        self.source_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "destination-address"):
                                        self.destination_address = value
                                        self.destination_address.value_namespace = name_space
                                        self.destination_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "source"):
                                        self.source = value
                                        self.source.value_namespace = name_space
                                        self.source.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.sham_link_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.sham_link_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sham-link-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "sham-link-scope"):
                                    for c in self.sham_link_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.sham_link_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "sham-link-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AreaScope(Entity):
                            """
                            Area scope configuration
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback>`
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: dead_interval_minimal
                            
                            	Interval after which a neighbor is declared dead
                            	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal>`
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/Disable OSPF demand circuit
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/Disable OSPF flood reduction
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: hello_interval
                            
                            	Interval between HELLO packets in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ldp_auto_config
                            
                            	Enable MPLS LDP Auto Config
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: ldp_sync_igp_shortcuts
                            
                            	Enable/Disable MPLS LDP sync for igp\-shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: link_down_fast_detect
                            
                            	Enable/Disable registration for early interface down notifications
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: loopback_stub_network
                            
                            	Enable/Disable advertising loopback as a stub network
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/Disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: network_type
                            
                            	Type of attached network
                            	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                            
                            .. attribute:: packet_size
                            
                            	Customize size of OSPF packets upto MTU
                            	**type**\:  int
                            
                            	**range:** 576..10000
                            
                            .. attribute:: passive
                            
                            	When enabled, prevent sending HELLO packets over link
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_primary
                            
                            	Enable/Disable prefix suppression for primary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_secondary
                            
                            	Enable/Disable prefix suppression for secondary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: priority
                            
                            	Router priority for DR and BDR election
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 1
                            
                            .. attribute:: retransmit_interval
                            
                            	Time in seconds between retransmitting lost link state advertisements
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 5
                            
                            .. attribute:: security
                            
                            	Container class for security related configuration parameters
                            	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security>`
                            
                            .. attribute:: segment_routing_forwarding
                            
                            	segment\-routing forwarding configuration Applicableonly in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                            
                            .. attribute:: transmit_delay
                            
                            	Number of seconds to delay transmission of LSAs
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope, self).__init__()

                                self.yang_name = "area-scope"
                                self.yang_parent_name = "area-area-id"

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.packet_size = YLeaf(YType.uint32, "packet-size")

                                self.passive = YLeaf(YType.boolean, "passive")

                                self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")

                                self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                self.cost_fallback.parent = self
                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                self._children_yang_names.add("cost-fallback")

                                self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                self.dead_interval_minimal.parent = self
                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                self._children_yang_names.add("dead-interval-minimal")

                                self.distribute_list = None
                                self._children_name_map["distribute_list"] = "distribute-list"
                                self._children_yang_names.add("distribute-list")

                                self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                self._children_yang_names.add("fast-reroute")

                                self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                self.security.parent = self
                                self._children_name_map["security"] = "security"
                                self._children_yang_names.add("security")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("cost",
                                                "database_filter",
                                                "demand_circuit",
                                                "flood_reduction",
                                                "hello_interval",
                                                "ldp_auto_config",
                                                "ldp_sync",
                                                "ldp_sync_igp_shortcuts",
                                                "link_down_fast_detect",
                                                "loopback_stub_network",
                                                "mtu_ignore",
                                                "network_type",
                                                "packet_size",
                                                "passive",
                                                "prefix_suppression_primary",
                                                "prefix_suppression_secondary",
                                                "priority",
                                                "retransmit_interval",
                                                "segment_routing_forwarding",
                                                "transmit_delay") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope, self).__setattr__(name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks intalled to RIB (disable as ACL
                                name means filtering is disabled)
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_name
                                
                                	Route Policy name
                                	**type**\:  str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "area-scope"
                                    self.is_presence_container = True

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("access_list_name",
                                                    "route_policy_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.access_list_name.is_set or
                                        self.route_policy_name.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.access_list_name.yfilter != YFilter.not_set or
                                        self.route_policy_name.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "distribute-list" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                    if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "access-list-name" or name == "route-policy-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "access-list-name"):
                                        self.access_list_name = value
                                        self.access_list_name.value_namespace = name_space
                                        self.access_list_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "route-policy-name"):
                                        self.route_policy_name = value
                                        self.route_policy_name.value_namespace = name_space
                                        self.route_policy_name.value_namespace_prefix = name_space_prefix


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	 use of Bidirectional Forwarding Detection
                                	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "area-scope"

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                    self.interval = YLeaf(YType.uint32, "interval")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("detection_multiplier",
                                                    "fast_detect_mode",
                                                    "interval") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.detection_multiplier.is_set or
                                        self.fast_detect_mode.is_set or
                                        self.interval.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.detection_multiplier.yfilter != YFilter.not_set or
                                        self.fast_detect_mode.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                    if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "detection-multiplier"):
                                        self.detection_multiplier = value
                                        self.detection_multiplier.value_namespace = name_space
                                        self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "fast-detect-mode"):
                                        self.fast_detect_mode = value
                                        self.fast_detect_mode.value_namespace = name_space
                                        self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: key
                                
                                	Authentication key configuration
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: message_digest_keies
                                
                                	Message digest authentication password (key) configurations, first 16 chars used
                                	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies>`
                                
                                .. attribute:: type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area-scope"

                                    self.key = YLeaf(YType.str, "key")

                                    self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                    self.message_digest_keies.parent = self
                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                    self._children_yang_names.add("message-digest-keies")

                                    self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                    self.type.parent = self
                                    self._children_name_map["type"] = "type"
                                    self._children_yang_names.add("type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("key") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__setattr__(name, value)


                                class Type(Entity):
                                    """
                                    Authentication type
                                    
                                    .. attribute:: authen_type
                                    
                                    	Authentication type code 
                                    	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                    
                                    .. attribute:: keychain_authen_type
                                    
                                    	Keychain authentication type
                                    	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Keychain name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__init__()

                                        self.yang_name = "type"
                                        self.yang_parent_name = "authentication"

                                        self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                        self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("authen_type",
                                                        "keychain_authen_type",
                                                        "keychain_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.authen_type.is_set or
                                            self.keychain_authen_type.is_set or
                                            self.keychain_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.authen_type.yfilter != YFilter.not_set or
                                            self.keychain_authen_type.yfilter != YFilter.not_set or
                                            self.keychain_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "type" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.authen_type.get_name_leafdata())
                                        if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                        if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "authen-type"):
                                            self.authen_type = value
                                            self.authen_type.value_namespace = name_space
                                            self.authen_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-authen-type"):
                                            self.keychain_authen_type = value
                                            self.keychain_authen_type.value_namespace = name_space
                                            self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "keychain-name"):
                                            self.keychain_name = value
                                            self.keychain_name.value_namespace = name_space
                                            self.keychain_name.value_namespace_prefix = name_space_prefix


                                class MessageDigestKeies(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configurations, first 16 chars used
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Message digest authentication password (key) configuration
                                    	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                        self.yang_name = "message-digest-keies"
                                        self.yang_parent_name = "authentication"

                                        self.message_digest_key = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configuration
                                        
                                        .. attribute:: key_id  <key>
                                        
                                        	Key ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: password
                                        
                                        	Password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "message-digest-keies"

                                            self.key_id = YLeaf(YType.uint32, "key-id")

                                            self.password = YLeaf(YType.str, "password")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("key_id",
                                                            "password") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.key_id.is_set or
                                                self.password.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.key_id.yfilter != YFilter.not_set or
                                                self.password.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.key_id.get_name_leafdata())
                                            if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.password.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "key-id" or name == "password"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "key-id"):
                                                self.key_id = value
                                                self.key_id.value_namespace = name_space
                                                self.key_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "password"):
                                                self.password = value
                                                self.password.value_namespace = name_space
                                                self.password.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.message_digest_key:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.message_digest_key:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "message-digest-keies" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-key"):
                                            for c in self.message_digest_key:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.message_digest_key.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.key.is_set or
                                        (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                        (self.type is not None and self.type.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.key.yfilter != YFilter.not_set or
                                        (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                        (self.type is not None and self.type.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "authentication" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.key.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "message-digest-keies"):
                                        if (self.message_digest_keies is None):
                                            self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        return self.message_digest_keies

                                    if (child_yang_name == "type"):
                                        if (self.type is None):
                                            self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                        return self.type

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "message-digest-keies" or name == "type" or name == "key"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "key"):
                                        self.key = value
                                        self.key.value_namespace = name_space
                                        self.key.value_namespace_prefix = name_space_prefix


                            class Security(Entity):
                                """
                                Container class for security related
                                configuration parameters
                                
                                .. attribute:: ttl
                                
                                	Enabling turns on TTL security
                                	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security, self).__init__()

                                    self.yang_name = "security"
                                    self.yang_parent_name = "area-scope"

                                    self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                    self.ttl.parent = self
                                    self._children_name_map["ttl"] = "ttl"
                                    self._children_yang_names.add("ttl")


                                class Ttl(Entity):
                                    """
                                    Enabling turns on TTL security
                                    
                                    .. attribute:: enable
                                    
                                    	Enable TTL security
                                    	**type**\:  bool
                                    
                                    .. attribute:: hop_count
                                    
                                    	Hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__init__()

                                        self.yang_name = "ttl"
                                        self.yang_parent_name = "security"

                                        self.enable = YLeaf(YType.boolean, "enable")

                                        self.hop_count = YLeaf(YType.uint32, "hop-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("enable",
                                                        "hop_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.enable.is_set or
                                            self.hop_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.enable.yfilter != YFilter.not_set or
                                            self.hop_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ttl" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.enable.get_name_leafdata())
                                        if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.hop_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "enable" or name == "hop-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "enable"):
                                            self.enable = value
                                            self.enable.value_namespace = name_space
                                            self.enable.value_namespace_prefix = name_space_prefix
                                        if(value_path == "hop-count"):
                                            self.hop_count = value
                                            self.hop_count.value_namespace = name_space
                                            self.hop_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (self.ttl is not None and self.ttl.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.ttl is not None and self.ttl.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "security" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ttl"):
                                        if (self.ttl is None):
                                            self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                        return self.ttl

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ttl"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class DeadIntervalMinimal(Entity):
                                """
                                Interval after which a neighbor is declared dead
                                
                                .. attribute:: interval
                                
                                	Interval size in seconds after which a neighbor is declared dead
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: multiplier
                                
                                	Number of Hellos in one second
                                	**type**\:  int
                                
                                	**range:** 3..20
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__init__()

                                    self.yang_name = "dead-interval-minimal"
                                    self.yang_parent_name = "area-scope"

                                    self.interval = YLeaf(YType.uint32, "interval")

                                    self.multiplier = YLeaf(YType.uint32, "multiplier")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interval",
                                                    "multiplier") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.interval.is_set or
                                        self.multiplier.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set or
                                        self.multiplier.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "dead-interval-minimal" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())
                                    if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multiplier.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "interval" or name == "multiplier"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multiplier"):
                                        self.multiplier = value
                                        self.multiplier.value_namespace = name_space
                                        self.multiplier.value_namespace_prefix = name_space_prefix


                            class FastReroute(Entity):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-prefix global configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__init__()

                                    self.yang_name = "fast-reroute"
                                    self.yang_parent_name = "area-scope"

                                    self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                    self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                    self._children_yang_names.add("per-link")

                                    self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                    self._children_yang_names.add("per-prefix")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("fast_reroute_enable") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__setattr__(name, value)


                                class PerLink(Entity):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__init__()

                                        self.yang_name = "per-link"
                                        self.yang_parent_name = "fast-reroute"

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__setattr__(name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-link"

                                            self.candidate_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.candidate_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.candidate_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interface"):
                                                for c in self.candidate_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.candidate_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-link"

                                            self.exclude_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.exclude_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.exclude_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "exclude-interface"):
                                                for c in self.exclude_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.exclude_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "exclude-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_use_candidate_only.is_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "per-link" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interfaces"):
                                            if (self.candidate_interfaces is None):
                                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            return self.candidate_interfaces

                                        if (child_yang_name == "exclude-interfaces"):
                                            if (self.exclude_interfaces is None):
                                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            return self.exclude_interfaces

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-use-candidate-only"):
                                            self.fast_reroute_use_candidate_only = value
                                            self.fast_reroute_use_candidate_only.value_namespace = name_space
                                            self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                class PerPrefix(Entity):
                                    """
                                    Fast\-reroute per\-prefix global configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: remote_lfa
                                    
                                    	Remote LFA configuration
                                    	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                    
                                    .. attribute:: tiebreakers
                                    
                                    	Fast\-reroute tiebreakers configurations
                                    	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                    
                                    .. attribute:: topology_independent_lfa
                                    
                                    	Topology Independet LFA configuration
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__init__()

                                        self.yang_name = "per-prefix"
                                        self.yang_parent_name = "fast-reroute"

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                        self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                        self.remote_lfa.parent = self
                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                        self._children_yang_names.add("remote-lfa")

                                        self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                        self.tiebreakers.parent = self
                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                        self._children_yang_names.add("tiebreakers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_use_candidate_only",
                                                        "topology_independent_lfa") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                    class RemoteLfa(Entity):
                                        """
                                        Remote LFA configuration
                                        
                                        .. attribute:: maximum_cost
                                        
                                        	Maximum path cost to remote LFA
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel
                                        
                                        	Enable/Disable remote LFA computation
                                        	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                            self.yang_name = "remote-lfa"
                                            self.yang_parent_name = "per-prefix"

                                            self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                            self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("maximum_cost",
                                                            "tunnel") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.maximum_cost.is_set or
                                                self.tunnel.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.maximum_cost.yfilter != YFilter.not_set or
                                                self.tunnel.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "remote-lfa" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                            if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.tunnel.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "maximum-cost" or name == "tunnel"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "maximum-cost"):
                                                self.maximum_cost = value
                                                self.maximum_cost.value_namespace = name_space
                                                self.maximum_cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "tunnel"):
                                                self.tunnel = value
                                                self.tunnel.value_namespace = name_space
                                                self.tunnel.value_namespace_prefix = name_space_prefix


                                    class Tiebreakers(Entity):
                                        """
                                        Fast\-reroute tiebreakers configurations
                                        
                                        .. attribute:: tiebreaker
                                        
                                        	Fast\-reroute tiebreakers configuration
                                        	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                            self.yang_name = "tiebreakers"
                                            self.yang_parent_name = "per-prefix"

                                            self.tiebreaker = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                        class Tiebreaker(Entity):
                                            """
                                            Fast\-reroute tiebreakers configuration
                                            
                                            .. attribute:: tiebreaker_type  <key>
                                            
                                            	Tiebreaker type
                                            	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                            
                                            .. attribute:: tiebreaker_index
                                            
                                            	Index value for a tiebreaker, 0 to disable
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                self.yang_name = "tiebreaker"
                                                self.yang_parent_name = "tiebreakers"

                                                self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("tiebreaker_type",
                                                                "tiebreaker_index") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.tiebreaker_type.is_set or
                                                    self.tiebreaker_index.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.tiebreaker_type.yfilter != YFilter.not_set or
                                                    self.tiebreaker_index.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "tiebreaker-type"):
                                                    self.tiebreaker_type = value
                                                    self.tiebreaker_type.value_namespace = name_space
                                                    self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tiebreaker-index"):
                                                    self.tiebreaker_index = value
                                                    self.tiebreaker_index.value_namespace = name_space
                                                    self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.tiebreaker:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.tiebreaker:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "tiebreakers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "tiebreaker"):
                                                for c in self.tiebreaker:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.tiebreaker.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "tiebreaker"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-prefix"

                                            self.candidate_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.candidate_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.candidate_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "candidate-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interface"):
                                                for c in self.candidate_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.candidate_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-prefix"

                                            self.exclude_interface = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("interface_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.interface_name.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.interface_name.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "interface-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "interface-name"):
                                                    self.interface_name = value
                                                    self.interface_name.value_namespace = name_space
                                                    self.interface_name.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.exclude_interface:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.exclude_interface:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "exclude-interfaces" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "exclude-interface"):
                                                for c in self.exclude_interface:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.exclude_interface.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "exclude-interface"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_use_candidate_only.is_set or
                                            self.topology_independent_lfa.is_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                            (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                            (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                            self.topology_independent_lfa.yfilter != YFilter.not_set or
                                            (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                            (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                            (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                            (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "per-prefix" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                        if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "candidate-interfaces"):
                                            if (self.candidate_interfaces is None):
                                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            return self.candidate_interfaces

                                        if (child_yang_name == "exclude-interfaces"):
                                            if (self.exclude_interfaces is None):
                                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            return self.exclude_interfaces

                                        if (child_yang_name == "remote-lfa"):
                                            if (self.remote_lfa is None):
                                                self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                            return self.remote_lfa

                                        if (child_yang_name == "tiebreakers"):
                                            if (self.tiebreakers is None):
                                                self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                            return self.tiebreakers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-use-candidate-only"):
                                            self.fast_reroute_use_candidate_only = value
                                            self.fast_reroute_use_candidate_only.value_namespace = name_space
                                            self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-independent-lfa"):
                                            self.topology_independent_lfa = value
                                            self.topology_independent_lfa.value_namespace = name_space
                                            self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.fast_reroute_enable.is_set or
                                        (self.per_link is not None and self.per_link.has_data()) or
                                        (self.per_prefix is not None and self.per_prefix.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.fast_reroute_enable.yfilter != YFilter.not_set or
                                        (self.per_link is not None and self.per_link.has_operation()) or
                                        (self.per_prefix is not None and self.per_prefix.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "fast-reroute" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "per-link"):
                                        if (self.per_link is None):
                                            self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                        return self.per_link

                                    if (child_yang_name == "per-prefix"):
                                        if (self.per_prefix is None):
                                            self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                        return self.per_prefix

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "fast-reroute-enable"):
                                        self.fast_reroute_enable = value
                                        self.fast_reroute_enable.value_namespace = name_space
                                        self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                            class CostFallback(Entity):
                                """
                                Interface fallback cost
                                
                                .. attribute:: cost
                                
                                	Fallback cost of link
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: threshold
                                
                                	Bandwidth threshold
                                	**type**\:  int
                                
                                	**range:** 1..4294967
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__init__()

                                    self.yang_name = "cost-fallback"
                                    self.yang_parent_name = "area-scope"

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.threshold = YLeaf(YType.uint32, "threshold")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("cost",
                                                    "threshold") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.cost.is_set or
                                        self.threshold.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.threshold.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "cost-fallback" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.threshold.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "cost" or name == "threshold"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "threshold"):
                                        self.threshold = value
                                        self.threshold.value_namespace = name_space
                                        self.threshold.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.cost.is_set or
                                    self.database_filter.is_set or
                                    self.demand_circuit.is_set or
                                    self.flood_reduction.is_set or
                                    self.hello_interval.is_set or
                                    self.ldp_auto_config.is_set or
                                    self.ldp_sync.is_set or
                                    self.ldp_sync_igp_shortcuts.is_set or
                                    self.link_down_fast_detect.is_set or
                                    self.loopback_stub_network.is_set or
                                    self.mtu_ignore.is_set or
                                    self.network_type.is_set or
                                    self.packet_size.is_set or
                                    self.passive.is_set or
                                    self.prefix_suppression_primary.is_set or
                                    self.prefix_suppression_secondary.is_set or
                                    self.priority.is_set or
                                    self.retransmit_interval.is_set or
                                    self.segment_routing_forwarding.is_set or
                                    self.transmit_delay.is_set or
                                    (self.authentication is not None and self.authentication.has_data()) or
                                    (self.bfd is not None and self.bfd.has_data()) or
                                    (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                    (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                    (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                    (self.security is not None and self.security.has_data()) or
                                    (self.distribute_list is not None))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.cost.yfilter != YFilter.not_set or
                                    self.database_filter.yfilter != YFilter.not_set or
                                    self.demand_circuit.yfilter != YFilter.not_set or
                                    self.flood_reduction.yfilter != YFilter.not_set or
                                    self.hello_interval.yfilter != YFilter.not_set or
                                    self.ldp_auto_config.yfilter != YFilter.not_set or
                                    self.ldp_sync.yfilter != YFilter.not_set or
                                    self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                    self.link_down_fast_detect.yfilter != YFilter.not_set or
                                    self.loopback_stub_network.yfilter != YFilter.not_set or
                                    self.mtu_ignore.yfilter != YFilter.not_set or
                                    self.network_type.yfilter != YFilter.not_set or
                                    self.packet_size.yfilter != YFilter.not_set or
                                    self.passive.yfilter != YFilter.not_set or
                                    self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                    self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                    self.priority.yfilter != YFilter.not_set or
                                    self.retransmit_interval.yfilter != YFilter.not_set or
                                    self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                    self.transmit_delay.yfilter != YFilter.not_set or
                                    (self.authentication is not None and self.authentication.has_operation()) or
                                    (self.bfd is not None and self.bfd.has_operation()) or
                                    (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                    (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                    (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                    (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                    (self.security is not None and self.security.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-scope" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cost.get_name_leafdata())
                                if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.database_filter.get_name_leafdata())
                                if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.network_type.get_name_leafdata())
                                if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.packet_size.get_name_leafdata())
                                if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.passive.get_name_leafdata())
                                if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.priority.get_name_leafdata())
                                if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "authentication"):
                                    if (self.authentication is None):
                                        self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                    return self.authentication

                                if (child_yang_name == "bfd"):
                                    if (self.bfd is None):
                                        self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                    return self.bfd

                                if (child_yang_name == "cost-fallback"):
                                    if (self.cost_fallback is None):
                                        self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                    return self.cost_fallback

                                if (child_yang_name == "dead-interval-minimal"):
                                    if (self.dead_interval_minimal is None):
                                        self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    return self.dead_interval_minimal

                                if (child_yang_name == "distribute-list"):
                                    if (self.distribute_list is None):
                                        self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList()
                                        self.distribute_list.parent = self
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                    return self.distribute_list

                                if (child_yang_name == "fast-reroute"):
                                    if (self.fast_reroute is None):
                                        self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                    return self.fast_reroute

                                if (child_yang_name == "security"):
                                    if (self.security is None):
                                        self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                    return self.security

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "security" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "cost"):
                                    self.cost = value
                                    self.cost.value_namespace = name_space
                                    self.cost.value_namespace_prefix = name_space_prefix
                                if(value_path == "database-filter"):
                                    self.database_filter = value
                                    self.database_filter.value_namespace = name_space
                                    self.database_filter.value_namespace_prefix = name_space_prefix
                                if(value_path == "demand-circuit"):
                                    self.demand_circuit = value
                                    self.demand_circuit.value_namespace = name_space
                                    self.demand_circuit.value_namespace_prefix = name_space_prefix
                                if(value_path == "flood-reduction"):
                                    self.flood_reduction = value
                                    self.flood_reduction.value_namespace = name_space
                                    self.flood_reduction.value_namespace_prefix = name_space_prefix
                                if(value_path == "hello-interval"):
                                    self.hello_interval = value
                                    self.hello_interval.value_namespace = name_space
                                    self.hello_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-auto-config"):
                                    self.ldp_auto_config = value
                                    self.ldp_auto_config.value_namespace = name_space
                                    self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-sync"):
                                    self.ldp_sync = value
                                    self.ldp_sync.value_namespace = name_space
                                    self.ldp_sync.value_namespace_prefix = name_space_prefix
                                if(value_path == "ldp-sync-igp-shortcuts"):
                                    self.ldp_sync_igp_shortcuts = value
                                    self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                    self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                if(value_path == "link-down-fast-detect"):
                                    self.link_down_fast_detect = value
                                    self.link_down_fast_detect.value_namespace = name_space
                                    self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                if(value_path == "loopback-stub-network"):
                                    self.loopback_stub_network = value
                                    self.loopback_stub_network.value_namespace = name_space
                                    self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu-ignore"):
                                    self.mtu_ignore = value
                                    self.mtu_ignore.value_namespace = name_space
                                    self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                if(value_path == "network-type"):
                                    self.network_type = value
                                    self.network_type.value_namespace = name_space
                                    self.network_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "packet-size"):
                                    self.packet_size = value
                                    self.packet_size.value_namespace = name_space
                                    self.packet_size.value_namespace_prefix = name_space_prefix
                                if(value_path == "passive"):
                                    self.passive = value
                                    self.passive.value_namespace = name_space
                                    self.passive.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppression-primary"):
                                    self.prefix_suppression_primary = value
                                    self.prefix_suppression_primary.value_namespace = name_space
                                    self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-suppression-secondary"):
                                    self.prefix_suppression_secondary = value
                                    self.prefix_suppression_secondary.value_namespace = name_space
                                    self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                if(value_path == "priority"):
                                    self.priority = value
                                    self.priority.value_namespace = name_space
                                    self.priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "retransmit-interval"):
                                    self.retransmit_interval = value
                                    self.retransmit_interval.value_namespace = name_space
                                    self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "segment-routing-forwarding"):
                                    self.segment_routing_forwarding = value
                                    self.segment_routing_forwarding.value_namespace = name_space
                                    self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                if(value_path == "transmit-delay"):
                                    self.transmit_delay = value
                                    self.transmit_delay.value_namespace = name_space
                                    self.transmit_delay.value_namespace_prefix = name_space_prefix


                        class NameScopes(Entity):
                            """
                            Name scope configurations
                            
                            .. attribute:: name_scope
                            
                            	Name scope configuration
                            	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes, self).__init__()

                                self.yang_name = "name-scopes"
                                self.yang_parent_name = "area-area-id"

                                self.name_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes, self).__setattr__(name, value)


                            class NameScope(Entity):
                                """
                                Name scope configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors>`
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_sid
                                
                                	Prefix SID
                                	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_sid_strict
                                
                                	Strict Prefix SID
                                	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__init__()

                                    self.yang_name = "name-scope"
                                    self.yang_parent_name = "name-scopes"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                    self.prefix_sid = None
                                    self._children_name_map["prefix_sid"] = "prefix-sid"
                                    self._children_yang_names.add("prefix-sid")

                                    self.prefix_sid_strict = None
                                    self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                    self._children_yang_names.add("prefix-sid-strict")

                                    self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "cost",
                                                    "database_filter",
                                                    "demand_circuit",
                                                    "flood_reduction",
                                                    "hello_interval",
                                                    "ldp_auto_config",
                                                    "ldp_sync",
                                                    "ldp_sync_igp_shortcuts",
                                                    "link_down_fast_detect",
                                                    "loopback_stub_network",
                                                    "mtu_ignore",
                                                    "network_type",
                                                    "packet_size",
                                                    "passive",
                                                    "prefix_suppression_primary",
                                                    "prefix_suppression_secondary",
                                                    "priority",
                                                    "retransmit_interval",
                                                    "running",
                                                    "segment_routing_forwarding",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__setattr__(name, value)


                                class PrefixSid(Entity):
                                    """
                                    Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__init__()

                                        self.yang_name = "prefix-sid"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("explicit_null",
                                                        "n_flag_clear",
                                                        "sid_value",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.explicit_null.is_set or
                                            self.n_flag_clear.is_set or
                                            self.sid_value.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.explicit_null.yfilter != YFilter.not_set or
                                            self.n_flag_clear.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "prefix-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                        if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "explicit-null"):
                                            self.explicit_null = value
                                            self.explicit_null.value_namespace = name_space
                                            self.explicit_null.value_namespace_prefix = name_space_prefix
                                        if(value_path == "n-flag-clear"):
                                            self.n_flag_clear = value
                                            self.n_flag_clear.value_namespace = name_space
                                            self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class PrefixSidStrict(Entity):
                                    """
                                    Strict Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                        self.yang_name = "prefix-sid-strict"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("explicit_null",
                                                        "n_flag_clear",
                                                        "sid_value",
                                                        "type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.explicit_null.is_set or
                                            self.n_flag_clear.is_set or
                                            self.sid_value.is_set or
                                            self.type.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.explicit_null.yfilter != YFilter.not_set or
                                            self.n_flag_clear.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.type.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "prefix-sid-strict" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.explicit_null.is_set or self.explicit_null.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.explicit_null.get_name_leafdata())
                                        if (self.n_flag_clear.is_set or self.n_flag_clear.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.n_flag_clear.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "explicit-null" or name == "n-flag-clear" or name == "sid-value" or name == "type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "explicit-null"):
                                            self.explicit_null = value
                                            self.explicit_null.value_namespace = name_space
                                            self.explicit_null.value_namespace_prefix = name_space_prefix
                                        if(value_path == "n-flag-clear"):
                                            self.n_flag_clear = value
                                            self.n_flag_clear.value_namespace = name_space
                                            self.n_flag_clear.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "type"):
                                            self.type = value
                                            self.type.value_namespace = name_space
                                            self.type.value_namespace_prefix = name_space_prefix


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "name-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "name-scope"

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("detection_multiplier",
                                                        "fast_detect_mode",
                                                        "interval") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.detection_multiplier.is_set or
                                            self.fast_detect_mode.is_set or
                                            self.interval.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.detection_multiplier.yfilter != YFilter.not_set or
                                            self.fast_detect_mode.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "bfd" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.detection_multiplier.is_set or self.detection_multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.detection_multiplier.get_name_leafdata())
                                        if (self.fast_detect_mode.is_set or self.fast_detect_mode.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_detect_mode.get_name_leafdata())
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "detection-multiplier" or name == "fast-detect-mode" or name == "interval"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "detection-multiplier"):
                                            self.detection_multiplier = value
                                            self.detection_multiplier.value_namespace = name_space
                                            self.detection_multiplier.value_namespace_prefix = name_space_prefix
                                        if(value_path == "fast-detect-mode"):
                                            self.fast_detect_mode = value
                                            self.fast_detect_mode.value_namespace = name_space
                                            self.fast_detect_mode.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "name-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "name-scope"

                                        self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("enable",
                                                            "hop_count") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.enable.is_set or
                                                self.hop_count.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.enable.yfilter != YFilter.not_set or
                                                self.hop_count.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "ttl" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.enable.is_set or self.enable.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.enable.get_name_leafdata())
                                            if (self.hop_count.is_set or self.hop_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.hop_count.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "enable" or name == "hop-count"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "enable"):
                                                self.enable = value
                                                self.enable.value_namespace = name_space
                                                self.enable.value_namespace_prefix = name_space_prefix
                                            if(value_path == "hop-count"):
                                                self.hop_count = value
                                                self.hop_count.value_namespace = name_space
                                                self.hop_count.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (self.ttl is not None and self.ttl.has_data())

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            (self.ttl is not None and self.ttl.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "security" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "ttl"):
                                            if (self.ttl is None):
                                                self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                                self.ttl.parent = self
                                                self._children_name_map["ttl"] = "ttl"
                                            return self.ttl

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "ttl"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "name-scope"

                                        self.neighbor = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__setattr__(name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("neighbor_address",
                                                            "cost",
                                                            "database_filter",
                                                            "poll_interval",
                                                            "priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.neighbor_address.is_set or
                                                self.cost.is_set or
                                                self.database_filter.is_set or
                                                self.poll_interval.is_set or
                                                self.priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.neighbor_address.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.database_filter.yfilter != YFilter.not_set or
                                                self.poll_interval.yfilter != YFilter.not_set or
                                                self.priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.database_filter.get_name_leafdata())
                                            if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "neighbor-address"):
                                                self.neighbor_address = value
                                                self.neighbor_address.value_namespace = name_space
                                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "database-filter"):
                                                self.database_filter = value
                                                self.database_filter.value_namespace = name_space
                                                self.database_filter.value_namespace_prefix = name_space_prefix
                                            if(value_path == "poll-interval"):
                                                self.poll_interval = value
                                                self.poll_interval.value_namespace = name_space
                                                self.poll_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority"):
                                                self.priority = value
                                                self.priority.value_namespace = name_space
                                                self.priority.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor"):
                                            for c in self.neighbor:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "name-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "name-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "name-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.demand_circuit.is_set or
                                        self.flood_reduction.is_set or
                                        self.hello_interval.is_set or
                                        self.ldp_auto_config.is_set or
                                        self.ldp_sync.is_set or
                                        self.ldp_sync_igp_shortcuts.is_set or
                                        self.link_down_fast_detect.is_set or
                                        self.loopback_stub_network.is_set or
                                        self.mtu_ignore.is_set or
                                        self.network_type.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.prefix_suppression_primary.is_set or
                                        self.prefix_suppression_secondary.is_set or
                                        self.priority.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.segment_routing_forwarding.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.bfd is not None and self.bfd.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.neighbors is not None and self.neighbors.has_data()) or
                                        (self.security is not None and self.security.has_data()) or
                                        (self.distribute_list is not None) or
                                        (self.prefix_sid is not None) or
                                        (self.prefix_sid_strict is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.demand_circuit.yfilter != YFilter.not_set or
                                        self.flood_reduction.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.ldp_auto_config.yfilter != YFilter.not_set or
                                        self.ldp_sync.yfilter != YFilter.not_set or
                                        self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set or
                                        self.link_down_fast_detect.yfilter != YFilter.not_set or
                                        self.loopback_stub_network.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.network_type.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.prefix_suppression_primary.yfilter != YFilter.not_set or
                                        self.prefix_suppression_secondary.yfilter != YFilter.not_set or
                                        self.priority.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.segment_routing_forwarding.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.bfd is not None and self.bfd.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.neighbors is not None and self.neighbors.has_operation()) or
                                        (self.prefix_sid is not None and self.prefix_sid.has_operation()) or
                                        (self.prefix_sid_strict is not None and self.prefix_sid_strict.has_operation()) or
                                        (self.security is not None and self.security.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "name-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.demand_circuit.is_set or self.demand_circuit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.demand_circuit.get_name_leafdata())
                                    if (self.flood_reduction.is_set or self.flood_reduction.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flood_reduction.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.ldp_auto_config.is_set or self.ldp_auto_config.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_auto_config.get_name_leafdata())
                                    if (self.ldp_sync.is_set or self.ldp_sync.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync.get_name_leafdata())
                                    if (self.ldp_sync_igp_shortcuts.is_set or self.ldp_sync_igp_shortcuts.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ldp_sync_igp_shortcuts.get_name_leafdata())
                                    if (self.link_down_fast_detect.is_set or self.link_down_fast_detect.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.link_down_fast_detect.get_name_leafdata())
                                    if (self.loopback_stub_network.is_set or self.loopback_stub_network.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.loopback_stub_network.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.network_type.is_set or self.network_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.network_type.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.prefix_suppression_primary.is_set or self.prefix_suppression_primary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_primary.get_name_leafdata())
                                    if (self.prefix_suppression_secondary.is_set or self.prefix_suppression_secondary.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_suppression_secondary.get_name_leafdata())
                                    if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.priority.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.segment_routing_forwarding.is_set or self.segment_routing_forwarding.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.segment_routing_forwarding.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "bfd"):
                                        if (self.bfd is None):
                                            self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                            self.bfd.parent = self
                                            self._children_name_map["bfd"] = "bfd"
                                        return self.bfd

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "neighbors"):
                                        if (self.neighbors is None):
                                            self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                            self.neighbors.parent = self
                                            self._children_name_map["neighbors"] = "neighbors"
                                        return self.neighbors

                                    if (child_yang_name == "prefix-sid"):
                                        if (self.prefix_sid is None):
                                            self.prefix_sid = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid()
                                            self.prefix_sid.parent = self
                                            self._children_name_map["prefix_sid"] = "prefix-sid"
                                        return self.prefix_sid

                                    if (child_yang_name == "prefix-sid-strict"):
                                        if (self.prefix_sid_strict is None):
                                            self.prefix_sid_strict = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict()
                                            self.prefix_sid_strict.parent = self
                                            self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        return self.prefix_sid_strict

                                    if (child_yang_name == "security"):
                                        if (self.security is None):
                                            self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                            self.security.parent = self
                                            self._children_name_map["security"] = "security"
                                        return self.security

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "bfd" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "prefix-sid" or name == "prefix-sid-strict" or name == "security" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "demand-circuit" or name == "flood-reduction" or name == "hello-interval" or name == "ldp-auto-config" or name == "ldp-sync" or name == "ldp-sync-igp-shortcuts" or name == "link-down-fast-detect" or name == "loopback-stub-network" or name == "mtu-ignore" or name == "network-type" or name == "packet-size" or name == "passive" or name == "prefix-suppression-primary" or name == "prefix-suppression-secondary" or name == "priority" or name == "retransmit-interval" or name == "running" or name == "segment-routing-forwarding" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "demand-circuit"):
                                        self.demand_circuit = value
                                        self.demand_circuit.value_namespace = name_space
                                        self.demand_circuit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flood-reduction"):
                                        self.flood_reduction = value
                                        self.flood_reduction.value_namespace = name_space
                                        self.flood_reduction.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-auto-config"):
                                        self.ldp_auto_config = value
                                        self.ldp_auto_config.value_namespace = name_space
                                        self.ldp_auto_config.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync"):
                                        self.ldp_sync = value
                                        self.ldp_sync.value_namespace = name_space
                                        self.ldp_sync.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ldp-sync-igp-shortcuts"):
                                        self.ldp_sync_igp_shortcuts = value
                                        self.ldp_sync_igp_shortcuts.value_namespace = name_space
                                        self.ldp_sync_igp_shortcuts.value_namespace_prefix = name_space_prefix
                                    if(value_path == "link-down-fast-detect"):
                                        self.link_down_fast_detect = value
                                        self.link_down_fast_detect.value_namespace = name_space
                                        self.link_down_fast_detect.value_namespace_prefix = name_space_prefix
                                    if(value_path == "loopback-stub-network"):
                                        self.loopback_stub_network = value
                                        self.loopback_stub_network.value_namespace = name_space
                                        self.loopback_stub_network.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "network-type"):
                                        self.network_type = value
                                        self.network_type.value_namespace = name_space
                                        self.network_type.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-primary"):
                                        self.prefix_suppression_primary = value
                                        self.prefix_suppression_primary.value_namespace = name_space
                                        self.prefix_suppression_primary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-suppression-secondary"):
                                        self.prefix_suppression_secondary = value
                                        self.prefix_suppression_secondary.value_namespace = name_space
                                        self.prefix_suppression_secondary.value_namespace_prefix = name_space_prefix
                                    if(value_path == "priority"):
                                        self.priority = value
                                        self.priority.value_namespace = name_space
                                        self.priority.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "segment-routing-forwarding"):
                                        self.segment_routing_forwarding = value
                                        self.segment_routing_forwarding.value_namespace = name_space
                                        self.segment_routing_forwarding.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.name_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.name_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "name-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "name-scope"):
                                    for c in self.name_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.name_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "name-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class MultiAreaInterfaceScopes(Entity):
                            """
                            Multi Area Interface scope configurations
                            
                            .. attribute:: multi_area_interface_scope
                            
                            	Multi Area Interface configuration
                            	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__init__()

                                self.yang_name = "multi-area-interface-scopes"
                                self.yang_parent_name = "area-area-id"

                                self.multi_area_interface_scope = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__setattr__(name, value)


                            class MultiAreaInterfaceScope(Entity):
                                """
                                Multi Area Interface configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Multi Area Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                    self.yang_name = "multi-area-interface-scope"
                                    self.yang_parent_name = "multi-area-interface-scopes"

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("interface_name",
                                                    "cost",
                                                    "database_filter",
                                                    "hello_interval",
                                                    "mtu_ignore",
                                                    "packet_size",
                                                    "passive",
                                                    "retransmit_interval",
                                                    "running",
                                                    "transmit_delay") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__setattr__(name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("access_list_name",
                                                        "route_policy_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.access_list_name.is_set or
                                            self.route_policy_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.access_list_name.yfilter != YFilter.not_set or
                                            self.route_policy_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "distribute-list" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.access_list_name.get_name_leafdata())
                                        if (self.route_policy_name.is_set or self.route_policy_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.route_policy_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "access-list-name" or name == "route-policy-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "access-list-name"):
                                            self.access_list_name = value
                                            self.access_list_name.value_namespace = name_space
                                            self.access_list_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "route-policy-name"):
                                            self.route_policy_name = value
                                            self.route_policy_name.value_namespace = name_space
                                            self.route_policy_name.value_namespace_prefix = name_space_prefix


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("key") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__setattr__(name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("authen_type",
                                                            "keychain_authen_type",
                                                            "keychain_name") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.authen_type.is_set or
                                                self.keychain_authen_type.is_set or
                                                self.keychain_name.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.authen_type.yfilter != YFilter.not_set or
                                                self.keychain_authen_type.yfilter != YFilter.not_set or
                                                self.keychain_name.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "type" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.authen_type.is_set or self.authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.authen_type.get_name_leafdata())
                                            if (self.keychain_authen_type.is_set or self.keychain_authen_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_authen_type.get_name_leafdata())
                                            if (self.keychain_name.is_set or self.keychain_name.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.keychain_name.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "authen-type" or name == "keychain-authen-type" or name == "keychain-name"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "authen-type"):
                                                self.authen_type = value
                                                self.authen_type.value_namespace = name_space
                                                self.authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-authen-type"):
                                                self.keychain_authen_type = value
                                                self.keychain_authen_type.value_namespace = name_space
                                                self.keychain_authen_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "keychain-name"):
                                                self.keychain_name = value
                                                self.keychain_name.value_namespace = name_space
                                                self.keychain_name.value_namespace_prefix = name_space_prefix


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"

                                            self.message_digest_key = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__setattr__(name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("key_id",
                                                                "password") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.key_id.is_set or
                                                    self.password.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.key_id.yfilter != YFilter.not_set or
                                                    self.password.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "message-digest-key" + "[key-id='" + self.key_id.get() + "']" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.key_id.get_name_leafdata())
                                                if (self.password.is_set or self.password.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.password.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "key-id" or name == "password"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "key-id"):
                                                    self.key_id = value
                                                    self.key_id.value_namespace = name_space
                                                    self.key_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "password"):
                                                    self.password = value
                                                    self.password.value_namespace = name_space
                                                    self.password.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.message_digest_key:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.message_digest_key:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "message-digest-keies" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "message-digest-key"):
                                                for c in self.message_digest_key:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.message_digest_key.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "message-digest-key"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.key.is_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_data()) or
                                            (self.type is not None and self.type.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.key.yfilter != YFilter.not_set or
                                            (self.message_digest_keies is not None and self.message_digest_keies.has_operation()) or
                                            (self.type is not None and self.type.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "authentication" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.key.is_set or self.key.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.key.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "message-digest-keies"):
                                            if (self.message_digest_keies is None):
                                                self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                                self.message_digest_keies.parent = self
                                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            return self.message_digest_keies

                                        if (child_yang_name == "type"):
                                            if (self.type is None):
                                                self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                                self.type.parent = self
                                                self._children_name_map["type"] = "type"
                                            return self.type

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "message-digest-keies" or name == "type" or name == "key"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "key"):
                                            self.key = value
                                            self.key.value_namespace = name_space
                                            self.key.value_namespace_prefix = name_space_prefix


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.neighbor = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__setattr__(name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("neighbor_address",
                                                            "cost",
                                                            "database_filter",
                                                            "poll_interval",
                                                            "priority") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.neighbor_address.is_set or
                                                self.cost.is_set or
                                                self.database_filter.is_set or
                                                self.poll_interval.is_set or
                                                self.priority.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.neighbor_address.yfilter != YFilter.not_set or
                                                self.cost.yfilter != YFilter.not_set or
                                                self.database_filter.yfilter != YFilter.not_set or
                                                self.poll_interval.yfilter != YFilter.not_set or
                                                self.priority.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                            if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.cost.get_name_leafdata())
                                            if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.database_filter.get_name_leafdata())
                                            if (self.poll_interval.is_set or self.poll_interval.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.poll_interval.get_name_leafdata())
                                            if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.priority.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "neighbor-address" or name == "cost" or name == "database-filter" or name == "poll-interval" or name == "priority"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "neighbor-address"):
                                                self.neighbor_address = value
                                                self.neighbor_address.value_namespace = name_space
                                                self.neighbor_address.value_namespace_prefix = name_space_prefix
                                            if(value_path == "cost"):
                                                self.cost = value
                                                self.cost.value_namespace = name_space
                                                self.cost.value_namespace_prefix = name_space_prefix
                                            if(value_path == "database-filter"):
                                                self.database_filter = value
                                                self.database_filter.value_namespace = name_space
                                                self.database_filter.value_namespace_prefix = name_space_prefix
                                            if(value_path == "poll-interval"):
                                                self.poll_interval = value
                                                self.poll_interval.value_namespace = name_space
                                                self.poll_interval.value_namespace_prefix = name_space_prefix
                                            if(value_path == "priority"):
                                                self.priority = value
                                                self.priority.value_namespace = name_space
                                                self.priority.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.neighbor:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.neighbor:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "neighbors" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "neighbor"):
                                            for c in self.neighbor:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.neighbor.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "neighbor"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interval",
                                                        "multiplier") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interval.is_set or
                                            self.multiplier.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interval.yfilter != YFilter.not_set or
                                            self.multiplier.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "dead-interval-minimal" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interval.get_name_leafdata())
                                        if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.multiplier.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interval" or name == "multiplier"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interval"):
                                            self.interval = value
                                            self.interval.value_namespace = name_space
                                            self.interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "multiplier"):
                                            self.multiplier = value
                                            self.multiplier.value_namespace = name_space
                                            self.multiplier.value_namespace_prefix = name_space_prefix


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("fast_reroute_enable") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__setattr__(name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__setattr__(name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-link" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "fast-reroute-use-candidate-only"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-01-02'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("fast_reroute_use_candidate_only",
                                                            "topology_independent_lfa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__setattr__(name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("maximum_cost",
                                                                "tunnel") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.maximum_cost.is_set or
                                                    self.tunnel.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.maximum_cost.yfilter != YFilter.not_set or
                                                    self.tunnel.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "remote-lfa" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.maximum_cost.is_set or self.maximum_cost.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.maximum_cost.get_name_leafdata())
                                                if (self.tunnel.is_set or self.tunnel.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "maximum-cost" or name == "tunnel"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "maximum-cost"):
                                                    self.maximum_cost = value
                                                    self.maximum_cost.value_namespace = name_space
                                                    self.maximum_cost.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel"):
                                                    self.tunnel = value
                                                    self.tunnel.value_namespace = name_space
                                                    self.tunnel.value_namespace_prefix = name_space_prefix


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"

                                                self.tiebreaker = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__setattr__(name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("tiebreaker_type",
                                                                    "tiebreaker_index") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.tiebreaker_type.is_set or
                                                        self.tiebreaker_index.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.tiebreaker_type.yfilter != YFilter.not_set or
                                                        self.tiebreaker_index.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.tiebreaker_type.is_set or self.tiebreaker_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_type.get_name_leafdata())
                                                    if (self.tiebreaker_index.is_set or self.tiebreaker_index.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tiebreaker_index.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "tiebreaker-type" or name == "tiebreaker-index"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "tiebreaker-type"):
                                                        self.tiebreaker_type = value
                                                        self.tiebreaker_type.value_namespace = name_space
                                                        self.tiebreaker_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tiebreaker-index"):
                                                        self.tiebreaker_index = value
                                                        self.tiebreaker_index.value_namespace = name_space
                                                        self.tiebreaker_index.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.tiebreaker:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "tiebreakers" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "tiebreaker"):
                                                    for c in self.tiebreaker:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tiebreaker.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "tiebreaker"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.candidate_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__setattr__(name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.candidate_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "candidate-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "candidate-interface"):
                                                    for c in self.candidate_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.candidate_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "candidate-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-01-02'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"

                                                self.exclude_interface = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in () and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__setattr__(name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-01-02'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.interface_name.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "interface-name"):
                                                        self.interface_name = value
                                                        self.interface_name.value_namespace = name_space
                                                        self.interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_data()):
                                                        return True
                                                return False

                                            def has_operation(self):
                                                for c in self.exclude_interface:
                                                    if (c.has_operation()):
                                                        return True
                                                return self.yfilter != YFilter.not_set

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "exclude-interfaces" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "exclude-interface"):
                                                    for c in self.exclude_interface:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.exclude_interface.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "exclude-interface"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (
                                                self.fast_reroute_use_candidate_only.is_set or
                                                self.topology_independent_lfa.is_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_data()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_data()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_data()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set or
                                                self.topology_independent_lfa.yfilter != YFilter.not_set or
                                                (self.candidate_interfaces is not None and self.candidate_interfaces.has_operation()) or
                                                (self.exclude_interfaces is not None and self.exclude_interfaces.has_operation()) or
                                                (self.remote_lfa is not None and self.remote_lfa.has_operation()) or
                                                (self.tiebreakers is not None and self.tiebreakers.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "per-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.fast_reroute_use_candidate_only.is_set or self.fast_reroute_use_candidate_only.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.fast_reroute_use_candidate_only.get_name_leafdata())
                                            if (self.topology_independent_lfa.is_set or self.topology_independent_lfa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.topology_independent_lfa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "candidate-interfaces"):
                                                if (self.candidate_interfaces is None):
                                                    self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                    self.candidate_interfaces.parent = self
                                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                return self.candidate_interfaces

                                            if (child_yang_name == "exclude-interfaces"):
                                                if (self.exclude_interfaces is None):
                                                    self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                    self.exclude_interfaces.parent = self
                                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                return self.exclude_interfaces

                                            if (child_yang_name == "remote-lfa"):
                                                if (self.remote_lfa is None):
                                                    self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                    self.remote_lfa.parent = self
                                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                                return self.remote_lfa

                                            if (child_yang_name == "tiebreakers"):
                                                if (self.tiebreakers is None):
                                                    self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                    self.tiebreakers.parent = self
                                                    self._children_name_map["tiebreakers"] = "tiebreakers"
                                                return self.tiebreakers

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "candidate-interfaces" or name == "exclude-interfaces" or name == "remote-lfa" or name == "tiebreakers" or name == "fast-reroute-use-candidate-only" or name == "topology-independent-lfa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "fast-reroute-use-candidate-only"):
                                                self.fast_reroute_use_candidate_only = value
                                                self.fast_reroute_use_candidate_only.value_namespace = name_space
                                                self.fast_reroute_use_candidate_only.value_namespace_prefix = name_space_prefix
                                            if(value_path == "topology-independent-lfa"):
                                                self.topology_independent_lfa = value
                                                self.topology_independent_lfa.value_namespace = name_space
                                                self.topology_independent_lfa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.fast_reroute_enable.is_set or
                                            (self.per_link is not None and self.per_link.has_data()) or
                                            (self.per_prefix is not None and self.per_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.fast_reroute_enable.yfilter != YFilter.not_set or
                                            (self.per_link is not None and self.per_link.has_operation()) or
                                            (self.per_prefix is not None and self.per_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "fast-reroute" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.fast_reroute_enable.is_set or self.fast_reroute_enable.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.fast_reroute_enable.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "per-link"):
                                            if (self.per_link is None):
                                                self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                                self.per_link.parent = self
                                                self._children_name_map["per_link"] = "per-link"
                                            return self.per_link

                                        if (child_yang_name == "per-prefix"):
                                            if (self.per_prefix is None):
                                                self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                                self.per_prefix.parent = self
                                                self._children_name_map["per_prefix"] = "per-prefix"
                                            return self.per_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "per-link" or name == "per-prefix" or name == "fast-reroute-enable"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "fast-reroute-enable"):
                                            self.fast_reroute_enable = value
                                            self.fast_reroute_enable.value_namespace = name_space
                                            self.fast_reroute_enable.value_namespace_prefix = name_space_prefix


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-01-02'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "multi-area-interface-scope"

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("cost",
                                                        "threshold") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.cost.is_set or
                                            self.threshold.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.cost.yfilter != YFilter.not_set or
                                            self.threshold.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "cost-fallback" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.cost.get_name_leafdata())
                                        if (self.threshold.is_set or self.threshold.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.threshold.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "cost" or name == "threshold"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "cost"):
                                            self.cost = value
                                            self.cost.value_namespace = name_space
                                            self.cost.value_namespace_prefix = name_space_prefix
                                        if(value_path == "threshold"):
                                            self.threshold = value
                                            self.threshold.value_namespace = name_space
                                            self.threshold.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.interface_name.is_set or
                                        self.cost.is_set or
                                        self.database_filter.is_set or
                                        self.hello_interval.is_set or
                                        self.mtu_ignore.is_set or
                                        self.packet_size.is_set or
                                        self.passive.is_set or
                                        self.retransmit_interval.is_set or
                                        self.running.is_set or
                                        self.transmit_delay.is_set or
                                        (self.authentication is not None and self.authentication.has_data()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_data()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_data()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                                        (self.neighbors is not None and self.neighbors.has_data()) or
                                        (self.distribute_list is not None))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.interface_name.yfilter != YFilter.not_set or
                                        self.cost.yfilter != YFilter.not_set or
                                        self.database_filter.yfilter != YFilter.not_set or
                                        self.hello_interval.yfilter != YFilter.not_set or
                                        self.mtu_ignore.yfilter != YFilter.not_set or
                                        self.packet_size.yfilter != YFilter.not_set or
                                        self.passive.yfilter != YFilter.not_set or
                                        self.retransmit_interval.yfilter != YFilter.not_set or
                                        self.running.yfilter != YFilter.not_set or
                                        self.transmit_delay.yfilter != YFilter.not_set or
                                        (self.authentication is not None and self.authentication.has_operation()) or
                                        (self.cost_fallback is not None and self.cost_fallback.has_operation()) or
                                        (self.dead_interval_minimal is not None and self.dead_interval_minimal.has_operation()) or
                                        (self.distribute_list is not None and self.distribute_list.has_operation()) or
                                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                                        (self.neighbors is not None and self.neighbors.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                                    if (self.cost.is_set or self.cost.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.cost.get_name_leafdata())
                                    if (self.database_filter.is_set or self.database_filter.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.database_filter.get_name_leafdata())
                                    if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.hello_interval.get_name_leafdata())
                                    if (self.mtu_ignore.is_set or self.mtu_ignore.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mtu_ignore.get_name_leafdata())
                                    if (self.packet_size.is_set or self.packet_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.packet_size.get_name_leafdata())
                                    if (self.passive.is_set or self.passive.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.passive.get_name_leafdata())
                                    if (self.retransmit_interval.is_set or self.retransmit_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_interval.get_name_leafdata())
                                    if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.running.get_name_leafdata())
                                    if (self.transmit_delay.is_set or self.transmit_delay.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.transmit_delay.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "authentication"):
                                        if (self.authentication is None):
                                            self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                            self.authentication.parent = self
                                            self._children_name_map["authentication"] = "authentication"
                                        return self.authentication

                                    if (child_yang_name == "cost-fallback"):
                                        if (self.cost_fallback is None):
                                            self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                            self.cost_fallback.parent = self
                                            self._children_name_map["cost_fallback"] = "cost-fallback"
                                        return self.cost_fallback

                                    if (child_yang_name == "dead-interval-minimal"):
                                        if (self.dead_interval_minimal is None):
                                            self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                            self.dead_interval_minimal.parent = self
                                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        return self.dead_interval_minimal

                                    if (child_yang_name == "distribute-list"):
                                        if (self.distribute_list is None):
                                            self.distribute_list = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList()
                                            self.distribute_list.parent = self
                                            self._children_name_map["distribute_list"] = "distribute-list"
                                        return self.distribute_list

                                    if (child_yang_name == "fast-reroute"):
                                        if (self.fast_reroute is None):
                                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                            self.fast_reroute.parent = self
                                            self._children_name_map["fast_reroute"] = "fast-reroute"
                                        return self.fast_reroute

                                    if (child_yang_name == "neighbors"):
                                        if (self.neighbors is None):
                                            self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                            self.neighbors.parent = self
                                            self._children_name_map["neighbors"] = "neighbors"
                                        return self.neighbors

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "authentication" or name == "cost-fallback" or name == "dead-interval-minimal" or name == "distribute-list" or name == "fast-reroute" or name == "neighbors" or name == "interface-name" or name == "cost" or name == "database-filter" or name == "hello-interval" or name == "mtu-ignore" or name == "packet-size" or name == "passive" or name == "retransmit-interval" or name == "running" or name == "transmit-delay"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "interface-name"):
                                        self.interface_name = value
                                        self.interface_name.value_namespace = name_space
                                        self.interface_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "cost"):
                                        self.cost = value
                                        self.cost.value_namespace = name_space
                                        self.cost.value_namespace_prefix = name_space_prefix
                                    if(value_path == "database-filter"):
                                        self.database_filter = value
                                        self.database_filter.value_namespace = name_space
                                        self.database_filter.value_namespace_prefix = name_space_prefix
                                    if(value_path == "hello-interval"):
                                        self.hello_interval = value
                                        self.hello_interval.value_namespace = name_space
                                        self.hello_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "mtu-ignore"):
                                        self.mtu_ignore = value
                                        self.mtu_ignore.value_namespace = name_space
                                        self.mtu_ignore.value_namespace_prefix = name_space_prefix
                                    if(value_path == "packet-size"):
                                        self.packet_size = value
                                        self.packet_size.value_namespace = name_space
                                        self.packet_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "passive"):
                                        self.passive = value
                                        self.passive.value_namespace = name_space
                                        self.passive.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-interval"):
                                        self.retransmit_interval = value
                                        self.retransmit_interval.value_namespace = name_space
                                        self.retransmit_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "running"):
                                        self.running = value
                                        self.running.value_namespace = name_space
                                        self.running.value_namespace_prefix = name_space_prefix
                                    if(value_path == "transmit-delay"):
                                        self.transmit_delay = value
                                        self.transmit_delay.value_namespace = name_space
                                        self.transmit_delay.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.multi_area_interface_scope:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.multi_area_interface_scope:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "multi-area-interface-scopes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "multi-area-interface-scope"):
                                    for c in self.multi_area_interface_scope:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.multi_area_interface_scope.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "multi-area-interface-scope"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AreaRanges(Entity):
                            """
                            Summarize routes matching address/mask (border
                            routers only)
                            
                            .. attribute:: area_range
                            
                            	Ordering index
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges, self).__init__()

                                self.yang_name = "area-ranges"
                                self.yang_parent_name = "area-area-id"

                                self.area_range = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges, self).__setattr__(name, value)


                            class AreaRange(Entity):
                                """
                                Ordering index
                                
                                .. attribute:: address  <key>
                                
                                	IP address to match
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: netmask  <key>
                                
                                	IP netmask for address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise this range
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-01-02'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-ranges"

                                    self.address = YLeaf(YType.str, "address")

                                    self.netmask = YLeaf(YType.str, "netmask")

                                    self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("address",
                                                    "netmask",
                                                    "not_advertise") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.address.is_set or
                                        self.netmask.is_set or
                                        self.not_advertise.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.address.yfilter != YFilter.not_set or
                                        self.netmask.yfilter != YFilter.not_set or
                                        self.not_advertise.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.address.is_set or self.address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.address.get_name_leafdata())
                                    if (self.netmask.is_set or self.netmask.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.netmask.get_name_leafdata())
                                    if (self.not_advertise.is_set or self.not_advertise.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.not_advertise.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "address" or name == "netmask" or name == "not-advertise"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "address"):
                                        self.address = value
                                        self.address.value_namespace = name_space
                                        self.address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "netmask"):
                                        self.netmask = value
                                        self.netmask.value_namespace = name_space
                                        self.netmask.value_namespace_prefix = name_space_prefix
                                    if(value_path == "not-advertise"):
                                        self.not_advertise = value
                                        self.not_advertise.value_namespace = name_space
                                        self.not_advertise.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.area_range:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.area_range:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "area-ranges" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "area-range"):
                                    for c in self.area_range:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.area_range.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "area-range"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Nssa(Entity):
                            """
                            Specify area as a NSSA area
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric_type
                            
                            	OSPF External metric type
                            	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                            
                            	**default value**\: type2
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: nssa_def_metric
                            
                            	OSPF default metric
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-01-02'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa, self).__init__()

                                self.yang_name = "nssa"
                                self.yang_parent_name = "area-area-id"

                                self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                self.no_summary = YLeaf(YType.boolean, "no-summary")

                                self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("default_info_originate",
                                                "metric_type",
                                                "no_redistribution",
                                                "no_summary",
                                                "nssa_def_metric") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.default_info_originate.is_set or
                                    self.metric_type.is_set or
                                    self.no_redistribution.is_set or
                                    self.no_summary.is_set or
                                    self.nssa_def_metric.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.default_info_originate.yfilter != YFilter.not_set or
                                    self.metric_type.yfilter != YFilter.not_set or
                                    self.no_redistribution.yfilter != YFilter.not_set or
                                    self.no_summary.yfilter != YFilter.not_set or
                                    self.nssa_def_metric.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "nssa" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.default_info_originate.is_set or self.default_info_originate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.default_info_originate.get_name_leafdata())
                                if (self.metric_type.is_set or self.metric_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.metric_type.get_name_leafdata())
                                if (self.no_redistribution.is_set or self.no_redistribution.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.no_redistribution.get_name_leafdata())
                                if (self.no_summary.is_set or self.no_summary.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.no_summary.get_name_leafdata())
                                if (self.nssa_def_metric.is_set or self.nssa_def_metric.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nssa_def_metric.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "default-info-originate" or name == "metric-type" or name == "no-redistribution" or name == "no-summary" or name == "nssa-def-metric"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "default-info-originate"):
                                    self.default_info_originate = value
                                    self.default_info_originate.value_namespace = name_space
                                    self.default_info_originate.value_namespace_prefix = name_space_prefix
                                if(value_path == "metric-type"):
                                    self.metric_type = value
                                    self.metric_type.value_namespace = name_space
                                    self.metric_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "no-redistribution"):
                                    self.no_redistribution = value
                                    self.no_redistribution.value_namespace = name_space
                                    self.no_redistribution.value_namespace_prefix = name_space_prefix
                                if(value_path == "no-summary"):
                                    self.no_summary = value
                                    self.no_summary.value_namespace = name_space
                                    self.no_summary.value_namespace_prefix = name_space_prefix
                                if(value_path == "nssa-def-metric"):
                                    self.nssa_def_metric = value
                                    self.nssa_def_metric.value_namespace = name_space
                                    self.nssa_def_metric.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.area_id.is_set or
                                self.default_cost.is_set or
                                self.external_out.is_set or
                                self.mpls_traffic_eng.is_set or
                                self.route_policy_in.is_set or
                                self.route_policy_out.is_set or
                                self.running.is_set or
                                self.segment_routing.is_set or
                                self.stub.is_set or
                                self.summary_in.is_set or
                                (self.area_ranges is not None and self.area_ranges.has_data()) or
                                (self.area_scope is not None and self.area_scope.has_data()) or
                                (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_data()) or
                                (self.name_scopes is not None and self.name_scopes.has_data()) or
                                (self.nssa is not None and self.nssa.has_data()) or
                                (self.sham_link_scopes is not None and self.sham_link_scopes.has_data()) or
                                (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.area_id.yfilter != YFilter.not_set or
                                self.default_cost.yfilter != YFilter.not_set or
                                self.external_out.yfilter != YFilter.not_set or
                                self.mpls_traffic_eng.yfilter != YFilter.not_set or
                                self.route_policy_in.yfilter != YFilter.not_set or
                                self.route_policy_out.yfilter != YFilter.not_set or
                                self.running.yfilter != YFilter.not_set or
                                self.segment_routing.yfilter != YFilter.not_set or
                                self.stub.yfilter != YFilter.not_set or
                                self.summary_in.yfilter != YFilter.not_set or
                                (self.area_ranges is not None and self.area_ranges.has_operation()) or
                                (self.area_scope is not None and self.area_scope.has_operation()) or
                                (self.multi_area_interface_scopes is not None and self.multi_area_interface_scopes.has_operation()) or
                                (self.name_scopes is not None and self.name_scopes.has_operation()) or
                                (self.nssa is not None and self.nssa.has_operation()) or
                                (self.sham_link_scopes is not None and self.sham_link_scopes.has_operation()) or
                                (self.virtual_link_scopes is not None and self.virtual_link_scopes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "area-area-id" + "[area-id='" + self.area_id.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.area_id.is_set or self.area_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.area_id.get_name_leafdata())
                            if (self.default_cost.is_set or self.default_cost.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.default_cost.get_name_leafdata())
                            if (self.external_out.is_set or self.external_out.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.external_out.get_name_leafdata())
                            if (self.mpls_traffic_eng.is_set or self.mpls_traffic_eng.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mpls_traffic_eng.get_name_leafdata())
                            if (self.route_policy_in.is_set or self.route_policy_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_in.get_name_leafdata())
                            if (self.route_policy_out.is_set or self.route_policy_out.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.route_policy_out.get_name_leafdata())
                            if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.running.get_name_leafdata())
                            if (self.segment_routing.is_set or self.segment_routing.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.segment_routing.get_name_leafdata())
                            if (self.stub.is_set or self.stub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.stub.get_name_leafdata())
                            if (self.summary_in.is_set or self.summary_in.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.summary_in.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "area-ranges"):
                                if (self.area_ranges is None):
                                    self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges()
                                    self.area_ranges.parent = self
                                    self._children_name_map["area_ranges"] = "area-ranges"
                                return self.area_ranges

                            if (child_yang_name == "area-scope"):
                                if (self.area_scope is None):
                                    self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope()
                                    self.area_scope.parent = self
                                    self._children_name_map["area_scope"] = "area-scope"
                                return self.area_scope

                            if (child_yang_name == "multi-area-interface-scopes"):
                                if (self.multi_area_interface_scopes is None):
                                    self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                                    self.multi_area_interface_scopes.parent = self
                                    self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                return self.multi_area_interface_scopes

                            if (child_yang_name == "name-scopes"):
                                if (self.name_scopes is None):
                                    self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes()
                                    self.name_scopes.parent = self
                                    self._children_name_map["name_scopes"] = "name-scopes"
                                return self.name_scopes

                            if (child_yang_name == "nssa"):
                                if (self.nssa is None):
                                    self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa()
                                    self.nssa.parent = self
                                    self._children_name_map["nssa"] = "nssa"
                                return self.nssa

                            if (child_yang_name == "sham-link-scopes"):
                                if (self.sham_link_scopes is None):
                                    self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                                    self.sham_link_scopes.parent = self
                                    self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                return self.sham_link_scopes

                            if (child_yang_name == "virtual-link-scopes"):
                                if (self.virtual_link_scopes is None):
                                    self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                                    self.virtual_link_scopes.parent = self
                                    self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                return self.virtual_link_scopes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "area-ranges" or name == "area-scope" or name == "multi-area-interface-scopes" or name == "name-scopes" or name == "nssa" or name == "sham-link-scopes" or name == "virtual-link-scopes" or name == "area-id" or name == "default-cost" or name == "external-out" or name == "mpls-traffic-eng" or name == "route-policy-in" or name == "route-policy-out" or name == "running" or name == "segment-routing" or name == "stub" or name == "summary-in"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "area-id"):
                                self.area_id = value
                                self.area_id.value_namespace = name_space
                                self.area_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "default-cost"):
                                self.default_cost = value
                                self.default_cost.value_namespace = name_space
                                self.default_cost.value_namespace_prefix = name_space_prefix
                            if(value_path == "external-out"):
                                self.external_out = value
                                self.external_out.value_namespace = name_space
                                self.external_out.value_namespace_prefix = name_space_prefix
                            if(value_path == "mpls-traffic-eng"):
                                self.mpls_traffic_eng = value
                                self.mpls_traffic_eng.value_namespace = name_space
                                self.mpls_traffic_eng.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-in"):
                                self.route_policy_in = value
                                self.route_policy_in.value_namespace = name_space
                                self.route_policy_in.value_namespace_prefix = name_space_prefix
                            if(value_path == "route-policy-out"):
                                self.route_policy_out = value
                                self.route_policy_out.value_namespace = name_space
                                self.route_policy_out.value_namespace_prefix = name_space_prefix
                            if(value_path == "running"):
                                self.running = value
                                self.running.value_namespace = name_space
                                self.running.value_namespace_prefix = name_space_prefix
                            if(value_path == "segment-routing"):
                                self.segment_routing = value
                                self.segment_routing.value_namespace = name_space
                                self.segment_routing.value_namespace_prefix = name_space_prefix
                            if(value_path == "stub"):
                                self.stub = value
                                self.stub.value_namespace = name_space
                                self.stub.value_namespace_prefix = name_space_prefix
                            if(value_path == "summary-in"):
                                self.summary_in = value
                                self.summary_in.value_namespace = name_space
                                self.summary_in.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.area_address:
                            if (c.has_data()):
                                return True
                        for c in self.area_area_id:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.area_address:
                            if (c.has_operation()):
                                return True
                        for c in self.area_area_id:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "area-addresses" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "area-address"):
                            for c in self.area_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.area_address.append(c)
                            return c

                        if (child_yang_name == "area-area-id"):
                            for c in self.area_area_id:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.area_area_id.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "area-address" or name == "area-area-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Timers(Entity):
                    """
                    Adjust routing timers
                    
                    .. attribute:: fast_reroute_timer
                    
                    	Number of ms between end of SPF and start of IPFRR computation
                    	**type**\:  int
                    
                    	**range:** 50..600000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 500
                    
                    .. attribute:: lsa_generation_timer
                    
                    	OSPF LSA timers (in milliseconds)
                    	**type**\:   :py:class:`LsaGenerationTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer>`
                    
                    .. attribute:: lsa_group_pacing
                    
                    	LSA group pacing timer (Seconds between group of LSAs being refreshed or maxaged)
                    	**type**\:  int
                    
                    	**range:** 10..1800
                    
                    	**units**\: second
                    
                    	**default value**\: 240
                    
                    .. attribute:: lsa_min_arrival
                    
                    	MinLSArrival timer (minimum interval in milliseconds between accepting the same LSA)
                    	**type**\:  int
                    
                    	**range:** 0..600000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 100
                    
                    .. attribute:: lsa_pacing_flood
                    
                    	Seconds between group of LSAs being refreshed or maxaged
                    	**type**\:  int
                    
                    	**range:** 5..100
                    
                    	**units**\: second
                    
                    .. attribute:: lsa_refresh
                    
                    	How often self\-originated LSAs should be refreshed
                    	**type**\:  int
                    
                    	**range:** 1800..2700
                    
                    	**units**\: second
                    
                    	**default value**\: 1800
                    
                    .. attribute:: spf_timer
                    
                    	OSPF SPF timers (in milliseconds)
                    	**type**\:   :py:class:`SpfTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-01-02'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "default-vrf"

                        self.fast_reroute_timer = YLeaf(YType.uint32, "fast-reroute-timer")

                        self.lsa_group_pacing = YLeaf(YType.uint32, "lsa-group-pacing")

                        self.lsa_min_arrival = YLeaf(YType.uint32, "lsa-min-arrival")

                        self.lsa_pacing_flood = YLeaf(YType.uint32, "lsa-pacing-flood")

                        self.lsa_refresh = YLeaf(YType.uint32, "lsa-refresh")

                        self.lsa_generation_timer = Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer()
                        self.lsa_generation_timer.parent = self
                        self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                        self._children_yang_names.add("lsa-generation-timer")

                        self.spf_timer = Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer()
                        self.spf_timer.parent = self
                        self._children_name_map["spf_timer"] = "spf-timer"
                        self._children_yang_names.add("spf-timer")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("fast_reroute_timer",
                                        "lsa_group_pacing",
                                        "lsa_min_arrival",
                                        "lsa_pacing_flood",
                                        "lsa_refresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Ospf.Processes.Process.DefaultVrf.Timers, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Ospf.Processes.Process.DefaultVrf.Timers, self).__setattr__(name, value)


                    class SpfTimer(Entity):
                        """
                        OSPF SPF timers (in milliseconds)
                        
                        .. attribute:: backoff_increment
                        
                        	Number of milliseconds delay between successive SPF runs
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 10000
                        
                        .. attribute:: initial_delay
                        
                        	Number of milliseconds before first SPF run
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 5000
                        
                        .. attribute:: max_delay
                        
                        	Max number of milliseconds between consecutive SPF calculations
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 10000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer, self).__init__()

                            self.yang_name = "spf-timer"
                            self.yang_parent_name = "timers"

                            self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                            self.max_delay = YLeaf(YType.uint32, "max-delay")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("backoff_increment",
                                            "initial_delay",
                                            "max_delay") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.backoff_increment.is_set or
                                self.initial_delay.is_set or
                                self.max_delay.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.backoff_increment.yfilter != YFilter.not_set or
                                self.initial_delay.yfilter != YFilter.not_set or
                                self.max_delay.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "spf-timer" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.backoff_increment.is_set or self.backoff_increment.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backoff_increment.get_name_leafdata())
                            if (self.initial_delay.is_set or self.initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.initial_delay.get_name_leafdata())
                            if (self.max_delay.is_set or self.max_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_delay.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "backoff-increment" or name == "initial-delay" or name == "max-delay"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "backoff-increment"):
                                self.backoff_increment = value
                                self.backoff_increment.value_namespace = name_space
                                self.backoff_increment.value_namespace_prefix = name_space_prefix
                            if(value_path == "initial-delay"):
                                self.initial_delay = value
                                self.initial_delay.value_namespace = name_space
                                self.initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-delay"):
                                self.max_delay = value
                                self.max_delay.value_namespace = name_space
                                self.max_delay.value_namespace_prefix = name_space_prefix


                    class LsaGenerationTimer(Entity):
                        """
                        OSPF LSA timers (in milliseconds)
                        
                        .. attribute:: backoff_increment
                        
                        	Number of milliseconds delay between successive LSA builds
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 200
                        
                        .. attribute:: initial_delay
                        
                        	Number of milliseconds before generating first LSA
                        	**type**\:  int
                        
                        	**range:** 0..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 50
                        
                        .. attribute:: max_delay
                        
                        	Max number of milliseconds between consecutive LSA builds 
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 200
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-01-02'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer, self).__init__()

                            self.yang_name = "lsa-generation-timer"
                            self.yang_parent_name = "timers"

                            self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                            self.max_delay = YLeaf(YType.uint32, "max-delay")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("backoff_increment",
                                            "initial_delay",
                                            "max_delay") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.backoff_increment.is_set or
                                self.initial_delay.is_set or
                                self.max_delay.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.backoff_increment.yfilter != YFilter.not_set or
                                self.initial_delay.yfilter != YFilter.not_set or
                                self.max_delay.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsa-generation-timer" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.backoff_increment.is_set or self.backoff_increment.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.backoff_increment.get_name_leafdata())
                            if (self.initial_delay.is_set or self.initial_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.initial_delay.get_name_leafdata())
                            if (self.max_delay.is_set or self.max_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.max_delay.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "backoff-increment" or name == "initial-delay" or name == "max-delay"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "backoff-increment"):
                                self.backoff_increment = value
                                self.backoff_increment.value_namespace = name_space
                                self.backoff_increment.value_namespace_prefix = name_space_prefix
                            if(value_path == "initial-delay"):
                                self.initial_delay = value
                                self.initial_delay.value_namespace = name_space
                                self.initial_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "max-delay"):
                                self.max_delay = value
                                self.max_delay.value_namespace = name_space
                                self.max_delay.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.fast_reroute_timer.is_set or
                            self.lsa_group_pacing.is_set or
                            self.lsa_min_arrival.is_set or
                            self.lsa_pacing_flood.is_set or
                            self.lsa_refresh.is_set or
                            (self.lsa_generation_timer is not None and self.lsa_generation_timer.has_data()) or
                            (self.spf_timer is not None and self.spf_timer.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.fast_reroute_timer.yfilter != YFilter.not_set or
                            self.lsa_group_pacing.yfilter != YFilter.not_set or
                            self.lsa_min_arrival.yfilter != YFilter.not_set or
                            self.lsa_pacing_flood.yfilter != YFilter.not_set or
                            self.lsa_refresh.yfilter != YFilter.not_set or
                            (self.lsa_generation_timer is not None and self.lsa_generation_timer.has_operation()) or
                            (self.spf_timer is not None and self.spf_timer.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "timers" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.fast_reroute_timer.is_set or self.fast_reroute_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_reroute_timer.get_name_leafdata())
                        if (self.lsa_group_pacing.is_set or self.lsa_group_pacing.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsa_group_pacing.get_name_leafdata())
                        if (self.lsa_min_arrival.is_set or self.lsa_min_arrival.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsa_min_arrival.get_name_leafdata())
                        if (self.lsa_pacing_flood.is_set or self.lsa_pacing_flood.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsa_pacing_flood.get_name_leafdata())
                        if (self.lsa_refresh.is_set or self.lsa_refresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsa_refresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "lsa-generation-timer"):
                            if (self.lsa_generation_timer is None):
                                self.lsa_generation_timer = Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer()
                                self.lsa_generation_timer.parent = self
                                self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                            return self.lsa_generation_timer

                        if (child_yang_name == "spf-timer"):
                            if (self.spf_timer is None):
                                self.spf_timer = Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer()
                                self.spf_timer.parent = self
                                self._children_name_map["spf_timer"] = "spf-timer"
                            return self.spf_timer

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "lsa-generation-timer" or name == "spf-timer" or name == "fast-reroute-timer" or name == "lsa-group-pacing" or name == "lsa-min-arrival" or name == "lsa-pacing-flood" or name == "lsa-refresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "fast-reroute-timer"):
                            self.fast_reroute_timer = value
                            self.fast_reroute_timer.value_namespace = name_space
                            self.fast_reroute_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsa-group-pacing"):
                            self.lsa_group_pacing = value
                            self.lsa_group_pacing.value_namespace = name_space
                            self.lsa_group_pacing.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsa-min-arrival"):
                            self.lsa_min_arrival = value
                            self.lsa_min_arrival.value_namespace = name_space
                            self.lsa_min_arrival.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsa-pacing-flood"):
                            self.lsa_pacing_flood = value
                            self.lsa_pacing_flood.value_namespace = name_space
                            self.lsa_pacing_flood.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsa-refresh"):
                            self.lsa_refresh = value
                            self.lsa_refresh.value_namespace = name_space
                            self.lsa_refresh.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.adjacency_changes.is_set or
                        self.default_metric.is_set or
                        self.ignore_mospf.is_set or
                        self.maximum_interfaces.is_set or
                        self.maximum_paths.is_set or
                        self.no_opaque.is_set or
                        self.router_id.is_set or
                        self.snmp_context.is_set or
                        self.spf_prefix_priority.is_set or
                        self.type7.is_set or
                        (self.adjacency_stagger is not None and self.adjacency_stagger.has_data()) or
                        (self.area_addresses is not None and self.area_addresses.has_data()) or
                        (self.auto_cost is not None and self.auto_cost.has_data()) or
                        (self.default_information is not None and self.default_information.has_data()) or
                        (self.distance is not None and self.distance.has_data()) or
                        (self.fast_reroute is not None and self.fast_reroute.has_data()) or
                        (self.max_metric is not None and self.max_metric.has_data()) or
                        (self.maximum_redistribute_prefix is not None and self.maximum_redistribute_prefix.has_data()) or
                        (self.microloop is not None and self.microloop.has_data()) or
                        (self.monitor_convergence is not None and self.monitor_convergence.has_data()) or
                        (self.mpls is not None and self.mpls.has_data()) or
                        (self.nsf is not None and self.nsf.has_data()) or
                        (self.outgoing_route_updates is not None and self.outgoing_route_updates.has_data()) or
                        (self.process_scope is not None and self.process_scope.has_data()) or
                        (self.queue is not None and self.queue.has_data()) or
                        (self.redistribution is not None and self.redistribution.has_data()) or
                        (self.segment_routing is not None and self.segment_routing.has_data()) or
                        (self.summary_prefixes is not None and self.summary_prefixes.has_data()) or
                        (self.timers is not None and self.timers.has_data()) or
                        (self.ucmp is not None and self.ucmp.has_data()) or
                        (self.af is not None) or
                        (self.max_lsa is not None))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.adjacency_changes.yfilter != YFilter.not_set or
                        self.default_metric.yfilter != YFilter.not_set or
                        self.ignore_mospf.yfilter != YFilter.not_set or
                        self.maximum_interfaces.yfilter != YFilter.not_set or
                        self.maximum_paths.yfilter != YFilter.not_set or
                        self.no_opaque.yfilter != YFilter.not_set or
                        self.router_id.yfilter != YFilter.not_set or
                        self.snmp_context.yfilter != YFilter.not_set or
                        self.spf_prefix_priority.yfilter != YFilter.not_set or
                        self.type7.yfilter != YFilter.not_set or
                        (self.adjacency_stagger is not None and self.adjacency_stagger.has_operation()) or
                        (self.af is not None and self.af.has_operation()) or
                        (self.area_addresses is not None and self.area_addresses.has_operation()) or
                        (self.auto_cost is not None and self.auto_cost.has_operation()) or
                        (self.default_information is not None and self.default_information.has_operation()) or
                        (self.distance is not None and self.distance.has_operation()) or
                        (self.fast_reroute is not None and self.fast_reroute.has_operation()) or
                        (self.max_lsa is not None and self.max_lsa.has_operation()) or
                        (self.max_metric is not None and self.max_metric.has_operation()) or
                        (self.maximum_redistribute_prefix is not None and self.maximum_redistribute_prefix.has_operation()) or
                        (self.microloop is not None and self.microloop.has_operation()) or
                        (self.monitor_convergence is not None and self.monitor_convergence.has_operation()) or
                        (self.mpls is not None and self.mpls.has_operation()) or
                        (self.nsf is not None and self.nsf.has_operation()) or
                        (self.outgoing_route_updates is not None and self.outgoing_route_updates.has_operation()) or
                        (self.process_scope is not None and self.process_scope.has_operation()) or
                        (self.queue is not None and self.queue.has_operation()) or
                        (self.redistribution is not None and self.redistribution.has_operation()) or
                        (self.segment_routing is not None and self.segment_routing.has_operation()) or
                        (self.summary_prefixes is not None and self.summary_prefixes.has_operation()) or
                        (self.timers is not None and self.timers.has_operation()) or
                        (self.ucmp is not None and self.ucmp.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "default-vrf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.adjacency_changes.is_set or self.adjacency_changes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adjacency_changes.get_name_leafdata())
                    if (self.default_metric.is_set or self.default_metric.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.default_metric.get_name_leafdata())
                    if (self.ignore_mospf.is_set or self.ignore_mospf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ignore_mospf.get_name_leafdata())
                    if (self.maximum_interfaces.is_set or self.maximum_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_interfaces.get_name_leafdata())
                    if (self.maximum_paths.is_set or self.maximum_paths.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.maximum_paths.get_name_leafdata())
                    if (self.no_opaque.is_set or self.no_opaque.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_opaque.get_name_leafdata())
                    if (self.router_id.is_set or self.router_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.router_id.get_name_leafdata())
                    if (self.snmp_context.is_set or self.snmp_context.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.snmp_context.get_name_leafdata())
                    if (self.spf_prefix_priority.is_set or self.spf_prefix_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.spf_prefix_priority.get_name_leafdata())
                    if (self.type7.is_set or self.type7.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.type7.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "adjacency-stagger"):
                        if (self.adjacency_stagger is None):
                            self.adjacency_stagger = Ospf.Processes.Process.DefaultVrf.AdjacencyStagger()
                            self.adjacency_stagger.parent = self
                            self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                        return self.adjacency_stagger

                    if (child_yang_name == "af"):
                        if (self.af is None):
                            self.af = Ospf.Processes.Process.DefaultVrf.Af()
                            self.af.parent = self
                            self._children_name_map["af"] = "af"
                        return self.af

                    if (child_yang_name == "area-addresses"):
                        if (self.area_addresses is None):
                            self.area_addresses = Ospf.Processes.Process.DefaultVrf.AreaAddresses()
                            self.area_addresses.parent = self
                            self._children_name_map["area_addresses"] = "area-addresses"
                        return self.area_addresses

                    if (child_yang_name == "auto-cost"):
                        if (self.auto_cost is None):
                            self.auto_cost = Ospf.Processes.Process.DefaultVrf.AutoCost()
                            self.auto_cost.parent = self
                            self._children_name_map["auto_cost"] = "auto-cost"
                        return self.auto_cost

                    if (child_yang_name == "default-information"):
                        if (self.default_information is None):
                            self.default_information = Ospf.Processes.Process.DefaultVrf.DefaultInformation()
                            self.default_information.parent = self
                            self._children_name_map["default_information"] = "default-information"
                        return self.default_information

                    if (child_yang_name == "distance"):
                        if (self.distance is None):
                            self.distance = Ospf.Processes.Process.DefaultVrf.Distance()
                            self.distance.parent = self
                            self._children_name_map["distance"] = "distance"
                        return self.distance

                    if (child_yang_name == "fast-reroute"):
                        if (self.fast_reroute is None):
                            self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                            self.fast_reroute.parent = self
                            self._children_name_map["fast_reroute"] = "fast-reroute"
                        return self.fast_reroute

                    if (child_yang_name == "max-lsa"):
                        if (self.max_lsa is None):
                            self.max_lsa = Ospf.Processes.Process.DefaultVrf.MaxLsa()
                            self.max_lsa.parent = self
                            self._children_name_map["max_lsa"] = "max-lsa"
                        return self.max_lsa

                    if (child_yang_name == "max-metric"):
                        if (self.max_metric is None):
                            self.max_metric = Ospf.Processes.Process.DefaultVrf.MaxMetric()
                            self.max_metric.parent = self
                            self._children_name_map["max_metric"] = "max-metric"
                        return self.max_metric

                    if (child_yang_name == "maximum-redistribute-prefix"):
                        if (self.maximum_redistribute_prefix is None):
                            self.maximum_redistribute_prefix = Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix()
                            self.maximum_redistribute_prefix.parent = self
                            self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                        return self.maximum_redistribute_prefix

                    if (child_yang_name == "microloop"):
                        if (self.microloop is None):
                            self.microloop = Ospf.Processes.Process.DefaultVrf.Microloop()
                            self.microloop.parent = self
                            self._children_name_map["microloop"] = "microloop"
                        return self.microloop

                    if (child_yang_name == "monitor-convergence"):
                        if (self.monitor_convergence is None):
                            self.monitor_convergence = Ospf.Processes.Process.DefaultVrf.MonitorConvergence()
                            self.monitor_convergence.parent = self
                            self._children_name_map["monitor_convergence"] = "monitor-convergence"
                        return self.monitor_convergence

                    if (child_yang_name == "mpls"):
                        if (self.mpls is None):
                            self.mpls = Ospf.Processes.Process.DefaultVrf.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"
                        return self.mpls

                    if (child_yang_name == "nsf"):
                        if (self.nsf is None):
                            self.nsf = Ospf.Processes.Process.DefaultVrf.Nsf()
                            self.nsf.parent = self
                            self._children_name_map["nsf"] = "nsf"
                        return self.nsf

                    if (child_yang_name == "outgoing-route-updates"):
                        if (self.outgoing_route_updates is None):
                            self.outgoing_route_updates = Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates()
                            self.outgoing_route_updates.parent = self
                            self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                        return self.outgoing_route_updates

                    if (child_yang_name == "process-scope"):
                        if (self.process_scope is None):
                            self.process_scope = Ospf.Processes.Process.DefaultVrf.ProcessScope()
                            self.process_scope.parent = self
                            self._children_name_map["process_scope"] = "process-scope"
                        return self.process_scope

                    if (child_yang_name == "queue"):
                        if (self.queue is None):
                            self.queue = Ospf.Processes.Process.DefaultVrf.Queue()
                            self.queue.parent = self
                            self._children_name_map["queue"] = "queue"
                        return self.queue

                    if (child_yang_name == "redistribution"):
                        if (self.redistribution is None):
                            self.redistribution = Ospf.Processes.Process.DefaultVrf.Redistribution()
                            self.redistribution.parent = self
                            self._children_name_map["redistribution"] = "redistribution"
                        return self.redistribution

                    if (child_yang_name == "segment-routing"):
                        if (self.segment_routing is None):
                            self.segment_routing = Ospf.Processes.Process.DefaultVrf.SegmentRouting()
                            self.segment_routing.parent = self
                            self._children_name_map["segment_routing"] = "segment-routing"
                        return self.segment_routing

                    if (child_yang_name == "summary-prefixes"):
                        if (self.summary_prefixes is None):
                            self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                            self.summary_prefixes.parent = self
                            self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        return self.summary_prefixes

                    if (child_yang_name == "timers"):
                        if (self.timers is None):
                            self.timers = Ospf.Processes.Process.DefaultVrf.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                        return self.timers

                    if (child_yang_name == "ucmp"):
                        if (self.ucmp is None):
                            self.ucmp = Ospf.Processes.Process.DefaultVrf.Ucmp()
                            self.ucmp.parent = self
                            self._children_name_map["ucmp"] = "ucmp"
                        return self.ucmp

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "adjacency-stagger" or name == "af" or name == "area-addresses" or name == "auto-cost" or name == "default-information" or name == "distance" or name == "fast-reroute" or name == "max-lsa" or name == "max-metric" or name == "maximum-redistribute-prefix" or name == "microloop" or name == "monitor-convergence" or name == "mpls" or name == "nsf" or name == "outgoing-route-updates" or name == "process-scope" or name == "queue" or name == "redistribution" or name == "segment-routing" or name == "summary-prefixes" or name == "timers" or name == "ucmp" or name == "adjacency-changes" or name == "default-metric" or name == "ignore-mospf" or name == "maximum-interfaces" or name == "maximum-paths" or name == "no-opaque" or name == "router-id" or name == "snmp-context" or name == "spf-prefix-priority" or name == "type7"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "adjacency-changes"):
                        self.adjacency_changes = value
                        self.adjacency_changes.value_namespace = name_space
                        self.adjacency_changes.value_namespace_prefix = name_space_prefix
                    if(value_path == "default-metric"):
                        self.default_metric = value
                        self.default_metric.value_namespace = name_space
                        self.default_metric.value_namespace_prefix = name_space_prefix
                    if(value_path == "ignore-mospf"):
                        self.ignore_mospf = value
                        self.ignore_mospf.value_namespace = name_space
                        self.ignore_mospf.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-interfaces"):
                        self.maximum_interfaces = value
                        self.maximum_interfaces.value_namespace = name_space
                        self.maximum_interfaces.value_namespace_prefix = name_space_prefix
                    if(value_path == "maximum-paths"):
                        self.maximum_paths = value
                        self.maximum_paths.value_namespace = name_space
                        self.maximum_paths.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-opaque"):
                        self.no_opaque = value
                        self.no_opaque.value_namespace = name_space
                        self.no_opaque.value_namespace_prefix = name_space_prefix
                    if(value_path == "router-id"):
                        self.router_id = value
                        self.router_id.value_namespace = name_space
                        self.router_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "snmp-context"):
                        self.snmp_context = value
                        self.snmp_context.value_namespace = name_space
                        self.snmp_context.value_namespace_prefix = name_space_prefix
                    if(value_path == "spf-prefix-priority"):
                        self.spf_prefix_priority = value
                        self.spf_prefix_priority.value_namespace = name_space
                        self.spf_prefix_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "type7"):
                        self.type7 = value
                        self.type7.value_namespace = name_space
                        self.type7.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.process_name.is_set or
                    self.nsr.is_set or
                    self.protocol_shutdown.is_set or
                    self.running.is_set or
                    self.start.is_set or
                    (self.default_vrf is not None and self.default_vrf.has_data()) or
                    (self.graceful_shutdown_timers is not None and self.graceful_shutdown_timers.has_data()) or
                    (self.snmp is not None and self.snmp.has_data()) or
                    (self.vrfs is not None and self.vrfs.has_data()) or
                    (self.distribute is not None))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.process_name.yfilter != YFilter.not_set or
                    self.nsr.yfilter != YFilter.not_set or
                    self.protocol_shutdown.yfilter != YFilter.not_set or
                    self.running.yfilter != YFilter.not_set or
                    self.start.yfilter != YFilter.not_set or
                    (self.default_vrf is not None and self.default_vrf.has_operation()) or
                    (self.distribute is not None and self.distribute.has_operation()) or
                    (self.graceful_shutdown_timers is not None and self.graceful_shutdown_timers.has_operation()) or
                    (self.snmp is not None and self.snmp.has_operation()) or
                    (self.vrfs is not None and self.vrfs.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + "[process-name='" + self.process_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/processes/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.process_name.is_set or self.process_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.process_name.get_name_leafdata())
                if (self.nsr.is_set or self.nsr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.nsr.get_name_leafdata())
                if (self.protocol_shutdown.is_set or self.protocol_shutdown.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol_shutdown.get_name_leafdata())
                if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.running.get_name_leafdata())
                if (self.start.is_set or self.start.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.start.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "default-vrf"):
                    if (self.default_vrf is None):
                        self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                        self.default_vrf.parent = self
                        self._children_name_map["default_vrf"] = "default-vrf"
                    return self.default_vrf

                if (child_yang_name == "distribute"):
                    if (self.distribute is None):
                        self.distribute = Ospf.Processes.Process.Distribute()
                        self.distribute.parent = self
                        self._children_name_map["distribute"] = "distribute"
                    return self.distribute

                if (child_yang_name == "graceful-shutdown-timers"):
                    if (self.graceful_shutdown_timers is None):
                        self.graceful_shutdown_timers = Ospf.Processes.Process.GracefulShutdownTimers()
                        self.graceful_shutdown_timers.parent = self
                        self._children_name_map["graceful_shutdown_timers"] = "graceful-shutdown-timers"
                    return self.graceful_shutdown_timers

                if (child_yang_name == "snmp"):
                    if (self.snmp is None):
                        self.snmp = Ospf.Processes.Process.Snmp()
                        self.snmp.parent = self
                        self._children_name_map["snmp"] = "snmp"
                    return self.snmp

                if (child_yang_name == "vrfs"):
                    if (self.vrfs is None):
                        self.vrfs = Ospf.Processes.Process.Vrfs()
                        self.vrfs.parent = self
                        self._children_name_map["vrfs"] = "vrfs"
                    return self.vrfs

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "default-vrf" or name == "distribute" or name == "graceful-shutdown-timers" or name == "snmp" or name == "vrfs" or name == "process-name" or name == "nsr" or name == "protocol-shutdown" or name == "running" or name == "start"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "process-name"):
                    self.process_name = value
                    self.process_name.value_namespace = name_space
                    self.process_name.value_namespace_prefix = name_space_prefix
                if(value_path == "nsr"):
                    self.nsr = value
                    self.nsr.value_namespace = name_space
                    self.nsr.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol-shutdown"):
                    self.protocol_shutdown = value
                    self.protocol_shutdown.value_namespace = name_space
                    self.protocol_shutdown.value_namespace_prefix = name_space_prefix
                if(value_path == "running"):
                    self.running = value
                    self.running.value_namespace = name_space
                    self.running.value_namespace_prefix = name_space_prefix
                if(value_path == "start"):
                    self.start = value
                    self.start.value_namespace = name_space
                    self.start.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.process:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.process:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "processes" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "process"):
                for c in self.process:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Ospf.Processes.Process()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.process.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "process"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Global_(Entity):
        """
        OSPF global configuration data
        
        .. attribute:: dns_name_lookup
        
        	Display OSPF router ids as DNS names
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ipv4-ospf-cfg'
        _revision = '2017-01-02'

        def __init__(self):
            super(Ospf.Global_, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "ospf"

            self.dns_name_lookup = YLeaf(YType.empty, "dns-name-lookup")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("dns_name_lookup") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Ospf.Global_, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Ospf.Global_, self).__setattr__(name, value)

        def has_data(self):
            return self.dns_name_lookup.is_set

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.dns_name_lookup.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.dns_name_lookup.is_set or self.dns_name_lookup.yfilter != YFilter.not_set):
                leaf_name_data.append(self.dns_name_lookup.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "dns-name-lookup"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "dns-name-lookup"):
                self.dns_name_lookup = value
                self.dns_name_lookup.value_namespace = name_space
                self.dns_name_lookup.value_namespace_prefix = name_space_prefix

    def has_data(self):
        return (
            (self.global_ is not None and self.global_.has_data()) or
            (self.processes is not None and self.processes.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.global_ is not None and self.global_.has_operation()) or
            (self.processes is not None and self.processes.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-ospf-cfg:ospf" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "global"):
            if (self.global_ is None):
                self.global_ = Ospf.Global_()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"
            return self.global_

        if (child_yang_name == "processes"):
            if (self.processes is None):
                self.processes = Ospf.Processes()
                self.processes.parent = self
                self._children_name_map["processes"] = "processes"
            return self.processes

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "global" or name == "processes"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Ospf()
        return self._top_entity

